<?php
// actions/debt/pay_debt.php

include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// Set header for JSON output
header('Content-Type: application/json');

// Check if user session is valid
if (!isset($_SESSION['user_id'])) {
    echo json_encode(['success' => false, 'message' => 'No valid user session.']);
    exit;
}

// Validate required POST fields (this file handles multipart/form-data)
if (
    !isset($_POST['debts_id']) ||
    !isset($_POST['payAmount']) ||
    !isset($_POST['payDate']) ||
    !isset($_POST['payType']) ||
    !isset($_POST['patientName'])
) {
    echo json_encode(['success' => false, 'message' => 'Missing required fields.']);
    exit;
}

$debts_id    = (int) $_POST['debts_id'];
$pay_amount  = (float) $_POST['payAmount'];
$pay_date    = trim($_POST['payDate']);  // Expected format: YYYY-MM-DD
$pay_type    = trim($_POST['payType']);
$pay_remarks = isset($_POST['payRemarks']) ? trim($_POST['payRemarks']) : '';
$patientName = trim($_POST['patientName']);

if ($debts_id <= 0 || $pay_amount <= 0 || empty($pay_date) || empty($pay_type)) {
    echo json_encode(['success' => false, 'message' => 'Invalid input values.']);
    exit;
}

$conn->begin_transaction();

try {
    // 1) Insert a new record into debt_payments (including pay_date)
    $stmt = $conn->prepare("
        INSERT INTO debt_payments (debts_id, payment_type, pay_amount, pay_date, remarks)
        VALUES (?, ?, ?, ?, ?)
    ");
    if (!$stmt) {
        throw new Exception("Prepare failed: " . $conn->error);
    }
    $stmt->bind_param("isdss", $debts_id, $pay_type, $pay_amount, $pay_date, $pay_remarks);
    if (!$stmt->execute()) {
        throw new Exception("Failed to insert debt payment: " . $stmt->error);
    }
    $debt_payment_id = $stmt->insert_id;
    $stmt->close();

    // 2) Update the debts table: fetch current payment_amount and balance_after_payment
    $stmtFetch = $conn->prepare("SELECT payment_amount, balance_after_payment FROM debts WHERE id = ?");
    if (!$stmtFetch) {
        throw new Exception("Prepare fetch failed: " . $conn->error);
    }
    $stmtFetch->bind_param("i", $debts_id);
    $stmtFetch->execute();
    $resFetch = $stmtFetch->get_result();
    if ($resFetch->num_rows === 0) {
        throw new Exception("Debt record not found.");
    }
    $debtRow = $resFetch->fetch_assoc();
    $old_payment_amount = (float)($debtRow['payment_amount'] ?? 0);
    $old_balance = (float)($debtRow['balance_after_payment'] ?? 0);
    $stmtFetch->close();

    // Calculate new values: update payment_amount and decrease balance by pay_amount.
    $new_payment_amount = $old_payment_amount + $pay_amount;
    $new_balance = $old_balance - $pay_amount;
    if ($new_balance < 0) {
        $new_balance = 0.0;
    }

    $stmtUpdate = $conn->prepare("
        UPDATE debts 
        SET payment_amount = ?, balance_after_payment = ?
        WHERE id = ?
    ");
    $stmtUpdate->bind_param("ddi", $new_payment_amount, $new_balance, $debts_id);
    if (!$stmtUpdate->execute()) {
        throw new Exception("Failed updating debts: " . $stmtUpdate->error);
    }
    $stmtUpdate->close();

    // 3) Process file uploads if any exist in $_FILES['receiptFiles']
    $uploadedFiles = [];
    if (isset($_FILES['receiptFiles']) && !empty($_FILES['receiptFiles']['name'][0])) {
        // Fetch the MSR number from the msr table using the debts record.
        $stmtMsr = $conn->prepare("SELECT m.msr_number FROM msr m JOIN debts d ON m.id = d.msr_id WHERE d.id = ?");
        if (!$stmtMsr) {
            throw new Exception("Prepare failed (MSR fetch): " . $conn->error);
        }
        $stmtMsr->bind_param("i", $debts_id);
        $stmtMsr->execute();
        $resultMsr = $stmtMsr->get_result();
        if ($resultMsr->num_rows > 0) {
            $rowMsr = $resultMsr->fetch_assoc();
            $msr_number = $rowMsr['msr_number'];
        } else {
            throw new Exception("MSR number not found.");
        }
        $stmtMsr->close();

        // Sanitize patient name for directory (remove spaces and non-alphanumerics)
        $sanitizedPatient = preg_replace('/[^A-Za-z0-9_-]/', '', str_replace(' ', '_', $patientName));
        // Construct target directory: uploads/receipts/{msr_number}/{sanitizedPatient}/receiptUploaded/
        $targetDir = ROOT_PATH . "uploads/receipts/{$msr_number}/{$sanitizedPatient}/receiptUploaded/";
        if (!is_dir($targetDir)) {
            if (!mkdir($targetDir, 0777, true)) {
                throw new Exception("Failed to create directory: " . $targetDir);
            }
        }
        // Loop over each uploaded file
        for ($i = 0; $i < count($_FILES['receiptFiles']['name']); $i++) {
            if ($_FILES['receiptFiles']['error'][$i] !== UPLOAD_ERR_OK) {
                continue; // Skip files with errors
            }
            $originalName = basename($_FILES['receiptFiles']['name'][$i]);
            $ext = pathinfo($originalName, PATHINFO_EXTENSION);
            // Generate a short unique name using 8-character hex.
            $uniqueName = bin2hex(random_bytes(4)) . '.' . $ext;
            $targetFile = $targetDir . $uniqueName;
            if (!move_uploaded_file($_FILES['receiptFiles']['tmp_name'][$i], $targetFile)) {
                throw new Exception("Failed to move uploaded file.");
            }
            // Compute relative file path (relative to project root)
            $relativePath = "uploads/receipts/{$msr_number}/{$sanitizedPatient}/receiptUploaded/" . $uniqueName;
            $uploadedFiles[] = $relativePath;
        }
    }

    // 4) Insert records for uploaded receipt files into debt_payment_receipts
    if (!empty($uploadedFiles)) {
        foreach ($uploadedFiles as $filePath) {
            $stmtR = $conn->prepare("
                INSERT INTO debt_payment_receipts (debt_payment_id, file_path)
                VALUES (?, ?)
            ");
            $stmtR->bind_param("is", $debt_payment_id, $filePath);
            if (!$stmtR->execute()) {
                throw new Exception("Failed to record receipt file: " . $stmtR->error);
            }
            $stmtR->close();
        }
    }

    $conn->commit();
    echo json_encode(['success' => true, 'message' => 'Payment recorded successfully.']);
} catch (Exception $ex) {
    $conn->rollback();
    error_log("pay_debt error: " . $ex->getMessage());
    echo json_encode(['success' => false, 'message' => $ex->getMessage()]);
}
