<?php
// actions/debt/update_payment.php

include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

header('Content-Type: application/json');

// Ensure a valid session.
if (!isset($_SESSION['user_id'])) {
    echo json_encode(['success' => false, 'message' => 'No valid session.']);
    exit;
}

// Expect update via multipart/form-data.
if (
    !isset($_POST['payment_id']) ||
    !isset($_POST['debts_id']) ||
    !isset($_POST['payAmount']) ||
    !isset($_POST['payDate']) ||
    !isset($_POST['payType']) ||
    !isset($_POST['patientName'])
) {
    echo json_encode(['success' => false, 'message' => 'Missing required fields.']);
    exit;
}

$payment_id   = (int) $_POST['payment_id'];
$debts_id     = (int) $_POST['debts_id'];
$pay_amount   = (float) $_POST['payAmount'];
$pay_date     = trim($_POST['payDate']);  // Format: YYYY-MM-DD
$pay_type     = trim($_POST['payType']);
$remarks      = isset($_POST['payRemarks']) ? trim($_POST['payRemarks']) : '';
$patientName  = trim($_POST['patientName']);

// Optionally, a comma-separated string of receipt IDs to delete.
$delete_receipt_ids = [];
if (isset($_POST['delete_receipt_ids']) && !empty($_POST['delete_receipt_ids'])) {
    $delete_receipt_ids = explode(',', $_POST['delete_receipt_ids']);
}

$conn->begin_transaction();

try {
    // 1) Update the debt_payments record.
    $stmt = $conn->prepare("
        UPDATE debt_payments 
        SET pay_amount = ?, pay_date = ?, payment_type = ?, remarks = ?
        WHERE id = ?
    ");
    $stmt->bind_param("dsssi", $pay_amount, $pay_date, $pay_type, $remarks, $payment_id);
    if (!$stmt->execute()) {
        throw new Exception("Failed to update payment: " . $stmt->error);
    }
    $stmt->close();

    // 2) Delete any receipts marked for deletion.
    if (!empty($delete_receipt_ids)) {
        foreach ($delete_receipt_ids as $rid) {
            $rid = (int)$rid;
            $stmtFetch = $conn->prepare("SELECT file_path FROM debt_payment_receipts WHERE id = ?");
            $stmtFetch->bind_param("i", $rid);
            $stmtFetch->execute();
            $resultFetch = $stmtFetch->get_result();
            if ($resultFetch->num_rows > 0) {
                $row = $resultFetch->fetch_assoc();
                $file_path = $row['file_path'];
                $fullPath = ROOT_PATH . $file_path;
                if (file_exists($fullPath)) {
                    unlink($fullPath);
                }
            }
            $stmtFetch->close();

            $stmtDel = $conn->prepare("DELETE FROM debt_payment_receipts WHERE id = ?");
            $stmtDel->bind_param("i", $rid);
            if (!$stmtDel->execute()) {
                throw new Exception("Failed to delete receipt record: " . $stmtDel->error);
            }
            $stmtDel->close();
        }
    }

    // 3) Process new file uploads if provided.
    $uploadedFiles = [];
    if (isset($_FILES['receiptFiles']) && !empty($_FILES['receiptFiles']['name'][0])) {
        // First, fetch the MSR number using the debts record.
        $stmtMsr = $conn->prepare("SELECT m.msr_number FROM msr m JOIN debts d ON m.id = d.msr_id WHERE d.id = ?");
        $stmtMsr->bind_param("i", $debts_id);
        $stmtMsr->execute();
        $resultMsr = $stmtMsr->get_result();
        if ($resultMsr->num_rows > 0) {
            $rowMsr = $resultMsr->fetch_assoc();
            $msr_number = $rowMsr['msr_number'];
        } else {
            throw new Exception("MSR number not found.");
        }
        $stmtMsr->close();

        // Sanitize the patient name.
        $sanitizedPatient = preg_replace('/[^A-Za-z0-9_-]/', '', str_replace(' ', '_', $patientName));
        // Build the target directory as: uploads/receipts/{msr_number}/{sanitizedPatient}/receiptUploaded/
        $targetDir = ROOT_PATH . "uploads/receipts/{$msr_number}/{$sanitizedPatient}/receiptUploaded/";
        if (!is_dir($targetDir)) {
            if (!mkdir($targetDir, 0777, true)) {
                throw new Exception("Failed to create directory: " . $targetDir);
            }
        }
        for ($i = 0; $i < count($_FILES['receiptFiles']['name']); $i++) {
            if ($_FILES['receiptFiles']['error'][$i] !== UPLOAD_ERR_OK) {
                continue;
            }
            $originalName = basename($_FILES['receiptFiles']['name'][$i]);
            $ext = pathinfo($originalName, PATHINFO_EXTENSION);
            // Generate a short unique file name using 8-character hex.
            $uniqueName = bin2hex(random_bytes(4)) . '.' . $ext;
            $targetFile = $targetDir . $uniqueName;
            if (!move_uploaded_file($_FILES['receiptFiles']['tmp_name'][$i], $targetFile)) {
                throw new Exception("Failed to move uploaded file.");
            }
            // Build the relative path for storage in the database.
            $relativePath = "uploads/receipts/{$msr_number}/{$sanitizedPatient}/receiptUploaded/" . $uniqueName;
            $uploadedFiles[] = $relativePath;
        }
    }

    // 4) Insert new receipt records for newly uploaded files.
    if (!empty($uploadedFiles)) {
        foreach ($uploadedFiles as $filePath) {
            $stmtR = $conn->prepare("INSERT INTO debt_payment_receipts (debt_payment_id, file_path) VALUES (?, ?)");
            $stmtR->bind_param("is", $payment_id, $filePath);
            if (!$stmtR->execute()) {
                throw new Exception("Failed to insert new receipt file: " . $stmtR->error);
            }
            $stmtR->close();
        }
    }

    // 5) Recalculate the cumulative payments for this debt.
    $stmtSum = $conn->prepare("SELECT SUM(pay_amount) as total_paid FROM debt_payments WHERE debts_id = ?");
    $stmtSum->bind_param("i", $debts_id);
    $stmtSum->execute();
    $resultSum = $stmtSum->get_result();
    $rowSum = $resultSum->fetch_assoc();
    $total_paid = (float)$rowSum['total_paid'];
    $stmtSum->close();

    // 6) Fetch the original debt_amount and discount from the debts record.
    $stmtDebt = $conn->prepare("SELECT debt_amount, discount FROM debts WHERE id = ?");
    $stmtDebt->bind_param("i", $debts_id);
    $stmtDebt->execute();
    $resultDebt = $stmtDebt->get_result();
    if ($resultDebt->num_rows === 0) {
        throw new Exception("Debt record not found for recalculation.");
    }
    $rowDebt = $resultDebt->fetch_assoc();
    $debt_amount = (float)$rowDebt['debt_amount'];  // Original treatment total.
    $record_discount = (float)$rowDebt['discount']; // Discount applied.
    $stmtDebt->close();

    // 7) Compute the net debt and new balance.
    // Net debt = treatment total - discount.
    $net_debt = $debt_amount - $record_discount;
    $new_balance = $net_debt - $total_paid;
    if ($new_balance < 0) {
        $new_balance = 0.0;
    }

    // 8) Update the debts record with the new cumulative payment and balance.
    $stmtUpdateDebt = $conn->prepare("UPDATE debts SET payment_amount = ?, balance_after_payment = ? WHERE id = ?");
    $stmtUpdateDebt->bind_param("ddi", $total_paid, $new_balance, $debts_id);
    if (!$stmtUpdateDebt->execute()) {
        throw new Exception("Failed updating debt record: " . $stmtUpdateDebt->error);
    }
    $stmtUpdateDebt->close();

    $conn->commit();
    echo json_encode(['success' => true, 'message' => 'Payment updated successfully.']);
} catch (Exception $ex) {
    $conn->rollback();
    error_log("update_payment error: " . $ex->getMessage());
    echo json_encode(['success' => false, 'message' => $ex->getMessage()]);
}
