<?php

/**
 * quick_add_diagnosis.php
 *
 * Receives JSON:
 *   { "patient_id": 29, "appointment_id": 25 }
 * Creates a new row in `diagnoses` if it doesn't already exist.
 * Returns JSON: { "success": bool, "message": string, "alreadyExists": bool }
 */

header('Content-Type: application/json; charset=utf-8');


// Load your config / DB connection and session check
include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// Ensure a valid user session
$currentUserID = $_SESSION['user_id'] ?? 0;
if ($currentUserID < 1) {
    echo json_encode(["success" => false, "message" => "No valid user session found.", "alreadyExists" => false]);
    exit;
}

// Parse JSON input
$raw = file_get_contents('php://input');
$data = json_decode($raw, true);
$pID   = (int)($data['patient_id'] ?? 0);
$apptID = (int)($data['appointment_id'] ?? 0);

try {
    // 1) Check if there's already a diagnosis for this patient + appointment
    $chk = $conn->prepare("SELECT DiagnosisID FROM diagnoses WHERE PatientID=? AND AppointmentID=? LIMIT 1");
    $chk->bind_param("ii", $pID, $apptID);
    $chk->execute();
    $res = $chk->get_result();
    if ($res->num_rows > 0) {
        // Already exists => return success + "alreadyExists"
        echo json_encode([
            "success"      => true,
            "message"      => "Diagnosis already exists for this appointment.",
            "alreadyExists" => true
        ]);
        exit;
    }
    $chk->close();

    // 2) Insert a new row
    $sql = "
      INSERT INTO diagnoses (
        PatientID,
        AppointmentID,
        Diagnosis,
        CreatedBy,
        UpdatedBy,
        CreatedAt,
        UpdatedAt
      ) VALUES (?, ?, 'Auto-created', ?, ?, NOW(), NOW())
    ";
    $st = $conn->prepare($sql);
    $st->bind_param("iiii", $pID, $apptID, $currentUserID, $currentUserID);
    $st->execute();
    $newID = $st->insert_id;
    $st->close();

    echo json_encode([
        "success"      => true,
        "message"      => "Diagnosis created (#{$newID}).",
        "alreadyExists" => false
    ]);
} catch (Exception $ex) {
    // If an exception occurs, still return JSON so the front-end can handle it
    $errMsg = "Error: " . $ex->getMessage();
    echo json_encode([
        "success" => false,
        "message" => $errMsg,
        "alreadyExists" => false
    ]);
}
