<?php

/**
 * mark_all_completed.php
 *
 * Example endpoint for “Mark All Completed” in the grouped follow-ups modal.
 *  - Expects ?appointment_id=123 in the query string.
 *  - If user is "staff", we block any follow-up with a future date/time.
 *  - If "admin", we allow all to be completed.
 *  - We update all PENDING follow-ups for that appointment to "Done".
 *
 * Returns JSON:
 *   { "success": true } on success
 *   { "success": false, "message": "Some error" } on failure
 */

header('Content-Type: application/json; charset=utf-8');

session_start();
require_once '../../common/config.php'; // adjust path to your config
// Or include your DB + session logic

// 1) Check user + role
$currentUserID = $_SESSION['user_id'] ?? 0;
$userRole      = $_SESSION['role']    ?? 'staff';  // staff | admin

if (!$currentUserID) {
    echo json_encode([
        'success' => false,
        'message' => 'No valid user session.'
    ]);
    exit;
}

// 2) Get the appointment_id param
$apptID = isset($_GET['appointment_id']) ? (int)$_GET['appointment_id'] : 0;
if ($apptID < 1) {
    echo json_encode([
        'success' => false,
        'message' => 'Invalid or missing appointment_id.'
    ]);
    exit;
}

// 3) If role=staff => we must block future-dated
if ($userRole === 'staff') {
    // 3a) Fetch all PENDING follow-ups for this appointment + category=3
    $sqlCheck = "
      SELECT FollowUpID, FollowUpDate
      FROM follow_up
      WHERE AppointmentID = ?
        AND followup_category_id = 3
        AND FollowUpStatus = 'Pending'
    ";
    $stmt = $conn->prepare($sqlCheck);
    $stmt->bind_param("i", $apptID);
    $stmt->execute();
    $res = $stmt->get_result();
    $nowTS = time();
    while ($row = $res->fetch_assoc()) {
        $fID = (int)$row['FollowUpID'];
        $dt  = $row['FollowUpDate'] ?? '';
        if (!empty($dt)) {
            $dtTS = strtotime($dt);
            if ($dtTS > $nowTS) {
                // future date => staff not allowed
                echo json_encode([
                    'success' => false,
                    'message' => "Cannot mark future follow-up #$fID as done."
                ]);
                $stmt->close();
                exit;
            }
        }
    }
    $stmt->close();
}

// 4) Update all PENDING to "Done" for that appointment
$sqlUp = "
  UPDATE follow_up
  SET FollowUpStatus = 'Done',
      UpdatedBy = ?,
      UpdatedAt = NOW()
  WHERE AppointmentID = ?
    AND followup_category_id = 3
    AND FollowUpStatus = 'Pending'
";
$stUp = $conn->prepare($sqlUp);
$stUp->bind_param("ii", $currentUserID, $apptID);
if (!$stUp->execute()) {
    echo json_encode([
        'success' => false,
        'message' => 'DB update error: ' . $conn->error
    ]);
    $stUp->close();
    exit;
}
$stUp->close();

// 5) Return success
echo json_encode(['success' => true]);
exit;
