<?php
// actions/msr/save_msr.php

include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

header('Content-Type: application/json');

// Check user session
if (!isset($_SESSION['user_id'])) {
    echo json_encode(['success' => false, 'message' => 'No valid user session.']);
    exit;
}
$user_id   = (int)$_SESSION['user_id'];
$user_role = $_SESSION['role'] ?? 'staff';

// Read JSON payload
$data = json_decode(file_get_contents('php://input'), true);
if (!$data) {
    echo json_encode(['success' => false, 'message' => 'No input received.']);
    exit;
}

// Distinguish holiday vs normal MSR
$holiday = !empty($data['holiday']) ? 1 : 0;
$remarks = trim($data['remarks'] ?? '');

// "rows" is only needed for normal MSR
$rows = isset($data['rows']) && is_array($data['rows']) ? $data['rows'] : [];

// The MSR date
$msr_date = isset($data['msr_date']) ? trim($data['msr_date']) : '';
if (!$msr_date || $msr_date === '0000-00-00') {
    // If staff => force today's date
    if ($user_role === 'staff') {
        $msr_date = date('Y-m-d');
    } else {
        echo json_encode(['success' => false, 'message' => 'No valid MSR date provided.']);
        exit;
    }
}

// (A) If staff + not holiday => check if they've already created an MSR for that date
if ($user_role === 'staff' && !$holiday) {
    $check_sql = "SELECT id FROM msr WHERE user_id = ? AND date_of_msr = ? LIMIT 1";
    $stmt = $conn->prepare($check_sql);
    $stmt->bind_param("is", $user_id, $msr_date);
    $stmt->execute();
    $res = $stmt->get_result();
    if ($res && $res->num_rows > 0) {
        echo json_encode([
            'success' => false,
            'message' => "You already created an MSR for {$msr_date}. Staff can only create one MSR per date."
        ]);
        exit;
    }
    $stmt->close();
}

// (B) Collision check for ANY msr or holiday with the same date
$collision_sql = "SELECT id FROM msr WHERE date_of_msr = ? LIMIT 1";
$stCol = $conn->prepare($collision_sql);
$stCol->bind_param('s', $msr_date);
$stCol->execute();
$resCol = $stCol->get_result();
if ($resCol && $resCol->num_rows > 0) {
    echo json_encode(['success' => false, 'message' => "There's already an MSR or holiday for {$msr_date}."]);
    exit;
}
$stCol->close();

$conn->begin_transaction();

try {
    // Generate MSR number function (unchanged from your code)
    function generateMSRNumber($conn, $msrDate)
    {
        $datePart = date('ymd', strtotime($msrDate));
        $prefix   = 'MSR-' . $datePart;
        $stmt = $conn->prepare("
            SELECT msr_number 
            FROM msr 
            WHERE msr_number LIKE ? 
            ORDER BY msr_number DESC 
            LIMIT 1
        ");
        $like = $prefix . '%';
        $stmt->bind_param('s', $like);
        $stmt->execute();
        $res = $stmt->get_result();
        $lastNum = null;
        if ($res && $r = $res->fetch_assoc()) {
            $lastNum = $r['msr_number'];
        }
        $stmt->close();
        if ($lastNum) {
            $seq = (int)substr($lastNum, strlen($prefix));
            $seq++;
        } else {
            $seq = 1;
        }
        return $prefix . str_pad($seq, 5, '0', STR_PAD_LEFT);
    }

    // Generate receipt number function (unchanged)
    function generateReceiptNumber($conn)
    {
        $datePart = date('ymd');
        $prefix = 'R-' . $datePart;
        $stmt = $conn->prepare("
            SELECT receipt_number 
            FROM receipts 
            WHERE receipt_number LIKE ? 
            ORDER BY receipt_number DESC 
            LIMIT 1
        ");
        $like = $prefix . '%';
        $stmt->bind_param("s", $like);
        $stmt->execute();
        $res = $stmt->get_result();
        $last = null;
        if ($res && $r = $res->fetch_assoc()) {
            $last = $r['receipt_number'];
        }
        $stmt->close();
        if ($last) {
            $seq = (int)substr($last, strlen($prefix));
            $seq++;
        } else {
            $seq = 1;
        }
        return $prefix . str_pad($seq, 5, '0', STR_PAD_LEFT);
    }

    // (C) Generate msr_number for ALL cases (including holiday),
    // to keep columns consistent + no null error
    $msr_number = generateMSRNumber($conn, $msr_date);
    if (!$msr_number) {
        throw new Exception("Failed to generate MSR number.");
    }

    // (D) Insert new MSR row with remarks + holiday
    $stmtIns = $conn->prepare("
        INSERT INTO msr (
            date_of_msr,
            msr_number,
            remarks,
            holiday,
            user_id,
            created_at
        ) VALUES (?, ?, ?, ?, ?, NOW())
    ");
    $stmtIns->bind_param("sssii", $msr_date, $msr_number, $remarks, $holiday, $user_id);
    if (!$stmtIns->execute()) {
        throw new Exception("Failed to insert MSR: " . $stmtIns->error);
    }
    $msr_id = $stmtIns->insert_id;
    $stmtIns->close();

    // (E) If it's a holiday => skip row logic, commit + exit
    if ($holiday) {
        $conn->commit();
        echo json_encode([
            'success' => true,
            'message' => "Holiday record created for {$msr_date} (MSR#: {$msr_number})."
        ]);
        exit;
    }

    // (F) Normal MSR => process each row
    foreach ($rows as $row) {
        $patient_id  = (int)($row['patient_id'] ?? 0);
        $reference   = trim($row['reference'] ?? '');
        $medicines   = trim($row['medicines'] ?? '');
        $treatments  = trim($row['treatments'] ?? '[]');
        $paymentType = $row['payment_type'] ?? 'Cash';
        $discount    = (float)($row['discount'] ?? 0);

        // Force total_paid to 0
        $paid = 0.0;
        // Calculate sum of treatments
        $tArr = json_decode($treatments, true);
        $treatmentSum = 0.0;
        if (is_array($tArr)) {
            foreach ($tArr as $item) {
                $treatmentSum += (float)($item['amount'] ?? 0);
            }
        }
        // leftover = sum - discount
        $leftover = $treatmentSum - $discount;
        if ($leftover < 0) {
            $leftover = 0;
        }
        // total day cost = discount + leftover = treatmentSum
        $dayTotal = $treatmentSum;

        // 1) Insert msr_patients
        $stmtMP = $conn->prepare("
            INSERT INTO msr_patients (
                msr_id, patient_id,
                reference, medicines, treatments
            ) VALUES (?,?,?,?,?)
        ");
        $stmtMP->bind_param(
            "iisss",
            $msr_id,
            $patient_id,
            $reference,
            $medicines,
            $treatments
        );
        if (!$stmtMP->execute()) {
            throw new Exception("Failed to insert msr_patients: " . $stmtMP->error);
        }
        $msr_patient_id = $stmtMP->insert_id;
        $stmtMP->close();

        // 2) Insert receipt record if needed
        $receipt_num = generateReceiptNumber($conn);
        $stmtR = $conn->prepare("
            INSERT INTO receipts (receipt_number, msr_patient_id, created_at)
            VALUES (?, ?, NOW())
        ");
        $stmtR->bind_param("si", $receipt_num, $msr_patient_id);
        if (!$stmtR->execute()) {
            throw new Exception("Failed to insert receipt: " . $stmtR->error);
        }
        $stmtR->close();

        // 3) Insert into debts
        $remarksD = '';
        $stmtD = $conn->prepare("
            INSERT INTO debts (
                msr_id, patient_id,
                payment_type, discount,
                debt_amount, payment_amount,
                balance_after_payment, remarks,
                date_of_debt
            ) VALUES (?,?,?,?,?,?,?,?,?)
        ");
        $stmtD->bind_param(
            "iisddddds",
            $msr_id,
            $patient_id,
            $paymentType,
            $discount,
            $dayTotal,
            $paid,
            $leftover,
            $remarksD,
            $msr_date
        );
        if (!$stmtD->execute()) {
            throw new Exception("Failed to insert debts: " . $stmtD->error);
        }
        $stmtD->close();
    }

    $conn->commit();
    echo json_encode(['success' => true, 'message' => 'MSR saved successfully.']);
} catch (Exception $ex) {
    $conn->rollback();
    echo json_encode(['success' => false, 'message' => $ex->getMessage()]);
}
