<?php
// actions/msr/update_msr_action.php

header('Content-Type: application/json');
include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

/**
 * Expected JSON payload structure:
 * {
 *   "msr_id": <int>,
 *   "rows": [
 *      {
 *         "msr_patient_id": <int>,
 *         "patient_id": <int>,
 *         "reference": <string>,
 *         "medicines": <string>,
 *         "treatments": <json-string>,
 *         "payment_type": <string>,
 *         "discount": <float>,
 *         "total_paid": 0,
 *         "balance": <float>
 *      },
 *      ...
 *   ],
 *   "deletedRows": [ <msr_patient_id>, ... ]
 * }
 */

$inputJSON = file_get_contents('php://input');
$input = json_decode($inputJSON, true);

if (!$input || !isset($input['msr_id']) || !isset($input['rows']) || !isset($input['deletedRows'])) {
    echo json_encode(['success' => false, 'message' => 'Invalid input.']);
    exit;
}

$msr_id = (int)$input['msr_id'];
$rows = is_array($input['rows']) ? $input['rows'] : [];
$deletedRows = is_array($input['deletedRows']) ? $input['deletedRows'] : [];

$conn->begin_transaction();

try {
    // ------------------------------------------------------------------
    // A) Handle deletedRows: remove from msr_patients, receipts, debts
    if (!empty($deletedRows)) {
        // Build placeholders
        $placeholders = implode(',', array_fill(0, count($deletedRows), '?'));
        $types = str_repeat('i', count($deletedRows));

        // 1) Remove from msr_patients
        $delMPsql = "DELETE FROM msr_patients WHERE id IN ($placeholders)";
        $delMP = $conn->prepare($delMPsql);
        $delMP->bind_param($types, ...$deletedRows);
        if (!$delMP->execute()) {
            throw new Exception("Failed deleting msr_patients: " . $delMP->error);
        }
        $delMP->close();

        // 2) Remove any receipts referencing those msr_patient_ids
        foreach ($deletedRows as $drId) {
            $delRc = $conn->prepare("DELETE FROM receipts WHERE msr_patient_id = ?");
            $delRc->bind_param("i", $drId);
            if (!$delRc->execute()) {
                throw new Exception("Failed removing receipts: " . $delRc->error);
            }
            $delRc->close();
        }

        // 3) Remove debt records for the affected patients.
        // (We assume debts and any associated partial payments should be reset.)
        $delDebt = $conn->prepare("DELETE FROM debts WHERE msr_id = ? AND patient_id IN (
            SELECT patient_id FROM msr_patients WHERE id IN ($placeholders)
        )");
        // Bind msr_id first, then the deletedRows values.
        $bindParams = array_merge([$msr_id], $deletedRows);
        // Build types string: 'i' for msr_id then 'i' for each deleted row.
        $types2 = 'i' . str_repeat('i', count($deletedRows));
        $delDebt->bind_param($types2, ...$bindParams);
        if (!$delDebt->execute()) {
            throw new Exception("Failed removing debts: " . $delDebt->error);
        }
        $delDebt->close();
    }

    // ------------------------------------------------------------------
    // B) Process each row: update msr_patients and then update payment records only if values have changed.
    foreach ($rows as $r) {
        $msr_patient_id = (int)($r['msr_patient_id'] ?? 0);
        $patient_id = (int)($r['patient_id'] ?? 0);
        $reference = trim($r['reference'] ?? '');
        $medicines = trim($r['medicines'] ?? '');
        $treatments = trim($r['treatments'] ?? '[]');
        $paymentType = trim($r['payment_type'] ?? 'Cash');
        $discount = (float)($r['discount'] ?? 0.0);
        // Force total_paid to 0 since we're resetting payments
        $paid = 0.0;

        // Decode treatments and compute treatmentSum.
        $tArr = json_decode($treatments, true);
        $treatmentSum = 0.0;
        if (is_array($tArr)) {
            foreach ($tArr as $item) {
                $treatmentSum += (float)($item['amount'] ?? 0);
            }
        }
        // The new balance is calculated as (treatmentSum - discount).
        $leftover = $treatmentSum - $discount;
        if ($leftover < 0) $leftover = 0.0;
        // The debt amount (original treatment total) equals treatmentSum.
        $newDebtAmt = $treatmentSum;

        if ($msr_patient_id > 0) {
            // Update existing msr_patients record.
            $updMP = $conn->prepare("
                UPDATE msr_patients
                SET patient_id = ?,
                    reference = ?,
                    medicines = ?,
                    treatments = ?
                WHERE id = ?
            ");
            $updMP->bind_param("isssi", $patient_id, $reference, $medicines, $treatments, $msr_patient_id);
            if (!$updMP->execute()) {
                throw new Exception("Failed updating msr_patients: " . $updMP->error);
            }
            $updMP->close();

            // Check if a debt record exists for this msr_id and patient_id.
            $stmtCheck = $conn->prepare("SELECT payment_type, discount, debt_amount, balance_after_payment FROM debts WHERE msr_id = ? AND patient_id = ?");
            $stmtCheck->bind_param("ii", $msr_id, $patient_id);
            if (!$stmtCheck->execute()) {
                throw new Exception("Failed checking existing debt record: " . $stmtCheck->error);
            }
            $result = $stmtCheck->get_result();
            if ($result->num_rows > 0) {
                $oldDebt = $result->fetch_assoc();
                // Compare old debt values with new computed values.
                if (
                    $oldDebt['payment_type'] !== $paymentType ||
                    floatval($oldDebt['discount']) !== $discount ||
                    floatval($oldDebt['debt_amount']) !== $newDebtAmt ||
                    floatval($oldDebt['balance_after_payment']) !== $leftover
                ) {
                    // Update the existing debt record.
                    $stmtUpdateDebt = $conn->prepare("UPDATE debts SET payment_type = ?, discount = ?, debt_amount = ?, payment_amount = 0, balance_after_payment = ? WHERE msr_id = ? AND patient_id = ?");
                    $stmtUpdateDebt->bind_param("sddddi", $paymentType, $discount, $newDebtAmt, $leftover, $msr_id, $patient_id);
                    if (!$stmtUpdateDebt->execute()) {
                        throw new Exception("Failed updating debt record: " . $stmtUpdateDebt->error);
                    }
                    $stmtUpdateDebt->close();
                }
            } else {
                // No existing debt record; insert a new one.
                $stmtInsertDebt = $conn->prepare("
                    INSERT INTO debts (
                      msr_id, patient_id,
                      payment_type, discount,
                      debt_amount, payment_amount,
                      balance_after_payment,
                      date_of_debt
                    ) VALUES (?, ?, ?, ?, ?, ?, ?, NOW())
                ");
                $stmtInsertDebt->bind_param("iisdddd", $msr_id, $patient_id, $paymentType, $discount, $newDebtAmt, $paid, $leftover);
                if (!$stmtInsertDebt->execute()) {
                    throw new Exception("Failed inserting new debt record: " . $stmtInsertDebt->error);
                }
                $stmtInsertDebt->close();
            }
            $stmtCheck->close();
        } else {
            // Insert new msr_patients record.
            $insMP = $conn->prepare("
                INSERT INTO msr_patients (msr_id, patient_id, reference, medicines, treatments)
                VALUES (?, ?, ?, ?, ?)
            ");
            $insMP->bind_param("iisss", $msr_id, $patient_id, $reference, $medicines, $treatments);
            if (!$insMP->execute()) {
                throw new Exception("Failed inserting msr_patients: " . $insMP->error);
            }
            $msr_patient_id = $insMP->insert_id;
            $insMP->close();

            // Insert new debt record for the new patient.
            $stmtD = $conn->prepare("
                INSERT INTO debts (
                  msr_id, patient_id,
                  payment_type, discount,
                  debt_amount, payment_amount,
                  balance_after_payment,
                  date_of_debt
                ) VALUES (?, ?, ?, ?, ?, ?, ?, NOW())
            ");
            $stmtD->bind_param("iisdddd", $msr_id, $patient_id, $paymentType, $discount, $newDebtAmt, $paid, $leftover);
            if (!$stmtD->execute()) {
                throw new Exception("Failed inserting new debt record: " . $stmtD->error);
            }
            $stmtD->close();
        }
    }

    $conn->commit();
    echo json_encode(['success' => true, 'message' => 'MSR updated successfully.']);
} catch (Exception $ex) {
    $conn->rollback();
    error_log("update_msr_action error: " . $ex->getMessage());
    echo json_encode(['success' => false, 'message' => $ex->getMessage()]);
}
