<?php
// actions/patient/addPatientProcess.php

include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// We'll accumulate errors in an array
$errors = [];

// Ensure form is submitted via POST
if ($_SERVER["REQUEST_METHOD"] !== "POST") {
    echo "<script>
        alert('Invalid request method.');
        window.location.href = '" . $baseURL . "pages/patient/patientAdd.php';
    </script>";
    exit();
}

/**
 * 1) Collect basic form fields
 */
$patient_id      = isset($_POST['patient_id']) ? (int)$_POST['patient_id'] : 0;  // 0 => new, else => edit
$patient_type    = $conn->real_escape_string($_POST['patient_type']   ?? '');
$patient_title   = $conn->real_escape_string($_POST['patient_title']  ?? '');
$patient_fname   = $conn->real_escape_string($_POST['patient_fname']  ?? '');
$patient_lname   = $conn->real_escape_string($_POST['patient_lname']  ?? '');
$patient_ic      = $conn->real_escape_string($_POST['patient_ic']     ?? '');
$patient_age     = (int)($_POST['patient_age'] ?? 0);
$patient_gender  = $conn->real_escape_string($_POST['patient_gender'] ?? '');
$patient_contact = $conn->real_escape_string($_POST['patient_contact'] ?? '');
$patient_occupation    = $conn->real_escape_string($_POST['patient_occupation']   ?? '');
$patient_maritalStatus = $conn->real_escape_string($_POST['patient_maritalStatus'] ?? '');
$patient_spouseName    = $conn->real_escape_string($_POST['patient_spouseName']    ?? '');
$patient_noOfChildren  = (int)($_POST['patient_noOfChildren'] ?? 0);
$dor                   = $conn->real_escape_string($_POST['dor'] ?? '');
$remarks               = $conn->real_escape_string($_POST['remarks']  ?? '');

// If marital status is Single => override spouse & children
if (strtolower($patient_maritalStatus) === 'single') {
    $patient_spouseName   = '';
    $patient_noOfChildren = 0;
}

/**
 * 2) Checkboxes to include or skip Medical History / Vitals
 */
$include_medical_history = isset($_POST['include_medical_history']) ? true : false;
$include_vitals          = isset($_POST['include_vitals']) ? true : false;

/**
 * 3) Address
 */
$add1      = $conn->real_escape_string($_POST['add1']     ?? '');
$add2      = $conn->real_escape_string($_POST['add2']     ?? '');
$states    = $conn->real_escape_string($_POST['states']   ?? '');
$cities    = $conn->real_escape_string($_POST['cities']   ?? '');
$postcodes = $conn->real_escape_string($_POST['postcodes'] ?? '');
$countries = $conn->real_escape_string($_POST['countries'] ?? '');

/**
 * 4) Medical History fields
 */
$history_of_disease = $conn->real_escape_string($_POST['history_of_disease'] ?? '');
$previousmedi       = $conn->real_escape_string($_POST['previousmedi']       ?? '');
$dorecord           = $conn->real_escape_string($_POST['dorecord']           ?? ''); // LMP

/**
 * 5) Vitals fields
 */
$dorecordvital = $conn->real_escape_string($_POST['dorecordvital'] ?? '');
$diabetic  = isset($_POST['diabetic'])  ? (float)$_POST['diabetic']   : null;
$pressure  = isset($_POST['pressure'])  ? (int)$_POST['pressure']     : null;
$height    = isset($_POST['height'])    ? (float)$_POST['height']     : null;
$weight    = isset($_POST['weight'])    ? (float)$_POST['weight']     : null;
$temp      = isset($_POST['temperature']) ? (float)$_POST['temperature'] : null;
$pulse     = isset($_POST['pulse'])     ? (int)$_POST['pulse']        : null;

/**
 * 6) Basic validations
 */
if (!$patient_fname)   $errors[] = "First Name is required.";
if (!$patient_lname)   $errors[] = "Last Name is required.";
if (!$patient_ic)      $errors[] = "IC/Passport Number is required.";
if (!$patient_gender)  $errors[] = "Gender is required.";
if (!$patient_contact) $errors[] = "Contact is required.";
// Address
if (!$add1)            $errors[] = "Address Line 1 is required.";
if (!$states)          $errors[] = "State is required.";
if (!$cities)          $errors[] = "City is required.";
if (!$postcodes)       $errors[] = "Postcode is required.";
if (!$countries)       $errors[] = "Country is required.";

if (!empty($errors)) {
    // If we found any errors, alert and go back
    $errorMsg = implode("\\n", $errors);
    $redirectURL = $baseURL . 'pages/patient/patientAdd.php';
    if ($patient_id > 0) {
        $redirectURL .= '?id=' . $patient_id;
    }
    echo "<script>
        alert('Errors encountered:\\n$errorMsg');
        window.location.href = '$redirectURL';
    </script>";
    exit();
}

/**
 * 7) Enforce unique IC on the server side
 */
if ($patient_id === 0) {
    // New insert => check if any patient has that IC
    $stmtCheck = $conn->prepare("SELECT id FROM patients WHERE identificationNumber = ? LIMIT 1");
    $stmtCheck->bind_param("s", $patient_ic);
} else {
    // Edit => check if any other patient (id != $patient_id) has that IC
    $stmtCheck = $conn->prepare("
        SELECT id FROM patients 
        WHERE identificationNumber = ? 
          AND id != ?
        LIMIT 1
    ");
    $stmtCheck->bind_param("si", $patient_ic, $patient_id);
}

$stmtCheck->execute();
$resCheck = $stmtCheck->get_result();
if ($resCheck->num_rows > 0) {
    // Duplicate IC
    $stmtCheck->close();
    echo "<script>
        alert('This IC/Passport Number already exists in the system. Please change it.');
        window.location.href = '" . $baseURL . "pages/patient/patientAdd.php" . ($patient_id > 0 ? "?id=$patient_id" : "") . "';
    </script>";
    exit();
}
$stmtCheck->close();

/**
 * 8) Decide: INSERT (patient_id=0) or UPDATE (patient_id>0)
 */
if ($patient_id === 0) {
    // ========== INSERT NEW PATIENT ==========
    $stmt = $conn->prepare("
        INSERT INTO patients (
          patientType,
          title,
          first_name,
          last_name,
          identificationNumber,
          age,
          sex,
          contact,
          occupation,
          marital_status,
          spouse,
          no_of_children,
          date_of_registration,
          remarks
        ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
    ");
    if (!$stmt) {
        dieWithError("Prepare failed: " . $conn->error);
    }

    $stmt->bind_param(
        "sssssisssssiss",
        $patient_type,
        $patient_title,
        $patient_fname,
        $patient_lname,
        $patient_ic,
        $patient_age,
        $patient_gender,
        $patient_contact,
        $patient_occupation,
        $patient_maritalStatus,
        $patient_spouseName,
        $patient_noOfChildren,
        $dor,
        $remarks
    );
    if (!$stmt->execute()) {
        dieWithError("Error inserting patient info: " . $stmt->error);
    }
    $newPatientID = $stmt->insert_id;
    $stmt->close();

    // Insert address
    $stmt2 = $conn->prepare("
        INSERT INTO patient_address (
          patient_id, add1, add2, state, city, postcode, country
        ) VALUES (?, ?, ?, ?, ?, ?, ?)
    ");
    $stmt2->bind_param("issssss", $newPatientID, $add1, $add2, $states, $cities, $postcodes, $countries);
    if (!$stmt2->execute()) {
        dieWithError("Error inserting address: " . $stmt2->error);
    }
    $stmt2->close();

    // Insert Medical History only if checkbox was checked
    if ($include_medical_history) {
        $stmt3 = $conn->prepare("
            INSERT INTO patient_medical_history (
              patient_id,
              history_of_disease,
              previous_medication,
              LMP
            ) VALUES (?, ?, ?, ?)
        ");
        $stmt3->bind_param("isss", $newPatientID, $history_of_disease, $previousmedi, $dorecord);
        if (!$stmt3->execute()) {
            dieWithError("Error inserting medical history: " . $stmt3->error);
        }
        $stmt3->close();
    }

    // Insert Vitals only if checkbox was checked
    if ($include_vitals) {
        $stmt4 = $conn->prepare("
            INSERT INTO patient_vitals (
              patient_id,
              dateOfRecord,
              diabetic,
              pressure,
              height,
              weight,
              temp,
              pulse_per_minute
            ) VALUES (?, ?, ?, ?, ?, ?, ?, ?)
        ");
        $stmt4->bind_param(
            "isiiiiii",
            $newPatientID,
            $dorecordvital,
            $diabetic,
            $pressure,
            $height,
            $weight,
            $temp,
            $pulse
        );
        if (!$stmt4->execute()) {
            dieWithError("Error inserting vitals: " . $stmt4->error);
        }
        $stmt4->close();
    }

    // Handle profile image upload if any
    handleProfileImageUpload($newPatientID, $patient_fname, $patient_lname);

    // Success
    echo "<script>
        alert('Patient added successfully!');
        window.location.href = '" . $baseURL . "pages/patient/patientProfile.php?id={$newPatientID}';
    </script>";
    exit();
} else {
    // ========== UPDATE EXISTING PATIENT ==========
    $stmt = $conn->prepare("
        UPDATE patients
        SET
          patientType          = ?,
          title                = ?,
          first_name           = ?,
          last_name            = ?,
          identificationNumber = ?,
          age                  = ?,
          sex                  = ?,
          contact              = ?,
          occupation           = ?,
          marital_status       = ?,
          spouse               = ?,
          no_of_children       = ?,
          date_of_registration = ?,
          remarks              = ?
        WHERE id = ?
    ");
    if (!$stmt) {
        dieWithError("Prepare failed: " . $conn->error);
    }
    $stmt->bind_param(
        "sssssisssssissi",
        $patient_type,
        $patient_title,
        $patient_fname,
        $patient_lname,
        $patient_ic,
        $patient_age,
        $patient_gender,
        $patient_contact,
        $patient_occupation,
        $patient_maritalStatus,
        $patient_spouseName,
        $patient_noOfChildren,
        $dor,
        $remarks,
        $patient_id
    );
    if (!$stmt->execute()) {
        dieWithError("Error updating patient info: " . $stmt->error);
    }
    $stmt->close();

    // Update or Insert address
    updateAddress($patient_id, $add1, $add2, $states, $cities, $postcodes, $countries);

    // Update or Insert / or Remove medical history
    if ($include_medical_history) {
        updateMedicalHistory($patient_id, $history_of_disease, $previousmedi, $dorecord);
    } else {
        // Optionally remove if it existed
        // $conn->query("DELETE FROM patient_medical_history WHERE patient_id = $patient_id");
    }

    // Update or Insert / or Remove vitals
    if ($include_vitals) {
        updateVitals($patient_id, $dorecordvital, $diabetic, $pressure, $height, $weight, $temp, $pulse);
    } else {
        // Optionally remove if it existed
        // $conn->query("DELETE FROM patient_vitals WHERE patient_id = $patient_id");
    }

    // Handle profile image upload
    handleProfileImageUpload($patient_id, $patient_fname, $patient_lname);

    // Success
    echo "<script>
        alert('Patient updated successfully!');
        window.location.href = '" . $baseURL . "pages/patient/patientProfile.php?id={$patient_id}';
    </script>";
    exit();
}

/** Helper function to stop execution with an error. */
function dieWithError($msg)
{
    global $baseURL;
    echo "<script>
        alert('{$msg}');
        window.location.href = '" . $baseURL . "pages/patient/patientAdd.php';
    </script>";
    exit();
}

/** 
 * Helper to update/insert address 
 */
function updateAddress($patient_id, $add1, $add2, $states, $cities, $postcodes, $countries)
{
    global $conn;
    $check = $conn->prepare("SELECT patient_id FROM patient_address WHERE patient_id = ?");
    $check->bind_param("i", $patient_id);
    $check->execute();
    $res = $check->get_result();
    $check->close();

    if ($res->num_rows > 0) {
        // update
        $stmt = $conn->prepare("
            UPDATE patient_address
            SET
              add1 = ?,
              add2 = ?,
              state = ?,
              city = ?,
              postcode = ?,
              country = ?
            WHERE patient_id = ?
        ");
        $stmt->bind_param("ssssssi", $add1, $add2, $states, $cities, $postcodes, $countries, $patient_id);
    } else {
        // insert
        $stmt = $conn->prepare("
            INSERT INTO patient_address (patient_id, add1, add2, state, city, postcode, country)
            VALUES (?, ?, ?, ?, ?, ?, ?)
        ");
        $stmt->bind_param("issssss", $patient_id, $add1, $add2, $states, $cities, $postcodes, $countries);
    }

    if (!$stmt->execute()) {
        dieWithError("Error updating address: " . $stmt->error);
    }
    $stmt->close();
}

/** 
 * Helper to update or insert patient_medical_history 
 */
function updateMedicalHistory($patient_id, $history_of_disease, $previousmedi, $dorecord)
{
    global $conn;
    $chk = $conn->prepare("SELECT patient_id FROM patient_medical_history WHERE patient_id = ?");
    $chk->bind_param("i", $patient_id);
    $chk->execute();
    $res = $chk->get_result();
    $chk->close();

    if ($res->num_rows > 0) {
        // update
        $stmt3 = $conn->prepare("
            UPDATE patient_medical_history
            SET
              history_of_disease = ?,
              previous_medication = ?,
              LMP = ?
            WHERE patient_id = ?
        ");
        $stmt3->bind_param("sssi", $history_of_disease, $previousmedi, $dorecord, $patient_id);
        if (!$stmt3->execute()) {
            dieWithError("Error updating medical history: " . $stmt3->error);
        }
        $stmt3->close();
    } else {
        // insert
        $stmt3 = $conn->prepare("
            INSERT INTO patient_medical_history (patient_id, history_of_disease, previous_medication, LMP)
            VALUES (?, ?, ?, ?)
        ");
        $stmt3->bind_param("isss", $patient_id, $history_of_disease, $previousmedi, $dorecord);
        if (!$stmt3->execute()) {
            dieWithError("Error inserting medical history: " . $stmt3->error);
        }
        $stmt3->close();
    }
}

/** 
 * Helper to update or insert patient_vitals 
 */
function updateVitals($patient_id, $dorecordvital, $diabetic, $pressure, $height, $weight, $temp, $pulse)
{
    global $conn;
    $chk = $conn->prepare("SELECT patient_id FROM patient_vitals WHERE patient_id = ?");
    $chk->bind_param("i", $patient_id);
    $chk->execute();
    $res = $chk->get_result();
    $chk->close();

    if ($res->num_rows > 0) {
        // update
        $stmt4 = $conn->prepare("
            UPDATE patient_vitals
            SET
              dateOfRecord     = ?,
              diabetic         = ?,
              pressure         = ?,
              height           = ?,
              weight           = ?,
              temp             = ?,
              pulse_per_minute = ?
            WHERE patient_id = ?
        ");
        $stmt4->bind_param(
            "siiiiiii",
            $dorecordvital,
            $diabetic,
            $pressure,
            $height,
            $weight,
            $temp,
            $pulse,
            $patient_id
        );
        if (!$stmt4->execute()) {
            dieWithError("Error updating vitals: " . $stmt4->error);
        }
        $stmt4->close();
    } else {
        // insert
        $stmt4 = $conn->prepare("
            INSERT INTO patient_vitals (
              patient_id,
              dateOfRecord,
              diabetic,
              pressure,
              height,
              weight,
              temp,
              pulse_per_minute
            ) VALUES (?, ?, ?, ?, ?, ?, ?, ?)
        ");
        $stmt4->bind_param(
            "isiiiiii",
            $patient_id,
            $dorecordvital,
            $diabetic,
            $pressure,
            $height,
            $weight,
            $temp,
            $pulse
        );
        if (!$stmt4->execute()) {
            dieWithError("Error inserting vitals: " . $stmt4->error);
        }
        $stmt4->close();
    }
}

/**
 * Handles the profile picture upload + resizing to 300x300
 * 
 * @param int $patientID
 * @param string $fname
 * @param string $lname
 */
function handleProfileImageUpload($patientID, $fname, $lname)
{
    global $conn;
    if (!isset($_FILES['profile_image']) || !is_uploaded_file($_FILES['profile_image']['tmp_name'])) {
        return; // no file uploaded
    }

    // Basic check if it's an image
    $imgInfo = @getimagesize($_FILES['profile_image']['tmp_name']);
    if (!$imgInfo) {
        // Not an image
        return;
    }

    // Create folder
    $uploadDir = ROOT_PATH . "uploads/profile/" . $patientID . "/";
    if (!is_dir($uploadDir)) {
        mkdir($uploadDir, 0775, true);
    }

    $targetFile = $uploadDir . "profilepicture.png";

    // We'll do 300x300
    $newWidth  = 300;
    $newHeight = 300;

    $srcWidth  = $imgInfo[0];
    $srcHeight = $imgInfo[1];
    $srcType   = $imgInfo[2]; // IMAGETYPE_XXX

    switch ($srcType) {
        case IMAGETYPE_PNG:
            $srcImg = imagecreatefrompng($_FILES['profile_image']['tmp_name']);
            break;
        case IMAGETYPE_JPEG:
            $srcImg = imagecreatefromjpeg($_FILES['profile_image']['tmp_name']);
            break;
        case IMAGETYPE_GIF:
            $srcImg = imagecreatefromgif($_FILES['profile_image']['tmp_name']);
            break;
        default:
            return; // unsupported
    }

    $dstImg = imagecreatetruecolor($newWidth, $newHeight);

    // handle transparency
    imagealphablending($dstImg, false);
    imagesavealpha($dstImg, true);

    imagecopyresampled(
        $dstImg,
        $srcImg,
        0,
        0,
        0,
        0,
        $newWidth,
        $newHeight,
        $srcWidth,
        $srcHeight
    );

    // Save as PNG
    imagepng($dstImg, $targetFile);

    imagedestroy($srcImg);
    imagedestroy($dstImg);

    // Store relative path
    $relPath = "uploads/profile/" . $patientID . "/profilepicture.png";
    $stmt = $conn->prepare("UPDATE patients SET profile_image = ? WHERE id = ?");
    $stmt->bind_param("si", $relPath, $patientID);
    $stmt->execute();
    $stmt->close();
}
