<?php
// actions/patient/search_patients.php

include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

header('Content-Type: application/json');

// Basic sanitize
function sanitize_input($data)
{
    return htmlspecialchars(strip_tags(trim($data)));
}

// Retrieve GET
$nameParam = isset($_GET['name']) ? sanitize_input($_GET['name']) : '';
$icParam   = isset($_GET['ic'])   ? sanitize_input($_GET['ic'])   : '';

// If both name & IC are empty, return empty to avoid listing all patients
if (empty($nameParam) && empty($icParam)) {
    echo json_encode([]);
    exit;
}

/**
 * We'll get each patient's ID, full name, IC,
 * and the most recent leftover from debts.balance_after_payment.
 *
 * We'll do this by using a correlated subquery:
 *
 *   SELECT
 *     (SELECT dd.balance_after_payment
 *      FROM debts dd
 *      WHERE dd.patient_id = p.id
 *      ORDER BY dd.date_of_debt DESC
 *      LIMIT 1
 *     ) AS final_leftover
 *
 * If no rows in debts => returns NULL => we default to 0 in the main SELECT via IFNULL().
 */

$sql = "
  SELECT
    p.id,
    CONCAT(p.first_name, ' ', p.last_name) AS name,
    p.identificationNumber,
    IFNULL(
      (
        SELECT dd.balance_after_payment
        FROM debts dd
        WHERE dd.patient_id = p.id
        ORDER BY dd.date_of_debt DESC
        LIMIT 1
      ),
      0
    ) AS final_leftover
  FROM patients p
  WHERE 1=1
";

$types = '';
$params = [];

// Filter by name
if (!empty($nameParam)) {
    $sql .= " AND (p.first_name LIKE ? OR p.last_name LIKE ?)";
    $likeName = '%' . $nameParam . '%';
    $types   .= 'ss';
    $params[] = $likeName;
    $params[] = $likeName;
}

// Filter by IC
if (!empty($icParam)) {
    $sql .= " AND p.identificationNumber LIKE ?";
    $likeIC = '%' . $icParam . '%';
    $types   .= 's';
    $params[] = $likeIC;
}

// Prepare
$stmt = $conn->prepare($sql);
if (!$stmt) {
    echo json_encode(['error' => true, 'message' => 'DB prepare failed']);
    exit;
}

// Bind if needed
if (!empty($types)) {
    $stmt->bind_param($types, ...$params);
}
$stmt->execute();
$res = $stmt->get_result();

$patients = [];
while ($row = $res->fetch_assoc()) {
    // final_leftover might be negative in some edge cases if there's an overpayment
    $debtVal = (float)$row['final_leftover'];
    // If you want to clamp to zero (no negative debts), do so here:
    if ($debtVal < 0) {
        $debtVal = 0.00;
    }

    $patients[] = [
        'id'                  => $row['id'],
        'name'                => $row['name'] ?: '',
        'identificationNumber' => $row['identificationNumber'] ?: '',
        // Return as e.g. "123.45"
        'old_debt'            => number_format($debtVal, 2, '.', '')
    ];
}
$stmt->close();
$conn->close();

echo json_encode($patients);
