<?php
// actions/user/edit_user.php

header('Content-Type: application/json');
include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// Ensure only admins can edit users
if ($_SESSION['role'] !== 'admin') {
    echo json_encode(['success' => false, 'message' => 'Unauthorized access.']);
    exit;
}

// Get the raw POST data
$inputJSON = file_get_contents('php://input');
$input = json_decode($inputJSON, true);

// Validate input
$required_fields = ['id', 'first_name', 'last_name', 'username', 'role'];
foreach ($required_fields as $field) {
    if (empty($input[$field])) {
        echo json_encode(['success' => false, 'message' => ucfirst(str_replace('_', ' ', $field)) . ' is required.']);
        exit;
    }
}

$id = intval($input['id']);
$first_name = trim($input['first_name']);
$last_name = trim($input['last_name']);
$username = trim($input['username']);
$password = isset($input['password']) ? trim($input['password']) : '';
$role = trim($input['role']);

// Validate role
if (!in_array($role, ['staff', 'admin'])) {
    echo json_encode(['success' => false, 'message' => 'Invalid role selected.']);
    exit;
}

// Check if user exists
$stmt = $conn->prepare("SELECT id FROM users WHERE id = ?");
$stmt->bind_param('i', $id);
$stmt->execute();
$stmt->store_result();
if ($stmt->num_rows === 0) {
    echo json_encode(['success' => false, 'message' => 'User not found.']);
    $stmt->close();
    exit;
}
$stmt->close();

// Check if the new username is taken by another user
$stmt = $conn->prepare("SELECT id FROM users WHERE username = ? AND id != ?");
$stmt->bind_param('si', $username, $id);
$stmt->execute();
$stmt->store_result();
if ($stmt->num_rows > 0) {
    echo json_encode(['success' => false, 'message' => 'Username already taken by another user.']);
    $stmt->close();
    exit;
}
$stmt->close();

// If password is provided, hash it; otherwise, keep the existing hash
if ($password !== '') {
    $password_hash = password_hash($password, PASSWORD_DEFAULT);
    $sql = "UPDATE users SET first_name = ?, last_name = ?, username = ?, password_hash = ?, role = ? WHERE id = ?";
    $stmt = $conn->prepare($sql);
    if (!$stmt) {
        echo json_encode(['success' => false, 'message' => 'Database error: ' . $conn->error]);
        exit;
    }
    $stmt->bind_param('sssssi', $first_name, $last_name, $username, $password_hash, $role, $id);
} else {
    // Do not update password
    $sql = "UPDATE users SET first_name = ?, last_name = ?, username = ?, role = ? WHERE id = ?";
    $stmt = $conn->prepare($sql);
    if (!$stmt) {
        echo json_encode(['success' => false, 'message' => 'Database error: ' . $conn->error]);
        exit;
    }
    $stmt->bind_param('ssssi', $first_name, $last_name, $username, $role, $id);
}

if ($stmt->execute()) {
    echo json_encode(['success' => true, 'message' => 'User updated successfully.']);
} else {
    echo json_encode(['success' => false, 'message' => 'Failed to update user: ' . $stmt->error]);
}

$stmt->close();
?>
