<?php

/**
 * actions/user_action.php
 *
 * This file processes POST requests for adding and editing users.
 * Both admin and staff users will have extra details (identification number,
 * job title, staff no, bank name, bank account number, and profile picture)
 * stored in the staff_details table.
 *
 * The profile picture is validated (only images allowed), resized to 150×150,
 * and stored in uploads/userProfile/ with a filename based on the user’s full name.
 *
 * Expected GET parameter:
 *   action = "add" or "edit"
 *
 * Returns a JSON response.
 */

include '../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// Set JSON response header
header("Content-Type: application/json");

// Only allow access if the current user is an admin
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'admin') {
    echo json_encode(['success' => false, 'message' => 'Access denied.']);
    exit;
}

// Get action parameter (must be "add" or "edit")
$action = $_GET['action'] ?? '';
if (!in_array($action, ['add', 'edit'])) {
    echo json_encode(['success' => false, 'message' => 'Invalid action.']);
    exit;
}

/**
 * processProfilePicture()
 *
 * Validates, resizes, and saves an uploaded image file.
 * Only accepts JPEG and PNG images. The image is resized to 150x150 pixels.
 * Returns the new file name if successful or null otherwise.
 *
 * @param array  $file     The uploaded file from $_FILES.
 * @param string $fullName The user's full name (used to generate the file name).
 * @return string|null
 */
function processProfilePicture($file, $fullName)
{
    if (empty($file) || $file['error'] !== UPLOAD_ERR_OK) {
        return null;
    }
    $imageInfo = getimagesize($file['tmp_name']);
    if ($imageInfo === false) {
        return null; // Not a valid image.
    }
    $allowedMime = ['image/jpeg', 'image/png'];
    if (!in_array($imageInfo['mime'], $allowedMime)) {
        return null;
    }
    // Generate a safe filename based on full name and current timestamp.
    $safeName = preg_replace('/[^A-Za-z0-9_\-]/', '_', strtolower($fullName));
    $ext = ($imageInfo['mime'] === 'image/png') ? '.png' : '.jpg';
    $newFileName = $safeName . '_' . time() . $ext;
    $uploadDir = ROOT_PATH . "uploads/userProfile/";
    if (!is_dir($uploadDir)) {
        mkdir($uploadDir, 0777, true);
    }
    $destination = $uploadDir . $newFileName;

    // Resize image to 150x150 using GD
    $destWidth = 150;
    $destHeight = 150;
    if ($imageInfo['mime'] === 'image/png') {
        $srcImage = imagecreatefrompng($file['tmp_name']);
    } else {
        $srcImage = imagecreatefromjpeg($file['tmp_name']);
    }
    if (!$srcImage) {
        return null;
    }
    $srcWidth = imagesx($srcImage);
    $srcHeight = imagesy($srcImage);
    $dstImage = imagecreatetruecolor($destWidth, $destHeight);
    // Preserve transparency for PNG images.
    if ($imageInfo['mime'] === 'image/png') {
        imagealphablending($dstImage, false);
        imagesavealpha($dstImage, true);
    }
    imagecopyresampled($dstImage, $srcImage, 0, 0, 0, 0, $destWidth, $destHeight, $srcWidth, $srcHeight);
    if ($imageInfo['mime'] === 'image/png') {
        imagepng($dstImage, $destination);
    } else {
        imagejpeg($dstImage, $destination, 90);
    }
    imagedestroy($srcImage);
    imagedestroy($dstImage);

    return $newFileName;
}

// ----------------------
// Action: Add User
// ----------------------
if ($action === 'add') {
    // Get basic user details from POST
    $first_name = trim($_POST['first_name'] ?? '');
    $last_name  = trim($_POST['last_name'] ?? '');
    $username   = trim($_POST['username'] ?? '');
    $password   = trim($_POST['password'] ?? '');
    $role       = trim($_POST['role'] ?? '');

    // Validate required fields
    if ($first_name === '' || $last_name === '' || $username === '' || $password === '' || $role === '') {
        echo json_encode(['success' => false, 'message' => 'Missing required fields.']);
        exit;
    }
    // Hash the password
    $passwordHash = password_hash($password, PASSWORD_DEFAULT);

    // Insert into users table
    $sql = "INSERT INTO users (first_name, last_name, username, password_hash, role) VALUES (?, ?, ?, ?, ?)";
    $stmt = $conn->prepare($sql);
    if (!$stmt) {
        echo json_encode(['success' => false, 'message' => 'Database error: ' . $conn->error]);
        exit;
    }
    $stmt->bind_param('sssss', $first_name, $last_name, $username, $passwordHash, $role);
    if (!$stmt->execute()) {
        echo json_encode(['success' => false, 'message' => 'Failed to add user: ' . $stmt->error]);
        exit;
    }
    $newUserID = $stmt->insert_id;
    $stmt->close();

    // Both admins and staff will have extra details in staff_details.
    // Get optional fields (if not provided, default to empty string)
    $identification_number = trim($_POST['identification_number'] ?? '');
    $job_title = trim($_POST['job_title'] ?? '');
    $staff_no = trim($_POST['staff_no'] ?? '');
    $bank_name = trim($_POST['bank_name'] ?? '');
    $bank_acc_number = trim($_POST['bank_acc_number'] ?? '');
    // Process profile picture upload (if any)
    $profile_picture = processProfilePicture($_FILES['profile_picture'] ?? null, $first_name . ' ' . $last_name);
    if ($profile_picture === null) {
        $profile_picture = ''; // Save as empty if none provided or invalid.
    }

    $sqlStaff = "INSERT INTO staff_details (user_id, identification_number, job_title, staff_no, bank_name, bank_acc_number, profile_picture)
                 VALUES (?, ?, ?, ?, ?, ?, ?)";
    $stmtStaff = $conn->prepare($sqlStaff);
    if (!$stmtStaff) {
        echo json_encode(['success' => false, 'message' => 'Database error (staff details): ' . $conn->error]);
        exit;
    }
    $stmtStaff->bind_param('issssss', $newUserID, $identification_number, $job_title, $staff_no, $bank_name, $bank_acc_number, $profile_picture);
    $stmtStaff->execute();
    $stmtStaff->close();

    echo json_encode(['success' => true, 'message' => 'User added successfully.']);
    exit;
} elseif ($action === 'edit') {
    // ----------------------
    // Action: Edit User
    // ----------------------
    $userID = (int)($_POST['id'] ?? 0);
    $first_name = trim($_POST['first_name'] ?? '');
    $last_name  = trim($_POST['last_name'] ?? '');
    $username   = trim($_POST['username'] ?? '');
    $role       = trim($_POST['role'] ?? '');

    if ($userID < 1 || $first_name === '' || $last_name === '' || $username === '' || $role === '') {
        echo json_encode(['success' => false, 'message' => 'Missing required fields.']);
        exit;
    }

    // Begin transaction to update both users and staff_details
    $conn->begin_transaction();
    try {
        // Update the users table.
        // If a new password is provided, update it; otherwise, leave it unchanged.
        if (!empty($_POST['password'])) {
            $password = trim($_POST['password']);
            $passwordHash = password_hash($password, PASSWORD_DEFAULT);
            $sqlUser = "UPDATE users SET first_name=?, last_name=?, username=?, password_hash=?, role=? WHERE id=?";
            $stmt = $conn->prepare($sqlUser);
            $stmt->bind_param('sssssi', $first_name, $last_name, $username, $passwordHash, $role, $userID);
        } else {
            $sqlUser = "UPDATE users SET first_name=?, last_name=?, username=?, role=? WHERE id=?";
            $stmt = $conn->prepare($sqlUser);
            $stmt->bind_param('ssssi', $first_name, $last_name, $username, $role, $userID);
        }
        if (!$stmt->execute()) {
            throw new Exception("Failed to update user: " . $stmt->error);
        }
        $stmt->close();

        // Process staff details for both staff and admin.
        $identification_number = trim($_POST['identification_number'] ?? '');
        $job_title = trim($_POST['job_title'] ?? '');
        $staff_no = trim($_POST['staff_no'] ?? '');
        $bank_name = trim($_POST['bank_name'] ?? '');
        $bank_acc_number = trim($_POST['bank_acc_number'] ?? '');
        $profile_picture = null;
        if (!empty($_FILES['profile_picture']['tmp_name'])) {
            $profile_picture = processProfilePicture($_FILES['profile_picture'], $first_name . ' ' . $last_name);
        }

        // Check if staff_details record exists for this user.
        $checkSql = "SELECT id FROM staff_details WHERE user_id=?";
        $chkStmt = $conn->prepare($checkSql);
        $chkStmt->bind_param('i', $userID);
        $chkStmt->execute();
        $chkRes = $chkStmt->get_result();
        if ($chkRes->num_rows > 0) {
            // Update record.
            if ($profile_picture !== null) {
                $sqlStaff = "UPDATE staff_details SET identification_number=?, job_title=?, staff_no=?, bank_name=?, bank_acc_number=?, profile_picture=? WHERE user_id=?";
                $stmtStaff = $conn->prepare($sqlStaff);
                $stmtStaff->bind_param('ssssssi', $identification_number, $job_title, $staff_no, $bank_name, $bank_acc_number, $profile_picture, $userID);
            } else {
                $sqlStaff = "UPDATE staff_details SET identification_number=?, job_title=?, staff_no=?, bank_name=?, bank_acc_number=? WHERE user_id=?";
                $stmtStaff = $conn->prepare($sqlStaff);
                $stmtStaff->bind_param('sssssi', $identification_number, $job_title, $staff_no, $bank_name, $bank_acc_number, $userID);
            }
            if (!$stmtStaff->execute()) {
                throw new Exception("Failed to update staff details: " . $stmtStaff->error);
            }
            $stmtStaff->close();
        } else {
            // Insert a new record.
            if ($profile_picture === null) {
                $profile_picture = '';
            }
            $sqlStaff = "INSERT INTO staff_details (user_id, identification_number, job_title, staff_no, bank_name, bank_acc_number, profile_picture)
                         VALUES (?, ?, ?, ?, ?, ?, ?)";
            $stmtStaff = $conn->prepare($sqlStaff);
            $stmtStaff->bind_param('issssss', $userID, $identification_number, $job_title, $staff_no, $bank_name, $bank_acc_number, $profile_picture);
            if (!$stmtStaff->execute()) {
                throw new Exception("Failed to insert staff details: " . $stmtStaff->error);
            }
            $stmtStaff->close();
        }
        $chkStmt->close();

        $conn->commit();
        echo json_encode(['success' => true, 'message' => 'User updated successfully.']);
        exit;
    } catch (Exception $e) {
        $conn->rollback();
        echo json_encode(['success' => false, 'message' => $e->getMessage()]);
        exit;
    }
}
