document.addEventListener("DOMContentLoaded", function () {
    const medicalTable = document.getElementById("medicalTable");
    const addRowBtn = document.getElementById("addRow");
    const submitMSRBtn = document.getElementById("submitMSR");
    const reportDate = document.getElementById("reportDate");
    const reportDay = document.getElementById("reportDay");
    const msrNumberEl = document.getElementById("msrNumber");
    const userRoleEl = document.getElementById("userRole");
    const userRole = userRoleEl ? userRoleEl.value : "staff";

    let activeRow = null; // for patient selection

    // 1) Check for existing daily submission (if applicable)
    checkDailySubmission();

    // 2) For admin: allow date selection up to today
    if (reportDate && userRole === "admin") {
        const now = new Date();
        const isoToday = formatDateYYYYMMDD(now);
        reportDate.max = isoToday;
        reportDate.addEventListener("change", () => {
            const chosenStr = reportDate.value || "";
            if (!chosenStr) return;
            const chosenDate = new Date(chosenStr + "T00:00:00");
            if (chosenDate > now) {
                alert("Cannot pick a future date!");
                reportDate.value = isoToday;
            }
            if (reportDay && reportDate.value) {
                const d = new Date(reportDate.value + "T00:00:00");
                reportDay.value = d.toLocaleString("en-US", { weekday: "long" });
            }
        });
    }

    // 3) "Add Row" button
    if (addRowBtn) {
        addRowBtn.addEventListener("click", () => {
            addNewRow();
        });
    }

    // 4) "Submit MSR" button
    if (submitMSRBtn) {
        submitMSRBtn.addEventListener("click", () => {
            submitMSR();
        });
    }

    // 5) Patient search functionality (triggered from modal)
    const searchBtn = document.getElementById("searchPatientBtn");
    const patientResults = document.getElementById("patientResults");
    if (searchBtn) {
        searchBtn.addEventListener("click", function () {
            const nameVal = document.getElementById("searchName").value.trim();
            const icVal = document.getElementById("searchIC").value.trim();
            const qp = new URLSearchParams();
            if (nameVal) qp.append("name", nameVal);
            if (icVal) qp.append("ic", icVal);
            fetch(`${baseURL}actions/patient/search_patients.php?${qp}`)
                .then(r => r.json())
                .then(data => {
                    patientResults.innerHTML = "";
                    if (!Array.isArray(data) || data.length === 0) {
                        patientResults.innerHTML = "<p>No patients found.</p>";
                        return;
                    }
                    let html = `
                    <table class='table table-bordered'>
                      <thead>
                        <tr>
                          <th>Name</th>
                          <th>IC</th>
                          <th>Debt (RM)</th>
                          <th>Action</th>
                        </tr>
                      </thead>
                      <tbody>
                    `;
                    data.forEach(pp => {
                        const fname = pp.name || "";
                        const icNum = pp.identificationNumber || "";
                        const oldDebt = parseFloat(pp.old_debt || 0).toFixed(2);
                        html += `
                          <tr>
                            <td>${fname}</td>
                            <td>${icNum}</td>
                            <td>${oldDebt}</td>
                            <td>
                              <button type="button" class="btn btn-sm btn-success select-patient-btn"
                                data-id="${pp.id}"
                                data-name="${fname}"
                                data-ic="${icNum}"
                                data-debt="${oldDebt}">
                                Select
                              </button>
                            </td>
                          </tr>
                        `;
                    });
                    html += "</tbody></table>";
                    patientResults.innerHTML = html;
                    document.querySelectorAll(".select-patient-btn").forEach(btn => {
                        btn.addEventListener("click", function () {
                            if (!activeRow) return;
                            const row = activeRow;
                            row.querySelector(".patient-id").value = this.dataset.id;
                            row.querySelector(".chosen-patient-name").textContent = this.dataset.name;
                            // Auto-populate reference from last 4 digits of IC
                            const icStr = this.dataset.ic || "";
                            if (icStr.length >= 4) {
                                row.querySelector(".reference-input").value = icStr.slice(-4);
                            }
                            const modalEl = document.getElementById("patientModal");
                            const bsModal = bootstrap.Modal.getInstance(modalEl);
                            if (bsModal) bsModal.hide();
                        });
                    });
                })
                .catch(err => {
                    console.error("Search patients error:", err);
                    patientResults.innerHTML = "<p>Error searching patients.</p>";
                });
        });
    }

    // Check daily submission (if staff)
    function checkDailySubmission() {
        fetch(`${baseURL}actions/msr/check_msr.php`)
            .then(r => r.json())
            .then(data => {
                if (data.exists) {
                    setReadonlyMode(data);
                } else {
                    if (userRole === "staff") {
                        const now = new Date();
                        const isoToday = formatDateYYYYMMDD(now);
                        if (reportDate) {
                            reportDate.value = isoToday;
                            reportDate.readOnly = true;
                        }
                        if (reportDay) {
                            reportDay.value = now.toLocaleString("en-US", { weekday: "long" });
                        }
                    } else {
                        const now = new Date();
                        if (reportDate) {
                            reportDate.value = formatDateYYYYMMDD(now);
                        }
                        if (reportDay) {
                            reportDay.value = now.toLocaleString("en-US", { weekday: "long" });
                        }
                    }
                }
            })
            .catch(err => {
                console.error("check_msr error:", err);
            });
    }

    function setReadonlyMode(msrData) {
        if (reportDate) {
            reportDate.value = msrData.date || "";
            reportDate.readOnly = true;
        }
        if (reportDay) {
            reportDay.value = msrData.day || "";
        }
        if (msrNumberEl) {
            msrNumberEl.value = msrData.msr_number || "";
        }
        medicalTable.innerHTML = "";
        if (Array.isArray(msrData.rows)) {
            msrData.rows.forEach((row, idx) => {
                const tr = document.createElement("tr");
                let treatHTML = "";
                if (row.treatments) {
                    try {
                        const tArr = JSON.parse(row.treatments);
                        treatHTML = tArr.map(t =>
                            `<div>${t.type}: RM ${parseFloat(t.amount || 0).toFixed(2)}</div>`
                        ).join("");
                    } catch (e) { }
                }
                tr.innerHTML = `
                  <td>${idx + 1}</td>
                  <td>${row.patient_name || ""}</td>
                  <td><input type="text" class="form-control" value="${(row.old_debt || 0).toFixed(2)}" readonly></td>
                  <td><input type="text" class="form-control" value="${row.reference || ""}" readonly></td>
                  <td><textarea class="form-control" rows="1" readonly>${row.medicines || ""}</textarea></td>
                  <td><textarea class="form-control" rows="1" readonly>${row.treatments || ""}</textarea></td>
                  <td><input type="number" class="form-control" value="${(row.discount || 0).toFixed(2)}" readonly></td>
                  <td><input type="number" class="form-control" value="${(row.balance || 0).toFixed(2)}" readonly></td>
                  <td>
                    <button class="btn btn-sm btn-danger" disabled><i class="fas fa-trash"></i></button>
                  </td>
                `;
                medicalTable.appendChild(tr);
            });
        }
        document.querySelectorAll("input, select, textarea, button").forEach(el => {
            el.disabled = true;
        });
    }

    // Add new row (without total-paid input)
    function addNewRow() {
        const rowCount = medicalTable.querySelectorAll("tr").length + 1;
        const tr = document.createElement("tr");
        tr.innerHTML = `
          <td>${rowCount}</td>
          <td>
            <button type="button" class="btn btn-sm btn-info choose-patient-btn">Choose</button>
            <span class="chosen-patient-name ms-2"></span>
            <input type="hidden" class="patient-id" value="">
          </td>
          <td><input type="text" class="form-control reference-input" value="" readonly></td>
          <td><textarea class="form-control medicines-notes" rows="1"></textarea></td>
          <td>
            <div class="treatments-container"></div>
            <button type="button" class="btn btn-sm btn-primary add-treatment-btn mt-2">+Add Treatment</button>
          </td>
          <td><input type="number" class="form-control discount" value="0"></td>
          <td><input type="number" class="form-control balance" value="0" readonly></td>
          <td>
            <button class="btn btn-sm btn-danger delete-row"><i class="fas fa-trash"></i></button>
          </td>
        `;
        medicalTable.appendChild(tr);
        tr.querySelector(".choose-patient-btn").addEventListener("click", () => {
            activeRow = tr;
            openPatientModal();
        });
        tr.querySelector(".delete-row").addEventListener("click", () => {
            if (confirm("Delete this row?")) {
                tr.remove();
                updateRowNumbers();
            }
        });
        tr.querySelector(".add-treatment-btn").addEventListener("click", () => {
            addTreatmentLine(tr);
        });
        tr.querySelector(".discount").addEventListener("input", () => recalcRowBalance(tr));
    }

    function openPatientModal() {
        document.getElementById("searchName").value = "";
        document.getElementById("searchIC").value = "";
        document.getElementById("patientResults").innerHTML = "";
        const modalEl = document.getElementById("patientModal");
        const bsModal = new bootstrap.Modal(modalEl);
        bsModal.show();
    }

    function updateRowNumbers() {
        let idx = 1;
        medicalTable.querySelectorAll("tr").forEach(tr => {
            tr.cells[0].textContent = idx++;
        });
    }

    function addTreatmentLine(tr) {
        const container = tr.querySelector(".treatments-container");
        const lines = container.querySelectorAll(".treatment-line").length;
        if (lines >= 4) {
            alert("Max 4 treatments per row!");
            return;
        }
        const div = document.createElement("div");
        div.classList.add("treatment-line", "d-flex", "gap-2", "mb-2", "align-items-center");
        div.innerHTML = `
          <select class="form-select treatment-type" style="width:40%;">
            <option value="">(Select)</option>
            <option value="Medicine">Medicine</option>
            <option value="Therapy">Therapy</option>
            <option value="Consultation">Consultation</option>
            <option value="OTC">OTC</option>
          </select>
          <input type="number" class="form-control treatment-amount" style="width:40%;" value="0">
          <button type="button" class="btn btn-sm btn-danger remove-tx-line"><i class="fas fa-times"></i></button>
        `;
        container.appendChild(div);
        div.querySelector(".remove-tx-line").addEventListener("click", () => {
            div.remove();
            recalcRowBalance(tr);
        });
        div.querySelectorAll(".treatment-type, .treatment-amount").forEach(inp => {
            inp.addEventListener("input", () => recalcRowBalance(tr));
        });
    }

    // recalcRowBalance: balance = sum(treatment amounts) - discount
    function recalcRowBalance(tr) {
        const discountVal = parseFloat(tr.querySelector(".discount").value) || 0;
        let sumTx = 0;
        tr.querySelectorAll(".treatment-line").forEach(ln => {
            const amt = parseFloat(ln.querySelector(".treatment-amount").value) || 0;
            sumTx += amt;
        });
        let leftover = sumTx - discountVal;
        if (leftover < 0) leftover = 0;
        tr.querySelector(".balance").value = leftover.toFixed(2);
    }

    function submitMSR() {
        const rows = medicalTable.querySelectorAll("tr");
        if (!rows.length) {
            alert("No rows to submit!");
            return;
        }
        let hasPatient = false;
        let rowData = [];
        rows.forEach(tr => {
            const pid = parseInt(tr.querySelector(".patient-id").value) || 0;
            if (pid > 0) {
                hasPatient = true;
            }
            const pName = tr.querySelector(".chosen-patient-name").textContent.trim() || "";
            const refVal = tr.querySelector(".reference-input").value.trim();
            const meds = tr.querySelector(".medicines-notes").value.trim();
            // Since payment type may not exist in creation phase, default to "Debit"
            const payTyp = "Debit";
            const disc = parseFloat(tr.querySelector(".discount").value) || 0;
            // Force total_paid to 0.
            const paid = 0;
            const bal = parseFloat(tr.querySelector(".balance").value) || 0;
            let tArr = [];
            tr.querySelectorAll(".treatment-line").forEach(ln => {
                const ttype = ln.querySelector(".treatment-type").value || "";
                const tamt = parseFloat(ln.querySelector(".treatment-amount").value) || 0;
                if (ttype && tamt > 0) {
                    tArr.push({ type: ttype, amount: tamt });
                }
            });
            const treatmentsStr = JSON.stringify(tArr);
            rowData.push({
                patient_id: pid,
                patient_name: pName,
                reference: refVal,
                medicines: meds,
                treatments: treatmentsStr,
                payment_type: payTyp,
                discount: disc,
                total_paid: paid,
                balance: bal
            });
        });
        if (!hasPatient) {
            alert("Please pick at least one patient!");
            return;
        }
        let msr_date = "";
        if (reportDate) {
            msr_date = reportDate.value || "";
        }
        const payLoad = {
            msr_date,
            rows: rowData
        };
        fetch(`${baseURL}actions/msr/save_msr.php`, {
            method: "POST",
            headers: { "Content-Type": "application/json" },
            body: JSON.stringify(payLoad)
        })
            .then(resp => resp.json())
            .then(res => {
                if (res.success) {
                    alert("MSR submitted successfully!");
                    location.reload();
                } else {
                    alert("Error: " + res.message);
                }
            })
            .catch(err => {
                console.error("submitMSR error:", err);
                alert("An error occurred saving MSR.");
            });
    }

    function formatDateYYYYMMDD(dt) {
        let mm = dt.getMonth() + 1,
            dd = dt.getDate(),
            yy = dt.getFullYear();
        if (mm < 10) mm = "0" + mm;
        if (dd < 10) dd = "0" + dd;
        return `${yy}-${mm}-${dd}`;
    }
});
