document.addEventListener("DOMContentLoaded", function () {
  // Grab elements
  const medicalTable = document.getElementById("medicalTable");
  if (!medicalTable) {
    console.error("No element with id 'medicalTable' found!");
    return;
  }
  const addRowBtn = document.getElementById("addRow");
  const submitBtn = document.getElementById("submitMSR");
  const reportDate = document.getElementById("reportDate");
  const reportDay = document.getElementById("reportDay");
  const msrNumberEl = document.getElementById("msrNumber");

  // msrData is provided via the global variable (populated in updateMsr.php)
  let msrDataGlobal = msrData || [];
  let deletedRows = [];
  let activeRow = null;

  console.log("Loaded msrDataGlobal:", msrDataGlobal);

  // If no data exists, push an empty row
  if (msrDataGlobal.length === 0) {
    msrDataGlobal.push({
      msr_id: 0,
      msr_number: "",
      date_of_msr: "",
      created_at: "",
      msr_patient_id: "",
      patient_id: "",
      patient_name: "",
      reference: "",
      medicines: "",
      treatments: "[]",
      payment_type: "Cash",
      discount: 0,
      total_paid: 0,
      balance: 0
    });
  }

  populateForm(msrDataGlobal);

  if (addRowBtn) {
    addRowBtn.addEventListener("click", function () {
      const rowCount = medicalTable.querySelectorAll("tr").length + 1;
      addOrEditRow({ isNew: true, rowData: {}, rowNumber: rowCount });
    });
  }

  if (submitBtn) {
    submitBtn.addEventListener("click", function () {
      updateMSR();
    });
  }

  function populateForm(data) {
    if (!data || data.length === 0) return;
    const first = data[0];
    if (first.date_of_msr) {
      reportDate.value = first.date_of_msr;
      const dt = new Date(first.date_of_msr + "T00:00:00");
      reportDay.value = dt.toLocaleString("en-US", { weekday: "long" });
    } else if (first.created_at) {
      const dt = new Date(first.created_at);
      reportDate.value = dt.toISOString().split("T")[0];
      reportDay.value = dt.toLocaleString("en-US", { weekday: "long" });
    }
    if (msrNumberEl) {
      msrNumberEl.value = first.msr_number || "";
    }
    medicalTable.innerHTML = "";
    data.forEach((rowData, idx) => {
      addOrEditRow({ isNew: false, rowData, rowNumber: idx + 1 });
    });
  }

  function addOrEditRow({ isNew, rowData, rowNumber }) {
    const tr = document.createElement("tr");
    // Use a hidden input for msr-patient-id (if exists)
    const msrPatId = isNew ? "" : (rowData.msr_patient_id || "");
    tr.innerHTML = `
          <td>
              ${rowNumber}
              <input type="hidden" class="msr-patient-id" value="${msrPatId}">
          </td>
          <!-- Name column -->
          <td>
              <button type="button" class="btn btn-sm btn-info choose-patient-btn">Choose</button>
              <span class="chosen-patient-name ms-2">${isNew ? "" : (rowData.patient_name || "")}</span>
              <input type="hidden" class="patient-id" value="${isNew ? "" : (rowData.patient_id || "")}">
          </td>
          <!-- Reference column (readonly) -->
          <td>
              <input type="text" class="form-control reference-input" value="${isNew ? "" : (rowData.reference || "")}" readonly>
          </td>
          <!-- Medicines/Notes -->
          <td>
              <textarea class="form-control medicines-notes" rows="1">${isNew ? "" : (rowData.medicines || "")}</textarea>
          </td>
          <!-- Treatments/Amount -->
          <td>
              <div class="treatments-container"></div>
              <button type="button" class="btn btn-sm btn-primary add-treatment-btn mt-2">+Add Treatment</button>
          </td>
          <!-- Discount -->
          <td>
              <input type="number" class="form-control discount" value="${isNew ? "0" : parseFloat(rowData.discount || 0).toFixed(2)}">
          </td>
          <!-- Balance (readonly) -->
          <td>
              <input type="number" class="form-control balance" value="${isNew ? "0" : parseFloat(rowData.balance || 0).toFixed(2)}" readonly>
          </td>
          <!-- Actions -->
          <td>
              <button class="btn btn-sm btn-danger delete-row" type="button"><i class="fas fa-trash"></i></button>
          </td>
      `;
    medicalTable.appendChild(tr);

    // Attach event listeners
    tr.querySelector(".choose-patient-btn").addEventListener("click", () => {
      activeRow = tr;
      openPatientModal();
    });
    tr.querySelector(".delete-row").addEventListener("click", () => {
      if (confirm("Remove this row?")) {
        const currentMsrPatId = tr.querySelector(".msr-patient-id").value;
        if (currentMsrPatId) {
          deletedRows.push(currentMsrPatId);
        }
        tr.remove();
        updateRowNumbers();
      }
    });
    // Populate treatments if any
    const container = tr.querySelector(".treatments-container");
    let treatmentsArr = [];
    try {
      treatmentsArr = JSON.parse(rowData.treatments || "[]");
    } catch (e) { }
    treatmentsArr.forEach(tt => {
      addTreatmentLine(tr, tt.type, tt.amount);
    });
    tr.querySelector(".add-treatment-btn").addEventListener("click", () => {
      addTreatmentLine(tr);
    });
    recalcRowTotal(tr);
  }

  function openPatientModal() {
    document.getElementById("searchName").value = "";
    document.getElementById("searchIC").value = "";
    document.getElementById("patientResults").innerHTML = "";
    const modalEl = document.getElementById("patientModal");
    const bsModal = new bootstrap.Modal(modalEl);
    bsModal.show();
  }

  function updateRowNumbers() {
    let idx = 1;
    medicalTable.querySelectorAll("tr").forEach(tr => {
      tr.cells[0].textContent = idx++;
    });
  }

  function addTreatmentLine(tr, defaultType = "", defaultAmt = 0) {
    const container = tr.querySelector(".treatments-container");
    const lines = container.querySelectorAll(".treatment-line").length;
    if (lines >= 4) {
      alert("Max 4 treatments allowed!");
      return;
    }
    const div = document.createElement("div");
    div.classList.add("treatment-line", "d-flex", "gap-2", "mb-2", "align-items-center");
    div.innerHTML = `
          <select class="form-select treatment-type" style="width:40%;">
              <option value="">(Select)</option>
              <option value="Medicine">Medicine</option>
              <option value="Therapy">Therapy</option>
              <option value="Consultation">Consultation</option>
              <option value="OTC">OTC</option>
          </select>
          <input type="number" class="form-control treatment-amount" style="width:40%;" value="${defaultAmt}">
          <button type="button" class="btn btn-sm btn-danger remove-tx-line"><i class="fas fa-times"></i></button>
      `;
    container.appendChild(div);
    if (defaultType) {
      div.querySelector(".treatment-type").value = defaultType;
    }
    div.querySelector(".remove-tx-line").addEventListener("click", () => {
      div.remove();
      recalcRowTotal(tr);
    });
    div.querySelectorAll(".treatment-type, .treatment-amount").forEach(inp => {
      inp.addEventListener("input", () => recalcRowTotal(tr));
    });
  }

  function recalcRowTotal(tr) {
    let sumTx = 0;
    tr.querySelectorAll(".treatment-line").forEach(ln => {
      const amt = parseFloat(ln.querySelector(".treatment-amount").value) || 0;
      sumTx += amt;
    });
    // Update total is used internally (if needed)
    // Now calculate balance = sum treatments - discount
    const discountVal = parseFloat(tr.querySelector(".discount").value) || 0;
    let balance = sumTx - discountVal;
    if (balance < 0) balance = 0;
    tr.querySelector(".balance").value = balance.toFixed(2);
  }

  function updateMSR() {
    if (!msrDataGlobal.length) {
      alert("No MSR data loaded!");
      return;
    }
    const msrId = msrDataGlobal[0].msr_id || 0;
    if (!msrId) {
      alert("No valid MSR ID found.");
      return;
    }
    const rows = [];
    medicalTable.querySelectorAll("tr").forEach(tr => {
      const mpId = parseInt(tr.querySelector(".msr-patient-id").value) || 0;
      const pId = parseInt(tr.querySelector(".patient-id").value) || 0;
      const ref = tr.querySelector(".reference-input").value.trim();
      const meds = tr.querySelector(".medicines-notes").value.trim();
      let tArr = [];
      tr.querySelectorAll(".treatment-line").forEach(ln => {
        const ttype = ln.querySelector(".treatment-type").value || "";
        const tamt = parseFloat(ln.querySelector(".treatment-amount").value) || 0;
        if (ttype && tamt > 0) {
          tArr.push({ type: ttype, amount: tamt });
        }
      });
      const treatmentsStr = JSON.stringify(tArr);
      const disc = parseFloat(tr.querySelector(".discount").value) || 0;
      const balance = parseFloat(tr.querySelector(".balance").value) || 0;
      rows.push({
        msr_patient_id: mpId,
        patient_id: pId,
        reference: ref,
        medicines: meds,
        treatments: treatmentsStr,
        payment_type: "Cash",
        discount: disc,
        total_paid: 0,
        balance: balance
      });
    });
    if (!rows.length) {
      alert("No rows to update!");
      return;
    }
    const payLoad = {
      msr_id: msrDataGlobal[0].msr_id,
      rows: rows,
      deletedRows: deletedRows
    };
    fetch(`${baseURL}actions/msr/update_msr_action.php`, {
      method: "POST",
      headers: { "Content-Type": "application/json" },
      body: JSON.stringify(payLoad)
    })
      .then(r => r.json())
      .then(resp => {
        if (!resp.success) {
          alert("Error updating MSR: " + resp.message);
          return;
        }
        alert("MSR updated successfully!");
        window.location.href = `${baseURL}pages/msr/viewMsr.php?id=${msrDataGlobal[0].msr_id}`;
      })
      .catch(err => {
        console.error("updateMSR error:", err);
        alert("An error occurred updating MSR.");
      });
  }

  function formatDateYYYYMMDD(dt) {
    let mm = dt.getMonth() + 1,
      dd = dt.getDate(),
      yy = dt.getFullYear();
    if (mm < 10) mm = "0" + mm;
    if (dd < 10) dd = "0" + dd;
    return `${yy}-${mm}-${dd}`;
  }

  // -------- Payment History Modal Functions --------
  function loadPaymentHistory(debtsId) {
    const historyContent = document.getElementById("paymentHistoryContent");
    historyContent.innerHTML = "<div class='text-center p-3'>Loading...</div>";
    fetch(`${baseURL}actions/debt/get_payments.php?debts_id=${debtsId}`)
      .then(r => r.json())
      .then(resp => {
        if (!resp.success) {
          historyContent.innerHTML = "<div class='text-danger p-3'>Failed to load payment history.</div>";
          return;
        }
        let html = "<table class='table table-bordered table-responsive'><thead><tr>" +
          "<th>Payment Date</th><th>Amount (RM)</th><th>Type</th><th>Remarks</th><th>Receipts</th><th>Action</th>" +
          "</tr></thead><tbody>";
        resp.payments.forEach(payment => {
          let receiptsHtml = "";
          if (payment.receipts.length > 0) {
            receiptsHtml = payment.receipts.map(r => {
              // Extract only the file name from the file path.
              const fileName = r.file_path.split('/').pop();
              return `<a href="${baseURL}${r.file_path}" target="_blank">${fileName}</a>`;
            }).join("<br>");
          } else {
            receiptsHtml = "-";
          }
          html += `<tr>
                      <td>${payment.pay_date}</td>
                      <td>${payment.pay_amount.toFixed(2)}</td>
                      <td>${payment.payment_type}</td>
                      <td>${payment.remarks}</td>
                      <td>${receiptsHtml}</td>
                      <td><button class="btn btn-sm btn-primary edit-payment-btn" data-payment='${JSON.stringify(payment)}'>Edit</button></td>
                  </tr>`;
        });
        html += "</tbody></table>";
        historyContent.innerHTML = html;
        document.querySelectorAll(".edit-payment-btn").forEach(btn => {
          btn.addEventListener("click", () => {
            const paymentData = JSON.parse(btn.getAttribute("data-payment"));
            openEditPaymentModal(paymentData);
          });
        });
      })
      .catch(err => {
        console.error("Error loading payment history:", err);
        historyContent.innerHTML = "<div class='text-danger p-3'>Error loading payment history.</div>";
      });
  }

  function openEditPaymentModal(payment) {
    document.getElementById("editPaymentId").value = payment.payment_id;
    document.getElementById("editDebtsId").value = payment.debts_id || "";
    document.getElementById("editPayAmount").value = payment.pay_amount;
    // Convert pay_date to YYYY-MM-DD format
    let pd = new Date(payment.pay_date);
    document.getElementById("editPayDate").value = pd.toISOString().substring(0, 10);
    document.getElementById("editPayType").value = payment.payment_type;
    document.getElementById("editPayRemarks").value = payment.remarks;
    // Populate existing receipts: display only short filename as hyperlink.
    const existingReceiptsDiv = document.getElementById("existingReceipts");
    existingReceiptsDiv.innerHTML = "";
    if (payment.receipts && payment.receipts.length > 0) {
      payment.receipts.forEach((obj) => {
        const fileName = obj.file_path.split('/').pop();
        existingReceiptsDiv.innerHTML += `<div class="existing-receipt p-2 border mb-2" data-receipt-id="${obj.id}">
                  <a href="${baseURL}${obj.file_path}" target="_blank">${fileName}</a>
                  <button type="button" class="btn btn-sm btn-danger delete-receipt-btn ms-2" data-receipt-id="${obj.id}">Delete</button>
              </div>`;
      });
    } else {
      existingReceiptsDiv.innerHTML = "<p>No existing receipts.</p>";
    }
    // Set the hidden patientName field (assumes an element with id "patientName" exists in the edit form)
    document.getElementById("editPatientName").value = document.getElementById("patientName").value;
    const editModal = new bootstrap.Modal(document.getElementById("editPaymentModal"));
    editModal.show();
  }
});
