<?php

/**
 * globalAppointments.php
 *
 * GLOBAL (ALL-PATIENTS) APPOINTMENTS PAGE
 * Incorporates logic from patientProfile.php (Appointments tab) plus
 * updated features like staff no-backdate, auto-create diagnosis, and
 * insertion into appointments_history.
 */

// Adjust your includes as needed
include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// Prevent caching
header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");
header("Pragma: no-cache");

// 1) Check user session
$currentUserID = $_SESSION['user_id'] ?? null;
$userRole      = $_SESSION['role']    ?? 'staff';
if (!$currentUserID) {
    die("No valid user session found. Please log in.");
}

// 2) Flash messages
if (!isset($_SESSION['error'])) {
    $_SESSION['error'] = '';
}
if (!isset($_SESSION['success'])) {
    $_SESSION['success'] = '';
}
$errorMsg   = $_SESSION['error'];
$successMsg = $_SESSION['success'];
$_SESSION['error']   = '';
$_SESSION['success'] = '';

// 3) Helper function: Insert into appointments_history
function insertAppointmentHistory(mysqli $conn, array $oldData, int $editedBy, string $actionType)
{
    $sql = "
        INSERT INTO appointments_history (
          AppointmentID,
          PatientID,
          FollowUpID,
          AppointmentDate,
          AppointmentTime,
          Purpose,
          Status,
          Remarks,
          EditedBy,
          EditedAt,
          ActionType
        ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, NOW(), ?)
    ";
    $stmt = $conn->prepare($sql);
    if (!$stmt) {
        error_log("insertAppointmentHistory error: " . $conn->error);
        return;
    }
    $stmt->bind_param(
        'iiisssssis',
        $oldData['AppointmentID'],
        $oldData['PatientID'],
        $oldData['FollowUpID'],
        $oldData['AppointmentDate'],
        $oldData['AppointmentTime'],
        $oldData['Purpose'],
        $oldData['Status'],
        $oldData['Remarks'],
        $editedBy,
        $actionType
    );
    $stmt->execute();
    $stmt->close();
}

// 4) Staff no-backdate check
function staffNoBackdateCheck($date, $time = '00:00:00'): bool
{
    // If user is staff, the appointment date/time must be >= now
    $now = date('Y-m-d H:i:s');
    $testDT = $date . ' ' . $time;
    return ($testDT < $now); // if true => it's backdated
}

// 5) POST actions: Add/Edit/Delete
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $action = $_POST['appt_action'] ?? '';

    // ADD Appointment
    if ($action === 'addAppointment') {
        $pID        = (int)($_POST['patient_id'] ?? 0);
        $apptDate   = $_POST['appointment_date'] ?? date('Y-m-d');
        $apptTime   = $_POST['appointment_time'] ?? '09:00:00';
        $purpose    = trim($_POST['purpose']      ?? '');
        $status     = $_POST['status']           ?? 'Scheduled';
        $remarks    = trim($_POST['remarks']      ?? '');
        $autoCreate = !empty($_POST['auto_create_diagnosis']);

        // staff => no backdate
        if ($userRole === 'staff') {
            if (staffNoBackdateCheck($apptDate, $apptTime)) {
                $_SESSION['error'] = "Staff cannot create an appointment in the past.";
                header("Location: globalAppointments.php");
                exit;
            }
        }
        if ($pID <= 0) {
            $_SESSION['error'] = "Invalid Patient ID.";
            header("Location: globalAppointments.php");
            exit;
        }
        if (empty($purpose)) {
            $_SESSION['error'] = "Purpose cannot be empty.";
            header("Location: globalAppointments.php");
            exit;
        }

        // Insert
        $conn->begin_transaction();
        try {
            $sqlA = "
                INSERT INTO appointments (
                    PatientID,
                    AppointmentDate,
                    AppointmentTime,
                    Purpose,
                    Status,
                    Remarks,
                    CreatedBy,
                    UpdatedBy,
                    CreatedAt,
                    UpdatedAt
                ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, NOW(), NOW())
            ";
            $stmtA = $conn->prepare($sqlA);
            $stmtA->bind_param(
                'isssssii',
                $pID,
                $apptDate,
                $apptTime,
                $purpose,
                $status,
                $remarks,
                $currentUserID,
                $currentUserID
            );
            $stmtA->execute();
            $newAID = $stmtA->insert_id;
            $stmtA->close();

            // Insert into appointments_history => 'ADD'
            if ($newAID > 0) {
                $rowAp = [
                    'AppointmentID'   => $newAID,
                    'PatientID'       => $pID,
                    'FollowUpID'      => null,
                    'AppointmentDate' => $apptDate,
                    'AppointmentTime' => $apptTime,
                    'Purpose'         => $purpose,
                    'Status'          => $status,
                    'Remarks'         => $remarks
                ];
                insertAppointmentHistory($conn, $rowAp, $currentUserID, 'ADD');
            }

            // If auto_create_diagnosis
            if ($autoCreate && $newAID > 0) {
                $dxSQL = "
                  INSERT INTO diagnoses (
                    PatientID,
                    AppointmentID,
                    Diagnosis,
                    CreatedBy,
                    UpdatedBy,
                    CreatedAt,
                    UpdatedAt
                  ) VALUES (?, ?, 'Auto-created Diagnosis', ?, ?, NOW(), NOW())
                ";
                $stDx = $conn->prepare($dxSQL);
                $stDx->bind_param('iiii', $pID, $newAID, $currentUserID, $currentUserID);
                $stDx->execute();
                $stDx->close();
            }

            $conn->commit();
            $_SESSION['success'] = "Appointment added (#{$newAID}).";
        } catch (Exception $ex) {
            $conn->rollback();
            $_SESSION['error'] = "Error adding appointment: " . $ex->getMessage();
        }
        header("Location: globalAppointments.php");
        exit;
    }

    // EDIT Appointment
    elseif ($action === 'editAppointment') {
        $apptID   = (int)($_POST['appointment_id'] ?? 0);
        $pID      = (int)($_POST['patient_id']     ?? 0);
        $apptDate = $_POST['appointment_date']     ?? date('Y-m-d');
        $apptTime = $_POST['appointment_time']     ?? '09:00:00';
        $purpose  = trim($_POST['purpose']         ?? '');
        $status   = $_POST['status']               ?? 'Scheduled';
        $remarks  = trim($_POST['remarks']         ?? '');

        // staff => no backdate
        if ($userRole === 'staff') {
            if (staffNoBackdateCheck($apptDate, $apptTime)) {
                $_SESSION['error'] = "Staff cannot backdate an appointment.";
                header("Location: globalAppointments.php");
                exit;
            }
        }

        // fetch old row
        $oldSQL = "SELECT * FROM appointments WHERE AppointmentID=? LIMIT 1";
        $stOld  = $conn->prepare($oldSQL);
        $stOld->bind_param('i', $apptID);
        $stOld->execute();
        $resOld = $stOld->get_result();
        if ($resOld->num_rows < 1) {
            $_SESSION['error'] = "Appointment #$apptID not found.";
            header("Location: globalAppointments.php");
            exit;
        }
        $oldAp = $resOld->fetch_assoc();
        $stOld->close();

        $conn->begin_transaction();
        try {
            // update
            $upSQL = "
                UPDATE appointments
                SET PatientID=?,
                    AppointmentDate=?,
                    AppointmentTime=?,
                    Purpose=?,
                    Status=?,
                    Remarks=?,
                    UpdatedBy=?,
                    UpdatedAt=NOW()
                WHERE AppointmentID=?
            ";
            $stUp = $conn->prepare($upSQL);
            $stUp->bind_param(
                'isssssii',
                $pID,
                $apptDate,
                $apptTime,
                $purpose,
                $status,
                $remarks,
                $currentUserID,
                $apptID
            );
            $stUp->execute();
            $stUp->close();

            // Insert into appointments_history => 'EDIT' (store old data)
            $oldData = [
                'AppointmentID'   => (int)$oldAp['AppointmentID'],
                'PatientID'       => (int)$oldAp['PatientID'],
                'FollowUpID'      => $oldAp['FollowUpID'] ? (int)$oldAp['FollowUpID'] : null,
                'AppointmentDate' => $oldAp['AppointmentDate'],
                'AppointmentTime' => $oldAp['AppointmentTime'],
                'Purpose'         => $oldAp['Purpose'],
                'Status'          => $oldAp['Status'],
                'Remarks'         => $oldAp['Remarks']
            ];
            insertAppointmentHistory($conn, $oldData, $currentUserID, 'EDIT');

            $conn->commit();
            $_SESSION['success'] = "Appointment #{$apptID} updated.";
        } catch (Exception $ex) {
            $conn->rollback();
            $_SESSION['error'] = "Error updating: " . $ex->getMessage();
        }
        header("Location: globalAppointments.php");
        exit;
    }

    // DELETE Appointment
    elseif ($action === 'deleteAppointment') {
        // staff cannot delete
        if ($userRole === 'staff') {
            $_SESSION['error'] = "Staff cannot delete appointments.";
            header("Location: globalAppointments.php");
            exit;
        }
        $apptID = (int)($_POST['appointment_id'] ?? 0);

        // fetch old
        $oldSQL = "SELECT * FROM appointments WHERE AppointmentID=? LIMIT 1";
        $sOld   = $conn->prepare($oldSQL);
        $sOld->bind_param('i', $apptID);
        $sOld->execute();
        $rOld = $sOld->get_result();
        $oldAp = null;
        if ($rOld->num_rows > 0) {
            $oldAp = $rOld->fetch_assoc();
        }
        $sOld->close();

        if ($oldAp) {
            $conn->begin_transaction();
            try {
                $delQ = "DELETE FROM appointments WHERE AppointmentID=?";
                $stD  = $conn->prepare($delQ);
                $stD->bind_param('i', $apptID);
                $stD->execute();
                $stD->close();

                // Insert appointments_history => 'DELETE'
                $rowData = [
                    'AppointmentID'   => (int)$oldAp['AppointmentID'],
                    'PatientID'       => (int)$oldAp['PatientID'],
                    'FollowUpID'      => $oldAp['FollowUpID'] ? (int)$oldAp['FollowUpID'] : null,
                    'AppointmentDate' => $oldAp['AppointmentDate'],
                    'AppointmentTime' => $oldAp['AppointmentTime'],
                    'Purpose'         => $oldAp['Purpose'],
                    'Status'          => $oldAp['Status'],
                    'Remarks'         => $oldAp['Remarks']
                ];
                insertAppointmentHistory($conn, $rowData, $currentUserID, 'DELETE');

                $conn->commit();
                $_SESSION['success'] = "Appointment #$apptID deleted.";
            } catch (Exception $ex) {
                $conn->rollback();
                $_SESSION['error'] = "Error deleting appointment: " . $ex->getMessage();
            }
        }
        header("Location: globalAppointments.php");
        exit;
    }
}

// 6) Display page => GET => Filter / List
// build dynamic WHERE
$startDate   = $_GET['start_date']   ?? '';
$endDate     = $_GET['end_date']     ?? '';
$searchName  = $_GET['search_name']  ?? '';
$filterAppt  = isset($_GET['appointment_id']) ? (int)$_GET['appointment_id'] : 0;
$filterStat  = $_GET['status']       ?? ''; // 'Scheduled','Completed','Cancelled','' => all

$whereClauses = [];
if (
    preg_match('/^\d{4}-\d{2}-\d{2}$/', $startDate) &&
    preg_match('/^\d{4}-\d{2}-\d{2}$/', $endDate)
) {
    $whereClauses[] = "DATE(a.AppointmentDate) BETWEEN '$startDate' AND '$endDate'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $startDate)) {
    $whereClauses[] = "DATE(a.AppointmentDate) >= '$startDate'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $endDate)) {
    $whereClauses[] = "DATE(a.AppointmentDate) <= '$endDate'";
}

// Filter by name => join patients
if (!empty($searchName)) {
    $escName = $conn->real_escape_string($searchName);
    $whereClauses[] = "(p.first_name LIKE '%$escName%' OR p.last_name LIKE '%$escName%')";
}

// Filter by appointment_id
if ($filterAppt > 0) {
    $whereClauses[] = "a.AppointmentID = $filterAppt";
}

// Filter by Status
if (in_array($filterStat, ['Scheduled', 'Completed', 'Cancelled'], true)) {
    $whereClauses[] = "a.Status='$filterStat'";
}

$fullWhere = '';
if (!empty($whereClauses)) {
    $fullWhere = 'WHERE ' . implode(' AND ', $whereClauses);
}

// pagination
$recordsPerPage = 10;
$page = isset($_GET['pg']) ? (int)$_GET['pg'] : 1;
if ($page < 1) $page = 1;
$offset = ($page - 1) * $recordsPerPage;

// Count
$countSQL = "
  SELECT COUNT(a.AppointmentID) AS total
  FROM appointments a
  LEFT JOIN patients p ON a.PatientID=p.id
  $fullWhere
";
$resCount = $conn->query($countSQL);
$total = (int)($resCount->fetch_assoc()['total'] ?? 0);
$totalPages = ceil($total / $recordsPerPage);

// Fetch
$sql = "
  SELECT
    a.*,
    p.first_name AS p_first,
    p.last_name  AS p_last,
    u1.username  AS created_by_name,
    u2.username  AS updated_by_name,
    (
      SELECT COUNT(d.DiagnosisID)
      FROM diagnoses d
      WHERE d.AppointmentID=a.AppointmentID
    ) AS diag_count
  FROM appointments a
  LEFT JOIN patients p ON a.PatientID=p.id
  LEFT JOIN users u1   ON a.CreatedBy=u1.id
  LEFT JOIN users u2   ON a.UpdatedBy=u2.id
  $fullWhere
  ORDER BY a.AppointmentDate DESC, a.AppointmentTime DESC
  LIMIT $recordsPerPage OFFSET $offset
";
$resMain = $conn->query($sql);
$appointments = [];
if ($resMain && $resMain->num_rows > 0) {
    while ($row = $resMain->fetch_assoc()) {
        $appointments[] = $row;
    }
}
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <title>Global Appointments</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">
    <link href="<?php echo $baseURL; ?>assets/css/styles.css" rel="stylesheet">
</head>

<body>
    <div id="wrapper">
        <?php include ROOT_PATH . 'includes/navbar.php'; ?>
        <div id="page-content-wrapper">
            <?php include ROOT_PATH . 'includes/sidebar.php'; ?>

            <div class="container-fluid mt-4">
                <!-- error/success -->
                <?php if (!empty($errorMsg)): ?>
                    <div class="alert alert-danger">
                        <i class="fas fa-exclamation-triangle"></i> <?php echo $errorMsg; ?>
                    </div>
                <?php endif; ?>
                <?php if (!empty($successMsg)): ?>
                    <div class="alert alert-success">
                        <i class="fas fa-check-circle"></i> <?php echo htmlspecialchars($successMsg); ?>
                    </div>
                <?php endif; ?>

                <div class="card mb-3">
                    <div class="card-body bg-primary text-white text-center rounded">
                        <h4 class="card-title mb-1">All Appointments</h4>
                        <p class="mb-0">Manage &amp; View Appointments Across All Patients</p>
                    </div>
                </div>

                <!-- Filter Form -->
                <form class="row g-3 mb-3">
                    <div class="col-md-2">
                        <label class="form-label">Start Date</label>
                        <input type="date" class="form-control" name="start_date" value="<?php echo htmlspecialchars($startDate); ?>">
                    </div>
                    <div class="col-md-2">
                        <label class="form-label">End Date</label>
                        <input type="date" class="form-control" name="end_date" value="<?php echo htmlspecialchars($endDate); ?>">
                    </div>
                    <div class="col-md-2">
                        <label class="form-label">Patient Name</label>
                        <input type="text" class="form-control" name="search_name" value="<?php echo htmlspecialchars($searchName); ?>">
                    </div>
                    <div class="col-md-2">
                        <label class="form-label">Status</label>
                        <select name="status" class="form-select">
                            <option value="">All</option>
                            <option value="Scheduled" <?php if ($filterStat === 'Scheduled') echo 'selected'; ?>>Scheduled</option>
                            <option value="Completed" <?php if ($filterStat === 'Completed') echo 'selected'; ?>>Completed</option>
                            <option value="Cancelled" <?php if ($filterStat === 'Cancelled') echo 'selected'; ?>>Cancelled</option>
                        </select>
                    </div>
                    <div class="col-md-2">
                        <label class="form-label">Appointment ID</label>
                        <input type="number" class="form-control" name="appointment_id" value="<?php echo ($filterAppt > 0 ? $filterAppt : ''); ?>">
                    </div>
                    <div class="col-md-2 d-flex align-items-end">
                        <button class="btn btn-primary w-100"><i class="fas fa-filter"></i> Filter</button>
                    </div>
                </form>

                <!-- Add Button -->
                <div class="text-end mb-3">
                    <button class="btn btn-success" data-bs-toggle="modal" data-bs-target="#addAppointmentModal">
                        <i class="fas fa-plus"></i> Add Appointment
                    </button>
                </div>

                <!-- Table -->
                <div class="table-responsive">
                    <table class="table table-bordered text-center align-middle">
                        <thead class="table-light">
                            <tr>
                                <th>ID</th>
                                <th>Patient</th>
                                <th>Date/Time</th>
                                <th>Purpose</th>
                                <th>Status</th>
                                <th>Remarks</th>
                                <th>Diagnosis?</th>
                                <th>Actions</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (!empty($appointments)): ?>
                                <?php foreach ($appointments as $apt): ?>
                                    <?php
                                    $aptID   = (int)$apt['AppointmentID'];
                                    $pName   = trim($apt['p_first'] . ' ' . $apt['p_last']);
                                    $aptData = [
                                        'AppointmentID'   => $aptID,
                                        'PatientID'       => $apt['PatientID'],
                                        'AppointmentDate' => $apt['AppointmentDate'],
                                        'AppointmentTime' => $apt['AppointmentTime'],
                                        'Purpose'         => $apt['Purpose'],
                                        'Status'          => $apt['Status'],
                                        'Remarks'         => $apt['Remarks']
                                    ];
                                    // Trim time to HH:MM if desired:
                                    $timeStr = substr($apt['AppointmentTime'], 0, 5);
                                    ?>
                                    <tr>
                                        <td><?php echo $aptID; ?></td>
                                        <td><?php echo htmlspecialchars($pName) . " (ID:{$apt['PatientID']})"; ?></td>
                                        <td>
                                            <?php echo htmlspecialchars($apt['AppointmentDate']) . ' '; ?>
                                            <?php echo $timeStr; ?>
                                        </td>
                                        <td><?php echo htmlspecialchars($apt['Purpose']); ?></td>
                                        <td>
                                            <?php if ($apt['Status'] === 'Completed'): ?>
                                                <span class="badge bg-success">Completed</span>
                                            <?php elseif ($apt['Status'] === 'Cancelled'): ?>
                                                <span class="badge bg-danger">Cancelled</span>
                                            <?php else: ?>
                                                <span class="badge bg-warning text-dark">Scheduled</span>
                                            <?php endif; ?>
                                        </td>
                                        <td style="white-space: pre-wrap;"><?php echo nl2br(htmlspecialchars($apt['Remarks'])); ?></td>
                                        <td>
                                            <?php if ($apt['diag_count'] > 0): ?>
                                                <span class="text-success fw-bold">Yes (<?php echo $apt['diag_count']; ?>)</span>
                                            <?php else: ?>
                                                <span class="text-muted">No</span>
                                            <?php endif; ?>
                                        </td>
                                        <td>
                                            <!-- EDIT -->
                                            <?php if ($userRole === 'staff' || $userRole === 'admin'): ?>
                                                <button class="btn btn-sm btn-warning"
                                                    data-bs-toggle="modal"
                                                    data-bs-target="#editAppointmentModal"
                                                    data-appointment='<?php echo json_encode($aptData); ?>'>
                                                    <i class="fas fa-edit"></i>
                                                </button>
                                            <?php endif; ?>

                                            <!-- DELETE => only admin -->
                                            <?php if ($userRole === 'admin'): ?>
                                                <form method="POST" class="d-inline-block" onsubmit="return confirm('Delete this appointment?');">
                                                    <input type="hidden" name="appt_action" value="deleteAppointment">
                                                    <input type="hidden" name="appointment_id" value="<?php echo $aptID; ?>">
                                                    <button class="btn btn-sm btn-danger"><i class="fas fa-trash"></i></button>
                                                </form>
                                            <?php endif; ?>

                                            <!-- Link to global Follow-Ups for this Appt, or a direct param -->
                                            <a href="<?php echo $baseURL; ?>pages/followUp/globalFollowUps.php?appointment_id=<?php echo $aptID; ?>"
                                                class="btn btn-sm btn-secondary">
                                                <i class="fas fa-calendar-check"></i> Follow-Ups
                                            </a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="8">No appointments found.</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <!-- Pagination -->
                <?php if ($totalPages > 1): ?>
                    <nav>
                        <ul class="pagination justify-content-center mt-3">
                            <!-- Prev -->
                            <?php if ($page > 1): ?>
                                <li class="page-item">
                                    <a class="page-link"
                                        href="?pg=<?php echo ($page - 1); ?>&start_date=<?php echo urlencode($startDate); ?>&end_date=<?php echo urlencode($endDate); ?>&search_name=<?php echo urlencode($searchName); ?>&status=<?php echo urlencode($filterStat); ?>&appointment_id=<?php echo $filterAppt; ?>">
                                        &laquo; Prev
                                    </a>
                                </li>
                            <?php else: ?>
                                <li class="page-item disabled"><span class="page-link">&laquo; Prev</span></li>
                            <?php endif; ?>

                            <!-- numbered pages -->
                            <?php for ($i = 1; $i <= $totalPages; $i++): ?>
                                <li class="page-item <?php if ($i == $page) echo 'active'; ?>">
                                    <a class="page-link"
                                        href="?pg=<?php echo $i; ?>&start_date=<?php echo urlencode($startDate); ?>&end_date=<?php echo urlencode($endDate); ?>&search_name=<?php echo urlencode($searchName); ?>&status=<?php echo urlencode($filterStat); ?>&appointment_id=<?php echo $filterAppt; ?>">
                                        <?php echo $i; ?>
                                    </a>
                                </li>
                            <?php endfor; ?>

                            <!-- Next -->
                            <?php if ($page < $totalPages): ?>
                                <li class="page-item">
                                    <a class="page-link"
                                        href="?pg=<?php echo ($page + 1); ?>&start_date=<?php echo urlencode($startDate); ?>&end_date=<?php echo urlencode($endDate); ?>&search_name=<?php echo urlencode($searchName); ?>&status=<?php echo urlencode($filterStat); ?>&appointment_id=<?php echo $filterAppt; ?>">
                                        Next &raquo;
                                    </a>
                                </li>
                            <?php else: ?>
                                <li class="page-item disabled"><span class="page-link">Next &raquo;</span></li>
                            <?php endif; ?>
                        </ul>
                    </nav>
                <?php endif; ?>
            </div>
        </div>
    </div>

    <!-- ADD APPOINTMENT MODAL -->
    <div class="modal fade" id="addAppointmentModal" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog">
            <form class="modal-content" method="POST">
                <input type="hidden" name="appt_action" value="addAppointment">
                <div class="modal-header">
                    <h5 class="modal-title">Add Appointment</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">

                    <!-- Choose Patient => or let them type ID or search -->
                    <div class="mb-3">
                        <label class="form-label">Patient ID</label>
                        <div class="input-group">
                            <input type="number" class="form-control" name="patient_id" required>
                            <!-- Optional: a "Search" button that opens a choose-patient modal -->
                        </div>
                    </div>

                    <div class="mb-3">
                        <label class="form-label">Appointment Date</label>
                        <input type="date" class="form-control" name="appointment_date" required
                            value="<?php echo date('Y-m-d'); ?>">
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Appointment Time</label>
                        <input type="time" class="form-control" name="appointment_time" required value="09:00">
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Purpose</label>
                        <input type="text" class="form-control" name="purpose" required>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Status</label>
                        <select class="form-select" name="status">
                            <option value="Scheduled">Scheduled</option>
                            <option value="Completed">Completed</option>
                            <option value="Cancelled">Cancelled</option>
                        </select>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Remarks</label>
                        <textarea class="form-control" name="remarks"></textarea>
                    </div>
                    <div class="form-check mb-3">
                        <input class="form-check-input" type="checkbox" id="auto_create_diagnosis" name="auto_create_diagnosis">
                        <label class="form-check-label" for="auto_create_diagnosis">
                            Auto-create a Diagnosis record?
                        </label>
                    </div>
                </div>
                <div class="modal-footer">
                    <button class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    <button class="btn btn-primary">Add Appointment</button>
                </div>
            </form>
        </div>
    </div>

    <!-- EDIT APPOINTMENT MODAL -->
    <div class="modal fade" id="editAppointmentModal" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog">
            <form class="modal-content" method="POST">
                <input type="hidden" name="appt_action" value="editAppointment">
                <input type="hidden" name="appointment_id" id="appointment_id_edit">
                <div class="modal-header">
                    <h5 class="modal-title">Edit Appointment</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">

                    <div class="mb-3">
                        <label class="form-label">Patient ID</label>
                        <input type="number" class="form-control" name="patient_id" id="patient_id_edit" required>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Appointment Date</label>
                        <input type="date" class="form-control" name="appointment_date" id="appointment_date_edit" required>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Appointment Time</label>
                        <input type="time" class="form-control" name="appointment_time" id="appointment_time_edit" required>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Purpose</label>
                        <input type="text" class="form-control" name="purpose" id="purpose_edit" required>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Status</label>
                        <select class="form-select" name="status" id="status_edit">
                            <option value="Scheduled">Scheduled</option>
                            <option value="Completed">Completed</option>
                            <option value="Cancelled">Cancelled</option>
                        </select>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Remarks</label>
                        <textarea class="form-control" name="remarks" id="remarks_edit"></textarea>
                    </div>

                </div>
                <div class="modal-footer">
                    <button class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    <button class="btn btn-warning">Update</button>
                </div>
            </form>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        document.addEventListener("DOMContentLoaded", function() {
            // fill "editAppointmentModal" upon show
            const editApptModalEl = document.getElementById("editAppointmentModal");
            if (editApptModalEl) {
                editApptModalEl.addEventListener("show.bs.modal", function(ev) {
                    const btn = ev.relatedTarget;
                    if (!btn) return;
                    const aptData = JSON.parse(btn.getAttribute("data-appointment") || "{}");
                    document.getElementById("appointment_id_edit").value = aptData.AppointmentID || "";
                    document.getElementById("patient_id_edit").value = aptData.PatientID || "";
                    document.getElementById("appointment_date_edit").value = aptData.AppointmentDate || "";
                    document.getElementById("appointment_time_edit").value = aptData.AppointmentTime || "09:00";
                    document.getElementById("purpose_edit").value = aptData.Purpose || "";
                    document.getElementById("status_edit").value = aptData.Status || "Scheduled";
                    document.getElementById("remarks_edit").value = aptData.Remarks || "";
                });
            }
        });
    </script>
</body>

</html>