<?php

/**
 * globalDiagnoses.php
 *
 * Lists & manages Diagnoses for all patients
 * Merges logic from patientProfile.php => "Diagnoses" tab
 * including staff restriction, insertion into diagnosis_history, etc.
 */

include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");
header("Pragma: no-cache");

// session + role
$currentUserID = $_SESSION['user_id'] ?? null;
$userRole      = $_SESSION['role']    ?? 'staff';
if (!$currentUserID) {
    die("No valid user session. Please log in.");
}

// flash
if (!isset($_SESSION['error']))   $_SESSION['error']   = '';
if (!isset($_SESSION['success'])) $_SESSION['success'] = '';
$errorMsg   = $_SESSION['error'];
$successMsg = $_SESSION['success'];
$_SESSION['error']   = '';
$_SESSION['success'] = '';

// Helper: Insert into diagnosis_history
function insertDiagnosisHistory(mysqli $conn, array $oldData, int $editedBy, string $actionType = 'EDIT')
{
    $sql = "
      INSERT INTO diagnosis_history (
        DiagnosisID,
        PatientID,
        AppointmentID,
        Diagnosis,
        TreatmentPlan,
        PrescribedMedication,
        FollowUpDate,
        Remarks,
        EditedBy,
        EditedAt,
        ActionType
      ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, NOW(), ?)
    ";
    $stmt = $conn->prepare($sql);
    if ($stmt) {
        $stmt->bind_param(
            'iiisssssis',
            $oldData['DiagnosisID'],
            $oldData['PatientID'],
            $oldData['AppointmentID'],
            $oldData['Diagnosis'],
            $oldData['TreatmentPlan'],
            $oldData['PrescribedMedication'],
            $oldData['FollowUpDate'],
            $oldData['Remarks'],
            $editedBy,
            $actionType
        );
        $stmt->execute();
        $stmt->close();
    }
}

// POST => add/edit/delete
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $diagAction = $_POST['diag_action'] ?? '';

    // ADD
    if ($diagAction === 'addDiagnosis') {
        if ($userRole === 'staff') {
            $_SESSION['error'] = "Staff cannot add diagnoses.";
            header("Location: globalDiagnoses.php");
            exit;
        }
        $pID    = (int)($_POST['patient_id']       ?? 0);
        $apptID = !empty($_POST['appointment_id']) ? (int)$_POST['appointment_id'] : null;
        $diag   = $_POST['diagnosis']             ?? '';
        $tPlan  = $_POST['treatment_plan']        ?? '';
        $pMeds  = $_POST['prescribed_meds']       ?? '';
        $fDate  = $_POST['followup_date']         ?? null;
        $rem    = $_POST['remarks']               ?? '';

        if ($pID <= 0 || empty($diag)) {
            $_SESSION['error'] = "Patient ID and Diagnosis text are required.";
            header("Location: globalDiagnoses.php");
            exit;
        }

        $sql = "
          INSERT INTO diagnoses (
            PatientID,
            AppointmentID,
            Diagnosis,
            TreatmentPlan,
            PrescribedMedication,
            FollowUpDate,
            Remarks,
            CreatedBy,
            UpdatedBy,
            CreatedAt,
            UpdatedAt
          ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, NOW(), NOW())
        ";
        $st = $conn->prepare($sql);
        $st->bind_param(
            'iisssssii',
            $pID,
            $apptID,
            $diag,
            $tPlan,
            $pMeds,
            $fDate,
            $rem,
            $currentUserID,
            $currentUserID
        );
        $st->execute();
        $newID = $st->insert_id;
        $st->close();
        $_SESSION['success'] = "Diagnosis #$newID added.";
        header("Location: globalDiagnoses.php");
        exit;
    }

    // EDIT
    elseif ($diagAction === 'editDiagnosis') {
        if ($userRole === 'staff') {
            $_SESSION['error'] = "Staff cannot edit diagnoses.";
            header("Location: globalDiagnoses.php");
            exit;
        }
        $diagID = (int)($_POST['diagnosis_id'] ?? 0);
        // fetch old
        $oldQ = "SELECT * FROM diagnoses WHERE DiagnosisID=? LIMIT 1";
        $stO  = $conn->prepare($oldQ);
        $stO->bind_param('i', $diagID);
        $stO->execute();
        $rO = $stO->get_result();
        if ($rO->num_rows < 1) {
            $_SESSION['error'] = "Diagnosis #$diagID not found.";
            header("Location: globalDiagnoses.php");
            exit;
        }
        $oldRow = $rO->fetch_assoc();
        $stO->close();

        $pID    = (int)($_POST['patient_id']       ?? 0);
        $apptID = !empty($_POST['appointment_id']) ? (int)$_POST['appointment_id'] : null;
        $diag   = $_POST['diagnosis']          ?? '';
        $tPlan  = $_POST['treatment_plan']     ?? '';
        $pMeds  = $_POST['prescribed_meds']    ?? '';
        $fDate  = $_POST['followup_date']      ?? null;
        $rem    = $_POST['remarks']            ?? '';

        // update
        $upQ = "
          UPDATE diagnoses
          SET AppointmentID=?,
              Diagnosis=?,
              TreatmentPlan=?,
              PrescribedMedication=?,
              FollowUpDate=?,
              Remarks=?,
              UpdatedBy=?,
              UpdatedAt=NOW()
          WHERE DiagnosisID=? AND PatientID=?
        ";
        $stU = $conn->prepare($upQ);
        $stU->bind_param(
            'isssssiii',
            $apptID,
            $diag,
            $tPlan,
            $pMeds,
            $fDate,
            $rem,
            $currentUserID,
            $diagID,
            $pID
        );
        $stU->execute();
        $stU->close();

        // insert diagnosis_history => 'EDIT'
        $oldData = [
            'DiagnosisID'          => (int)$oldRow['DiagnosisID'],
            'PatientID'            => (int)$oldRow['PatientID'],
            'AppointmentID'        => $oldRow['AppointmentID'] ? (int)$oldRow['AppointmentID'] : null,
            'Diagnosis'            => $oldRow['Diagnosis'],
            'TreatmentPlan'        => $oldRow['TreatmentPlan'],
            'PrescribedMedication' => $oldRow['PrescribedMedication'],
            'FollowUpDate'         => $oldRow['FollowUpDate'],
            'Remarks'              => $oldRow['Remarks']
        ];
        insertDiagnosisHistory($conn, $oldData, $currentUserID, 'EDIT');

        $_SESSION['success'] = "Diagnosis #$diagID updated.";
        header("Location: globalDiagnoses.php");
        exit;
    }

    // DELETE
    elseif ($diagAction === 'deleteDiagnosis') {
        if ($userRole === 'staff') {
            $_SESSION['error'] = "Staff cannot delete diagnoses.";
            header("Location: globalDiagnoses.php");
            exit;
        }
        $diagID = (int)($_POST['diagnosis_id'] ?? 0);
        if ($diagID > 0) {
            // fetch old
            $oQ = "SELECT * FROM diagnoses WHERE DiagnosisID=? LIMIT 1";
            $stO = $conn->prepare($oQ);
            $stO->bind_param('i', $diagID);
            $stO->execute();
            $rO = $stO->get_result();
            $oldRow = null;
            if ($rO->num_rows > 0) {
                $oldRow = $rO->fetch_assoc();
            }
            $stO->close();

            // delete
            $delQ = "DELETE FROM diagnoses WHERE DiagnosisID=?";
            $stD = $conn->prepare($delQ);
            $stD->bind_param('i', $diagID);
            $stD->execute();
            $stD->close();

            // history => 'DELETE'
            if ($oldRow) {
                $oldData = [
                    'DiagnosisID'          => (int)$oldRow['DiagnosisID'],
                    'PatientID'            => (int)$oldRow['PatientID'],
                    'AppointmentID'        => $oldRow['AppointmentID'] ? (int)$oldRow['AppointmentID'] : null,
                    'Diagnosis'            => $oldRow['Diagnosis'],
                    'TreatmentPlan'        => $oldRow['TreatmentPlan'],
                    'PrescribedMedication' => $oldRow['PrescribedMedication'],
                    'FollowUpDate'         => $oldRow['FollowUpDate'],
                    'Remarks'              => $oldRow['Remarks']
                ];
                insertDiagnosisHistory($conn, $oldData, $currentUserID, 'DELETE');
            }

            $_SESSION['success'] = "Diagnosis #$diagID deleted.";
        }
        header("Location: globalDiagnoses.php");
        exit;
    }
}

// GET => filter + list
$startD = $_GET['diag_start'] ?? '';
$endD   = $_GET['diag_end']   ?? '';
$searchNm = $_GET['search_name'] ?? '';
$apptID   = isset($_GET['appt_id']) ? (int)$_GET['appt_id'] : 0;

$whereClauses = [];
if (
    preg_match('/^\d{4}-\d{2}-\d{2}$/', $startD) &&
    preg_match('/^\d{4}-\d{2}-\d{2}$/', $endD)
) {
    $whereClauses[] = "DATE(d.CreatedAt) BETWEEN '$startD' AND '$endD'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $startD)) {
    $whereClauses[] = "DATE(d.CreatedAt) >= '$startD'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $endD)) {
    $whereClauses[] = "DATE(d.CreatedAt) <= '$endD'";
}
if (!empty($searchNm)) {
    $esc = $conn->real_escape_string($searchNm);
    // join with patients
    $whereClauses[] = "(p.first_name LIKE '%$esc%' OR p.last_name LIKE '%$esc%')";
}
if ($apptID > 0) {
    $whereClauses[] = "d.AppointmentID=$apptID";
}

$whereStr = '';
if (!empty($whereClauses)) {
    $whereStr = 'WHERE ' . implode(' AND ', $whereClauses);
}

// pagination
$perPage = 10;
$page   = isset($_GET['pg']) ? (int)$_GET['pg'] : 1;
if ($page < 1) $page = 1;
$offset = ($page - 1) * $perPage;

// count
$cQ = "
  SELECT COUNT(d.DiagnosisID) AS total
  FROM diagnoses d
  LEFT JOIN patients p ON d.PatientID=p.id
  $whereStr
";
$rC = $conn->query($cQ);
$total = (int)($rC->fetch_assoc()['total'] ?? 0);
$totalPages = ceil($total / $perPage);

// fetch
$sqlMain = "
  SELECT
    d.*,
    p.first_name AS p_first,
    p.last_name  AS p_last,
    a.AppointmentDate,
    a.AppointmentTime,
    u1.username AS created_by_name,
    u2.username AS updated_by_name
  FROM diagnoses d
  LEFT JOIN patients p     ON d.PatientID=p.id
  LEFT JOIN appointments a ON d.AppointmentID=a.AppointmentID
  LEFT JOIN users u1       ON d.CreatedBy=u1.id
  LEFT JOIN users u2       ON d.UpdatedBy=u2.id
  $whereStr
  ORDER BY d.CreatedAt DESC
  LIMIT $perPage OFFSET $offset
";
$resM = $conn->query($sqlMain);
$diagList = [];
if ($resM && $resM->num_rows > 0) {
    while ($row = $resM->fetch_assoc()) {
        $diagList[] = $row;
    }
}
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <title>Global Diagnoses</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">
    <link href="<?php echo $baseURL; ?>assets/css/styles.css" rel="stylesheet">
</head>

<body>
    <div id="wrapper">
        <?php include ROOT_PATH . 'includes/navbar.php'; ?>
        <div id="page-content-wrapper">
            <?php include ROOT_PATH . 'includes/sidebar.php'; ?>

            <div class="container-fluid mt-4">
                <?php if ($errorMsg): ?>
                    <div class="alert alert-danger">
                        <i class="fas fa-exclamation-triangle"></i>
                        <?php echo htmlspecialchars($errorMsg); ?>
                    </div>
                <?php endif; ?>
                <?php if ($successMsg): ?>
                    <div class="alert alert-success">
                        <i class="fas fa-check-circle"></i>
                        <?php echo htmlspecialchars($successMsg); ?>
                    </div>
                <?php endif; ?>

                <div class="card mb-3">
                    <div class="card-body bg-primary text-white text-center rounded">
                        <h4 class="card-title mb-1">All Diagnoses</h4>
                        <p class="mb-0">Manage diagnoses across all patients</p>
                    </div>
                </div>

                <!-- filter -->
                <form class="row g-3 mb-3">
                    <div class="col-md-2">
                        <label class="form-label">Start Date</label>
                        <input type="date" class="form-control" name="diag_start" value="<?php echo htmlspecialchars($startD); ?>">
                    </div>
                    <div class="col-md-2">
                        <label class="form-label">End Date</label>
                        <input type="date" class="form-control" name="diag_end" value="<?php echo htmlspecialchars($endD); ?>">
                    </div>
                    <div class="col-md-2">
                        <label class="form-label">Patient Name</label>
                        <input type="text" class="form-control" name="search_name" value="<?php echo htmlspecialchars($searchNm); ?>">
                    </div>
                    <div class="col-md-2">
                        <label class="form-label">Appointment ID</label>
                        <input type="number" class="form-control" name="appt_id" value="<?php echo $apptID > 0 ? $apptID : ''; ?>">
                    </div>
                    <div class="col-md-2 d-flex align-items-end">
                        <button class="btn btn-primary w-100"><i class="fas fa-filter"></i> Filter</button>
                    </div>
                </form>

                <!-- add diag if admin -->
                <?php if ($userRole === 'admin'): ?>
                    <div class="text-end mb-3">
                        <button class="btn btn-success" data-bs-toggle="modal" data-bs-target="#addDiagnosisModal">
                            <i class="fas fa-plus"></i> Add Diagnosis
                        </button>
                    </div>
                <?php endif; ?>

                <div class="table-responsive">
                    <table class="table table-bordered text-center align-middle">
                        <thead class="table-light">
                            <tr>
                                <th>ID</th>
                                <th>Patient</th>
                                <th>Diagnosis</th>
                                <th>Treatment Plan</th>
                                <th>Prescribed Meds</th>
                                <th>FollowUpDate</th>
                                <th>Appointment</th>
                                <th>Actions</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (!empty($diagList)): ?>
                                <?php foreach ($diagList as $dg):
                                    $dgID = (int)$dg['DiagnosisID'];
                                    $pName = trim($dg['p_first'] . ' ' . $dg['p_last']);
                                    $dgData = [
                                        'DiagnosisID' => $dgID,
                                        'PatientID' => $dg['PatientID'],
                                        'AppointmentID' => $dg['AppointmentID'],
                                        'Diagnosis' => $dg['Diagnosis'],
                                        'TreatmentPlan' => $dg['TreatmentPlan'],
                                        'PrescribedMedication' => $dg['PrescribedMedication'],
                                        'FollowUpDate' => $dg['FollowUpDate'],
                                        'Remarks' => $dg['Remarks']
                                    ];
                                ?>
                                    <tr>
                                        <td><?php echo $dgID; ?></td>
                                        <td><?php echo htmlspecialchars($pName) . " (ID:{$dg['PatientID']})"; ?></td>
                                        <td style="white-space:pre-wrap;"><?php echo nl2br(htmlspecialchars($dg['Diagnosis'] ?? '')); ?></td>
                                        <td style="white-space:pre-wrap;"><?php echo nl2br(htmlspecialchars($dg['TreatmentPlan'] ?? '')); ?></td>
                                        <td style="white-space:pre-wrap;"><?php echo nl2br(htmlspecialchars($dg['PrescribedMedication'] ?? '')); ?></td>
                                        <td><?php echo $dg['FollowUpDate'] ?: '-'; ?></td>
                                        <td>
                                            <?php if ($dg['AppointmentID']): ?>
                                                <a href="<?php echo $baseURL; ?>pages/appointments/globalAppointments.php?appointment_id=<?php echo $dg['AppointmentID']; ?>"
                                                    class="btn btn-sm btn-info" target="_blank">
                                                    Appt #<?php echo $dg['AppointmentID']; ?>
                                                </a>
                                            <?php else: ?>
                                                <em class="text-muted">N/A</em>
                                            <?php endif; ?>
                                        </td>
                                        <td>
                                            <?php if ($userRole === 'admin'): ?>
                                                <button class="btn btn-sm btn-warning"
                                                    data-bs-toggle="modal"
                                                    data-bs-target="#editDiagnosisModal"
                                                    data-diagnosis='<?php echo json_encode($dgData); ?>'>
                                                    <i class="fas fa-edit"></i>
                                                </button>
                                                <form method="POST" class="d-inline-block" onsubmit="return confirm('Delete this diagnosis?');">
                                                    <input type="hidden" name="diag_action" value="deleteDiagnosis">
                                                    <input type="hidden" name="diagnosis_id" value="<?php echo $dgID; ?>">
                                                    <button class="btn btn-sm btn-danger">
                                                        <i class="fas fa-trash"></i>
                                                    </button>
                                                </form>
                                            <?php else: ?>
                                                <em class="text-muted">No Edit</em>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="8">No diagnoses found.</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <?php if ($totalPages > 1): ?>
                    <nav class="mt-3">
                        <ul class="pagination justify-content-center">
                            <!-- prev -->
                            <?php if ($page > 1): ?>
                                <li class="page-item">
                                    <a class="page-link"
                                        href="?pg=<?php echo ($page - 1); ?>&diag_start=<?php echo urlencode($startD); ?>&diag_end=<?php echo urlencode($endD); ?>&search_name=<?php echo urlencode($searchNm); ?>&appt_id=<?php echo $apptID; ?>">
                                        &laquo; Prev
                                    </a>
                                </li>
                            <?php else: ?>
                                <li class="page-item disabled"><span class="page-link">&laquo; Prev</span></li>
                            <?php endif; ?>

                            <?php for ($i = 1; $i <= $totalPages; $i++): ?>
                                <li class="page-item <?php if ($i == $page) echo 'active'; ?>">
                                    <a class="page-link"
                                        href="?pg=<?php echo $i; ?>&diag_start=<?php echo urlencode($startD); ?>&diag_end=<?php echo urlencode($endD); ?>&search_name=<?php echo urlencode($searchNm); ?>&appt_id=<?php echo $apptID; ?>">
                                        <?php echo $i; ?>
                                    </a>
                                </li>
                            <?php endfor; ?>

                            <!-- next -->
                            <?php if ($page < $totalPages): ?>
                                <li class="page-item">
                                    <a class="page-link"
                                        href="?pg=<?php echo ($page + 1); ?>&diag_start=<?php echo urlencode($startD); ?>&diag_end=<?php echo urlencode($endD); ?>&search_name=<?php echo urlencode($searchNm); ?>&appt_id=<?php echo $apptID; ?>">
                                        Next &raquo;
                                    </a>
                                </li>
                            <?php else: ?>
                                <li class="page-item disabled"><span class="page-link">Next &raquo;</span></li>
                            <?php endif; ?>
                        </ul>
                    </nav>
                <?php endif; ?>

            </div><!-- container -->
        </div><!-- page-content-wrapper -->
    </div><!-- wrapper -->

    <!-- ADD DIAGNOSIS Modal (admin only) -->
    <div class="modal fade" id="addDiagnosisModal" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog">
            <form class="modal-content" method="POST">
                <input type="hidden" name="diag_action" value="addDiagnosis">
                <div class="modal-header">
                    <h5 class="modal-title">Add Diagnosis</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <div class="mb-3">
                        <label class="form-label">Patient ID</label>
                        <input type="number" class="form-control" name="patient_id" required>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Appointment ID (optional)</label>
                        <input type="number" class="form-control" name="appointment_id">
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Diagnosis</label>
                        <textarea class="form-control" name="diagnosis" required></textarea>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Treatment Plan</label>
                        <textarea class="form-control" name="treatment_plan"></textarea>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Prescribed Medication</label>
                        <textarea class="form-control" name="prescribed_meds"></textarea>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Follow-Up Date</label>
                        <input type="date" class="form-control" name="followup_date">
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Remarks</label>
                        <textarea class="form-control" name="remarks"></textarea>
                    </div>
                </div>
                <div class="modal-footer">
                    <button class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    <button class="btn btn-primary">Add Diagnosis</button>
                </div>
            </form>
        </div>
    </div>

    <!-- EDIT DIAGNOSIS Modal -->
    <div class="modal fade" id="editDiagnosisModal" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog">
            <form class="modal-content" method="POST">
                <input type="hidden" name="diag_action" value="editDiagnosis">
                <input type="hidden" name="diagnosis_id" id="diagnosis_id_edit">
                <div class="modal-header">
                    <h5 class="modal-title">Edit Diagnosis</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <div class="mb-3">
                        <label class="form-label">Patient ID</label>
                        <input type="number" class="form-control" name="patient_id" id="patient_id_edit_diag" required>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Appointment ID (optional)</label>
                        <input type="number" class="form-control" name="appointment_id" id="appointment_id_edit_diag">
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Diagnosis</label>
                        <textarea class="form-control" name="diagnosis" id="diagnosis_edit_diag" required></textarea>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Treatment Plan</label>
                        <textarea class="form-control" name="treatment_plan" id="treatment_plan_edit_diag"></textarea>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Prescribed Medication</label>
                        <textarea class="form-control" name="prescribed_meds" id="prescribed_meds_edit_diag"></textarea>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Follow-Up Date</label>
                        <input type="date" class="form-control" name="followup_date" id="followup_date_edit_diag">
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Remarks</label>
                        <textarea class="form-control" name="remarks" id="remarks_edit_diag"></textarea>
                    </div>
                </div>
                <div class="modal-footer">
                    <button class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    <button class="btn btn-warning">Update Diagnosis</button>
                </div>
            </form>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        document.addEventListener("DOMContentLoaded", function() {
            const editDiagEl = document.getElementById("editDiagnosisModal");
            if (editDiagEl) {
                editDiagEl.addEventListener("show.bs.modal", function(evt) {
                    const btn = evt.relatedTarget;
                    if (!btn) return;
                    const dxData = JSON.parse(btn.getAttribute('data-diagnosis') || "{}");
                    document.getElementById("diagnosis_id_edit").value = dxData.DiagnosisID || "";
                    document.getElementById("patient_id_edit_diag").value = dxData.PatientID || "";
                    document.getElementById("appointment_id_edit_diag").value = dxData.AppointmentID || "";
                    document.getElementById("diagnosis_edit_diag").value = dxData.Diagnosis || "";
                    document.getElementById("treatment_plan_edit_diag").value = dxData.TreatmentPlan || "";
                    document.getElementById("prescribed_meds_edit_diag").value = dxData.PrescribedMedication || "";
                    document.getElementById("followup_date_edit_diag").value = dxData.FollowUpDate || "";
                    document.getElementById("remarks_edit_diag").value = dxData.Remarks || "";
                });
            }
        });
    </script>
</body>

</html>