<?php
// pages/diagnosis/diagnosisDetails.php

include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// Prevent browser caching
header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");
header("Pragma: no-cache");

// Ensure user is logged in
$currentUserID = $_SESSION['user_id'] ?? null;
$userRole      = $_SESSION['role'] ?? ''; // e.g. 'admin', 'doctor', 'staff'
if (!$currentUserID) {
    die("No valid user session. Please log in.");
}

// Initialize session messages if not set
if (!isset($_SESSION['error'])) {
    $_SESSION['error'] = '';
}
if (!isset($_SESSION['success'])) {
    $_SESSION['success'] = '';
}

// Determine the Diagnosis ID either from POST (for form submissions) or GET (for direct page views)
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['diagnosis_id']) && is_numeric($_POST['diagnosis_id'])) {
    $diagnosisID = (int)$_POST['diagnosis_id'];
} elseif (isset($_GET['id']) && is_numeric($_GET['id'])) {
    $diagnosisID = (int)$_GET['id'];
} else {
    die("Invalid Diagnosis ID.");
}



/************************************************************************
 * (A) Helper functions (for appointment date/time validation and history logging)
 ************************************************************************/
function validateAppointmentDate($dateStr)
{
    if (!preg_match('/^\d{4}-\d{2}-\d{2}$/', $dateStr)) {
        return "Invalid date format (must be YYYY-MM-DD).";
    }
    list($yyyy, $mm, $dd) = explode('-', $dateStr);
    if ($yyyy < 1900 || $yyyy > 2100) {
        return "Appointment year must be between 1900 and 2100.";
    }
    $today = date('Y-m-d');
    if ($dateStr < $today) {
        return "Appointment date cannot be in the past.";
    }
    return '';
}
function validateAppointmentTime($timeStr)
{
    if (!preg_match('/^\d{2}:\d{2}$/', $timeStr)) {
        return "Invalid time format (must be HH:MM).";
    }
    list($hh, $mm) = explode(':', $timeStr);
    if ($hh < 7 || $hh > 20) {
        return "Appointment time must be between 07:00 and 20:00.";
    }
    return '';
}
function insertDiagnosisHistory($conn, $oldRow, $editedBy, $actionType = 'EDIT')
{
    $histSql = "
        INSERT INTO diagnosis_history (
            DiagnosisID,
            PatientID,
            AppointmentID,
            Diagnosis,
            TreatmentPlan,
            PrescribedMedication,
            FollowUpDate,
            Remarks,
            EditedBy,
            EditedAt,
            ActionType
        ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, NOW(), ?)
    ";
    $stmt = $conn->prepare($histSql);
    $stmt->bind_param(
        "iiisssssis",
        $oldRow['DiagnosisID'],
        $oldRow['PatientID'],
        $oldRow['AppointmentID'],
        $oldRow['Diagnosis'],
        $oldRow['TreatmentPlan'],
        $oldRow['PrescribedMedication'],
        $oldRow['FollowUpDate'],
        $oldRow['Remarks'],
        $editedBy,
        $actionType
    );
    $stmt->execute();
    $stmt->close();
}

/************************************************************************
 * (C) Fetch the diagnosis record along with appointment, patient, and user info.
 *     (Moved UP so it's available for report handling)
 ************************************************************************/
$sql = "
    SELECT 
        d.*,
        a.AppointmentDate,
        a.AppointmentTime,
        a.Purpose AS apptPurpose,
        a.Status   AS apptStatus,
        a.Remarks  AS apptRemarks,
        p.id AS patient_id,
        p.first_name AS p_first,
        p.last_name  AS p_last,
        u1.username AS created_by_name,
        u2.username AS updated_by_name
    FROM diagnoses d
    LEFT JOIN appointments a ON d.AppointmentID = a.AppointmentID
    LEFT JOIN patients p     ON d.PatientID     = p.id
    LEFT JOIN users u1       ON d.CreatedBy     = u1.id
    LEFT JOIN users u2       ON d.UpdatedBy     = u2.id
    WHERE d.DiagnosisID = ?
";
$stmt = $conn->prepare($sql);
$stmt->bind_param("i", $diagnosisID);
$stmt->execute();
$result = $stmt->get_result();
if ($result->num_rows < 1) {
    die("Diagnosis record not found (ID: $diagnosisID).");
}
$diagnosisRow = $result->fetch_assoc();
$stmt->close();

$appointmentID = $diagnosisRow['AppointmentID'] ?? null;
$patientName   = trim($diagnosisRow['p_first'] . ' ' . $diagnosisRow['p_last']);

/************************************************************************
 * (B) REPORTS handling (Add/Edit/Delete) – Diagnosis-specific reports
 ************************************************************************/
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['report_action'])) {
    $reportAction = $_POST['report_action'];
    // Use the patient id from the diagnosis record for redirection.
    $patientID = $diagnosisRow['patient_id'];

    if ($userRole === 'staff') {
        $_SESSION['error'] = "Staff cannot modify or delete reports.";
        header("Location: ../patient/patientProfile.php?id=$patientID&diagnoses-tab=1");
        exit;
    }
    if ($userRole !== 'admin' && $userRole !== 'doctor') {
        $_SESSION['error'] = "Only Admin or Doctor can manage reports.";
        header("Location: ../patient/patientProfile.php?id=$patientID&diagnoses-tab=1");
        exit;
    }
    // (B1) Add Report – assign report to this diagnosis
    if ($reportAction === 'addReport') {
        $reportType = $_POST['report_type']  ?? 'Other';
        $reportDate = $_POST['report_date']  ?? date('Y-m-d');
        $remarks    = $_POST['remarks']      ?? '';
        $reportPath = null;
        if (isset($_FILES['report_file']) && $_FILES['report_file']['error'] === UPLOAD_ERR_OK) {
            $safePatientName = preg_replace('/[^A-Za-z0-9_\-]/', '_', $patientName);
            $reportFolder    = ROOT_PATH . "uploads/reports/" . $safePatientName;
            if (!is_dir($reportFolder)) {
                mkdir($reportFolder, 0777, true);
            }
            $tmpName  = $_FILES['report_file']['tmp_name'];
            $origName = preg_replace('/[^A-Za-z0-9_\-\.]/', '_', $_FILES['report_file']['name']);
            $finalPath = $reportFolder . '/' . date('YmdHis') . '_' . $origName;
            if (!move_uploaded_file($tmpName, $finalPath)) {
                $_SESSION['error'] = "Error saving the uploaded file.";
                header("Location: ../patient/patientProfile.php?id=$patientID&diagnoses-tab=1");
                exit;
            }
            $reportPath = "reports/$safePatientName/" . basename($finalPath);
        }
        // Insert report with DiagnosisID
        $rSql = "INSERT INTO reports (PatientID, DiagnosisID, ReportType, ReportDate, ReportPath, remarks, CreatedBy, UpdatedBy, CreatedAt, UpdatedAt) VALUES (?, ?, ?, ?, ?, ?, ?, ?, NOW(), NOW())";
        $stmtR = $conn->prepare($rSql);
        $stmtR->bind_param("iissssii", $diagnosisRow['PatientID'], $diagnosisID, $reportType, $reportDate, $reportPath, $remarks, $currentUserID, $currentUserID);
        $stmtR->execute();
        $stmtR->close();
        $_SESSION['success'] = "Report added successfully.";
        header("Location: ../patient/patientProfile.php?id=$patientID&diagnoses-tab=1");
        exit;
    }
    // (B2) Edit Report – update report for this diagnosis
    elseif ($reportAction === 'editReport') {
        $reportID   = (int)$_POST['report_id'];
        $reportType = $_POST['report_type'] ?? 'Other';
        $reportDate = $_POST['report_date'] ?? date('Y-m-d');
        $remarks    = $_POST['remarks']     ?? '';
        $selSql = "SELECT ReportPath FROM reports WHERE ReportID = ? AND DiagnosisID = ? LIMIT 1";
        $sStmt = $conn->prepare($selSql);
        $sStmt->bind_param("ii", $reportID, $diagnosisID);
        $sStmt->execute();
        $sRes = $sStmt->get_result();
        if ($sRes->num_rows < 1) {
            $_SESSION['error'] = "Report not found or does not belong to this Diagnosis.";
            header("Location: ../patient/patientProfile.php?id=$patientID&diagnoses-tab=1");
            exit;
        }
        $oldPath = $sRes->fetch_assoc()['ReportPath'] ?? null;
        $sStmt->close();
        $newReportPath = $oldPath;
        if (isset($_FILES['report_file']) && $_FILES['report_file']['error'] === UPLOAD_ERR_OK) {
            if ($oldPath) {
                $absOld = ROOT_PATH . 'uploads/' . $oldPath;
                if (file_exists($absOld)) {
                    unlink($absOld);
                }
            }
            $safePatientName = preg_replace('/[^A-Za-z0-9_\-]/', '_', $patientName);
            $reportFolder    = ROOT_PATH . "uploads/reports/" . $safePatientName;
            if (!is_dir($reportFolder)) {
                mkdir($reportFolder, 0777, true);
            }
            $tmpName  = $_FILES['report_file']['tmp_name'];
            $origName = preg_replace('/[^A-Za-z0-9_\-\.]/', '_', $_FILES['report_file']['name']);
            $finalPath = $reportFolder . '/' . date('YmdHis') . '_' . $origName;
            if (!move_uploaded_file($tmpName, $finalPath)) {
                $_SESSION['error'] = "Error moving the new file.";
                header("Location: ../patient/patientProfile.php?id=$patientID&diagnoses-tab=1");
                exit;
            }
            $newReportPath = "reports/$safePatientName/" . basename($finalPath);
        }
        $upSql = "UPDATE reports SET ReportType = ?, ReportDate = ?, ReportPath = ?, remarks = ?, UpdatedBy  = ?, UpdatedAt  = NOW() WHERE ReportID = ? AND DiagnosisID = ?";
        $uStmt = $conn->prepare($upSql);
        $uStmt->bind_param("ssssiii", $reportType, $reportDate, $newReportPath, $remarks, $currentUserID, $reportID, $diagnosisID);
        $uStmt->execute();
        $uStmt->close();
        $_SESSION['success'] = "Report #$reportID updated successfully.";
        header("Location: ../patient/patientProfile.php?id=$patientID&diagnoses-tab=1");
        exit;
    }
    // (B3) Delete Report – remove report for this diagnosis
    elseif ($reportAction === 'deleteReport') {
        $reportID = (int)($_POST['report_id'] ?? 0);
        $selSql = "SELECT ReportPath FROM reports WHERE ReportID = ? AND DiagnosisID = ? LIMIT 1";
        $selStmt = $conn->prepare($selSql);
        $selStmt->bind_param("ii", $reportID, $diagnosisID);
        $selStmt->execute();
        $sRes = $selStmt->get_result();
        if ($sRes->num_rows < 1) {
            $_SESSION['error'] = "Report not found or does not belong to this Diagnosis.";
            header("Location: ../patient/patientProfile.php?id=$patientID&diagnoses-tab=1");
            exit;
        }
        $oldRow = $sRes->fetch_assoc();
        $oldP   = $oldRow['ReportPath'] ?? null;
        $selStmt->close();
        $delSql = "DELETE FROM reports WHERE ReportID = ? AND DiagnosisID = ?";
        $dStmt  = $conn->prepare($delSql);
        $dStmt->bind_param("ii", $reportID, $diagnosisID);
        $dStmt->execute();
        $dStmt->close();
        if ($oldP) {
            $absFile = ROOT_PATH . 'uploads/' . $oldP;
            if (file_exists($absFile)) {
                unlink($absFile);
            }
        }
        $_SESSION['success'] = "Report #$reportID has been deleted.";
        header("Location: ../patient/patientProfile.php?id=$patientID&diagnoses-tab=1");
        exit;
    }
}


/************************************************************************
 * (D) Reports: Filter + Pagination (for reports assigned to this diagnosis)
 ************************************************************************/
$reports = [];
$reportTypeFilter    = $_GET['report_type'] ?? '';
$reportStartDate     = $_GET['report_sdate'] ?? '';
$reportEndDate       = $_GET['report_edate'] ?? '';
$reportSearchRemarks = $_GET['report_search'] ?? '';
$rClauses = [];
// Filter by DiagnosisID for reports
$rClauses[] = "r.DiagnosisID = $diagnosisID";
if (in_array($reportTypeFilter, ['Lab Test', 'Imaging', 'Prescription', 'Other'])) {
    $rClauses[] = "r.ReportType = '{$reportTypeFilter}'";
}
if (
    preg_match('/^\d{4}-\d{2}-\d{2}$/', $reportStartDate) &&
    preg_match('/^\d{4}-\d{2}-\d{2}$/', $reportEndDate)
) {
    $rClauses[] = "r.ReportDate BETWEEN '$reportStartDate' AND '$reportEndDate'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $reportStartDate)) {
    $rClauses[] = "r.ReportDate >= '$reportStartDate'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $reportEndDate)) {
    $rClauses[] = "r.ReportDate <= '$reportEndDate'";
}
if (!empty($reportSearchRemarks)) {
    $esc = $conn->real_escape_string($reportSearchRemarks);
    $rClauses[] = "(r.remarks LIKE '%$esc%')";
}
$reportWhere = !empty($rClauses) ? 'WHERE ' . implode(' AND ', $rClauses) : '';
$rPerPage = 5;
$rPg      = isset($_GET['rpg']) ? (int)$_GET['rpg'] : 1;
if ($rPg < 1) {
    $rPg = 1;
}
$rOffset  = ($rPg - 1) * $rPerPage;
$countSqlRpt = "SELECT COUNT(r.ReportID) AS total FROM reports r $reportWhere";
$resCountRpt = $conn->query($countSqlRpt);
$totalReports = $resCountRpt->fetch_assoc()['total'] ?? 0;
$totalRptPages = ceil($totalReports / $rPerPage);
$r_sql = "
    SELECT 
        r.*,
        u1.username AS created_by_name,
        u2.username AS updated_by_name
    FROM reports r
    LEFT JOIN users u1 ON r.CreatedBy = u1.id
    LEFT JOIN users u2 ON r.UpdatedBy = u2.id
    $reportWhere
    ORDER BY r.ReportDate DESC, r.ReportID DESC
    LIMIT $rPerPage OFFSET $rOffset
";
$rStmt = $conn->prepare($r_sql);
$rStmt->execute();
$rRes = $rStmt->get_result();
while ($row = $rRes->fetch_assoc()) {
    $reports[] = $row;
}
$rStmt->close();
$errorMsg   = $_SESSION['error']   ?? '';
$successMsg = $_SESSION['success'] ?? '';
$_SESSION['error']   = '';
$_SESSION['success'] = '';
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <title>Diagnosis & Reports | #<?php echo $diagnosisID; ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">
    <link href="<?php echo $baseURL; ?>assets/css/styles.css" rel="stylesheet">
    <!-- Quill Snow Theme CSS -->
    <link href="https://cdn.jsdelivr.net/npm/quill@2.0.3/dist/quill.snow.css" rel="stylesheet">
    <!-- highlight.js CSS -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/highlight.js/11.2.0/styles/default.min.css">
    <style>
        /* Hide Next Appointment details until checkbox is checked */
        #nextApptDetails {
            display: none;
        }
    </style>
</head>

<body>
    <div id="wrapper">
        <?php include ROOT_PATH . 'includes/navbar.php'; ?>
        <div id="page-content-wrapper">
            <?php include ROOT_PATH . 'includes/sidebar.php'; ?>
            <div class="container-fluid mt-4">
                <!-- Display messages -->
                <?php if ($errorMsg): ?>
                    <div class="alert alert-danger"><i class="fas fa-exclamation-triangle"></i> <?php echo htmlspecialchars($errorMsg); ?></div>
                <?php endif; ?>
                <?php if ($successMsg): ?>
                    <div class="alert alert-success"><i class="fas fa-check-circle"></i> <?php echo htmlspecialchars($successMsg); ?></div>
                <?php endif; ?>
                <div class="card mb-4 shadow border-0">
                    <div class="card-body text-center bg-primary text-white rounded">
                        <h4 class="card-title mb-1">Diagnosis Details</h4>
                        <p class="mb-0">Diagnosis #<?php echo $diagnosisID; ?></p>
                    </div>
                </div>
                <!-- Back Button -->
                <div class="mb-3">
                    <a href="<?php echo $baseURL; ?>pages/patient/patientProfile.php?id=<?php echo $diagnosisRow['patient_id']; ?>&diagnoses-tab=1" class="btn btn-secondary btn-action"><i class="fas fa-arrow-left"></i> Back to Patient Profile</a>
                </div>
                <!-- Main Tabs: View Diagnosis, Edit Diagnosis, Reports -->
                <ul class="nav nav-tabs" role="tablist">
                    <li class="nav-item" role="presentation">
                        <button class="nav-link active" id="view-diagnosis-tab" data-bs-toggle="tab" data-bs-target="#viewDiagnosisTabContent" type="button" role="tab" aria-controls="viewDiagnosisTabContent" aria-selected="true">View Diagnosis</button>
                    </li>
                    <?php if ($userRole === 'admin' || $userRole === 'doctor'): ?>
                        <li class="nav-item" role="presentation">
                            <button class="nav-link" id="edit-diagnosis-tab" data-bs-toggle="tab" data-bs-target="#editDiagnosisTabContent" type="button" role="tab" aria-controls="editDiagnosisTabContent" aria-selected="false">Edit Diagnosis</button>
                        </li>
                    <?php endif; ?>
                    <li class="nav-item" role="presentation">
                        <button class="nav-link" id="reports-tab" data-bs-toggle="tab" data-bs-target="#reportsTabContent" type="button" role="tab" aria-controls="reportsTabContent" aria-selected="false">Reports</button>
                    </li>
                </ul>
                <div class="tab-content mt-3">
                    <!-- (1) VIEW DIAGNOSIS TAB -->
                    <div class="tab-pane fade show active" id="viewDiagnosisTabContent" role="tabpanel" aria-labelledby="view-diagnosis-tab">
                        <div class="row">
                            <div class="col-md-8 offset-md-2">
                                <div class="card mb-4 border shadow-sm">
                                    <div class="card-header bg-light">
                                        <strong>Patient: </strong><?php echo htmlspecialchars($patientName . " (ID: {$diagnosisRow['patient_id']})"); ?>
                                    </div>
                                    <div class="card-body">
                                        <h5 class="card-title text-primary"><i class="fas fa-calendar-check"></i> Appointment Info</h5>
                                        <div class="row mb-3">
                                            <div class="col-md-6">
                                                <p class="mb-1"><strong>Date:</strong> <?php echo htmlspecialchars($diagnosisRow['AppointmentDate'] ?? ''); ?></p>
                                                <p class="mb-1"><strong>Time:</strong> <?php echo htmlspecialchars($diagnosisRow['AppointmentTime'] ?? ''); ?></p>
                                                <p class="mb-1"><strong>Purpose:</strong> <?php echo htmlspecialchars($diagnosisRow['apptPurpose'] ?? ''); ?></p>
                                            </div>
                                            <div class="col-md-6">
                                                <p class="mb-1"><strong>Status:</strong> <?php echo htmlspecialchars($diagnosisRow['apptStatus'] ?? ''); ?></p>
                                                <p class="mb-1"><strong>Remarks:</strong><br>
                                                    <small><?php echo nl2br(htmlspecialchars($diagnosisRow['apptRemarks'] ?? '')); ?></small>
                                                </p>
                                            </div>
                                        </div>
                                        <hr>
                                        <!-- Sub-tabs for rich text content display -->
                                        <div class="nav nav-tabs" id="viewDiagnosisSubTabs" role="tablist">
                                            <button class="nav-link active" id="view-subtab-diagnosis" data-bs-toggle="tab" data-bs-target="#viewSubtabDiagnosisContent" type="button" role="tab">Diagnosis</button>
                                            <button class="nav-link" id="view-subtab-treatment" data-bs-toggle="tab" data-bs-target="#viewSubtabTreatmentContent" type="button" role="tab">Treatment Plan</button>
                                            <button class="nav-link" id="view-subtab-prescribed" data-bs-toggle="tab" data-bs-target="#viewSubtabPrescribedContent" type="button" role="tab">Prescribed Medication</button>
                                        </div>
                                        <div class="tab-content mt-3" id="viewDiagnosisSubTabContent">
                                            <div class="tab-pane fade show active" id="viewSubtabDiagnosisContent" role="tabpanel">
                                                <?php echo $diagnosisRow['Diagnosis']; ?>
                                            </div>
                                            <div class="tab-pane fade" id="viewSubtabTreatmentContent" role="tabpanel">
                                                <?php echo $diagnosisRow['TreatmentPlan']; ?>
                                            </div>
                                            <div class="tab-pane fade" id="viewSubtabPrescribedContent" role="tabpanel">
                                                <?php echo $diagnosisRow['PrescribedMedication']; ?>
                                            </div>
                                        </div>
                                        <div class="mt-3 border-top pt-2 text-muted small">
                                            <p class="mb-1"><i class="fas fa-user-check"></i> Created By: <?php echo htmlspecialchars($diagnosisRow['created_by_name']); ?> | <i class="fas fa-user-edit"></i> Updated By: <?php echo htmlspecialchars($diagnosisRow['updated_by_name']); ?></p>
                                            <p class="mb-0"><i class="fas fa-clock"></i> Created At: <?php echo htmlspecialchars($diagnosisRow['CreatedAt']); ?> | Updated At: <?php echo htmlspecialchars($diagnosisRow['UpdatedAt']); ?></p>
                                        </div>
                                    </div>
                                </div>
                                <?php if (!($userRole === 'admin' || $userRole === 'doctor')): ?>
                                    <p class="text-muted text-center">You do not have permission to edit this diagnosis.</p>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                    <!-- (2) EDIT DIAGNOSIS TAB (only for admin/doctor) -->
                    <?php if ($userRole === 'admin' || $userRole === 'doctor'): ?>
                        <div class="tab-pane fade" id="editDiagnosisTabContent" role="tabpanel" aria-labelledby="edit-diagnosis-tab">
                            <div class="row">
                                <div class="col-md-10 offset-md-1">
                                    <div class="card shadow-sm border">
                                        <div class="card-header bg-light text-dark">
                                            <h5>Edit Diagnosis #<?php echo $diagnosisID; ?></h5>
                                        </div>
                                        <div class="card-body">
                                            <!-- Edit Diagnosis Form (submitted via AJAX) -->
                                            <form id="editDiagnosisForm">
                                                <input type="hidden" name="id" value="<?php echo $diagnosisID; ?>">
                                                <div class="mb-3">
                                                    <label for="appointment_id_edit" class="form-label">Appointment ID</label>
                                                    <input type="number" class="form-control" name="appointment_id" id="appointment_id_edit" value="<?php echo $diagnosisRow['AppointmentID'] ?: ''; ?>">
                                                </div>
                                                <!-- Rich Text Editors for three fields with sub-tabs -->
                                                <ul class="nav nav-tabs" id="editDiagnosisSubTabs" role="tablist">
                                                    <li class="nav-item">
                                                        <button class="nav-link active" id="subtab-diagnosis" data-bs-toggle="tab" data-bs-target="#subtabDiagnosisContent" type="button" role="tab">Diagnosis</button>
                                                    </li>
                                                    <li class="nav-item">
                                                        <button class="nav-link" id="subtab-treatment" data-bs-toggle="tab" data-bs-target="#subtabTreatmentContent" type="button" role="tab">Treatment Plan</button>
                                                    </li>
                                                    <li class="nav-item">
                                                        <button class="nav-link" id="subtab-prescribed" data-bs-toggle="tab" data-bs-target="#subtabPrescribedContent" type="button" role="tab">Prescribed Medication</button>
                                                    </li>
                                                </ul>
                                                <div class="tab-content" id="editDiagnosisSubTabContent">
                                                    <div class="tab-pane fade show active" id="subtabDiagnosisContent" role="tabpanel">
                                                        <div class="mb-3 mt-3">
                                                            <div id="editor_diagnosis" style="height: 200px;"><?php echo $diagnosisRow['Diagnosis']; ?></div>
                                                            <input type="hidden" name="diagnosis" id="diagnosis_input">
                                                        </div>
                                                    </div>
                                                    <div class="tab-pane fade" id="subtabTreatmentContent" role="tabpanel">
                                                        <div class="mb-3 mt-3">
                                                            <div id="editor_treatment" style="height: 200px;"><?php echo $diagnosisRow['TreatmentPlan']; ?></div>
                                                            <input type="hidden" name="treatment_plan" id="treatment_plan_input">
                                                        </div>
                                                    </div>
                                                    <div class="tab-pane fade" id="subtabPrescribedContent" role="tabpanel">
                                                        <div class="mb-3 mt-3">
                                                            <div id="editor_prescribed" style="height: 200px;"><?php echo $diagnosisRow['PrescribedMedication']; ?></div>
                                                            <input type="hidden" name="prescribed_meds" id="prescribed_meds_input">
                                                        </div>
                                                    </div>
                                                </div>
                                                <!-- Combined Remarks and Next Follow-Up Date -->
                                                <div class="row mb-3">
                                                    <div class="col-md-8">
                                                        <label for="remarks_edit" class="form-label">Remarks</label>
                                                        <textarea class="form-control" name="remarks" id="remarks_edit" rows="3"><?php echo $diagnosisRow['Remarks']; ?></textarea>
                                                    </div>
                                                    <div class="col-md-4">
                                                        <label for="next_fu_date_edit" class="form-label">Next Follow‑Up Date</label>
                                                        <input type="date" class="form-control" name="next_fu_date" id="next_fu_date_edit">
                                                    </div>
                                                </div>
                                                <!-- Create Next Appointment -->
                                                <div class="form-check mb-2">
                                                    <input class="form-check-input" type="checkbox" id="create_next_appointment_edit" name="create_next_appointment" value="1">
                                                    <label class="form-check-label" for="create_next_appointment_edit">Create Next Appointment?</label>
                                                </div>
                                                <div id="nextApptDetails" class="border p-2 mb-2 bg-light">
                                                    <label class="form-label"><strong>Next Appointment Details</strong></label>
                                                    <div class="mb-2">
                                                        <label for="next_appt_date_edit" class="form-label">Date</label>
                                                        <input type="date" class="form-control" name="next_appt_date" id="next_appt_date_edit">
                                                    </div>
                                                    <div class="mb-2">
                                                        <label for="next_appt_time_edit" class="form-label">Time</label>
                                                        <input type="time" class="form-control" name="next_appt_time" id="next_appt_time_edit">
                                                    </div>
                                                    <div class="mb-2">
                                                        <label for="next_appt_purpose_edit" class="form-label">Purpose</label>
                                                        <input type="text" class="form-control" name="next_appt_purpose" id="next_appt_purpose_edit" placeholder="e.g. Follow‑up Exam">
                                                    </div>
                                                </div>
                                                <div class="form-check mb-2">
                                                    <input class="form-check-input" type="checkbox" id="mark_current_completed_edit" name="mark_current_completed" value="1">
                                                    <label class="form-check-label" for="mark_current_completed_edit">Mark Current Appointment as Completed?</label>
                                                </div>
                                                <div class="d-grid">
                                                    <button type="button" id="updateDiagnosisBtn" class="btn btn-warning">Update Diagnosis</button>
                                                </div>
                                            </form>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        <?php endif; ?>
                        <!-- (3) REPORTS TAB -->
                        <div class="tab-pane fade" id="reportsTabContent" role="tabpanel" aria-labelledby="reports-tab">
                            <div class="row">
                                <div class="col-md-10 offset-md-1">
                                    <?php if (!$diagnosisID): ?>
                                        <div class="alert alert-info mt-3">
                                            <i class="fas fa-info-circle"></i> This diagnosis has no associated records, so no reports can be added.
                                        </div>
                                    <?php else: ?>
                                        <div class="card mb-3 border shadow-sm">
                                            <div class="card-header bg-light">
                                                <h5 class="mb-0">Filter Reports</h5>
                                            </div>
                                            <div class="card-body">
                                                <form method="GET" class="row gy-2 gx-3 align-items-end">
                                                    <input type="hidden" name="id" value="<?php echo $diagnosisID; ?>">
                                                    <input type="hidden" name="reports-tab" value="1">
                                                    <div class="col-md-3">
                                                        <label for="report_type" class="form-label">Report Type</label>
                                                        <select name="report_type" id="report_type" class="form-select">
                                                            <option value="">All</option>
                                                            <option value="Lab Test" <?php if (($reportTypeFilter ?? '') === 'Lab Test') echo 'selected'; ?>>Lab Test</option>
                                                            <option value="Imaging" <?php if (($reportTypeFilter ?? '') === 'Imaging') echo 'selected'; ?>>Imaging</option>
                                                            <option value="Prescription" <?php if (($reportTypeFilter ?? '') === 'Prescription') echo 'selected'; ?>>Prescription</option>
                                                            <option value="Other" <?php if (($reportTypeFilter ?? '') === 'Other') echo 'selected'; ?>>Other</option>
                                                        </select>
                                                    </div>
                                                    <div class="col-md-2">
                                                        <label for="report_sdate" class="form-label">Start Date</label>
                                                        <input type="date" class="form-control" name="report_sdate" id="report_sdate" value="<?php echo htmlspecialchars($reportStartDate ?? ''); ?>">
                                                    </div>
                                                    <div class="col-md-2">
                                                        <label for="report_edate" class="form-label">End Date</label>
                                                        <input type="date" class="form-control" name="report_edate" id="report_edate" value="<?php echo htmlspecialchars($reportEndDate ?? ''); ?>">
                                                    </div>
                                                    <div class="col-md-3">
                                                        <label for="report_search" class="form-label">Search Remarks</label>
                                                        <input type="text" class="form-control" name="report_search" id="report_search" placeholder="Enter text..." value="<?php echo htmlspecialchars($reportSearchRemarks ?? ''); ?>">
                                                    </div>
                                                    <div class="col-md-2 d-flex align-items-end">
                                                        <div class="w-100 d-flex gap-2">
                                                            <button type="submit" class="btn btn-primary w-50">
                                                                <i class="fas fa-filter"></i> Filter
                                                            </button>
                                                            <a href="?id=<?php echo $diagnosisID; ?>#reports-tab" class="btn btn-secondary w-50">
                                                                <i class="fas fa-times"></i> Clear
                                                            </a>
                                                        </div>
                                                    </div>
                                                </form>
                                            </div>
                                        </div>
                                        <?php if ($userRole === 'admin' || $userRole === 'doctor'): ?>
                                            <div class="text-end mb-3">
                                                <button class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#addReportModal">
                                                    <i class="fas fa-plus"></i> Add Report
                                                </button>
                                            </div>
                                        <?php endif; ?>

                                        <?php if (!empty($reports)): ?>
                                            <div class="table-responsive">
                                                <table class="table table-bordered table-striped align-middle">
                                                    <thead class="table-light">
                                                        <tr>
                                                            <th>Report ID</th>
                                                            <th>Report Type</th>
                                                            <th>
                                                                <a href="?id=<?php echo $diagnosisID; ?>&reports-tab=1&order_by=ReportDate&order=<?php echo $newOrder; ?>" class="text-decoration-none text-dark">
                                                                    Report Date <?php if ($order_by_param === 'ReportDate') {
                                                                                    echo ($currentOrder === 'asc') ? '<i class="fas fa-arrow-up"></i>' : '<i class="fas fa-arrow-down"></i>';
                                                                                } ?>
                                                                </a>
                                                            </th>
                                                            <th>File</th>
                                                            <th>Remarks</th>
                                                            <th>Created/Updated By</th>
                                                            <th style="min-width:100px;">Actions</th>
                                                        </tr>
                                                    </thead>
                                                    <tbody>
                                                        <?php foreach ($reports as $rep): ?>
                                                            <tr>
                                                                <td><?php echo $rep['ReportID']; ?></td>
                                                                <td><?php echo htmlspecialchars($rep['ReportType']); ?></td>
                                                                <td><?php echo htmlspecialchars($rep['ReportDate']); ?></td>
                                                                <td>
                                                                    <?php if (!empty($rep['ReportPath'])): ?>
                                                                        <a href="<?php echo htmlspecialchars($baseURL . 'uploads/' . $rep['ReportPath']); ?>" target="_blank" class="btn btn-success btn-sm">
                                                                            <i class="fas fa-download"></i> View
                                                                        </a>
                                                                    <?php else: ?>
                                                                        <span class="text-muted">No file</span>
                                                                    <?php endif; ?>
                                                                </td>
                                                                <td style="white-space: pre-wrap; max-width:180px;"><?php echo nl2br(htmlspecialchars($rep['remarks'] ?? '')); ?></td>
                                                                <td style="width:140px;">
                                                                    <small>Created: <?php echo htmlspecialchars($rep['created_by_name']); ?></small><br>
                                                                    <small>Updated: <?php echo htmlspecialchars($rep['updated_by_name']); ?></small>
                                                                </td>
                                                                <td>
                                                                    <?php if ($userRole === 'admin' || $userRole === 'doctor'): ?>
                                                                        <button class="btn btn-warning btn-sm" data-bs-toggle="modal" data-bs-target="#editReportModal" data-report='<?php echo json_encode($rep, JSON_HEX_TAG | JSON_HEX_APOS | JSON_HEX_QUOT | JSON_HEX_AMP); ?>'>
                                                                            <i class="fas fa-edit"></i>
                                                                        </button>
                                                                        <form method="POST" class="d-inline-block" onsubmit="return confirm('Delete this report?');">
                                                                            <input type="hidden" name="report_action" value="deleteReport">
                                                                            <input type="hidden" name="report_id" value="<?php echo $rep['ReportID']; ?>">
                                                                            <button class="btn btn-danger btn-sm">
                                                                                <i class="fas fa-trash"></i>
                                                                            </button>
                                                                        </form>
                                                                    <?php else: ?>
                                                                        <span class="text-muted">No actions</span>
                                                                    <?php endif; ?>
                                                                </td>
                                                            </tr>
                                                        <?php endforeach; ?>
                                                    </tbody>
                                                </table>
                                            </div>
                                            <!-- Pagination for Reports -->
                                            <?php if ($totalRptPages > 1): ?>
                                                <nav class="mt-3">
                                                    <ul class="pagination justify-content-center">
                                                        <?php if ($rPg > 1): ?>
                                                            <li class="page-item">
                                                                <a class="page-link" href="?id=<?php echo $diagnosisID; ?>&reports-tab=1&repg=<?php echo ($rPg - 1); ?>">
                                                                    « Prev
                                                                </a>
                                                            </li>
                                                        <?php else: ?>
                                                            <li class="page-item disabled"><span class="page-link">« Prev</span></li>
                                                        <?php endif; ?>
                                                        <?php for ($i = 1; $i <= $totalRptPages; $i++): ?>
                                                            <li class="page-item <?php if ($i == $rPg) echo 'active'; ?>">
                                                                <a class="page-link" href="?id=<?php echo $diagnosisID; ?>&reports-tab=1&repg=<?php echo $i; ?>">
                                                                    <?php echo $i; ?>
                                                                </a>
                                                            </li>
                                                        <?php endfor; ?>
                                                        <?php if ($rPg < $totalRptPages): ?>
                                                            <li class="page-item">
                                                                <a class="page-link" href="?id=<?php echo $diagnosisID; ?>&reports-tab=1&repg=<?php echo ($rPg + 1); ?>">
                                                                    Next »
                                                                </a>
                                                            </li>
                                                        <?php else: ?>
                                                            <li class="page-item disabled"><span class="page-link">Next »</span></li>
                                                        <?php endif; ?>
                                                    </ul>
                                                </nav>
                                            <?php endif; ?>
                                        <?php endif; ?>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div> <!-- end of Reports Tab -->
                        </div> <!-- end container-fluid -->
                </div> <!-- end page-content-wrapper -->
            </div> <!-- end wrapper -->

            <!-- (B) ADD REPORT MODAL -->
            <?php if ($diagnosisID && ($userRole === 'admin' || $userRole === 'doctor')): ?>
                <div class="modal fade" id="addReportModal" tabindex="-1" aria-labelledby="addReportModalLabel" aria-hidden="true">
                    <div class="modal-dialog">
                        <form class="modal-content" method="POST" enctype="multipart/form-data" action="<?php echo $baseURL; ?>pages/diagnosis/diagnosisDetails.php">
                            <input type="hidden" name="report_action" value="addReport">
                            <input type="hidden" name="diagnosis_id" value="<?php echo $diagnosisID; ?>">
                            <div class="modal-header">
                                <h5 class="modal-title" id="addReportModalLabel">Add Report</h5>
                                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                            </div>
                            <div class="modal-body">
                                <div class="mb-3">
                                    <label for="report_type_add" class="form-label">Report Type</label>
                                    <select name="report_type" class="form-select" id="report_type_add">
                                        <option value="Lab Test">Lab Test</option>
                                        <option value="Imaging">Imaging</option>
                                        <option value="Prescription">Prescription</option>
                                        <option value="Other">Other</option>
                                    </select>
                                </div>
                                <div class="mb-3">
                                    <label for="report_date_add" class="form-label">Report Date</label>
                                    <input type="date" class="form-control" name="report_date" id="report_date_add" value="<?php echo date('Y-m-d'); ?>">
                                </div>
                                <div class="mb-3">
                                    <label for="report_file_add" class="form-label">Upload File (optional)</label>
                                    <input type="file" class="form-control" name="report_file" id="report_file_add" accept=".pdf,.jpg,.jpeg,.png,.doc,.docx,.xls,.xlsx">
                                </div>
                                <div class="mb-3">
                                    <label for="remarks_add_report" class="form-label">Remarks</label>
                                    <textarea class="form-control" name="remarks" id="remarks_add_report" rows="3"></textarea>
                                </div>
                            </div>
                            <div class="modal-footer">
                                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                                <button type="submit" class="btn btn-primary">Add Report</button>
                            </div>
                        </form>
                    </div>
                </div>
            <?php endif; ?>

            <!-- (C) EDIT REPORT MODAL -->
            <?php if ($diagnosisID && ($userRole === 'admin' || $userRole === 'doctor')): ?>
                <div class="modal fade" id="editReportModal" tabindex="-1" aria-labelledby="editReportModalLabel" aria-hidden="true">
                    <div class="modal-dialog">
                        <form class="modal-content" method="POST" enctype="multipart/form-data" action="<?php echo $baseURL; ?>pages/diagnosis/diagnosisDetails.php">
                            <input type="hidden" name="report_action" value="editReport">
                            <input type="hidden" name="report_id" id="report_id_edit">
                            <input type="hidden" name="diagnosis_id" value="<?php echo $diagnosisID; ?>">
                            <div class="modal-header">
                                <h5 class="modal-title" id="editReportModalLabel">Edit Report</h5>
                                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                            </div>
                            <div class="modal-body">
                                <div class="mb-3">
                                    <label for="report_type_edit" class="form-label">Report Type</label>
                                    <select class="form-select" name="report_type" id="report_type_edit">
                                        <option value="Lab Test">Lab Test</option>
                                        <option value="Imaging">Imaging</option>
                                        <option value="Prescription">Prescription</option>
                                        <option value="Other">Other</option>
                                    </select>
                                </div>
                                <div class="mb-3">
                                    <label for="report_date_edit" class="form-label">Report Date</label>
                                    <input type="date" class="form-control" name="report_date" id="report_date_edit">
                                </div>
                                <div class="mb-3">
                                    <label for="report_file_edit" class="form-label">Upload New File (optional)</label>
                                    <input type="file" class="form-control" name="report_file" id="report_file_edit" accept=".pdf,.jpg,.jpeg,.png,.doc,.docx,.xls,.xlsx">
                                </div>
                                <div class="mb-3">
                                    <label for="remarks_edit_report" class="form-label">Remarks</label>
                                    <textarea class="form-control" name="remarks" id="remarks_edit_report" rows="3"></textarea>
                                </div>
                            </div>
                            <div class="modal-footer">
                                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                                <button type="submit" class="btn btn-warning">Update Report</button>
                            </div>
                        </form>
                    </div>
                </div>
            <?php endif; ?>

            <!-- Load JS libraries -->
            <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
            <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
            <script src="https://cdnjs.cloudflare.com/ajax/libs/highlight.js/11.2.0/highlight.min.js"></script>
            <script src="https://cdn.jsdelivr.net/npm/quill@2.0.3/dist/quill.js"></script>
            <script src="quill-image-resize-module-patched.js"></script>
            <!-- Custom Image Blot to persist inline styles -->
            <script>
                var Image = Quill.import('formats/image');
                class CustomImage extends Image {
                    static create(value) {
                        let node = super.create(value);
                        if (typeof value === 'object' && value.src) {
                            node.setAttribute('src', value.src);
                            if (value.width) {
                                node.style.width = value.width;
                            }
                            if (value.height) {
                                node.style.height = value.height;
                            }
                        } else {
                            node.setAttribute('src', value);
                        }
                        return node;
                    }
                    static formats(domNode) {
                        let formats = super.formats(domNode);
                        if (domNode.style.width) {
                            formats.width = domNode.style.width;
                        }
                        if (domNode.style.height) {
                            formats.height = domNode.style.height;
                        }
                        return formats;
                    }
                    format(name, value) {
                        if (name === 'width' || name === 'height') {
                            if (value) {
                                this.domNode.style[name] = value;
                            } else {
                                this.domNode.style[name] = '';
                            }
                        } else {
                            super.format(name, value);
                        }
                    }
                    formats() {
                        let formats = super.formats();
                        if (this.domNode.style.width) {
                            formats.width = this.domNode.style.width;
                        }
                        if (this.domNode.style.height) {
                            formats.height = this.domNode.style.height;
                        }
                        return formats;
                    }
                }
                Quill.register(CustomImage, true);
            </script>
            <script>
                // Add tooltips to Quill toolbar icons
                function addTooltips() {
                    const mapping = {
                        'ql-bold': 'Bold',
                        'ql-italic': 'Italic',
                        'ql-underline': 'Underline',
                        'ql-strike': 'Strike',
                        'ql-blockquote': 'Blockquote',
                        'ql-code-block': 'Code Block',
                        'ql-header': 'Header',
                        'ql-list': 'List',
                        'ql-indent': 'Indent',
                        'ql-direction': 'Text Direction',
                        'ql-size': 'Font Size',
                        'ql-color': 'Text Color',
                        'ql-background': 'Background Color',
                        'ql-align': 'Text Alignment',
                        'ql-link': 'Link',
                        'ql-image': 'Image',
                        'ql-video': 'Video',
                        'ql-clean': 'Remove Formatting'
                    };
                    var toolbar = document.querySelector('.ql-toolbar');
                    if (!toolbar) return;
                    Object.keys(mapping).forEach(function(className) {
                        var buttons = toolbar.querySelectorAll('.' + className);
                        buttons.forEach(function(button) {
                            button.setAttribute('title', mapping[className]);
                        });
                    });
                }
                setTimeout(addTooltips, 100);

                // Toggle Next Appointment Details when checkbox is checked
                document.getElementById('create_next_appointment_edit').addEventListener('change', function() {
                    document.getElementById('nextApptDetails').style.display = this.checked ? 'block' : 'none';
                });

                // Define separate image handlers for each editor:
                function imageHandlerDiagnosis() {
                    var input = document.createElement('input');
                    input.setAttribute('type', 'file');
                    input.setAttribute('accept', 'image/*');
                    input.click();
                    input.onchange = function() {
                        var file = input.files[0];
                        if (file) {
                            var formData = new FormData();
                            formData.append('image', file);
                            fetch('upload_image.php', {
                                    method: 'POST',
                                    body: formData
                                })
                                .then(response => response.json())
                                .then(result => {
                                    if (result.success) {
                                        var range = quillDiagnosis.getSelection();
                                        if (range) {
                                            quillDiagnosis.insertEmbed(range.index, 'image', result.image_url);
                                        } else {
                                            quillDiagnosis.insertEmbed(quillDiagnosis.getLength(), 'image', result.image_url);
                                        }
                                    } else {
                                        alert("Image upload failed: " + result.error);
                                    }
                                })
                                .catch(error => {
                                    console.error('Error:', error);
                                    alert("Image upload failed.");
                                });
                        }
                    };
                }

                function imageHandlerTreatment() {
                    var input = document.createElement('input');
                    input.setAttribute('type', 'file');
                    input.setAttribute('accept', 'image/*');
                    input.click();
                    input.onchange = function() {
                        var file = input.files[0];
                        if (file) {
                            var formData = new FormData();
                            formData.append('image', file);
                            fetch('upload_image.php', {
                                    method: 'POST',
                                    body: formData
                                })
                                .then(response => response.json())
                                .then(result => {
                                    if (result.success) {
                                        var range = quillTreatment.getSelection();
                                        if (range) {
                                            quillTreatment.insertEmbed(range.index, 'image', result.image_url);
                                        } else {
                                            quillTreatment.insertEmbed(quillTreatment.getLength(), 'image', result.image_url);
                                        }
                                    } else {
                                        alert("Image upload failed: " + result.error);
                                    }
                                })
                                .catch(error => {
                                    console.error('Error:', error);
                                    alert("Image upload failed.");
                                });
                        }
                    };
                }

                function imageHandlerPrescribed() {
                    var input = document.createElement('input');
                    input.setAttribute('type', 'file');
                    input.setAttribute('accept', 'image/*');
                    input.click();
                    input.onchange = function() {
                        var file = input.files[0];
                        if (file) {
                            var formData = new FormData();
                            formData.append('image', file);
                            fetch('upload_image.php', {
                                    method: 'POST',
                                    body: formData
                                })
                                .then(response => response.json())
                                .then(result => {
                                    if (result.success) {
                                        var range = quillPrescribed.getSelection();
                                        if (range) {
                                            quillPrescribed.insertEmbed(range.index, 'image', result.image_url);
                                        } else {
                                            quillPrescribed.insertEmbed(quillPrescribed.getLength(), 'image', result.image_url);
                                        }
                                    } else {
                                        alert("Image upload failed: " + result.error);
                                    }
                                })
                                .catch(error => {
                                    console.error('Error:', error);
                                    alert("Image upload failed.");
                                });
                        }
                    };
                }

                // Initialize three Quill editors with separate image handlers.
                var toolbarOptions = [
                    [{
                        'font': []
                    }],
                    [{
                        'header': [1, 2, 3, 4, 5, 6, false]
                    }],
                    ['bold', 'italic', 'underline', 'strike'],
                    ['blockquote', 'code-block'],
                    [{
                        'script': 'sub'
                    }, {
                        'script': 'super'
                    }],
                    [{
                        'list': 'ordered'
                    }, {
                        'list': 'bullet'
                    }],
                    [{
                        'indent': '-1'
                    }, {
                        'indent': '+1'
                    }],
                    [{
                        'direction': 'rtl'
                    }],
                    [{
                        'size': ['small', false, 'large', 'huge']
                    }],
                    [{
                        'color': []
                    }, {
                        'background': []
                    }],
                    [{
                        'align': []
                    }],
                    ['link', 'image', 'video'],
                    ['clean']
                ];

                var quillDiagnosis = new Quill('#editor_diagnosis', {
                    theme: 'snow',
                    modules: {
                        toolbar: {
                            container: toolbarOptions,
                            handlers: {
                                image: imageHandlerDiagnosis
                            }
                        },
                        syntax: true,
                        ImageResize: {}
                    }
                });
                var quillTreatment = new Quill('#editor_treatment', {
                    theme: 'snow',
                    modules: {
                        toolbar: {
                            container: toolbarOptions,
                            handlers: {
                                image: imageHandlerTreatment
                            }
                        },
                        syntax: true,
                        ImageResize: {}
                    }
                });
                var quillPrescribed = new Quill('#editor_prescribed', {
                    theme: 'snow',
                    modules: {
                        toolbar: {
                            container: toolbarOptions,
                            handlers: {
                                image: imageHandlerPrescribed
                            }
                        },
                        syntax: true,
                        ImageResize: {}
                    }
                });

                // Update Diagnosis button: gather all fields and send via AJAX to update_diagnosis.php
                document.getElementById('updateDiagnosisBtn').addEventListener('click', function() {
                    // Set hidden inputs with each editor's HTML content
                    document.getElementById('diagnosis_input').value = quillDiagnosis.root.innerHTML;
                    document.getElementById('treatment_plan_input').value = quillTreatment.root.innerHTML;
                    document.getElementById('prescribed_meds_input').value = quillPrescribed.root.innerHTML;
                    // Gather the rest of the form data
                    var formData = new URLSearchParams(new FormData(document.getElementById('editDiagnosisForm')));
                    fetch('update_diagnosis.php', {
                            method: 'POST',
                            headers: {
                                'Content-Type': 'application/x-www-form-urlencoded'
                            },
                            body: formData.toString()
                        })
                        .then(response => response.text())
                        .then(data => {
                            alert(data);
                            location.reload();
                        })
                        .catch(error => {
                            console.error('Error:', error);
                            alert("An error occurred while updating the diagnosis.");
                        });
                });

                // Setup Edit Report modal population and auto-show Reports tab if indicated
                document.addEventListener('DOMContentLoaded', function() {
                    let hash = window.location.hash;
                    if (hash === '#reports-tab') {
                        let triggerEl = document.querySelector('button[data-bs-target="#reportsTabContent"]');
                        if (triggerEl) {
                            let tab = new bootstrap.Tab(triggerEl);
                            tab.show();
                        }
                    }
                    var editReportModalEl = document.getElementById('editReportModal');
                    if (editReportModalEl) {
                        editReportModalEl.addEventListener('show.bs.modal', function(event) {
                            if (!event.relatedTarget) return;
                            var button = event.relatedTarget;
                            var repData = JSON.parse(button.getAttribute('data-report') || '{}');
                            document.getElementById('report_id_edit').value = repData.ReportID || '';
                            document.getElementById('report_type_edit').value = repData.ReportType || 'Other';
                            document.getElementById('report_date_edit').value = repData.ReportDate || '';
                            document.getElementById('remarks_edit_report').value = repData.remarks || '';
                        });
                    }
                });
            </script>
</body>

</html>