/*!
 * quill-image-resize-module-patched.js
 * A patched image-resize module for Quill 2.x.
 * This module adds an overlay with a single resize handle to images.
 */
(function () {
    'use strict';

    // Make sure Quill is loaded
    if (typeof Quill === 'undefined') {
        console.error('Quill is not defined');
        return;
    }

    class ImageResize {
        constructor(quill, options) {
            this.quill = quill;
            this.options = options || {};
            this.img = null;           // currently selected image element
            this.overlay = null;       // overlay element for resizing
            this.handle = null;        // resize handle element
            this.dragging = false;     // flag to indicate if resizing is in progress

            // Bind methods
            this.handleClick = this.handleClick.bind(this);
            this.handleMouseDown = this.handleMouseDown.bind(this);
            this.handleMouseMove = this.handleMouseMove.bind(this);
            this.handleMouseUp = this.handleMouseUp.bind(this);

            // Listen for clicks on the editor root
            this.quill.root.addEventListener('click', this.handleClick);
            // Update overlay on window resize
            window.addEventListener('resize', () => this.updateOverlay());
        }

        handleClick(e) {
            // If an image was clicked, select it
            if (e.target && e.target.tagName && e.target.tagName.toUpperCase() === 'IMG') {
                this.selectImage(e.target);
            } else {
                this.hideOverlay();
            }
        }

        selectImage(img) {
            if (this.img === img) return; // already selected
            this.img = img;
            this.showOverlay();
            this.updateOverlay();
        }

        createOverlay() {
            // Create the overlay element if it does not exist
            if (!this.overlay) {
                this.overlay = document.createElement('div');
                this.overlay.classList.add('ql-image-resize-overlay');
                Object.assign(this.overlay.style, {
                    position: 'absolute',
                    border: '2px dashed #06C',
                    boxSizing: 'border-box',
                    pointerEvents: 'none'
                });
                document.body.appendChild(this.overlay);
            }
            // Create the resize handle if it does not exist
            if (!this.handle) {
                this.handle = document.createElement('div');
                this.handle.classList.add('ql-image-resize-handle');
                Object.assign(this.handle.style, {
                    position: 'absolute',
                    width: '12px',
                    height: '12px',
                    background: '#06C',
                    cursor: 'nwse-resize',
                    pointerEvents: 'all'
                });
                this.overlay.appendChild(this.handle);
                // Attach mouse events to the handle
                this.handle.addEventListener('mousedown', this.handleMouseDown);
            }
        }

        showOverlay() {
            this.createOverlay();
            this.overlay.style.display = 'block';
        }

        hideOverlay() {
            if (this.overlay) {
                this.overlay.style.display = 'none';
            }
            this.img = null;
        }

        updateOverlay() {
            if (!this.img || !this.overlay) return;
            const rect = this.img.getBoundingClientRect();
            Object.assign(this.overlay.style, {
                left: rect.left + window.pageXOffset + 'px',
                top: rect.top + window.pageYOffset + 'px',
                width: rect.width + 'px',
                height: rect.height + 'px'
            });
            // Place the resize handle at the bottom-right corner of the image
            Object.assign(this.handle.style, {
                left: (rect.width - 12) + 'px',
                top: (rect.height - 12) + 'px'
            });
        }

        handleMouseDown(e) {
            e.preventDefault();
            e.stopPropagation();
            this.dragging = true;
            this.startX = e.pageX;
            this.startY = e.pageY;
            const rect = this.img.getBoundingClientRect();
            this.startWidth = rect.width;
            this.startHeight = rect.height;
            // Attach listeners to the document to track mouse movement and mouseup
            document.addEventListener('mousemove', this.handleMouseMove);
            document.addEventListener('mouseup', this.handleMouseUp);
        }

        handleMouseMove(e) {
            if (!this.dragging) return;
            const dx = e.pageX - this.startX;
            const dy = e.pageY - this.startY;
            let newWidth = this.startWidth + dx;
            let newHeight = this.startHeight + dy;
            // Set minimum size limits
            if (newWidth < 50) newWidth = 50;
            if (newHeight < 50) newHeight = 50;
            // Update image dimensions via inline styles
            this.img.style.width = newWidth + 'px';
            this.img.style.height = newHeight + 'px';
            this.updateOverlay();
        }

        handleMouseUp(e) {
            this.dragging = false;
            document.removeEventListener('mousemove', this.handleMouseMove);
            document.removeEventListener('mouseup', this.handleMouseUp);
        }
    }

    // Register the module with Quill under the key "modules/ImageResize"
    Quill.register('modules/ImageResize', ImageResize);
})();
