<?php

/**
 * globalFollowUps.php
 *
 * GLOBAL (ALL-PATIENTS) FOLLOW-UPS PAGE
 * Incorporates logic from patientProfile.php (Follow-Ups tab) + staff restrictions,
 * plus insertion into follow_up_history, auto-create appointment, etc.
 */

include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");
header("Pragma: no-cache");

// user session
$currentUserID = $_SESSION['user_id'] ?? null;
$userRole      = $_SESSION['role']    ?? 'staff';
if (!$currentUserID) {
    die("No valid user session. Please log in.");
}

// flash messages
if (!isset($_SESSION['error']))   $_SESSION['error']   = '';
if (!isset($_SESSION['success'])) $_SESSION['success'] = '';
$errorMsg   = $_SESSION['error'];
$successMsg = $_SESSION['success'];
$_SESSION['error']   = '';
$_SESSION['success'] = '';

// helper: insertFollowUpHistory
function insertFollowUpHistory(mysqli $conn, array $oldData, int $editedBy, string $actionType)
{
    $sql = "
      INSERT INTO follow_up_history (
        FollowUpID,
        PatientID,
        AppointmentID,
        FollowUpDate,
        StatusUpdate,
        FollowUpType,
        NextFollowUpDate,
        Remarks,
        EditedBy,
        EditedAt,
        ActionType,
        FollowUpStatus
      ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, NOW(), ?, ?)
    ";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param(
        "iiisssssiss",
        $oldData['FollowUpID'],
        $oldData['PatientID'],
        $oldData['AppointmentID'],
        $oldData['FollowUpDate'],
        $oldData['StatusUpdate'],
        $oldData['FollowUpType'],
        $oldData['NextFollowUpDate'],
        $oldData['Remarks'],
        $editedBy,
        $actionType,
        $oldData['FollowUpStatus']
    );
    $stmt->execute();
    $stmt->close();
}

// staff no-backdate
function staffCannotBackdate($dateStr)
{
    // If staff => compare with current date/time
    $nowDT = date('Y-m-d H:i');
    return ($dateStr < $nowDT);
}

// (POST) => add/edit/delete
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $fuAction = $_POST['followup_action'] ?? '';

    // ADD Follow-Up
    if ($fuAction === 'addFollowUp') {
        $pID          = (int)($_POST['patient_id'] ?? 0);
        $fuDT         = $_POST['followup_datetime'] ?? '';
        $statusUpdate = trim($_POST['status_update'] ?? '');
        $fuType       = $_POST['followup_type']      ?? 'Call';
        $nextDT       = $_POST['next_followup_date'] ?? null;
        $remarks      = trim($_POST['remarks']       ?? '');
        $createAppt   = !empty($_POST['create_appointment']);
        $apptDT       = $_POST['appointment_datetime'] ?? '';
        $fuStatus     = 'Pending'; // default

        // staff => no backdate
        if ($userRole === 'staff') {
            // fuDT => "YYYY-MM-DDTHH:MM"
            if (staffCannotBackdate(str_replace('T', ' ', $fuDT))) {
                $_SESSION['error'] = "Staff cannot add Follow-Up in the past.";
                header("Location: globalFollowUps.php");
                exit;
            }
            if ($createAppt && !empty($apptDT)) {
                if (staffCannotBackdate(str_replace('T', ' ', $apptDT))) {
                    $_SESSION['error'] = "Staff cannot create a backdated Appointment from Follow-Up.";
                    header("Location: globalFollowUps.php");
                    exit;
                }
            }
        }

        // parse fuDT => date/time
        $conn->begin_transaction();
        try {
            // Insert follow_up
            $fuSql = "
              INSERT INTO follow_up (
                PatientID,
                AppointmentID,
                FollowUpDate,
                StatusUpdate,
                FollowUpType,
                NextFollowUpDate,
                Remarks,
                FollowUpStatus,
                CreatedBy,
                UpdatedBy,
                CreatedAt,
                UpdatedAt
              ) VALUES (?, NULL, ?, ?, ?, ?, ?, ?, ?, ?, NOW(), NOW())
            ";
            $stmtFU = $conn->prepare($fuSql);
            // convert "YYYY-MM-DDTHH:MM" => "YYYY-MM-DD HH:MM:00"
            $fuDateTime = '';
            if (strpos($fuDT, 'T') !== false) {
                [$d, $t] = explode('T', $fuDT);
                $fuDateTime = $d . ' ' . $t . ':00';
            } else {
                $fuDateTime = date('Y-m-d H:i:s');
            }
            $stmtFU->bind_param(
                'isssssii',
                $pID,
                $fuDateTime,
                $statusUpdate,
                $fuType,
                $nextDT,
                $remarks,
                $fuStatus,
                $currentUserID,
                $currentUserID
            );
            $stmtFU->execute();
            $newFUID = $stmtFU->insert_id;
            $stmtFU->close();

            // Insert follow_up_history => 'ADD'
            $rowFU = [
                'FollowUpID'       => $newFUID,
                'PatientID'        => $pID,
                'AppointmentID'    => null,
                'FollowUpDate'     => $fuDateTime,
                'StatusUpdate'     => $statusUpdate,
                'FollowUpType'     => $fuType,
                'NextFollowUpDate' => $nextDT,
                'Remarks'          => $remarks,
                'FollowUpStatus'   => $fuStatus
            ];
            insertFollowUpHistory($conn, $rowFU, $currentUserID, 'ADD');

            // If create Appointment
            if ($createAppt && !empty($apptDT)) {
                // parse
                $apptDate = date('Y-m-d');
                $apptTime = '09:00:00';
                if (strpos($apptDT, 'T') !== false) {
                    [$d2, $t2] = explode('T', $apptDT);
                    $apptDate = $d2;
                    $apptTime = $t2 . ':00';
                }
                // Insert new appointment
                $apptSQL = "
                  INSERT INTO appointments (
                    PatientID,
                    FollowUpID,
                    AppointmentDate,
                    AppointmentTime,
                    Purpose,
                    Status,
                    Remarks,
                    CreatedBy,
                    UpdatedBy,
                    CreatedAt,
                    UpdatedAt
                  ) VALUES (?, ?, ?, ?, 'Follow-Up Appointment', 'Scheduled', 'Auto-created from Follow-Up', ?, ?, NOW(), NOW())
                ";
                $stA = $conn->prepare($apptSQL);
                $stA->bind_param(
                    'iisssii',
                    $pID,
                    $newFUID,
                    $apptDate,
                    $apptTime,
                    $currentUserID,
                    $currentUserID
                );
                $stA->execute();
                $newApptID = $stA->insert_id;
                $stA->close();

                // insert appointments_history => 'ADD'
                $apHistRow = [
                    'AppointmentID'   => $newApptID,
                    'PatientID'       => $pID,
                    'FollowUpID'      => $newFUID,
                    'AppointmentDate' => $apptDate,
                    'AppointmentTime' => $apptTime,
                    'Purpose'         => 'Follow-Up Appointment',
                    'Status'          => 'Scheduled',
                    'Remarks'         => 'Auto-created from Follow-Up'
                ];
                // You can reuse your insertAppointmentHistory if desired
                // or just do a simple function here if you have it
                // (omitted for brevity)...

                // update follow_up => store new Appt ID
                $uFUsql = "UPDATE follow_up SET AppointmentID=? WHERE FollowUpID=?";
                $uFUst  = $conn->prepare($uFUsql);
                $uFUst->bind_param('ii', $newApptID, $newFUID);
                $uFUst->execute();
                $uFUst->close();

                // update follow_up_history => 'EDIT' to reflect new AppointmentID
                $rowFU['AppointmentID'] = $newApptID;
                insertFollowUpHistory($conn, $rowFU, $currentUserID, 'EDIT');
            }

            $conn->commit();
            $_SESSION['success'] = "Follow-Up #$newFUID created.";
        } catch (Exception $ex) {
            $conn->rollback();
            $_SESSION['error'] = "Error adding Follow-Up: " . $ex->getMessage();
        }
        header("Location: globalFollowUps.php");
        exit;
    }

    // EDIT Follow-Up
    elseif ($fuAction === 'editFollowUp') {
        $fuID    = (int)($_POST['followup_id'] ?? 0);
        $pID     = (int)($_POST['patient_id']  ?? 0);
        $fuDT    = $_POST['followup_datetime'] ?? '';
        $statUpd = trim($_POST['status_update'] ?? '');
        $fuType  = $_POST['followup_type']     ?? 'Call';
        $nextDT  = $_POST['next_followup_date'] ?? null;
        $remarks = trim($_POST['remarks']      ?? '');
        $fuStatus = $_POST['followup_status']   ?? 'Pending';

        if ($userRole === 'staff') {
            if (staffCannotBackdate(str_replace('T', ' ', $fuDT))) {
                $_SESSION['error'] = "Staff cannot backdate a Follow-Up.";
                header("Location: globalFollowUps.php");
                exit;
            }
        }

        // fetch old row
        $oldSQL = "SELECT * FROM follow_up WHERE FollowUpID=? LIMIT 1";
        $stOld  = $conn->prepare($oldSQL);
        $stOld->bind_param('i', $fuID);
        $stOld->execute();
        $rOld = $stOld->get_result();
        if ($rOld->num_rows < 1) {
            $_SESSION['error'] = "Follow-Up #$fuID not found.";
            header("Location: globalFollowUps.php");
            exit;
        }
        $oldFU = $rOld->fetch_assoc();
        $stOld->close();

        // parse fuDT => "YYYY-MM-DD HH:MM:00"
        $fuDateTime = '';
        if (strpos($fuDT, 'T') !== false) {
            [$d, $t] = explode('T', $fuDT);
            $fuDateTime = $d . ' ' . $t . ':00';
        } else {
            $fuDateTime = date('Y-m-d H:i:s');
        }

        $conn->begin_transaction();
        try {
            $upSQL = "
              UPDATE follow_up
              SET PatientID=?,
                  FollowUpDate=?,
                  StatusUpdate=?,
                  FollowUpType=?,
                  NextFollowUpDate=?,
                  Remarks=?,
                  FollowUpStatus=?,
                  UpdatedBy=?,
                  UpdatedAt=NOW()
              WHERE FollowUpID=?
            ";
            $stUp = $conn->prepare($upSQL);
            $stUp->bind_param(
                'isssssiii',
                $pID,
                $fuDateTime,
                $statUpd,
                $fuType,
                $nextDT,
                $remarks,
                $fuStatus,
                $currentUserID,
                $fuID
            );
            $stUp->execute();
            $stUp->close();

            // insert follow_up_history => 'EDIT'
            $oldData = [
                'FollowUpID'       => (int)$oldFU['FollowUpID'],
                'PatientID'        => (int)$oldFU['PatientID'],
                'AppointmentID'    => $oldFU['AppointmentID'] ? (int)$oldFU['AppointmentID'] : null,
                'FollowUpDate'     => $oldFU['FollowUpDate'],
                'StatusUpdate'     => $oldFU['StatusUpdate'],
                'FollowUpType'     => $oldFU['FollowUpType'],
                'NextFollowUpDate' => $oldFU['NextFollowUpDate'],
                'Remarks'          => $oldFU['Remarks'],
                'FollowUpStatus'   => $oldFU['FollowUpStatus']
            ];
            insertFollowUpHistory($conn, $oldData, $currentUserID, 'EDIT');

            $conn->commit();
            $_SESSION['success'] = "Follow-Up #{$fuID} updated.";
        } catch (Exception $ex) {
            $conn->rollback();
            $_SESSION['error'] = "Error editing Follow-Up: " . $ex->getMessage();
        }
        header("Location: globalFollowUps.php");
        exit;
    }

    // DELETE
    elseif ($fuAction === 'deleteFollowUp') {
        if ($userRole === 'staff') {
            $_SESSION['error'] = "Staff cannot delete follow-ups.";
            header("Location: globalFollowUps.php");
            exit;
        }
        $fuID = (int)($_POST['followup_id'] ?? 0);
        if ($fuID > 0) {
            // fetch
            $oldSQL = "SELECT * FROM follow_up WHERE FollowUpID=? LIMIT 1";
            $stOld  = $conn->prepare($oldSQL);
            $stOld->bind_param('i', $fuID);
            $stOld->execute();
            $rOld = $stOld->get_result();
            $oldFU = null;
            if ($rOld->num_rows > 0) {
                $oldFU = $rOld->fetch_assoc();
            }
            $stOld->close();

            if ($oldFU) {
                $conn->begin_transaction();
                try {
                    $delQ = "DELETE FROM follow_up WHERE FollowUpID=?";
                    $stD  = $conn->prepare($delQ);
                    $stD->bind_param('i', $fuID);
                    $stD->execute();
                    $stD->close();

                    // insert follow_up_history => 'DELETE'
                    $rowH = [
                        'FollowUpID'       => (int)$oldFU['FollowUpID'],
                        'PatientID'        => (int)$oldFU['PatientID'],
                        'AppointmentID'    => $oldFU['AppointmentID'] ? (int)$oldFU['AppointmentID'] : null,
                        'FollowUpDate'     => $oldFU['FollowUpDate'],
                        'StatusUpdate'     => $oldFU['StatusUpdate'],
                        'FollowUpType'     => $oldFU['FollowUpType'],
                        'NextFollowUpDate' => $oldFU['NextFollowUpDate'],
                        'Remarks'          => $oldFU['Remarks'],
                        'FollowUpStatus'   => $oldFU['FollowUpStatus']
                    ];
                    insertFollowUpHistory($conn, $rowH, $currentUserID, 'DELETE');

                    $conn->commit();
                    $_SESSION['success'] = "Follow-Up #$fuID deleted.";
                } catch (Exception $ex) {
                    $conn->rollback();
                    $_SESSION['error'] = "Error deleting Follow-Up: " . $ex->getMessage();
                }
            }
        }
        header("Location: globalFollowUps.php");
        exit;
    }
}

// GET => listing + filter
$fuStart  = $_GET['fu_start']  ?? '';
$fuEnd    = $_GET['fu_end']    ?? '';
$fuStatus = $_GET['fu_status'] ?? '';
$searchNm = $_GET['search_name'] ?? '';
$apptID   = isset($_GET['appointment_id']) ? (int)$_GET['appointment_id'] : 0;

$clauses = [];
if (preg_match('/^\d{4}-\d{2}-\d{2}$/', $fuStart) && preg_match('/^\d{4}-\d{2}-\d{2}$/', $fuEnd)) {
    $clauses[] = "DATE(f.FollowUpDate) BETWEEN '$fuStart' AND '$fuEnd'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $fuStart)) {
    $clauses[] = "DATE(f.FollowUpDate) >= '$fuStart'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $fuEnd)) {
    $clauses[] = "DATE(f.FollowUpDate) <= '$fuEnd'";
}
if (in_array($fuStatus, ['Pending', 'Done'], true)) {
    $clauses[] = "f.FollowUpStatus='$fuStatus'";
}
if ($apptID > 0) {
    $clauses[] = "f.AppointmentID=$apptID";
}
if (!empty($searchNm)) {
    $esc = $conn->real_escape_string($searchNm);
    $clauses[] = "(p.first_name LIKE '%$esc%' OR p.last_name LIKE '%$esc%')";
}
$whereStr = '';
if (!empty($clauses)) {
    $whereStr = 'WHERE ' . implode(' AND ', $clauses);
}

// pagination
$perPage = 10;
$page    = isset($_GET['pg']) ? (int)$_GET['pg'] : 1;
if ($page < 1) $page = 1;
$offset = ($page - 1) * $perPage;

// count
$cSQL = "
  SELECT COUNT(f.FollowUpID) AS total
  FROM follow_up f
  LEFT JOIN patients p ON f.PatientID=p.id
  $whereStr
";
$resC = $conn->query($cSQL);
$total = (int)($resC->fetch_assoc()['total'] ?? 0);
$totalPages = ceil($total / $perPage);

// fetch
$sqlMain = "
  SELECT
    f.*,
    p.first_name AS p_first,
    p.last_name  AS p_last,
    a.AppointmentDate,
    a.AppointmentTime,
    u1.username AS created_by_name,
    u2.username AS updated_by_name
  FROM follow_up f
  LEFT JOIN patients p     ON f.PatientID=p.id
  LEFT JOIN appointments a ON f.AppointmentID=a.AppointmentID
  LEFT JOIN users u1       ON f.CreatedBy=u1.id
  LEFT JOIN users u2       ON f.UpdatedBy=u2.id
  $whereStr
  ORDER BY f.FollowUpDate DESC, f.FollowUpID DESC
  LIMIT $perPage OFFSET $offset
";
$resM = $conn->query($sqlMain);
$followUps = [];
if ($resM && $resM->num_rows > 0) {
    while ($row = $resM->fetch_assoc()) {
        $followUps[] = $row;
    }
}
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <title>Global Follow-Ups</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">
    <link href="<?php echo $baseURL; ?>assets/css/styles.css" rel="stylesheet">
</head>

<body>
    <div id="wrapper">
        <?php include ROOT_PATH . 'includes/navbar.php'; ?>
        <div id="page-content-wrapper">
            <?php include ROOT_PATH . 'includes/sidebar.php'; ?>

            <div class="container-fluid mt-4">
                <!-- errors / success -->
                <?php if (!empty($errorMsg)): ?>
                    <div class="alert alert-danger">
                        <i class="fas fa-exclamation-triangle"></i> <?php echo htmlspecialchars($errorMsg); ?>
                    </div>
                <?php endif; ?>
                <?php if (!empty($successMsg)): ?>
                    <div class="alert alert-success">
                        <i class="fas fa-check-circle"></i> <?php echo htmlspecialchars($successMsg); ?>
                    </div>
                <?php endif; ?>

                <div class="card mb-3">
                    <div class="card-body bg-primary text-white text-center rounded">
                        <h4 class="card-title mb-1">All Follow-Ups</h4>
                        <p class="mb-0">Manage &amp; View Follow-Ups Across All Patients</p>
                    </div>
                </div>

                <!-- filter -->
                <form class="row g-3 mb-3">
                    <div class="col-md-2">
                        <label class="form-label">Start Date</label>
                        <input type="date" class="form-control" name="fu_start" value="<?php echo htmlspecialchars($fuStart); ?>">
                    </div>
                    <div class="col-md-2">
                        <label class="form-label">End Date</label>
                        <input type="date" class="form-control" name="fu_end" value="<?php echo htmlspecialchars($fuEnd); ?>">
                    </div>
                    <div class="col-md-2">
                        <label class="form-label">Status</label>
                        <select name="fu_status" class="form-select">
                            <option value="">All</option>
                            <option value="Pending" <?php if ($fuStatus === 'Pending') echo 'selected'; ?>>Pending</option>
                            <option value="Done" <?php if ($fuStatus === 'Done') echo 'selected'; ?>>Done</option>
                        </select>
                    </div>
                    <div class="col-md-2">
                        <label class="form-label">Appointment ID</label>
                        <input type="number" class="form-control" name="appointment_id" value="<?php echo $apptID > 0 ? $apptID : ''; ?>">
                    </div>
                    <div class="col-md-2">
                        <label class="form-label">Patient Name</label>
                        <input type="text" class="form-control" name="search_name" value="<?php echo htmlspecialchars($searchNm); ?>">
                    </div>
                    <div class="col-md-2 d-flex align-items-end">
                        <button class="btn btn-primary w-100"><i class="fas fa-filter"></i> Filter</button>
                    </div>
                </form>

                <!-- add btn -->
                <div class="text-end mb-3">
                    <button class="btn btn-success" data-bs-toggle="modal" data-bs-target="#addFollowUpModal">
                        <i class="fas fa-plus"></i> Add Follow-Up
                    </button>
                </div>

                <!-- table -->
                <div class="table-responsive">
                    <table class="table table-bordered text-center align-middle">
                        <thead class="table-light">
                            <tr>
                                <th>ID</th>
                                <th>Patient</th>
                                <th>Follow-Up Date</th>
                                <th>Next FU</th>
                                <th>Type</th>
                                <th>Status Update</th>
                                <th>Status</th>
                                <th>Appt</th>
                                <th>Actions</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (!empty($followUps)): ?>
                                <?php foreach ($followUps as $fu): ?>
                                    <?php
                                    $fuID   = (int)$fu['FollowUpID'];
                                    $pName  = trim($fu['p_first'] . ' ' . $fu['p_last']);
                                    $fuData = [
                                        'FollowUpID'       => $fuID,
                                        'PatientID'        => $fu['PatientID'],
                                        'AppointmentID'    => $fu['AppointmentID'],
                                        'FollowUpDate'     => $fu['FollowUpDate'],
                                        'StatusUpdate'     => $fu['StatusUpdate'],
                                        'FollowUpType'     => $fu['FollowUpType'],
                                        'NextFollowUpDate' => $fu['NextFollowUpDate'],
                                        'Remarks'          => $fu['Remarks'],
                                        'FollowUpStatus'   => $fu['FollowUpStatus']
                                    ];
                                    ?>
                                    <tr>
                                        <td><?php echo $fuID; ?></td>
                                        <td><?php echo htmlspecialchars($pName) . " (ID:{$fu['PatientID']})"; ?></td>
                                        <td><?php echo htmlspecialchars($fu['FollowUpDate']); ?></td>
                                        <td><?php echo $fu['NextFollowUpDate'] ?: '-'; ?></td>
                                        <td><?php echo htmlspecialchars($fu['FollowUpType']); ?></td>
                                        <td style="white-space:pre-wrap;"><?php echo nl2br(htmlspecialchars($fu['StatusUpdate'] ?? '')); ?></td>
                                        <td>
                                            <?php if ($fu['FollowUpStatus'] === 'Done'): ?>
                                                <span class="badge bg-success">Done</span>
                                            <?php else: ?>
                                                <span class="badge bg-warning text-dark">Pending</span>
                                            <?php endif; ?>
                                        </td>
                                        <td>
                                            <?php if ($fu['AppointmentID']): ?>
                                                <a class="btn btn-sm btn-info"
                                                    href="<?php echo $baseURL; ?>pages/appointments/globalAppointments.php?appointment_id=<?php echo (int)$fu['AppointmentID']; ?>"
                                                    target="_blank">
                                                    Appt #<?php echo $fu['AppointmentID']; ?>
                                                </a>
                                            <?php else: ?>
                                                <em class="text-muted">-</em>
                                            <?php endif; ?>
                                        </td>
                                        <td>
                                            <!-- EDIT (staff/admin) -->
                                            <?php if ($userRole === 'staff' || $userRole === 'admin'): ?>
                                                <button class="btn btn-sm btn-warning"
                                                    data-bs-toggle="modal"
                                                    data-bs-target="#editFollowUpModal"
                                                    data-followup='<?php echo json_encode($fuData); ?>'>
                                                    <i class="fas fa-edit"></i>
                                                </button>
                                            <?php endif; ?>

                                            <!-- DELETE => admin only -->
                                            <?php if ($userRole === 'admin'): ?>
                                                <form method="POST" class="d-inline-block" onsubmit="return confirm('Delete this follow-up?');">
                                                    <input type="hidden" name="followup_action" value="deleteFollowUp">
                                                    <input type="hidden" name="followup_id" value="<?php echo $fuID; ?>">
                                                    <button class="btn btn-sm btn-danger">
                                                        <i class="fas fa-trash"></i>
                                                    </button>
                                                </form>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="9">No follow-ups found.</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <!-- pagination -->
                <?php if ($totalPages > 1): ?>
                    <nav class="mt-3">
                        <ul class="pagination justify-content-center">
                            <!-- prev -->
                            <?php if ($page > 1): ?>
                                <li class="page-item">
                                    <a class="page-link"
                                        href="?pg=<?php echo ($page - 1); ?>&fu_start=<?php echo urlencode($fuStart); ?>&fu_end=<?php echo urlencode($fuEnd); ?>&fu_status=<?php echo urlencode($fuStatus); ?>&appointment_id=<?php echo $apptID; ?>&search_name=<?php echo urlencode($searchNm); ?>">
                                        &laquo; Prev
                                    </a>
                                </li>
                            <?php else: ?>
                                <li class="page-item disabled"><span class="page-link">&laquo; Prev</span></li>
                            <?php endif; ?>

                            <?php for ($i = 1; $i <= $totalPages; $i++): ?>
                                <li class="page-item <?php if ($i == $page) echo 'active'; ?>">
                                    <a class="page-link"
                                        href="?pg=<?php echo $i; ?>&fu_start=<?php echo urlencode($fuStart); ?>&fu_end=<?php echo urlencode($fuEnd); ?>&fu_status=<?php echo urlencode($fuStatus); ?>&appointment_id=<?php echo $apptID; ?>&search_name=<?php echo urlencode($searchNm); ?>">
                                        <?php echo $i; ?>
                                    </a>
                                </li>
                            <?php endfor; ?>

                            <!-- next -->
                            <?php if ($page < $totalPages): ?>
                                <li class="page-item">
                                    <a class="page-link"
                                        href="?pg=<?php echo ($page + 1); ?>&fu_start=<?php echo urlencode($fuStart); ?>&fu_end=<?php echo urlencode($fuEnd); ?>&fu_status=<?php echo urlencode($fuStatus); ?>&appointment_id=<?php echo $apptID; ?>&search_name=<?php echo urlencode($searchNm); ?>">
                                        Next &raquo;
                                    </a>
                                </li>
                            <?php else: ?>
                                <li class="page-item disabled"><span class="page-link">Next &raquo;</span></li>
                            <?php endif; ?>
                        </ul>
                    </nav>
                <?php endif; ?>

            </div>
        </div>
    </div>

    <!-- ADD Follow-Up Modal -->
    <div class="modal fade" id="addFollowUpModal" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog">
            <form class="modal-content" method="POST">
                <input type="hidden" name="followup_action" value="addFollowUp">
                <div class="modal-header">
                    <h5 class="modal-title">Add Follow-Up</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <!-- patient_id -->
                    <div class="mb-3">
                        <label class="form-label">Patient ID</label>
                        <input type="number" class="form-control" name="patient_id" required>
                    </div>
                    <!-- followup_datetime -->
                    <div class="mb-3">
                        <label class="form-label">Follow-Up Date/Time</label>
                        <input type="datetime-local" class="form-control" name="followup_datetime" required>
                    </div>
                    <!-- status_update -->
                    <div class="mb-3">
                        <label class="form-label">Status Update</label>
                        <textarea class="form-control" name="status_update"></textarea>
                    </div>
                    <!-- followup_type -->
                    <div class="mb-3">
                        <label class="form-label">Follow-Up Type</label>
                        <select class="form-select" name="followup_type">
                            <option value="Call">Call</option>
                            <option value="Message">Message</option>
                            <option value="In-Person">In-Person</option>
                        </select>
                    </div>
                    <!-- next_followup_date -->
                    <div class="mb-3">
                        <label class="form-label">Next Follow-Up Date</label>
                        <input type="date" class="form-control" name="next_followup_date">
                    </div>
                    <!-- remarks -->
                    <div class="mb-3">
                        <label class="form-label">Remarks</label>
                        <textarea class="form-control" name="remarks"></textarea>
                    </div>
                    <!-- create_appointment? -->
                    <div class="form-check mb-3">
                        <input class="form-check-input" type="checkbox" name="create_appointment" value="1" id="chkCreateAppt">
                        <label class="form-check-label" for="chkCreateAppt">
                            Also create an Appointment
                        </label>
                    </div>
                    <div class="border p-2 bg-light mb-3">
                        <label class="form-label">New Appointment Date/Time</label>
                        <input type="datetime-local" class="form-control" name="appointment_datetime">
                    </div>
                </div>
                <div class="modal-footer">
                    <button class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    <button class="btn btn-primary">Add Follow-Up</button>
                </div>
            </form>
        </div>
    </div>

    <!-- EDIT Follow-Up Modal -->
    <div class="modal fade" id="editFollowUpModal" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog">
            <form class="modal-content" method="POST">
                <input type="hidden" name="followup_action" value="editFollowUp">
                <input type="hidden" name="followup_id" id="followup_id_edit">
                <div class="modal-header">
                    <h5 class="modal-title">Edit Follow-Up</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">

                    <div class="mb-3">
                        <label class="form-label">Patient ID</label>
                        <input type="number" class="form-control" name="patient_id" id="patient_id_edit_fu" required>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Follow-Up Date/Time</label>
                        <input type="datetime-local" class="form-control" name="followup_datetime" id="followup_datetime_edit" required>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Status Update</label>
                        <textarea class="form-control" name="status_update" id="status_update_edit"></textarea>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Follow-Up Type</label>
                        <select class="form-select" name="followup_type" id="followup_type_edit">
                            <option value="Call">Call</option>
                            <option value="Message">Message</option>
                            <option value="In-Person">In-Person</option>
                        </select>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Next Follow-Up Date</label>
                        <input type="date" class="form-control" name="next_followup_date" id="next_followup_date_edit">
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Remarks</label>
                        <textarea class="form-control" name="remarks" id="remarks_edit_fu"></textarea>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Follow-Up Status</label>
                        <select class="form-select" name="followup_status" id="followup_status_edit">
                            <option value="Pending">Pending</option>
                            <option value="Done">Done</option>
                        </select>
                    </div>

                </div>
                <div class="modal-footer">
                    <button class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    <button class="btn btn-warning">Update Follow-Up</button>
                </div>
            </form>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        document.addEventListener("DOMContentLoaded", function() {
            const editFUel = document.getElementById("editFollowUpModal");
            if (editFUel) {
                editFUel.addEventListener("show.bs.modal", function(ev) {
                    const btn = ev.relatedTarget;
                    if (!btn) return;
                    const fuData = JSON.parse(btn.getAttribute("data-followup") || "{}");
                    document.getElementById("followup_id_edit").value = fuData.FollowUpID || "";
                    document.getElementById("patient_id_edit_fu").value = fuData.PatientID || "";
                    // parse date/time => we have fuData.FollowUpDate => "YYYY-mm-dd HH:ii:ss"
                    // convert => "YYYY-mm-ddTHH:ii"
                    let dtLocal = "";
                    if (fuData.FollowUpDate && fuData.FollowUpDate.length >= 16) {
                        // "2025-01-20 09:00:00"
                        let parts = fuData.FollowUpDate.split(" ");
                        dtLocal = parts[0] + "T" + parts[1].slice(0, 5);
                    }
                    document.getElementById("followup_datetime_edit").value = dtLocal;
                    document.getElementById("status_update_edit").value = fuData.StatusUpdate || "";
                    document.getElementById("followup_type_edit").value = fuData.FollowUpType || "Call";
                    document.getElementById("next_followup_date_edit").value = fuData.NextFollowUpDate || "";
                    document.getElementById("remarks_edit_fu").value = fuData.Remarks || "";
                    document.getElementById("followup_status_edit").value = fuData.FollowUpStatus || "Pending";
                });
            }
        });
    </script>
</body>

</html>