<?php
// pages/msr/printMsr.php
include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// Get the MSR ID
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    echo "Invalid MSR ID.";
    exit;
}
$msr_id = (int)$_GET['id'];

// 1) Fetch MSR header
$stmt = $conn->prepare("
    SELECT
        m.id            AS msr_id,
        m.msr_number,
        m.date_of_msr,
        m.created_at,
        m.approved,
        m.approved_by,
        u.first_name    AS creator_first_name,
        u.last_name     AS creator_last_name,
        a.first_name    AS approver_first_name,
        a.last_name     AS approver_last_name
    FROM msr m
    JOIN users u      ON m.user_id     = u.id
    LEFT JOIN users a ON m.approved_by = a.id
    WHERE m.id = ?
    LIMIT 1
");
$stmt->bind_param("i", $msr_id);
$stmt->execute();
$res = $stmt->get_result();
if ($res->num_rows === 0) {
    echo "MSR not found.";
    exit;
}
$msr = $res->fetch_assoc();
$stmt->close();

// We'll store the date
$msrDate = $msr['date_of_msr'] ?? null;
if (!$msrDate) {
    $msrDate = date('Y-m-d', strtotime($msr['created_at']));
}

// 2) Fetch msr_patients => joined with debts
$sql = "
SELECT
  mp.id AS msr_patient_id,
  mp.patient_id,
  CONCAT(p.first_name,' ', p.last_name) AS patient_name,
  mp.reference,
  mp.medicines,
  mp.treatments,
  r.receipt_number,

  d.id                 AS debts_id,
  d.payment_type,
  d.debt_amount,
  d.discount,
  d.payment_amount,
  d.balance_after_payment
FROM msr_patients mp
JOIN msr m         ON mp.msr_id     = m.id
JOIN patients p    ON mp.patient_id = p.id
LEFT JOIN receipts r ON r.msr_patient_id = mp.id
LEFT JOIN debts d  ON d.msr_id     = mp.msr_id
                  AND d.patient_id = mp.patient_id
WHERE mp.msr_id = ?
ORDER BY mp.id ASC
";
$stmt2 = $conn->prepare($sql);
$stmt2->bind_param("i", $msr_id);
$stmt2->execute();
$result2 = $stmt2->get_result();

$rows = [];

// We'll track sums
$totalSales       = 0.0;  // Gross from 'today_total'
$totalCash        = 0.0;
$totalOnline      = 0.0;
$totalDebts       = 0.0;
$totalDiscount    = 0.0;  // NEW
// We'll compute "sales after discount" from totalSales - totalDiscount

while ($row = $result2->fetch_assoc()) {
    // parse treatments => sum them => today_total
    $todayTotal = 0.0;
    if (!empty($row['treatments'])) {
        $tArr = json_decode($row['treatments'], true);
        if (is_array($tArr)) {
            foreach ($tArr as $tItem) {
                $amt = (float)($tItem['amount'] ?? 0);
                $todayTotal += max(0, $amt);
            }
        }
    }

    // accumulate totals
    $totalSales += $todayTotal;

    // track discount
    $discount = (float)($row['discount'] ?? 0);
    $totalDiscount += $discount; // NEW

    $payType  = $row['payment_type'] ?? 'Cash';
    $payAmt   = (float)($row['payment_amount'] ?? 0);

    // sum up by payment type
    if (strcasecmp($payType, 'Cash') === 0) {
        $totalCash += $payAmt;
    } elseif (strcasecmp($payType, 'Online') === 0) {
        $totalOnline += $payAmt;
    }

    $leftover = (float)($row['balance_after_payment'] ?? 0);
    $totalDebts += $leftover;

    $rows[] = [
        'msr_patient_id' => (int) $row['msr_patient_id'],
        'patient_name'   => $row['patient_name'] ?? '',
        'reference'      => $row['reference']    ?? '',
        'medicines'      => $row['medicines']    ?? '',
        'receipt_number' => $row['receipt_number'] ?? '',
        'payment_type'   => $payType,
        'debt_amount'    => (float)($row['debt_amount'] ?? 0),
        'discount'       => $discount,
        'payment_amount' => $payAmt,
        'balance_after'  => $leftover,
        'today_total'    => $todayTotal,
    ];
}
$stmt2->close();

// compute final "sales after discount"
$salesAfterDiscount = $totalSales - $totalDiscount;
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <title>Print MSR</title>
    <!-- Minimal Bootstrap for styling (optional but nice) -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">

    <!-- 
    PRO TIP: create a dedicated print.css to avoid conflicts
    but we can inline the essential print rules here
  -->
    <style>
        /********************************************
     * 1) Hide Unnecessary Elements for Print
     ********************************************/
        @media print {

            /* Hide any classes you do NOT want to print */
            .navbar,
            .sidebar,
            .footer,
            .actions-buttons {
                display: none !important;
                visibility: hidden !important;
            }
        }

        /********************************************
     * 2) Set the Page Dimensions for A4 
     *    in Landscape Orientation
     ********************************************/
        @page {
            size: A4 landscape;
            margin: 1cm;
            /* Adjust margins as needed */
        }

        /********************************************
     * 3) Align & Scale Content
     ********************************************/
        @media print {
            body {
                margin: 0 !important;
                padding: 0 !important;
            }

            .print-content {
                width: 100%;
                padding: 0;
                box-sizing: border-box;
                font-size: 12px;
                /* Slightly smaller for A4 */
            }

            table {
                width: 100%;
                border-collapse: collapse;
            }

            table th,
            table td {
                border: 1px solid #000;
                padding: 6px;
            }

            header,
            footer {
                display: block;
                text-align: center;
                font-weight: bold;
                margin-bottom: 1cm;
            }
        }

        /* Minimal base styling in normal screen mode */
        body {
            margin: 0;
            padding: 0;
            font-family: Arial, sans-serif;
            font-size: 14px;
        }

        .heading-area {
            text-align: center;
            margin-bottom: 1rem;
        }

        .heading-area h4 {
            margin: 0.5rem 0;
            font-weight: 700;
        }

        .summary-row>div {
            border: 1px solid #ccc;
            border-radius: 4px;
            text-align: center;
            padding: 0.75rem;
            margin-bottom: 1rem;
        }

        .fw-700 {
            font-weight: 700;
        }

        .fs-5 {
            font-size: 1.25rem;
        }

        @media print {
            .table-responsive {
                overflow: visible !important;
            }
        }
    </style>
</head>

<body>
    <div class="container-fluid p-3 print-content">
        <!-- A button to trigger print (in normal screen mode). 
             It won't show in print due to default media rules. -->
        <div class="mb-3 text-end">
            <button class="btn btn-secondary d-print-none" onclick="window.print();">Print</button>
        </div>

        <!-- Heading -->
        <div class="heading-area">
            <h4>Agasthiar Siddha Ayurmed Sdn. Bhd</h4>
            <p>Medicine Sold Report (MSR)</p>
        </div>

        <!-- MSR Info -->
        <div class="mb-3">
            <h6 class="fw-700">MSR Details</h6>
            <div class="row">
                <div class="col-md-4 mb-2">
                    <strong>MSR Number:</strong>
                    <?php echo htmlspecialchars($msr['msr_number']); ?>
                </div>
                <div class="col-md-4 mb-2">
                    <strong>MSR Date:</strong>
                    <?php
                    if ($msrDate) {
                        echo date('d M Y', strtotime($msrDate));
                    } else {
                        echo '-';
                    }
                    ?>
                </div>
                <div class="col-md-4 mb-2">
                    <strong>Created At:</strong>
                    <?php
                    $createdTS = strtotime($msr['created_at']);
                    echo date('d M Y, h:i A', $createdTS);
                    ?>
                </div>
                <div class="col-md-4 mb-2">
                    <strong>Created By:</strong>
                    <?php
                    echo htmlspecialchars(
                        $msr['creator_first_name'] . ' ' . $msr['creator_last_name']
                    );
                    ?>
                </div>
                <div class="col-md-4 mb-2">
                    <strong>Status:</strong>
                    <?php if ((int)$msr['approved'] === 1): ?>
                        <span class="text-success fw-700">Approved</span>
                    <?php else: ?>
                        <span class="text-warning fw-700">Pending</span>
                    <?php endif; ?>
                </div>
                <?php if ((int)$msr['approved'] === 1): ?>
                    <div class="col-md-4 mb-2">
                        <strong>Approved By:</strong>
                        <?php
                        echo htmlspecialchars(
                            $msr['approver_first_name'] . ' ' . $msr['approver_last_name']
                        );
                        ?>
                    </div>
                <?php endif; ?>
            </div>
        </div>

        <!-- Summary Card -->
        <div class="mb-3">
            <h6 class="fw-700">Summary</h6>
            <!-- We now have 6 columns in one row, to accommodate 2 new items -->
            <div class="row summary-row">
                <div class="col-md-2 col-6">
                    <span class="fw-700">Total Sales</span><br>
                    <span class="fs-5">RM <?php echo number_format($totalSales, 2); ?></span>
                </div>
                <div class="col-md-2 col-6">
                    <span class="fw-700">Discount</span><br>
                    <span class="fs-5">RM <?php echo number_format($totalDiscount, 2); ?></span>
                </div>
                <div class="col-md-2 col-6">
                    <span class="fw-700">Sales After Discount</span><br>
                    <span class="fs-5">RM <?php echo number_format($salesAfterDiscount, 2); ?></span>
                </div>
                <div class="col-md-2 col-6">
                    <span class="fw-700">Total Cash</span><br>
                    <span class="fs-5">RM <?php echo number_format($totalCash, 2); ?></span>
                </div>
                <div class="col-md-2 col-6">
                    <span class="fw-700">Total Online</span><br>
                    <span class="fs-5">RM <?php echo number_format($totalOnline, 2); ?></span>
                </div>
                <div class="col-md-2 col-6">
                    <span class="fw-700">Total Debts</span><br>
                    <span class="fs-5">RM <?php echo number_format($totalDebts, 2); ?></span>
                </div>
            </div>
        </div>

        <!-- Table of lines -->
        <div class="table-responsive mb-3">
            <table class="table table-bordered text-center align-middle">
                <thead class="table-light">
                    <tr>
                        <th>No</th>
                        <th>Patient</th>
                        <th>Reference</th>
                        <th>Receipt</th>
                        <th>Medicines</th>
                        <th>Payment Type</th>
                        <th>Today Total (RM)</th>
                        <th>Debt (RM)</th>
                        <th>Discount (RM)</th>
                        <th>Paid (RM)</th>
                        <th>Balance (RM)</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if (!empty($rows)): ?>
                        <?php foreach ($rows as $i => $r): ?>
                            <tr>
                                <td><?php echo $i + 1; ?></td>
                                <td><?php echo htmlspecialchars($r['patient_name']); ?></td>
                                <td><?php echo htmlspecialchars($r['reference']); ?></td>
                                <td><?php echo htmlspecialchars($r['receipt_number']); ?></td>
                                <td><?php echo nl2br(htmlspecialchars($r['medicines'])); ?></td>
                                <td><?php echo htmlspecialchars($r['payment_type']); ?></td>
                                <td><?php echo number_format($r['today_total'], 2); ?></td>
                                <td><?php echo number_format($r['debt_amount'], 2); ?></td>
                                <td><?php echo number_format($r['discount'], 2); ?></td>
                                <td><?php echo number_format($r['payment_amount'], 2); ?></td>
                                <td><?php echo number_format($r['balance_after'], 2); ?></td>
                            </tr>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="11">No patients found in this MSR.</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>

        <!-- Debt Settlement Panel -->
        <div>
            <h6 class="fw-700 text-danger">Debt Settlement (Same Day Only)</h6>
            <p class="text-muted">
                If a patient has leftover for this day, you can do partial or full payments.
            </p>
            <?php
            $debtors = array_filter($rows, fn($r) => ($r['balance_after'] > 0 && $r['payment_type']));
            if (empty($debtors)):
            ?>
                <p>No one owes leftover today.</p>
            <?php else: ?>
                <table class="table table-bordered text-center align-middle">
                    <thead>
                        <tr>
                            <th>Patient</th>
                            <th>Balance (RM)</th>
                            <th>Note</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($debtors as $dd): ?>
                            <tr>
                                <td><?php echo htmlspecialchars($dd['patient_name']); ?></td>
                                <td><?php echo number_format($dd['balance_after'], 2); ?></td>
                                <td>Payment can be done via debt settlement process.</td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            <?php endif; ?>
        </div>

    </div> <!-- /container-fluid -->

    <!-- Minimal JS if needed -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>

</html>