<?php
// pages/msr/printReceipt.php

include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// Validate msr_patient_id
if (!isset($_GET['msr_patient_id']) || !is_numeric($_GET['msr_patient_id'])) {
    echo "Invalid MSR Patient ID.";
    exit;
}

$msr_patient_id = (int) $_GET['msr_patient_id'];

// Fetch data, including receipts and debts (to get discount, paid amounts, etc.)
$sql = "
    SELECT 
        mp.id AS msr_patient_id,
        mp.patient_id,
        mp.treatments,
        mp.medicines,
        IFNULL(r.receipt_number,'') AS receipt_number,

        -- We assume discount/payment/balance come from debts table. 
        -- If your schema differs, adjust accordingly.
        IFNULL(d.discount, 0) AS discount,
        IFNULL(d.payment_amount, 0) AS paid_amount,
        IFNULL(d.balance_after_payment, 0) AS balance_after,

        p.first_name,
        p.last_name,
        p.identificationNumber,

        m.date_of_msr       AS msr_date,
        m.created_at        AS msr_created_at
    FROM msr_patients mp
    JOIN patients p ON mp.patient_id = p.id
    JOIN msr m      ON mp.msr_id     = m.id
    LEFT JOIN receipts r ON mp.id    = r.msr_patient_id
    LEFT JOIN debts d ON (d.msr_id = m.id AND d.patient_id = p.id)
    WHERE mp.id = ?
    LIMIT 1
";
$stmt = $conn->prepare($sql);
if (!$stmt) {
    echo "Database query preparation failed.";
    exit;
}
$stmt->bind_param("i", $msr_patient_id);
if (!$stmt->execute()) {
    echo "Database query execution failed.";
    $stmt->close();
    exit;
}
$result = $stmt->get_result();
if ($result->num_rows === 0) {
    echo "Receipt not found (msr_patient_id: $msr_patient_id).";
    $stmt->close();
    exit;
}

// We have exactly one row
$patient = $result->fetch_assoc();
$stmt->close();

// Build a displayable patient name
$patient['patient_name'] = trim($patient['first_name'] . ' ' . $patient['last_name']);

// Parse treatments JSON
$treatments = [];
$subtotal = 0.0;
if (!empty($patient['treatments'])) {
    $tArr = json_decode($patient['treatments'], true);
    if (is_array($tArr)) {
        foreach ($tArr as $tItem) {
            // Each $tItem might look like { "type": "Therapy", "amount": "50" }
            $desc   = isset($tItem['type'])   ? $tItem['type']   : 'Item';
            $amount = isset($tItem['amount']) ? (float) $tItem['amount'] : 0.0;

            // Keep track
            $treatments[] = [
                'desc'   => $desc,
                'amount' => $amount
            ];

            $subtotal += $amount;
        }
    }
}

// If discount from debts is present:
$discount   = (float) $patient['discount'];
$paidAmount = (float) $patient['paid_amount'];
$balance    = (float) $patient['balance_after'];

// Calculate final total
$total = $subtotal - $discount;
if ($total < 0) {
    $total = 0;
}

// Prepare date/time
$msrDate = $patient['msr_date'] ?: $patient['msr_created_at'];
$msrDateFormatted = $msrDate ? date('d M Y', strtotime($msrDate)) : date('d M Y');

?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <title>Receipt - <?php echo htmlspecialchars($patient['receipt_number']); ?></title>
    <!-- Minimal styling / Bootstrap is optional -->
    <style>
        body {
            font-family: Arial, sans-serif;
        }

        .receipt-header,
        .receipt-footer {
            text-align: center;
        }

        .company-logo {
            max-height: 80px;
            margin-top: 20px;
            margin-bottom: 10px;
        }

        .company-details {
            margin-bottom: 20px;
        }

        .receipt-content {
            margin-top: 20px;
        }

        .receipt-table {
            width: 100%;
            border-collapse: collapse;
            margin-bottom: 20px;
        }

        .receipt-table th,
        .receipt-table td {
            border: 1px solid #ccc;
            padding: 8px;
        }

        .receipt-table th {
            background-color: #f2f2f2;
            text-align: left;
        }

        .receipt-table td.amount-cell {
            text-align: right;
        }

        .separator-row td {
            border-top: 2px solid #000 !important;
        }

        .calculation-row td {
            border: none !important;
        }

        .customer-details,
        .receipt-details {
            margin-bottom: 10px;
        }

        .customer-details p,
        .receipt-details p {
            margin: 0;
            padding: 2px 0;
        }

        .container {
            width: 80%;
            margin: 0 auto;
        }

        /* Hide browser print headers/footers */
        @page {
            margin: 20mm;
        }

        @media print {
            body {
                margin: 0;
            }

            html,
            body {
                width: 100%;
                height: 100%;
                overflow: hidden;
            }

            @page {
                size: auto;
                margin: 0mm;
            }

            .print-button {
                display: none;
            }
        }

        .text-end {
            text-align: right;
        }
    </style>
</head>

<body>
    <div class="container">
        <div class="receipt-header">
            <!-- Company Logo -->
            <img src="<?php echo $baseURL; ?>assets/images/agLogo.png" alt="Company Logo" class="company-logo">
            <h2>Agasthiar Siddha Ayurmed Sdn. Bhd</h2>
            <div class="company-details">
                <p>No 3290, Jalan Selasih A/1,</p>
                <p>09000 Kulim, Kedah</p>
                <p>Email: agasthiarkulim@gmail.com | Phone: +60 16-40 80 745</p>
            </div>
        </div>

        <div class="receipt-content">
            <!-- Receipt / MSR Info -->
            <div class="receipt-details">
                <p><strong>Date:</strong> <?php echo htmlspecialchars($msrDateFormatted); ?></p>
                <p><strong>Receipt #:</strong> <?php echo htmlspecialchars($patient['receipt_number']); ?></p>
            </div>
            <!-- Customer Info -->
            <div class="customer-details">
                <p><strong>Customer Name:</strong> <?php echo htmlspecialchars($patient['patient_name']); ?></p>
                <p><strong>Customer ID:</strong> <?php echo htmlspecialchars($patient['identificationNumber']); ?></p>
            </div>

            <!-- Items Table (parsed from treatments) -->
            <table class="receipt-table">
                <thead>
                    <tr>
                        <th style="width: 40px;">No</th>
                        <th>Description</th>
                        <th style="width: 120px;">Amount (RM)</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if (!empty($treatments)): ?>
                        <?php foreach ($treatments as $i => $tItem): ?>
                            <tr>
                                <td><?php echo $i + 1; ?></td>
                                <td><?php echo htmlspecialchars($tItem['desc']); ?></td>
                                <td class="amount-cell"><?php echo number_format($tItem['amount'], 2); ?></td>
                            </tr>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <!-- If no treatments were found, you can still show a placeholder row. -->
                        <tr>
                            <td>1</td>
                            <td>No treatments recorded</td>
                            <td class="amount-cell">0.00</td>
                        </tr>
                    <?php endif; ?>

                    <!-- Separator row -->
                    <tr class="separator-row">
                        <td colspan="3"></td>
                    </tr>

                    <!-- Subtotal -->
                    <tr class="calculation-row">
                        <td></td>
                        <td class="text-end"><strong>Subtotal:</strong></td>
                        <td class="amount-cell">RM <?php echo number_format($subtotal, 2); ?></td>
                    </tr>

                    <!-- Discount -->
                    <?php if ($discount > 0): ?>
                        <tr class="calculation-row">
                            <td></td>
                            <td class="text-end"><strong>Discount:</strong></td>
                            <td class="amount-cell">- RM <?php echo number_format($discount, 2); ?></td>
                        </tr>
                    <?php endif; ?>

                    <!-- Final Total -->
                    <tr class="calculation-row">
                        <td></td>
                        <td class="text-end"><strong>Total:</strong></td>
                        <td class="amount-cell">RM <?php echo number_format($total, 2); ?></td>
                    </tr>

                </tbody>
            </table>

            <!-- Payment info (if any) -->
            <p><strong>Amount Paid:</strong> RM <?php echo number_format($paidAmount, 2); ?></p>
            <p><strong>Balance:</strong> RM <?php echo number_format($balance, 2); ?></p>
        </div>

        <div class="receipt-footer">
            <p>Thank you for your business!</p>
            <button class="print-button" onclick="window.print()">Print</button>
        </div>
    </div>
</body>

</html>