<?php
// pages/msr/viewMsr.php
include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");
header("Pragma: no-cache");

$user_role = $_SESSION['role'] ?? 'staff';

if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    echo "Invalid MSR ID.";
    exit;
}
$msr_id = (int) $_GET['id'];

// Fetch MSR header
$stmt = $conn->prepare("
    SELECT
        m.id            AS msr_id,
        m.msr_number,
        m.date_of_msr,
        m.created_at,
        m.approved,
        m.approved_by,
        u.first_name    AS creator_first_name,
        u.last_name     AS creator_last_name,
        a.first_name    AS approver_first_name,
        a.last_name     AS approver_last_name
    FROM msr m
    JOIN users u      ON m.user_id = u.id
    LEFT JOIN users a ON m.approved_by = a.id
    WHERE m.id = ?
    LIMIT 1
");
$stmt->bind_param("i", $msr_id);
$stmt->execute();
$res = $stmt->get_result();
if ($res->num_rows === 0) {
    echo "MSR not found.";
    exit;
}
$msr = $res->fetch_assoc();
$stmt->close();

$msrDate = $msr['date_of_msr'] ?? null;
if (!$msrDate) {
    $msrDate = date('Y-m-d', strtotime($msr['created_at']));
}

// Fetch msr_patients info, including debt_amount and a subquery that sums payments from debt_payments.
$sql = "
SELECT
  mp.id AS msr_patient_id,
  mp.patient_id,
  CONCAT(p.first_name, ' ', p.last_name) AS patient_name,
  mp.reference,
  mp.medicines,
  mp.treatments,
  r.receipt_number,
  d.id AS debts_id,
  d.payment_type,
  d.discount,
  d.debt_amount,
  d.balance_after_payment,
  (SELECT IFNULL(SUM(dp.pay_amount), 0) FROM debt_payments dp WHERE dp.debts_id = d.id) AS total_paid,
  0 AS today_total
FROM msr_patients mp
JOIN msr m ON mp.msr_id = m.id
JOIN patients p ON mp.patient_id = p.id
LEFT JOIN receipts r ON r.msr_patient_id = mp.id
LEFT JOIN debts d ON d.msr_id = mp.msr_id AND d.patient_id = mp.patient_id
WHERE mp.msr_id = ?
ORDER BY mp.id ASC
";
$stmt2 = $conn->prepare($sql);
$stmt2->bind_param("i", $msr_id);
$stmt2->execute();
$result2 = $stmt2->get_result();

$rows = [];
while ($row = $result2->fetch_assoc()) {
    $todayTotal = (float)($row['today_total'] ?? 0);
    if ($todayTotal == 0 && !empty($row['treatments'])) {
        $tArr = json_decode($row['treatments'], true);
        if (is_array($tArr)) {
            foreach ($tArr as $tItem) {
                $todayTotal += max(0, (float)($tItem['amount'] ?? 0));
            }
        }
    }
    $treatmentDisplay = '';
    if (!empty($row['treatments'])) {
        $tArr = json_decode($row['treatments'], true);
        if (is_array($tArr)) {
            $lines = [];
            foreach ($tArr as $tItem) {
                $amt = (float)($tItem['amount'] ?? 0);
                $type = $tItem['type'] ?? 'Treatment';
                $lines[] = htmlspecialchars($type) . ' (RM ' . number_format($amt, 2) . ')';
            }
            $treatmentDisplay = implode("<br>", $lines);
        }
    }
    // Use the subquery result as total_paid
    $total_paid = (float)($row['total_paid'] ?? 0);
    $rows[] = [
        'msr_patient_id'  => (int)$row['msr_patient_id'],
        'patient_id'      => (int)$row['patient_id'],
        'patient_name'    => $row['patient_name'] ?: '',
        'reference'       => $row['reference'] ?: '',
        'medicines'       => $row['medicines'] ?: '',
        'treatments_html' => $treatmentDisplay,
        'receipt_number'  => $row['receipt_number'] ?? '',
        'debts_id'        => $row['debts_id'] ? (int)$row['debts_id'] : null,
        'payment_type'    => $row['payment_type'] ?? 'Cash',
        'discount'        => (float)($row['discount'] ?? 0),
        'debt_amount'     => (float)($row['debt_amount'] ?? 0),
        // We'll show the summed total paid in the Paid column:
        'payment_amount'  => $total_paid,
        'balance_after'   => (float)($row['balance_after_payment'] ?? 0),
        'today_total'     => $todayTotal,
    ];
}
$stmt2->close();
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <title>View MSR</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">
    <link href="<?php echo $baseURL; ?>assets/css/styles.css" rel="stylesheet">
    <style>
        /* Custom styles for improved visual appeal */
        .modal-header {
            background-color: #007bff;
            color: #fff;
        }
    </style>
</head>

<body>
    <div id="wrapper">
        <?php include ROOT_PATH . 'includes/navbar.php'; ?>
        <div id="page-content-wrapper">
            <?php include ROOT_PATH . 'includes/sidebar.php'; ?>
            <div class="container-fluid mt-4">
                <!-- Header Card -->
                <div class="card mb-4 shadow border-0">
                    <div class="card-body text-center bg-primary text-white rounded">
                        <h4 class="card-title mb-1">Agasthiar Siddha Ayurmed Sdn. Bhd</h4>
                        <p class="mb-0">View Medicine Sold Report (MSR)</p>
                    </div>
                </div>
                <!-- MSR Info Card -->
                <div class="card mb-4 shadow border-0">
                    <div class="card-body">
                        <h5 class="text-primary">MSR Details</h5>
                        <div class="row g-3">
                            <div class="col-md-4">
                                <strong>MSR Number:</strong>
                                <?php echo htmlspecialchars($msr['msr_number']); ?>
                            </div>
                            <div class="col-md-4">
                                <strong>MSR Date:</strong>
                                <?php echo $msrDate ? date('d M Y', strtotime($msrDate)) : '-'; ?>
                            </div>
                            <div class="col-md-4">
                                <strong>Created At:</strong>
                                <?php
                                $createdTS = strtotime($msr['created_at']);
                                echo date('d M Y, h:i A', $createdTS);
                                ?>
                            </div>
                            <div class="col-md-4">
                                <strong>Created By:</strong>
                                <?php echo htmlspecialchars($msr['creator_first_name'] . ' ' . $msr['creator_last_name']); ?>
                            </div>
                            <div class="col-md-4">
                                <strong>Status:</strong>
                                <?php if ((int)$msr['approved'] === 1): ?>
                                    <span class="badge bg-success">Approved</span>
                                <?php else: ?>
                                    <span class="badge bg-warning text-dark">Pending</span>
                                <?php endif; ?>
                            </div>
                            <?php if ((int)$msr['approved'] === 1): ?>
                                <div class="col-md-4">
                                    <strong>Approved By:</strong>
                                    <?php echo htmlspecialchars($msr['approver_first_name'] . ' ' . $msr['approver_last_name']); ?>
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
                <!-- Action Buttons -->
                <div class="mb-4">
                    <?php if ($user_role === 'admin'): ?>
                        <a href="<?php echo $baseURL; ?>pages/msr/updateMsr.php?id=<?php echo urlencode($msr_id); ?>"
                            class="btn btn-primary">
                            <i class="fas fa-edit"></i> Edit MSR
                        </a>
                    <?php endif; ?>
                    <a href="<?php echo $baseURL; ?>pages/msr/printMsr.php?id=<?php echo urlencode($msr_id); ?>"
                        target="_blank" class="btn btn-secondary" title="Print MSR">
                        <i class="fas fa-print"></i> Print MSR
                    </a>
                    <?php if ($user_role === 'admin' && (int)$msr['approved'] === 0): ?>
                        <button id="approveMSR" class="btn btn-success">
                            <i class="fas fa-check"></i> Approve MSR
                        </button>
                    <?php endif; ?>
                </div>
                <!-- Main MSR Table -->
                <div class="card shadow border-0">
                    <div class="card-body">
                        <div class="table-responsive">
                            <table class="table table-bordered text-center align-middle">
                                <thead class="table-light">
                                    <tr>
                                        <th>No</th>
                                        <th>Patient</th>
                                        <th>Reference</th>
                                        <th>Receipt</th>
                                        <th>Medicines (notes)</th>
                                        <th>Treatments</th>
                                        <th>Today Total (RM)</th>
                                        <th>Discount (RM)</th>
                                        <th>Paid (RM)</th>
                                        <th>Balance (RM)</th>
                                        <th>Actions</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php if (!empty($rows)): ?>
                                        <?php foreach ($rows as $i => $r): ?>
                                            <tr>
                                                <td><?php echo $i + 1; ?></td>
                                                <td><?php echo htmlspecialchars($r['patient_name']); ?></td>
                                                <td><?php echo htmlspecialchars($r['reference']); ?></td>
                                                <td><?php echo htmlspecialchars($r['receipt_number']); ?></td>
                                                <td><?php echo nl2br(htmlspecialchars($r['medicines'])); ?></td>
                                                <td><?php echo $r['treatments_html'] ?: '-'; ?></td>
                                                <td><?php echo number_format($r['today_total'], 2); ?></td>
                                                <td><?php echo number_format($r['discount'], 2); ?></td>
                                                <td><?php echo number_format($r['payment_amount'], 2); ?></td>
                                                <td><?php echo number_format($r['balance_after'], 2); ?></td>
                                                <td>
                                                    <a href="<?php echo $baseURL; ?>pages/msr/printReceipt.php?msr_patient_id=<?php echo urlencode($r['msr_patient_id']); ?>"
                                                        class="btn btn-info btn-sm" target="_blank" title="Print Receipt">
                                                        <i class="fas fa-receipt"></i>
                                                    </a>
                                                </td>
                                            </tr>
                                        <?php endforeach; ?>
                                    <?php else: ?>
                                        <tr>
                                            <td colspan="12">No patients found in this MSR.</td>
                                        </tr>
                                    <?php endif; ?>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
                <!-- Debt Settlement Panel -->
                <div class="card shadow border-0 mt-4">
                    <div class="card-body">
                        <h5 class="text-danger">Debt Settlement (Same Day Only)</h5>
                        <p class="text-muted mb-3">
                            If a patient has leftover for this day, you can do partial or full payments below.
                            Each payment is logged in <code>debt_payments</code> and its receipts in <code>debt_payment_receipts</code>.
                        </p>
                        <?php
                        // Filter rows that have a debt record.
                        $debtors = array_filter($rows, fn($r) => $r['debts_id']);
                        if (empty($debtors)):
                        ?>
                            <p>No debts found for today.</p>
                        <?php else: ?>
                            <table class="table table-bordered text-center align-middle">
                                <thead>
                                    <tr>
                                        <th>Patient</th>
                                        <th>Balance (RM)</th>
                                        <th>Action</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($debtors as $drow):
                                        // Calculate due amount as today's total minus discount.
                                        $due = $drow['today_total'] - $drow['discount'];
                                        // If the debt amount, payment amount, and balance are all 0, payment is not required.
                                        if ($drow['debt_amount'] == 0 && $drow['payment_amount'] == 0 && $drow['balance_after'] == 0):
                                    ?>
                                            <tr>
                                                <td><?php echo htmlspecialchars($drow['patient_name']); ?></td>
                                                <td><?php echo number_format($drow['balance_after'], 2); ?></td>
                                                <td>
                                                    <span class="badge bg-secondary">Payment Not Required</span>
                                                </td>
                                            </tr>
                                        <?php
                                        // Otherwise, check if the sum of payments covers the due.
                                        elseif ($drow['payment_amount'] >= $due):
                                        ?>
                                            <tr>
                                                <td><?php echo htmlspecialchars($drow['patient_name']); ?></td>
                                                <td><?php echo number_format($drow['balance_after'], 2); ?></td>
                                                <td>
                                                    <span class="badge bg-success">Paid</span>
                                                    <button class="btn btn-sm btn-secondary view-payments-btn"
                                                        data-debts-id="<?php echo $drow['debts_id']; ?>"
                                                        data-patient-name="<?php echo htmlspecialchars($drow['patient_name']); ?>">
                                                        <i class="fas fa-eye"></i> Payments
                                                    </button>
                                                </td>
                                            </tr>
                                        <?php else: ?>
                                            <tr>
                                                <td><?php echo htmlspecialchars($drow['patient_name']); ?></td>
                                                <td><?php echo number_format($drow['balance_after'], 2); ?></td>
                                                <td>
                                                    <button class="btn btn-sm btn-warning pay-btn"
                                                        data-debts-id="<?php echo $drow['debts_id']; ?>"
                                                        data-balance="<?php echo $drow['balance_after']; ?>"
                                                        data-patient-name="<?php echo htmlspecialchars($drow['patient_name']); ?>">
                                                        <i class="fas fa-money-check"></i> Pay
                                                    </button>
                                                    <button class="btn btn-sm btn-secondary view-payments-btn"
                                                        data-debts-id="<?php echo $drow['debts_id']; ?>"
                                                        data-patient-name="<?php echo htmlspecialchars($drow['patient_name']); ?>">
                                                        <i class="fas fa-eye"></i> Payments
                                                    </button>
                                                </td>
                                            </tr>
                                        <?php endif; ?>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- Payment Modal -->
    <div class="modal fade" id="payModal" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <form id="payForm" class="needs-validation" novalidate enctype="multipart/form-data">
                    <div class="modal-header">
                        <h5 class="modal-title">Make a Payment</h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                    </div>
                    <div class="modal-body">
                        <input type="hidden" name="debts_id" id="debts_id" value="">
                        <input type="hidden" name="patientName" id="patientName" value="">
                        <div class="mb-3">
                            <label for="currentBalance" class="form-label">Current Balance (RM)</label>
                            <input type="text" class="form-control" id="currentBalance" readonly>
                        </div>
                        <div class="mb-3">
                            <label for="payAmount" class="form-label">Amount to Pay (RM)</label>
                            <input type="number" class="form-control" id="payAmount" name="payAmount" min="0.01" step="0.01" required>
                            <div class="invalid-feedback">Please enter a valid amount.</div>
                        </div>
                        <div class="mb-3">
                            <label for="payDate" class="form-label">Payment Date</label>
                            <input type="date" class="form-control" id="payDate" name="payDate" required>
                            <div class="invalid-feedback">Please select a payment date.</div>
                        </div>
                        <div class="mb-3">
                            <label for="payType" class="form-label">Payment Type</label>
                            <select class="form-select" id="payType" name="payType">
                                <option value="Cash">Cash</option>
                                <option value="Online">Online</option>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="receiptFiles" class="form-label">Upload Receipt(s)</label>
                            <input type="file" class="form-control" id="receiptFiles" name="receiptFiles[]" multiple accept=".jpg,.jpeg,.png,.pdf">
                        </div>
                        <div class="mb-3">
                            <label for="payRemarks" class="form-label">Remarks (optional)</label>
                            <textarea class="form-control" id="payRemarks" name="payRemarks"></textarea>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-primary">Submit Payment</button>
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
    <!-- Payment History Modal -->
    <div class="modal fade" id="paymentHistoryModal" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog modal-lg modal-dialog-scrollable">
            <div class="modal-content">
                <div class="modal-header bg-secondary text-white">
                    <h5 class="modal-title">Payment History - <span id="historyPatientName"></span></h5>
                    <button type="button" class="btn-close btn-close-white" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <div id="paymentHistoryContent">
                        <div class="text-center">Loading...</div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- Edit Payment Modal -->
    <div class="modal fade" id="editPaymentModal" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <form id="editPaymentForm" class="needs-validation" novalidate enctype="multipart/form-data">
                    <div class="modal-header">
                        <h5 class="modal-title">Edit Payment</h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                    </div>
                    <div class="modal-body">
                        <input type="hidden" name="payment_id" id="editPaymentId" value="">
                        <input type="hidden" name="debts_id" id="editDebtsId" value="">
                        <input type="hidden" name="patientName" id="editPatientName" value="">
                        <div class="mb-3">
                            <label for="editPayAmount" class="form-label">Amount Paid (RM)</label>
                            <input type="number" class="form-control" id="editPayAmount" name="payAmount" min="0.01" step="0.01" required>
                            <div class="invalid-feedback">Please enter a valid amount.</div>
                        </div>
                        <div class="mb-3">
                            <label for="editPayDate" class="form-label">Payment Date</label>
                            <input type="date" class="form-control" id="editPayDate" name="payDate" required>
                            <div class="invalid-feedback">Please select a payment date.</div>
                        </div>
                        <div class="mb-3">
                            <label for="editPayType" class="form-label">Payment Type</label>
                            <select class="form-select" id="editPayType" name="payType">
                                <option value="Cash">Cash</option>
                                <option value="Online">Online</option>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="editReceiptFiles" class="form-label">Upload New Receipt(s)</label>
                            <input type="file" class="form-control" id="editReceiptFiles" name="receiptFiles[]" multiple accept=".jpg,.jpeg,.png,.pdf">
                        </div>
                        <div class="mb-3">
                            <label for="editPayRemarks" class="form-label">Remarks (optional)</label>
                            <textarea class="form-control" id="editPayRemarks" name="payRemarks"></textarea>
                        </div>
                        <div class="mb-3">
                            <label class="form-label">Existing Receipts</label>
                            <div id="existingReceipts">
                                <!-- Existing receipts will be loaded here with delete options -->
                            </div>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-primary">Update Payment</button>
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
    <script>
        const baseURL = "<?php echo $baseURL; ?>";
    </script>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script src="<?php echo htmlspecialchars($baseURL); ?>assets/js/scripts.js"></script>
    <script>
        document.addEventListener("DOMContentLoaded", function() {
            // New Payment Modal handler
            document.querySelectorAll(".pay-btn").forEach(btn => {
                btn.addEventListener("click", () => {
                    const debtsId = btn.dataset.debtsId || "";
                    const balance = parseFloat(btn.dataset.balance || "0").toFixed(2);
                    const patientName = btn.dataset.patientName || "";
                    document.getElementById("debts_id").value = debtsId;
                    document.getElementById("currentBalance").value = balance;
                    document.getElementById("payAmount").value = "";
                    document.getElementById("payDate").value = "";
                    document.getElementById("payRemarks").value = "";
                    document.getElementById("patientName").value = patientName;
                    const payModal = new bootstrap.Modal(document.getElementById("payModal"));
                    payModal.show();
                });
            });
            // New Payment Form Submission
            const payForm = document.getElementById("payForm");
            payForm.addEventListener("submit", function(e) {
                e.preventDefault();
                if (!payForm.checkValidity()) {
                    payForm.classList.add("was-validated");
                    return;
                }
                const formData = new FormData(payForm);
                fetch(`${baseURL}actions/debt/pay_debt.php`, {
                        method: "POST",
                        body: formData
                    })
                    .then(r => r.json())
                    .then(resp => {
                        if (!resp.success) {
                            alert("Error: " + resp.message);
                            return;
                        }
                        alert("Payment recorded!");
                        location.reload();
                    })
                    .catch(err => {
                        console.error("Pay debt error:", err);
                        alert("Error paying debt. Check console.");
                    });
            });
            // Payment History Modal handler
            document.querySelectorAll(".view-payments-btn").forEach(btn => {
                btn.addEventListener("click", () => {
                    const debtsId = btn.dataset.debtsId || "";
                    const patientName = btn.dataset.patientName || "";
                    document.getElementById("historyPatientName").textContent = patientName;
                    loadPaymentHistory(debtsId);
                    const historyModal = new bootstrap.Modal(document.getElementById("paymentHistoryModal"));
                    historyModal.show();
                });
            });

            function loadPaymentHistory(debtsId) {
                const historyContent = document.getElementById("paymentHistoryContent");
                historyContent.innerHTML = "<div class='text-center p-3'>Loading...</div>";
                fetch(`${baseURL}actions/debt/get_payments.php?debts_id=${debtsId}`)
                    .then(r => r.json())
                    .then(resp => {
                        if (!resp.success) {
                            historyContent.innerHTML = "<div class='text-danger p-3'>Failed to load payment history.</div>";
                            return;
                        }
                        let html = "<table class='table table-bordered'><thead><tr><th>Payment Date</th><th>Amount (RM)</th><th>Type</th><th>Remarks</th><th>Receipts</th><th>Action</th></tr></thead><tbody>";
                        resp.payments.forEach(payment => {
                            let receiptsHtml = "";
                            if (payment.receipts.length > 0) {
                                receiptsHtml = payment.receipts.map(r => {
                                    // Extract only the file name from the file path.
                                    const fileName = r.file_path.split('/').pop();
                                    return `<a href="${baseURL}${r.file_path}" target="_blank">${fileName}</a>`;
                                }).join("<br>");
                            } else {
                                receiptsHtml = "-";
                            }
                            html += `<tr>
                                <td>${payment.pay_date}</td>
                                <td>${payment.pay_amount.toFixed(2)}</td>
                                <td>${payment.payment_type}</td>
                                <td>${payment.remarks}</td>
                                <td>${receiptsHtml}</td>
                                <td><button class="btn btn-sm btn-primary edit-payment-btn" data-payment='${JSON.stringify(payment)}'>Edit</button></td>
                            </tr>`;
                        });
                        html += "</tbody></table>";
                        historyContent.innerHTML = html;
                        document.querySelectorAll(".edit-payment-btn").forEach(btn => {
                            btn.addEventListener("click", () => {
                                const paymentData = JSON.parse(btn.getAttribute("data-payment"));
                                openEditPaymentModal(paymentData);
                            });
                        });
                    })
                    .catch(err => {
                        console.error("Error loading payment history:", err);
                        historyContent.innerHTML = "<div class='text-danger p-3'>Error loading payment history.</div>";
                    });
            }

            function openEditPaymentModal(payment) {
                document.getElementById("editPaymentId").value = payment.payment_id;
                document.getElementById("editDebtsId").value = payment.debts_id || "";
                document.getElementById("editPayAmount").value = payment.pay_amount;
                let pd = payment.pay_date;
                try {
                    pd = new Date(payment.pay_date).toISOString().substring(0, 10);
                } catch (e) {}
                document.getElementById("editPayDate").value = pd;
                document.getElementById("editPayType").value = payment.payment_type;
                document.getElementById("editPayRemarks").value = payment.remarks;
                const existingReceiptsDiv = document.getElementById("existingReceipts");
                existingReceiptsDiv.innerHTML = "";
                if (payment.receipts && payment.receipts.length > 0) {
                    payment.receipts.forEach((obj) => {
                        const fileName = obj.file_path.split('/').pop();
                        existingReceiptsDiv.innerHTML += `<div class="existing-receipt p-2 border mb-2" data-receipt-id="${obj.id}">
                            <a href="${baseURL}${obj.file_path}" target="_blank">${fileName}</a>
                            <button type="button" class="btn btn-sm btn-danger delete-receipt-btn ms-2" data-receipt-id="${obj.id}">Delete</button>
                        </div>`;
                    });
                } else {
                    existingReceiptsDiv.innerHTML = "<p>No existing receipts.</p>";
                }
                document.getElementById("editPatientName").value = document.getElementById("patientName").value;
                const editModal = new bootstrap.Modal(document.getElementById("editPaymentModal"));
                editModal.show();
            }
            document.addEventListener("click", function(e) {
                if (e.target && e.target.classList.contains("delete-receipt-btn")) {
                    e.target.parentElement.classList.add("to-delete");
                    e.target.parentElement.style.textDecoration = "line-through";
                }
            });
            const editPaymentForm = document.getElementById("editPaymentForm");
            editPaymentForm.addEventListener("submit", function(e) {
                e.preventDefault();
                if (!editPaymentForm.checkValidity()) {
                    editPaymentForm.classList.add("was-validated");
                    return;
                }
                let delete_receipt_ids = [];
                document.querySelectorAll("#existingReceipts .to-delete").forEach(el => {
                    let rid = el.getAttribute("data-receipt-id");
                    if (rid !== null) {
                        delete_receipt_ids.push(rid);
                    }
                });
                const formData = new FormData(editPaymentForm);
                formData.append("delete_receipt_ids", delete_receipt_ids.join(","));
                fetch(`${baseURL}actions/debt/update_payment.php`, {
                        method: "POST",
                        body: formData
                    })
                    .then(r => r.json())
                    .then(resp => {
                        if (!resp.success) {
                            alert("Error updating payment: " + resp.message);
                            return;
                        }
                        alert("Payment updated successfully!");
                        const debtsId = document.getElementById("editDebtsId").value;
                        loadPaymentHistory(debtsId);
                        const editModalEl = document.getElementById("editPaymentModal");
                        const editModal = bootstrap.Modal.getInstance(editModalEl);
                        editModal.hide();
                    })
                    .catch(err => {
                        console.error("Error updating payment:", err);
                        alert("Error updating payment. Check console.");
                    });
            });
            const approveBtn = document.getElementById("approveMSR");
            if (approveBtn) {
                approveBtn.addEventListener("click", () => {
                    if (confirm("Are you sure you want to approve this MSR?")) {
                        fetch(`${baseURL}actions/msr/approve_msr.php?id=<?php echo $msr_id; ?>`)
                            .then(r => r.json())
                            .then(resp => {
                                if (!resp.success) {
                                    alert("Error: " + resp.message);
                                    return;
                                }
                                alert("MSR approved successfully!");
                                location.reload();
                            })
                            .catch(err => {
                                console.error("Approve MSR error:", err);
                                alert("Error approving MSR. Check console.");
                            });
                    }
                });
            }
        });
    </script>
    <?php include ROOT_PATH . 'includes/footer.php'; ?>
</body>

</html>