<?php
// appointments_logic.php
// Make sure session is started, e.g. session_start();
// Also ensure $conn (mysqli), $currentUserID (int), $userRole, etc. exist.
session_start();
if (!isset($apptAction) || empty($apptAction)) {
    return; // no action => do nothing
}

// =================== (1) ADD APPOINTMENT ===================
if ($apptAction === 'addAppointment') {
    $pID          = (int)($_POST['patient_id'] ?? 0);
    $apptDate     = trim($_POST['appointment_date'] ?? '');
    $apptTime     = trim($_POST['appointment_time'] ?? '');
    $purpose      = trim($_POST['purpose'] ?? '');
    $status       = trim($_POST['status'] ?? 'Scheduled');
    $remarks      = trim($_POST['remarks'] ?? '');
    $autoDx       = !empty($_POST['auto_create_diagnosis']);
    $autoSchedule = !empty($_POST['auto_schedule_followups']);

    if (!$pID || !$apptDate || !$apptTime || !$purpose || !$status) {
        $_SESSION['error'] = "Please fill in the required fields: date, time, purpose, status.";
        header("Location: patientProfile.php?id={$pID}&appointments-tab=1");
        exit;
    }

    // Staff cannot backdate
    if ($userRole === 'staff' && $apptDate < date('Y-m-d')) {
        $_SESSION['error'] = "Staff cannot create an appointment in the past.";
        header("Location: patientProfile.php?id={$pID}&appointments-tab=1");
        exit;
    }

    $conn->begin_transaction();
    try {
        // (A) Check if patient already has a Scheduled appointment
        $chkSQL = "SELECT AppointmentID FROM appointments WHERE PatientID=? AND Status='Scheduled' LIMIT 1";
        $chkSt = $conn->prepare($chkSQL);
        $chkSt->bind_param('i', $pID);
        $chkSt->execute();
        $chkRes = $chkSt->get_result();
        if ($chkRes->num_rows > 0 && $status === 'Scheduled') {
            // If the new one is also 'Scheduled', let's block it
            $conn->rollback();
            $_SESSION['error'] = "Patient already has a 'Scheduled' appointment. Complete or cancel it first.";
            header("Location: patientProfile.php?id={$pID}&appointments-tab=1");
            exit;
        }
        $chkSt->close();

        // (B) Check collision => same date & time for same patient
        $colSQL = "SELECT AppointmentID FROM appointments 
                   WHERE PatientID=? AND AppointmentDate=? AND AppointmentTime=? LIMIT 1";
        $colSt = $conn->prepare($colSQL);
        $colSt->bind_param('iss', $pID, $apptDate, $apptTime);
        $colSt->execute();
        $colRes = $colSt->get_result();
        if ($colRes->num_rows > 0) {
            $conn->rollback();
            $_SESSION['error'] = "An appointment already exists at {$apptDate} {$apptTime} for this patient.";
            header("Location: patientProfile.php?id={$pID}&appointments-tab=1");
            exit;
        }
        $colSt->close();

        // (C) Insert new appointment
        $sqlA = "
          INSERT INTO appointments (
            PatientID,
            AppointmentDate,
            AppointmentTime,
            Purpose,
            Status,
            Remarks,
            CreatedBy,
            UpdatedBy,
            CreatedAt,
            UpdatedAt
          ) VALUES (?,?,?,?,?,?,?,?,NOW(),NOW())
        ";
        $stA = $conn->prepare($sqlA);
        $stA->bind_param(
            'isssssii',
            $pID,
            $apptDate,
            $apptTime,
            $purpose,
            $status,
            $remarks,
            $currentUserID,
            $currentUserID
        );
        $stA->execute();
        $newAID = $stA->insert_id;
        $stA->close();

        // (D) Auto-create minimal Diagnosis?
        if ($autoDx && $newAID > 0) {
            $dxSQL = "
              INSERT INTO diagnoses (
                PatientID,
                AppointmentID,
                Diagnosis,
                CreatedBy,
                UpdatedBy,
                CreatedAt,
                UpdatedAt
              ) VALUES (?, ?, 'Auto-created Diagnosis', ?, ?, NOW(), NOW())
            ";
            $stDx = $conn->prepare($dxSQL);
            $stDx->bind_param('iiii', $pID, $newAID, $currentUserID, $currentUserID);
            $stDx->execute();
            $stDx->close();
        }

        // (E) Auto-schedule follow-ups if requested
        if ($autoSchedule && $newAID > 0) {
            $ts = strtotime($apptDate . ' ' . $apptTime);
            $offsets = [-7, -3, -1];
            foreach ($offsets as $days) {
                $fTime = $ts + ($days * 86400);
                // Only create if still in the future
                if ($fTime < time()) {
                    continue;
                }
                $fuDate       = date('Y-m-d H:i:s', $fTime);
                $statusUpdate = "Auto-scheduled follow-up";
                $fuType       = "Auto";
                $fuRem        = "Auto-scheduled for Appointment #{$newAID}";

                $sqlFU = "
                  INSERT INTO follow_up(
                    PatientID,
                    AppointmentID,
                    FollowUpDate,
                    StatusUpdate,
                    FollowUpType,
                    NextFollowUpDate,
                    Remarks,
                    followup_category_id,
                    FollowUpStatus,
                    linked_followup_id,
                    CreatedBy,
                    UpdatedBy,
                    CreatedAt,
                    UpdatedAt
                  ) VALUES(
                    ?,
                    ?,
                    ?,
                    ?,
                    ?,
                    NULL,
                    ?,
                    3,
                    'Pending',
                    NULL,
                    ?,
                    ?,
                    NOW(),
                    NOW()
                  )
                ";
                $stFU = $conn->prepare($sqlFU);
                $stFU->bind_param(
                    'iissssii',
                    $pID,
                    $newAID,
                    $fuDate,
                    $statusUpdate,
                    $fuType,
                    $fuRem,
                    $currentUserID,
                    $currentUserID
                );
                $stFU->execute();
                $stFU->close();
            }
        }

        $conn->commit();
        $_SESSION['success'] = "Appointment added (#{$newAID}).";
    } catch (Exception $ex) {
        $conn->rollback();
        $_SESSION['error'] = "Error adding Appointment: " . $ex->getMessage();
    }
    header("Location: patientProfile.php?id={$pID}&appointments-tab=1");
    exit;
}


// =================== (2) EDIT APPOINTMENT ===================
elseif ($apptAction === 'editAppointment') {
    $apptID             = (int)($_POST['appointment_id'] ?? 0);
    $pID                = (int)($_POST['patient_id'] ?? 0);
    $apptDate           = $_POST['appointment_date'] ?? date('Y-m-d');
    $apptTime           = $_POST['appointment_time'] ?? '09:00:00';
    $purpose            = trim($_POST['purpose'] ?? '');
    $status             = $_POST['status'] ?? 'Scheduled';
    $remarks            = trim($_POST['remarks'] ?? '');
    $autoUpdateFollowups = !empty($_POST['auto_update_followups']);

    // Staff cannot backdate
    if ($userRole === 'staff' && $apptDate < date('Y-m-d')) {
        $_SESSION['error'] = "Staff cannot backdate an appointment.";
        header("Location: patientProfile.php?id={$pID}&appointments-tab=1");
        exit;
    }

    // Fetch the old appointment row
    $oldSQL = "SELECT * FROM appointments WHERE AppointmentID=? AND PatientID=? LIMIT 1";
    $stOld = $conn->prepare($oldSQL);
    $stOld->bind_param('ii', $apptID, $pID);
    $stOld->execute();
    $resOld = $stOld->get_result();
    if ($resOld->num_rows < 1) {
        $_SESSION['error'] = "Appointment not found or invalid patient for update.";
        header("Location: patientProfile.php?id={$pID}&appointments-tab=1");
        exit;
    }
    $oldAp = $resOld->fetch_assoc();
    $stOld->close();

    $conn->begin_transaction();
    try {
        // (1) Update the appointment
        $sqlUpA = "
          UPDATE appointments
          SET
            AppointmentDate=?,
            AppointmentTime=?,
            Purpose=?,
            Status=?,
            Remarks=?,
            UpdatedBy=?,
            UpdatedAt=NOW()
          WHERE AppointmentID=? AND PatientID=?
        ";
        $stUpA = $conn->prepare($sqlUpA);
        $stUpA->bind_param(
            'sssssiii',
            $apptDate,
            $apptTime,
            $purpose,
            $status,
            $remarks,
            $currentUserID,
            $apptID,
            $pID
        );
        $stUpA->execute();
        $stUpA->close();

        // (2) If auto_update_followups => remove & recreate the auto-scheduled ones
        if ($autoUpdateFollowups) {
            // Remove existing auto-scheduled follow-ups for this appointment (category_id=3)
            $delSQL = "DELETE FROM follow_up WHERE AppointmentID=? AND followup_category_id=3";
            $stDel = $conn->prepare($delSQL);
            $stDel->bind_param('i', $apptID);
            $stDel->execute();
            $stDel->close();

            // Reinsert them based on the new date/time
            $apptDateTime = strtotime($apptDate . ' ' . $apptTime);
            $offsets = [-7, -3, -1];
            foreach ($offsets as $days) {
                $fuTime = $apptDateTime + ($days * 86400);
                if ($fuTime < time()) {
                    continue;
                }
                $fuDate          = date('Y-m-d H:i:s', $fuTime);
                $statusUpdateFU  = "Auto-updated follow-up";
                $fuType          = "Auto";
                $fuRemarks       = "Auto-updated follow-up for Appointment #{$apptID}";

                $sqlFU = "
                  INSERT INTO follow_up (
                    PatientID,
                    AppointmentID,
                    FollowUpDate,
                    StatusUpdate,
                    FollowUpType,
                    NextFollowUpDate,
                    Remarks,
                    FollowUpStatus,
                    followup_category_id,
                    linked_followup_id,
                    CreatedBy,
                    UpdatedBy,
                    CreatedAt,
                    UpdatedAt
                  ) VALUES (
                    ?,
                    ?,
                    ?,
                    ?,
                    ?,
                    NULL,
                    ?,
                    'Pending',
                    3,
                    NULL,
                    ?,
                    ?,
                    NOW(),
                    NOW()
                  )
                ";
                $stFU = $conn->prepare($sqlFU);
                $stFU->bind_param(
                    'iisssssii',
                    $pID,
                    $apptID,
                    $fuDate,
                    $statusUpdateFU,
                    $fuType,
                    $fuRemarks,
                    $currentUserID,
                    $currentUserID
                );
                $stFU->execute();
                $stFU->close();
            }
        }

        $conn->commit();
        $_SESSION['success'] = "Appointment #{$apptID} updated.";
    } catch (Exception $ex) {
        $conn->rollback();
        $_SESSION['error'] = "Error updating Appointment: " . $ex->getMessage();
    }

    header("Location: patientProfile.php?id={$pID}&appointments-tab=1");
    exit;
}


// =================== (3) DELETE APPOINTMENT ===================
elseif ($apptAction === 'deleteAppointment') {
    if ($userRole === 'staff') {
        $_SESSION['error'] = "Staff cannot delete appointments.";
        header("Location: patientProfile.php?id={$patient_id}&appointments-tab=1");
        exit;
    }
    $apptID = (int)($_POST['appointment_id'] ?? 0);
    if ($apptID > 0) {
        // Fetch old row (if you want to do any checks)
        $oldSQL = "SELECT * FROM appointments WHERE AppointmentID=? AND PatientID=? LIMIT 1";
        $sOld = $conn->prepare($oldSQL);
        $sOld->bind_param('ii', $apptID, $patient_id);
        $sOld->execute();
        $rOld = $sOld->get_result();
        $oldAp = ($rOld->num_rows > 0) ? $rOld->fetch_assoc() : null;
        $sOld->close();

        $conn->begin_transaction();
        try {
            $delA = "DELETE FROM appointments WHERE AppointmentID=? AND PatientID=?";
            $stDelA = $conn->prepare($delA);
            $stDelA->bind_param('ii', $apptID, $patient_id);
            $stDelA->execute();
            $stDelA->close();

            $conn->commit();
            $_SESSION['success'] = "Appointment #{$apptID} deleted.";
        } catch (Exception $ex) {
            $conn->rollback();
            $_SESSION['error'] = "Error deleting Appointment: " . $ex->getMessage();
        }
    }
    header("Location: patientProfile.php?id={$patient_id}&appointments-tab=1");
    exit;
}
