<?php
/**
 * diagnoses_fetch.php
 *
 * Fetches diagnosis records for a specific patient with filtering, sorting, and pagination.
 *
 * Expected GET parameters:
 *   - diag_start: (optional) Start date for DiagnosisDate filter (format YYYY-MM-DD)
 *   - diag_end:   (optional) End date for DiagnosisDate filter (format YYYY-MM-DD)
 *   - order_by:   (optional) Either 'diagnosis_id' or 'diagnosis_date'. Default is 'diagnosis_date'.
 *   - order:      (optional) Either 'asc' or 'desc'. Default is 'desc'.
 *   - dgpg:       (optional) Current page number for pagination. Default is 1.
 *
 * Outputs:
 *   - $diagnoses:      An array of diagnosis records.
 *   - $dgPg:           The current page number.
 *   - $dgTotalPages:   The total number of pages.
 *   - $dgOffset:       The offset used in the SQL LIMIT clause.
 *
 * Requires that the following variables are already defined:
 *   - $conn: The active mysqli connection.
 *   - $patient_id: The current patient’s ID.
 */

// --- Sorting Settings ---
$order_by = isset($_GET['order_by']) ? $_GET['order_by'] : 'diagnosis_date';
$allowed_order_by = ['diagnosis_id', 'diagnosis_date'];
if (!in_array($order_by, $allowed_order_by)) {
    $order_by = 'diagnosis_date';
}

$order = isset($_GET['order']) ? strtolower($_GET['order']) : 'desc';
if ($order !== 'asc') {
    $order = 'desc';
}

// --- Pagination Settings ---
$dgPerPage = 5;
$dgPg = isset($_GET['dgpg']) ? (int)$_GET['dgpg'] : 1;
if ($dgPg < 1) {
    $dgPg = 1;
}
$dgOffset = ($dgPg - 1) * $dgPerPage;

// --- Build Filtering Conditions ---
$filters = [];
$filters[] = "d.PatientID = $patient_id";

if (isset($_GET['diag_start']) && preg_match('/^\d{4}-\d{2}-\d{2}$/', $_GET['diag_start'])) {
    $diag_start = $_GET['diag_start'];
    $filters[] = "DATE(d.DiagnosisDate) >= '$diag_start'";
}

if (isset($_GET['diag_end']) && preg_match('/^\d{4}-\d{2}-\d{2}$/', $_GET['diag_end'])) {
    $diag_end = $_GET['diag_end'];
    $filters[] = "DATE(d.DiagnosisDate) <= '$diag_end'";
}

$dgWhere = '';
if (!empty($filters)) {
    $dgWhere = 'WHERE ' . implode(' AND ', $filters);
}

// --- Determine ORDER BY Clause ---
if ($order_by === 'diagnosis_id') {
    $orderClause = "d.DiagnosisID $order";
} else { // default is diagnosis_date
    $orderClause = "d.DiagnosisDate $order";
}

// --- Count Total Records ---
$countSQL = "SELECT COUNT(d.DiagnosisID) AS total FROM diagnoses d $dgWhere";
$countRes = $conn->query($countSQL);
if ($countRes) {
    $countRow = $countRes->fetch_assoc();
    $dgTotal = (int)($countRow['total'] ?? 0);
    $countRes->free();
} else {
    error_log("Diagnoses fetch error (count): " . $conn->error);
    $dgTotal = 0;
}
$dgTotalPages = ($dgTotal > 0) ? ceil($dgTotal / $dgPerPage) : 1;

// --- Fetch Diagnosis Records ---
$sql = "
  SELECT 
    d.*,
    a.AppointmentDate,
    a.AppointmentTime,
    u1.username AS created_by_name,
    u2.username AS updated_by_name
  FROM diagnoses d
  LEFT JOIN appointments a ON d.AppointmentID = a.AppointmentID
  LEFT JOIN users u1 ON d.CreatedBy = u1.id
  LEFT JOIN users u2 ON d.UpdatedBy = u2.id
  $dgWhere
  ORDER BY $orderClause
  LIMIT $dgPerPage OFFSET $dgOffset
";

$res = $conn->query($sql);
if ($res) {
    $diagnoses = $res->fetch_all(MYSQLI_ASSOC);
    $res->free();
} else {
    error_log("Diagnoses fetch error (data): " . $conn->error);
    $diagnoses = [];
}
?>
