<?php
// pages/patient/diagnoses_logic.php

// Include common files to set up $conn, session, and config.
include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// Initialize current user and role from session.
$currentUserID = $_SESSION['user_id'] ?? null;
$userRole      = $_SESSION['role'] ?? 'staff';

if (!isset($_POST['diag_action']) || empty($_POST['diag_action'])) {
    return;
}

function normalizeDate($dateStr)
{
    $dateStr = trim($dateStr);
    return ($dateStr === '') ? null : $dateStr;
}

$diagAction = $_POST['diag_action'];
$pID = (int)($_POST['patient_id'] ?? 0);

if ($diagAction === 'addDiagnosis') {
    // Only admin (or doctor) can add diagnoses.
    if ($userRole === 'staff') {
        $_SESSION['error'] = "Staff cannot add diagnoses.";
        header("Location: patientProfile.php?id=$pID&diagnoses-tab=1");
        exit;
    }
    // If no appointment is provided, set to null.
    $apptID = !empty($_POST['appointment_id']) ? (int)$_POST['appointment_id'] : null;
    $diagDate = normalizeDate($_POST['diagnosis_date'] ?? '');
    $fDate = normalizeDate($_POST['followup_date'] ?? '');
    if (!$diagDate) {
        $_SESSION['error'] = "Diagnosis Date is required.";
        header("Location: patientProfile.php?id=$pID&diagnoses-tab=1");
        exit;
    }
    $sql = "INSERT INTO diagnoses (
                PatientID,
                AppointmentID,
                DiagnosisDate,
                FollowUpDate,
                CreatedBy,
                UpdatedBy,
                CreatedAt,
                UpdatedAt
            ) VALUES (?, ?, ?, ?, ?, ?, NOW(), NOW())";
    $stmt = $conn->prepare($sql);
    if (!$stmt) {
        $_SESSION['error'] = "Prepare failed (addDiagnosis): " . $conn->error;
        header("Location: patientProfile.php?id=$pID&diagnoses-tab=1");
        exit;
    }
    $stmt->bind_param('iissii', $pID, $apptID, $diagDate, $fDate, $currentUserID, $currentUserID);
    $stmt->execute();
    if ($stmt->affected_rows > 0) {
        $newDiagID = $stmt->insert_id;
        $_SESSION['success'] = "Diagnosis (#$newDiagID) added.";
    } else {
        $_SESSION['error'] = "Failed to add diagnosis.";
    }
    $stmt->close();
    header("Location: patientProfile.php?id=$pID&diagnoses-tab=1");
    exit;
} elseif ($diagAction === 'editDiagnosis') {
    if ($userRole === 'staff') {
        $_SESSION['error'] = "Staff cannot edit diagnoses.";
        header("Location: patientProfile.php?id=$pID&diagnoses-tab=1");
        exit;
    }
    $diagID = (int)($_POST['diagnosis_id'] ?? 0);
    $diagDate = normalizeDate($_POST['diagnosis_date'] ?? '');
    $fDate = normalizeDate($_POST['followup_date'] ?? '');
    if (!$diagDate) {
        $_SESSION['error'] = "Diagnosis Date is required.";
        header("Location: patientProfile.php?id=$pID&diagnoses-tab=1");
        exit;
    }
    // Fetch current record to check if the dates are changed.
    $sqlFetch = "SELECT DiagnosisDate, FollowUpDate FROM diagnoses WHERE DiagnosisID = ? AND PatientID = ?";
    $stmtFetch = $conn->prepare($sqlFetch);
    if (!$stmtFetch) {
        $_SESSION['error'] = "Prepare failed (fetch): " . $conn->error;
        header("Location: patientProfile.php?id=$pID&diagnoses-tab=1");
        exit;
    }
    $stmtFetch->bind_param('ii', $diagID, $pID);
    $stmtFetch->execute();
    $resultFetch = $stmtFetch->get_result();
    if ($resultFetch->num_rows < 1) {
        $_SESSION['error'] = "Diagnosis record not found.";
        header("Location: patientProfile.php?id=$pID&diagnoses-tab=1");
        exit;
    }
    $currentRow = $resultFetch->fetch_assoc();
    $stmtFetch->close();
    // If both dates are the same as the current record, do not update.
    if ($currentRow['DiagnosisDate'] === $diagDate && $currentRow['FollowUpDate'] === $fDate) {
        $_SESSION['error'] = "Diagnosis already has the same date(s).";
        header("Location: patientProfile.php?id=$pID&diagnoses-tab=1");
        exit;
    }
    $sql = "UPDATE diagnoses
            SET DiagnosisDate = ?,
                FollowUpDate = ?,
                UpdatedBy = ?,
                UpdatedAt = NOW()
            WHERE DiagnosisID = ? AND PatientID = ?";
    $stmt = $conn->prepare($sql);
    if (!$stmt) {
        $_SESSION['error'] = "Prepare failed (editDiagnosis): " . $conn->error;
        header("Location: patientProfile.php?id=$pID&diagnoses-tab=1");
        exit;
    }
    $stmt->bind_param('ssiii', $diagDate, $fDate, $currentUserID, $diagID, $pID);
    $stmt->execute();
    if ($stmt->affected_rows > 0) {
        $_SESSION['success'] = "Diagnosis (#$diagID) updated.";
    } else {
        $_SESSION['error'] = "Diagnosis not updated. (Maybe no change was made.)";
    }
    $stmt->close();
    header("Location: patientProfile.php?id=$pID&diagnoses-tab=1");
    exit;
} elseif ($diagAction === 'deleteDiagnosis') {
    if ($userRole === 'staff') {
        $_SESSION['error'] = "Staff cannot delete diagnoses.";
        header("Location: patientProfile.php?id=$pID&diagnoses-tab=1");
        exit;
    }
    $diagID = (int)($_POST['diagnosis_id'] ?? 0);
    if ($diagID > 0) {
        $sql = "DELETE FROM diagnoses WHERE DiagnosisID = ? AND PatientID = ?";
        $stmt = $conn->prepare($sql);
        if ($stmt) {
            $stmt->bind_param('ii', $diagID, $pID);
            $stmt->execute();
            if ($stmt->affected_rows > 0) {
                $_SESSION['success'] = "Diagnosis (#$diagID) deleted.";
            } else {
                $_SESSION['error'] = "Failed to delete diagnosis.";
            }
            $stmt->close();
        } else {
            $_SESSION['error'] = "Prepare failed (deleteDiagnosis): " . $conn->error;
        }
    }
    header("Location: patientProfile.php?id=$pID&diagnoses-tab=1");
    exit;
}
