<?php

/**
 * followups_fetch.php
 *
 * Fetches follow-up records for a specific patient, with optional filters:
 *   - fu_start (YYYY-MM-DD)
 *   - fu_end   (YYYY-MM-DD)
 *   - fu_status (Pending, Done)
 *   - fu_category (ID from followup_categories)
 *   - Sorting via sort_by and sort_order GET parameters.
 *   - Pagination via fupg in $_GET.
 *
 * Outputs:
 *   - $followUps      : an array of follow_up records (with linked info and two-level ancestry)
 *   - $fuPg           : current page
 *   - $fuTotalPages   : total pages
 */

// 1. Grab filters from $_GET
$fu_start    = $_GET['fu_start']    ?? '';
$fu_end      = $_GET['fu_end']      ?? '';
$fu_status   = $_GET['fu_status']   ?? '';
$fu_category = $_GET['fu_category'] ?? '';

// 2. Build WHERE clauses
$fuClauses = ["f.PatientID = {$patient_id}"];
if (preg_match('/^\d{4}-\d{2}-\d{2}$/', $fu_start) && preg_match('/^\d{4}-\d{2}-\d{2}$/', $fu_end)) {
    $fuClauses[] = "f.FollowUpDate BETWEEN '$fu_start' AND '$fu_end'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $fu_start)) {
    $fuClauses[] = "f.FollowUpDate >= '$fu_start'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $fu_end)) {
    $fuClauses[] = "f.FollowUpDate <= '$fu_end'";
}
if (in_array($fu_status, ['Pending', 'Done'])) {
    $fuClauses[] = "f.FollowUpStatus = '$fu_status'";
}
if (is_numeric($fu_category) && $fu_category > 0) {
    $fuClauses[] = "f.followup_category_id = " . ((int)$fu_category);
}
$fuWhere = 'WHERE ' . implode(' AND ', $fuClauses);

// 3. Sorting
$sort_by    = $_GET['sort_by'] ?? 'date'; // allowed: id, type, category, date
$sort_order = $_GET['sort_order'] ?? 'desc';
$sort_order = (strtolower($sort_order) === 'asc') ? 'ASC' : 'DESC';
switch ($sort_by) {
    case 'id':
        $orderCol = "f.FollowUpID";
        break;
    case 'type':
        $orderCol = "f.FollowUpType";
        break;
    case 'category':
        $orderCol = "cat.name";
        break;
    case 'date':
    default:
        $orderCol = "f.FollowUpDate";
        break;
}

// 4. Pagination
$fuPerPage = 5;
$fuPg = isset($_GET['fupg']) ? (int)$_GET['fupg'] : 1;
if ($fuPg < 1) {
    $fuPg = 1;
}
$fuOffset = ($fuPg - 1) * $fuPerPage;

// 5. Count total follow-ups
$countFU = "SELECT COUNT(*) AS total FROM follow_up f $fuWhere";
$cFUr = $conn->query($countFU);
$fuRow = $cFUr->fetch_assoc();
$fuTotal = (int)($fuRow['total'] ?? 0);
$cFUr->close();
$fuTotalPages = ceil($fuTotal / $fuPerPage);

// 6. Fetch follow-ups with linked data and two-level ancestry
$sqlFU = "
  SELECT
    f.*,
    f.AppointmentID AS appointment_id,
    u1.username AS created_by_name,
    u2.username AS updated_by_name,
    cat.name AS category_name,
    f.linked_followup_id AS linked_id,
    linked.FollowUpDate AS linked_dt,
    linked.StatusUpdate AS linked_status,
    linked.Remarks AS linked_remarks,
    linkedCat.name AS linked_cat_name,
    CONCAT(
      '[',
      IF(linked.FollowUpID IS NOT NULL,
         CONCAT(
           '{\"FollowUpID\":', linked.FollowUpID,
           ',\"FollowUpDate\":\"', linked.FollowUpDate,
           '\",\"StatusUpdate\":\"', IFNULL(linked.StatusUpdate, ''),
           '\",\"Remarks\":\"', IFNULL(linked.Remarks, ''),
           '\",\"category_name\":\"', IFNULL(linkedCat.name, 'Unknown'),
           '\"}'
         ),
         ''
      ),
      IF(linked.FollowUpID IS NOT NULL AND anc1.FollowUpID IS NOT NULL, ',', ''),
      IF(anc1.FollowUpID IS NOT NULL,
         CONCAT(
           '{\"FollowUpID\":', anc1.FollowUpID,
           ',\"FollowUpDate\":\"', anc1.FollowUpDate,
           '\",\"StatusUpdate\":\"', IFNULL(anc1.StatusUpdate, ''),
           '\",\"Remarks\":\"', IFNULL(anc1.Remarks, ''),
           '\",\"category_name\":\"', IFNULL(ancCat.name, 'Unknown'),
           '\"}'
         ),
         ''
      ),
      ']'
    ) AS previous_linked
  FROM follow_up f
  LEFT JOIN users u1 ON f.CreatedBy = u1.id
  LEFT JOIN users u2 ON f.UpdatedBy = u2.id
  LEFT JOIN followup_categories cat ON f.followup_category_id = cat.id
  LEFT JOIN follow_up linked ON f.linked_followup_id = linked.FollowUpID
  LEFT JOIN followup_categories linkedCat ON linked.followup_category_id = linkedCat.id
  LEFT JOIN follow_up anc1 ON linked.linked_followup_id = anc1.FollowUpID
  LEFT JOIN followup_categories ancCat ON anc1.followup_category_id = ancCat.id
  $fuWhere
  ORDER BY $orderCol $sort_order, f.FollowUpID DESC
  LIMIT $fuPerPage OFFSET $fuOffset
";
$resFU = $conn->query($sqlFU);
$followUps = $resFU->fetch_all(MYSQLI_ASSOC);
$resFU->close();
