<?php

/**
 * patient_overview_section.php
 *
 * This partial displays the "Overview" tab details using a card layout.
 * Each section (Profile, Address, Medical History) is grouped into its own card.
 */

// Helper function to parse DOB and calculate current age from an IC Number
function parseDOBFromIC(string $icNumber): ?array
{
    if (preg_match('/^(\d{2})(\d{2})(\d{2})/', $icNumber, $matches)) {
        $yy = (int)$matches[1];
        $mm = (int)$matches[2];
        $dd = (int)$matches[3];
        if ($mm < 1 || $mm > 12 || $dd < 1 || $dd > 31) {
            return null;
        }

        // Determine century
        $century = ($yy < 30) ? 2000 : 1900;
        $fullYear = $century + $yy;
        $dobStr = sprintf('%04d-%02d-%02d', $fullYear, $mm, $dd);

        // Calculate current age
        $dob = new DateTime($dobStr);
        $today = new DateTime();
        $diff = $dob->diff($today);

        return [
            'dob' => $dobStr,
            'ageToday' => $diff->y . ' years, ' . $diff->m . ' months',
        ];
    }
    return null;
}

// Prepare patient data
$icNumber = $patient['identificationNumber'] ?? '';
$parsedIC = parseDOBFromIC($icNumber);

$ageWhenReg = (int)($patient['age'] ?? 0);  // Age recorded at registration
$currentAge = ($parsedIC) ? $parsedIC['ageToday'] : $ageWhenReg;
$dateReg    = !empty($patient['date_of_registration'])
    ? date('d M Y', strtotime($patient['date_of_registration']))
    : '-';

// If sex is female, we show LMP
$gender     = strtolower($patient['sex'] ?? '');
$showLMP    = ($gender === 'female');
$lmpDisplay = ($showLMP && !empty($medical_history['LMP']))
    ? date('d M Y', strtotime($medical_history['LMP']))
    : '-';

$fullName = trim(($patient['title'] ?? '') . ' ' . ($patient['first_name'] ?? '') . ' ' . ($patient['last_name'] ?? ''));

// Build full address string
$addressFields = array_filter([
    $address['add1'] ?? '',
    $address['add2'] ?? '',
    $address['city'] ?? '',
    $address['state'] ?? '',
    $address['postcode'] ?? '',
    $address['country'] ?? '',
]);
$formattedAddress = (!empty($addressFields)) ? implode(', ', $addressFields) : '-';

// Determine the patient's profile picture path or use a placeholder
$profileImagePath = !empty($patient['profile_image'])
    ? $baseURL . $patient['profile_image']   // e.g. "https://yoursite.com/uploads/profile/123/profilepicture.png"
    : "https://i.imgur.com/bDLhJiP.jpg";      // fallback/placeholder

?>
<div class="card shadow-sm border-0 mb-4">
    <!-- Profile Header -->
    <div class="d-flex justify-content-between align-items-center p-4" style="background-color: #f7f9fc; border-bottom: 2px solid #e6e6e6;">
        <div class="d-flex align-items-center">
            <!-- Show the dynamic profile picture here -->
            <img
                src="<?php echo htmlspecialchars($profileImagePath); ?>"
                alt="Profile Photo"
                class="rounded-circle me-4"
                style="width: 100px; height: 100px; object-fit: cover;">
            <div>
                <h4 class="fw-bold mb-1"><?php echo htmlspecialchars($fullName); ?></h4>
                <p class="text-muted mb-0">ID: <?php echo htmlspecialchars($icNumber); ?></p>
                <p class="text-muted">
                    <strong>Date of Registration:</strong> <?php echo htmlspecialchars($dateReg); ?>
                </p>
            </div>
        </div>
        <a href="<?php echo $baseURL; ?>pages/patient/patientAdd.php?id=<?php echo $patient['id']; ?>" class="btn btn-primary">
            <i class="fas fa-edit me-1"></i> Edit Patient
        </a>
    </div>

    <!-- Basic Details -->
    <div class="p-4">
        <h6 class="fw-bold text-primary mb-3">Basic Details</h6>
        <div class="row">
            <div class="col-md-6 mb-3">
                <p><strong>Age (When Registered):</strong> <?php echo htmlspecialchars($ageWhenReg); ?></p>
                <p><strong>Current Age:</strong> <?php echo htmlspecialchars($currentAge); ?></p>
                <p><strong>Sex:</strong> <?php echo htmlspecialchars($patient['sex'] ?? '-'); ?></p>
                <p><strong>Contact:</strong> <?php echo htmlspecialchars($patient['contact'] ?? '-'); ?></p>
            </div>
            <div class="col-md-6">
                <p><strong>Occupation:</strong> <?php echo htmlspecialchars($patient['occupation'] ?? '-'); ?></p>
                <p><strong>Marital Status:</strong> <?php echo htmlspecialchars($patient['marital_status'] ?? '-'); ?></p>
                <p><strong>Spouse:</strong> <?php echo htmlspecialchars($patient['spouse'] ?? '-'); ?></p>
                <p><strong>No. of Children:</strong> <?php echo (int)($patient['no_of_children'] ?? 0); ?></p>
            </div>
        </div>
    </div>
</div>

<!-- Address Section -->
<div class="card p-4 shadow-sm border-0 mb-4">
    <h6 class="fw-bold text-primary"><i class="fas fa-map-marker-alt me-2"></i> Address</h6>
    <p class="mb-0"><?php echo htmlspecialchars($formattedAddress); ?></p>
</div>

<!-- Medical History Section -->
<div class="card p-4 shadow-sm border-0">
    <h6 class="fw-bold text-primary"><i class="fas fa-notes-medical me-2"></i> Medical History</h6>
    <p>
        <strong>Disease History:</strong><br>
        <?php echo nl2br(htmlspecialchars($medical_history['history_of_disease'] ?? '-')); ?>
    </p>
    <p>
        <strong>Previous Medication:</strong><br>
        <?php echo nl2br(htmlspecialchars($medical_history['previous_medication'] ?? '-')); ?>
    </p>
    <?php if ($showLMP): ?>
        <p><strong>LMP:</strong> <?php echo htmlspecialchars($lmpDisplay); ?></p>
    <?php endif; ?>
</div>