<?php

/**
 * patientProfile.php
 *
 * Shows the patient profile with all tabs:
 * Overview, Vitals, Debts, Follow‑Ups, Appointments, Diagnoses, and Reports.
 * The inline Appointments section is included directly here; 
 * other tabs are included via separate files (e.g. 'diagnosis_section.php').
 */

date_default_timezone_set('Asia/Kuala_Lumpur');

// ---------------------------------------------------------------------------
// (1) REQUIRED FILES & INITIAL CHECKS
// ---------------------------------------------------------------------------
include '../../common/url.php';         // Defines $baseURL, etc.
include ROOT_PATH . 'common/session.php'; // Manages session checks
include ROOT_PATH . 'common/config.php';  // Provides $conn (mysqli)

$currentUserID = $_SESSION['user_id'] ?? null;
$userRole      = $_SESSION['role']    ?? 'staff';

// If no valid user is logged in, stop.
if (!$currentUserID) {
    die("No valid user session found. Please log in.");
}

// Prevent caching issues.
header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");
header("Pragma: no-cache");

// ---------------------------------------------------------------------------
// (2) FLASH MESSAGES & ACTIVE TAB
// ---------------------------------------------------------------------------
if (!isset($_SESSION['error']))   $_SESSION['error']   = '';
if (!isset($_SESSION['success'])) $_SESSION['success'] = '';
$errorMsg   = $_SESSION['error'];
$successMsg = $_SESSION['success'];
// Reset after reading.
$_SESSION['error']   = '';
$_SESSION['success'] = '';

// Determine which tab is active based on GET parameters.
$activeTab = 'overviewTab'; // Default
if (isset($_GET['debts-tab'])) {
    $activeTab = 'debtsTab';
} elseif (isset($_GET['followups-tab'])) {
    $activeTab = 'followupsTab';
} elseif (isset($_GET['appointments-tab'])) {
    $activeTab = 'appointmentsTab';
} elseif (isset($_GET['diagnoses-tab'])) {
    $activeTab = 'diagnosesTab';
} elseif (isset($_GET['reports-tab'])) {
    $activeTab = 'reportsTab';
} elseif (isset($_GET['vitals-tab'])) {
    $activeTab = 'vitalsTab';
}

// ---------------------------------------------------------------------------
// (3) VALIDATE PATIENT ID
// ---------------------------------------------------------------------------
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    echo "<div class='container mt-4'><h3>Invalid Patient ID.</h3></div>";
    exit;
}
$patient_id = (int)$_GET['id'];

// ---------------------------------------------------------------------------
// (4) OPTIONAL HELPER FUNCTIONS
//     E.g., you might have logic for inserting histories, if needed.
// ---------------------------------------------------------------------------
function insertAppointmentHistory(mysqli $conn, array $oldData, int $editedBy, string $actionType)
{
    // Example logic to insert into appointments_history if required.
}

function insertFollowUpHistory(mysqli $conn, array $oldData, int $editedBy, string $actionType)
{
    // Example logic to insert into follow_up_history if required.
}

// ---------------------------------------------------------------------------
// (5) PROCESS ANY POST ACTIONS (FOLLOWUPS, DIAGNOSES, REPORTS, ETC.)
// ---------------------------------------------------------------------------
if ($_SERVER['REQUEST_METHOD'] === 'POST') {

    // Additional logic files for each module:
    if (!empty($_POST['followup_action'])) {
        include 'followups_logic.php';
    }
    if (!empty($_POST['diag_action'])) {
        include 'diagnoses_logic.php';
    }
    if (!empty($_POST['report_action'])) {
        include 'reports_logic.php';
    }
    if (!empty($_POST['vitals_action'])) {
        include 'vitals_logic.php';
    }

    // ------------------- Appointments Logic (Inline) -------------------
    $apptAction = $_POST['appt_action'] ?? '';
    if (!empty($apptAction)) {
        if ($apptAction === 'addAppointment') {
            // (A) Add an appointment
            $pID      = (int)($_POST['patient_id'] ?? 0);
            $apptDate = trim($_POST['appointment_date'] ?? '');
            $apptTime = trim($_POST['appointment_time'] ?? '');
            $purpose  = trim($_POST['purpose'] ?? '');
            $status   = trim($_POST['status'] ?? 'Scheduled');
            $remarks  = (string) trim($_POST['remarks'] ?? '');

            // Optional auto-check
            $autoDx        = !empty($_POST['auto_create_diagnosis']);
            $autoSchedule  = !empty($_POST['auto_schedule_followups']);

            // Validate basic fields:
            if (!$pID || !$apptDate || !$apptTime || !$purpose || !$status) {
                $_SESSION['error'] = "Please fill in all required fields (date, time, purpose, status).";
                header("Location: patientProfile.php?id={$pID}&appointments-tab=1");
                exit;
            }
            // Staff cannot backdate.
            if ($userRole === 'staff' && $apptDate < date('Y-m-d')) {
                $_SESSION['error'] = "Staff cannot create an appointment in the past.";
                header("Location: patientProfile.php?id={$pID}&appointments-tab=1");
                exit;
            }

            // Start transaction
            $conn->begin_transaction();
            try {
                // Check if a Scheduled appointment already exists
                $chk = $conn->prepare("SELECT AppointmentID FROM appointments
                                       WHERE PatientID=? AND Status='Scheduled' LIMIT 1");
                $chk->bind_param('i', $pID);
                $chk->execute();
                $chres = $chk->get_result();
                if ($chres->num_rows > 0 && $status === 'Scheduled') {
                    $conn->rollback();
                    $_SESSION['error'] = "Patient already has a Scheduled appointment. Complete or cancel it first.";
                    header("Location: patientProfile.php?id={$pID}&appointments-tab=1");
                    exit;
                }
                $chk->close();

                // Check collision for same date/time
                $col = $conn->prepare("SELECT AppointmentID FROM appointments
                                       WHERE PatientID=? AND AppointmentDate=? AND AppointmentTime=? LIMIT 1");
                $col->bind_param('iss', $pID, $apptDate, $apptTime);
                $col->execute();
                $colres = $col->get_result();
                if ($colres->num_rows > 0) {
                    $conn->rollback();
                    $_SESSION['error'] = "An appointment already exists at {$apptDate} {$apptTime} for this patient.";
                    header("Location: patientProfile.php?id={$pID}&appointments-tab=1");
                    exit;
                }
                $col->close();

                // Insert new appointment
                $sqlA = "
                  INSERT INTO appointments (
                    PatientID,
                    AppointmentDate,
                    AppointmentTime,
                    Purpose,
                    Status,
                    Remarks,
                    CreatedBy,
                    UpdatedBy,
                    CreatedAt,
                    UpdatedAt
                  ) VALUES (?,?,?,?,?,?,?, ?,NOW(),NOW())
                ";
                $stA = $conn->prepare($sqlA);
                $stA->bind_param(
                    'isssssii',
                    $pID,
                    $apptDate,
                    $apptTime,
                    $purpose,
                    $status,
                    $remarks,
                    $currentUserID,
                    $currentUserID
                );
                $stA->execute();
                $newAID = $stA->insert_id;
                $stA->close();

                // Auto-create diagnosis if requested
                if ($autoDx && $newAID > 0) {
                    $dxSQL = "
                      INSERT INTO diagnoses (
                        PatientID,
                        AppointmentID,
                        Diagnosis,
                        CreatedBy,
                        UpdatedBy,
                        CreatedAt,
                        UpdatedAt
                      ) VALUES (?, ?, 'Auto-created Diagnosis', ?, ?, NOW(),NOW())
                    ";
                    $stDx = $conn->prepare($dxSQL);
                    $stDx->bind_param('iiii', $pID, $newAID, $currentUserID, $currentUserID);
                    $stDx->execute();
                    $stDx->close();
                }

                // Auto-schedule follow-ups if requested
                if ($autoSchedule && $newAID > 0) {
                    $ts = strtotime("$apptDate $apptTime");
                    $offsets = [-7, -3, -1]; // e.g. 1 week, 3 days, 1 day prior
                    foreach ($offsets as $days) {
                        $fTime = $ts + ($days * 86400);
                        if ($fTime < time()) {
                            // If the calculated time is in the past, skip
                            continue;
                        }
                        $fuDate = date('Y-m-d H:i:s', $fTime);
                        $statusUpdate = "Auto-scheduled follow-up";
                        $fuType       = "Auto";
                        $fuRem        = "Auto-scheduled for Appointment #{$newAID}";
                        $fuSQL = "
                          INSERT INTO follow_up (
                            PatientID, AppointmentID,
                            FollowUpDate, StatusUpdate,
                            FollowUpType, NextFollowUpDate,
                            Remarks, followup_category_id,
                            FollowUpStatus, linked_followup_id,
                            CreatedBy, UpdatedBy, CreatedAt, UpdatedAt
                          ) VALUES (
                            ?, ?, ?, ?, ?,
                            NULL, ?, 3, 'Pending', NULL,
                            ?, ?, NOW(), NOW()
                          )
                        ";
                        $stFU = $conn->prepare($fuSQL);
                        $stFU->bind_param(
                            'iissssii',
                            $pID,
                            $newAID,
                            $fuDate,
                            $statusUpdate,
                            $fuType,
                            $fuRem,
                            $currentUserID,
                            $currentUserID
                        );
                        $stFU->execute();
                        $stFU->close();
                    }
                }

                $conn->commit();
                $_SESSION['success'] = "Appointment added (#{$newAID}).";
            } catch (Exception $ex) {
                $conn->rollback();
                $_SESSION['error'] = "Error adding Appointment: " . $ex->getMessage();
            }
            header("Location: patientProfile.php?id={$pID}&appointments-tab=1");
            exit;
        } elseif ($apptAction === 'editAppointment') {
            // (B) Edit an appointment
            $apptID   = (int)($_POST['appointment_id'] ?? 0);
            $pID      = (int)($_POST['patient_id'] ?? 0);
            $apptDate = $_POST['appointment_date'] ?? date('Y-m-d');
            $apptTime = $_POST['appointment_time'] ?? '09:00:00';
            $purpose  = trim($_POST['purpose'] ?? '');
            $status   = $_POST['status'] ?? 'Scheduled';
            $remarks  = trim($_POST['remarks'] ?? '');
            $autoUpdateFollowups = !empty($_POST['auto_update_followups']);

            // Staff cannot backdate
            if ($userRole === 'staff' && $apptDate < date('Y-m-d')) {
                $_SESSION['error'] = "Staff cannot backdate an appointment.";
                header("Location: patientProfile.php?id={$pID}&appointments-tab=1");
                exit;
            }

            // Fetch old record
            $oldSQL = "SELECT * FROM appointments WHERE AppointmentID=? AND PatientID=? LIMIT 1";
            $stOld = $conn->prepare($oldSQL);
            $stOld->bind_param('ii', $apptID, $pID);
            $stOld->execute();
            $resOld = $stOld->get_result();
            if ($resOld->num_rows < 1) {
                $_SESSION['error'] = "Appointment not found or invalid for update.";
                header("Location: patientProfile.php?id={$pID}&appointments-tab=1");
                exit;
            }
            $oldAp = $resOld->fetch_assoc();
            $stOld->close();

            $conn->begin_transaction();
            try {
                // Update main appointment
                $sqlUpA = "
                  UPDATE appointments
                  SET AppointmentDate=?,
                      AppointmentTime=?,
                      Purpose=?,
                      Status=?,
                      Remarks=?,
                      UpdatedBy=?,
                      UpdatedAt=NOW()
                  WHERE AppointmentID=? AND PatientID=?
                ";
                $stUpA = $conn->prepare($sqlUpA);
                $stUpA->bind_param(
                    'sssssiii',
                    $apptDate,
                    $apptTime,
                    $purpose,
                    $status,
                    $remarks,
                    $currentUserID,
                    $apptID,
                    $pID
                );
                $stUpA->execute();
                $stUpA->close();

                // If asked, remove and recreate the "auto" follow-ups (cat=3)
                if ($autoUpdateFollowups) {
                    $delSQL = "DELETE FROM follow_up WHERE AppointmentID=? AND followup_category_id=3";
                    $stDel = $conn->prepare($delSQL);
                    $stDel->bind_param('i', $apptID);
                    $stDel->execute();
                    $stDel->close();

                    $apptDateTime = strtotime("$apptDate $apptTime");
                    $offsets = [-7, -3, -1];
                    foreach ($offsets as $days) {
                        $fuTime = $apptDateTime + ($days * 86400);
                        if ($fuTime < time()) {
                            continue;
                        }
                        $fuDate = date('Y-m-d H:i:s', $fuTime);
                        $statusUpdateFU = "Auto-updated follow-up";
                        $fuType         = "Auto";
                        $fuRemarks      = "Auto-updated follow-up for Appointment #{$apptID}";
                        $sqlFU = "
                          INSERT INTO follow_up (
                            PatientID, AppointmentID,
                            FollowUpDate, StatusUpdate,
                            FollowUpType, NextFollowUpDate,
                            Remarks, FollowUpStatus,
                            followup_category_id, linked_followup_id,
                            CreatedBy, UpdatedBy, CreatedAt, UpdatedAt
                          ) VALUES (
                            ?, ?, ?, ?, ?,
                            NULL, ?, 'Pending', 3, NULL,
                            ?, ?, NOW(), NOW()
                          )
                        ";
                        $stFU = $conn->prepare($sqlFU);
                        $stFU->bind_param(
                            'iissssii',
                            $pID,
                            $apptID,
                            $fuDate,
                            $statusUpdateFU,
                            $fuType,
                            $fuRemarks,
                            $currentUserID,
                            $currentUserID
                        );
                        $stFU->execute();
                        $stFU->close();
                    }
                }

                $conn->commit();
                $_SESSION['success'] = "Appointment #{$apptID} updated.";
            } catch (Exception $ex) {
                $conn->rollback();
                $_SESSION['error'] = "Error updating Appointment: " . $ex->getMessage();
            }
            header("Location: patientProfile.php?id={$pID}&appointments-tab=1");
            exit;
        } elseif ($apptAction === 'deleteAppointment') {
            // (C) Delete an appointment
            if ($userRole === 'staff') {
                $_SESSION['error'] = "Staff cannot delete appointments.";
                header("Location: patientProfile.php?id={$patient_id}&appointments-tab=1");
                exit;
            }
            $apptID = (int)($_POST['appointment_id'] ?? 0);
            if ($apptID > 0) {
                $oldSQL = "SELECT * FROM appointments WHERE AppointmentID=? AND PatientID=? LIMIT 1";
                $sOld = $conn->prepare($oldSQL);
                $sOld->bind_param('ii', $apptID, $patient_id);
                $sOld->execute();
                $rOld = $sOld->get_result();
                // Not absolutely necessary here, but you could read $oldAp if needed
                $oldAp = ($rOld->num_rows > 0) ? $rOld->fetch_assoc() : null;
                $sOld->close();

                $conn->begin_transaction();
                try {
                    // Delete from appointments
                    $delA = "DELETE FROM appointments WHERE AppointmentID=? AND PatientID=?";
                    $stDelA = $conn->prepare($delA);
                    $stDelA->bind_param('ii', $apptID, $patient_id);
                    $stDelA->execute();
                    $stDelA->close();

                    $conn->commit();
                    $_SESSION['success'] = "Appointment #{$apptID} deleted.";
                } catch (Exception $ex) {
                    $conn->rollback();
                    $_SESSION['error'] = "Error deleting Appointment: " . $ex->getMessage();
                }
            }
            header("Location: patientProfile.php?id={$patient_id}&appointments-tab=1");
            exit;
        }
    } // end if ($apptAction)
} // end if POST

// ---------------------------------------------------------------------------
// (6) FETCH PATIENT INFO FOR OVERVIEW
// ---------------------------------------------------------------------------
$stP = $conn->prepare('SELECT * FROM patients WHERE id=? LIMIT 1');
$stP->bind_param('i', $patient_id);
$stP->execute();
$resP = $stP->get_result();
if ($resP->num_rows < 1) {
    die('<div class="container mt-4"><h3>Patient not found in DB.</h3></div>');
}
$patient = $resP->fetch_assoc();
$stP->close();

// Also fetch address, medical history, etc.
$stA = $conn->prepare('SELECT * FROM patient_address WHERE patient_id=? LIMIT 1');
$stA->bind_param('i', $patient_id);
$stA->execute();
$addrRes = $stA->get_result();
$address = $addrRes->fetch_assoc();
$stA->close();

$stMH = $conn->prepare('SELECT * FROM patient_medical_history WHERE patient_id=? LIMIT 1');
$stMH->bind_param('i', $patient_id);
$stMH->execute();
$mRes = $stMH->get_result();
$medical_history = $mRes->fetch_assoc();
$stMH->close();

// ---------------------------------------------------------------------------
// (7) FETCH OTHER SECTIONS (Debts, FollowUps, Appointments, Diagnoses, Reports, Vitals)
// ---------------------------------------------------------------------------
// In your code, you have separate "include" files that do the queries for each section:
include 'debts_fetch.php';
include 'followups_fetch.php';

// ---- (A) APPOINTMENTS FETCH CODE (Inline) ----
$filterApptID = isset($_GET['appt_id']) ? (int)$_GET['appt_id'] : 0;
$appt_start   = $_GET['appt_start'] ?? '';
$appt_end     = $_GET['appt_end']   ?? '';
$appt_status  = $_GET['appt_status'] ?? '';

$apClauses = ["a.PatientID = {$patient_id}"];
if ($filterApptID > 0) {
    $apClauses[] = "a.AppointmentID = {$filterApptID}";
}

// Handle date filters
if (preg_match('/^\d{4}-\d{2}-\d{2}$/', $appt_start) && preg_match('/^\d{4}-\d{2}-\d{2}$/', $appt_end)) {
    $apClauses[] = "DATE(a.AppointmentDate) BETWEEN '{$appt_start}' AND '{$appt_end}'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $appt_start)) {
    $apClauses[] = "DATE(a.AppointmentDate) >= '{$appt_start}'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $appt_end)) {
    $apClauses[] = "DATE(a.AppointmentDate) <= '{$appt_end}'";
}

// Filter by status
if (in_array($appt_status, ['Scheduled', 'Completed', 'Cancelled'], true)) {
    $apClauses[] = "a.Status = '{$appt_status}'";
}
$apWhere = "WHERE " . implode(' AND ', $apClauses);

$apPerPage = 5;
$apPg = isset($_GET['apg']) ? (int)$_GET['apg'] : 1;
if ($apPg < 1) {
    $apPg = 1;
}
$apOffset = ($apPg - 1) * $apPerPage;

// Count total appointments
$countAptSQL = "SELECT COUNT(a.AppointmentID) AS total FROM appointments a {$apWhere}";
$resCountAp = $conn->query($countAptSQL);
if (!$resCountAp) {
    $apTotal = 0;
} else {
    $countRow = $resCountAp->fetch_assoc();
    $apTotal = (int)($countRow['total'] ?? 0);
    $resCountAp->free();
}
$apTotalPages = ($apTotal > 0) ? ceil($apTotal / $apPerPage) : 1;

// Fetch the actual appointment rows
$sqlAp = "
  SELECT
    a.AppointmentID,
    a.AppointmentDate,
    a.AppointmentTime,
    a.PatientID,
    a.Purpose,
    a.Status,
    a.Remarks,
    CASE WHEN COUNT(d.DiagnosisID) > 0 THEN 1 ELSE 0 END AS has_diagnosis
  FROM appointments a
  LEFT JOIN diagnoses d
         ON d.AppointmentID = a.AppointmentID
        AND d.PatientID     = a.PatientID
  {$apWhere}
  GROUP BY a.AppointmentID
  ORDER BY a.AppointmentDate DESC, a.AppointmentTime DESC
  LIMIT {$apPerPage} OFFSET {$apOffset}
";
$resAp = $conn->query($sqlAp);
if (!$resAp) {
    $appointments = [];
} else {
    $appointments = $resAp->fetch_all(MYSQLI_ASSOC);
    $resAp->free();
}

// ---- (B) Diagnoses, Reports, Vitals fetch code in separate files ----
include 'diagnoses_fetch.php';
include 'reports_fetch.php';
include 'vitals_fetch.php';

// Build a combined full name for display
$patientFullName = trim($patient['first_name'] . ' ' . $patient['last_name']);
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <title>Patient Profile (All Tabs)</title>

    <!-- Bootstrap + FontAwesome (CDN) -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">

    <!-- Custom CSS -->
    <link href="<?php echo $baseURL; ?>assets/css/patientProfile.css" rel="stylesheet">
    <link href="<?php echo $baseURL; ?>assets/css/styles.css" rel="stylesheet">

    <style>
        /* Optional styling for your action buttons / layout */
        .btn-action {
            min-width: 40px;
            padding: .375rem .75rem;
            font-size: 0.875rem;
        }

        .appointments-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
        }

        /* Add any additional custom styles as needed */
    </style>
</head>

<body>
    <div id="wrapper">
        <?php include ROOT_PATH . 'includes/navbar.php'; ?>
        <div id="page-content-wrapper">
            <?php include ROOT_PATH . 'includes/sidebar.php'; ?>

            <div class="container-fluid mt-4">
                <!-- FLASH MESSAGES (success/error) -->
                <?php if (!empty($errorMsg)): ?>
                    <div class="alert alert-danger alert-dismissible fade show">
                        <i class="fas fa-exclamation-triangle me-1"></i>
                        <?php echo htmlspecialchars($errorMsg, ENT_QUOTES, 'UTF-8'); ?>
                        <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                    </div>
                <?php endif; ?>
                <?php if (!empty($successMsg)): ?>
                    <div class="alert alert-success alert-dismissible fade show">
                        <i class="fas fa-check-circle me-1"></i>
                        <?php echo htmlspecialchars($successMsg, ENT_QUOTES, 'UTF-8'); ?>
                        <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                    </div>
                <?php endif; ?>

                <!-- PAGE TITLE (PATIENT PROFILE) -->
                <div class="card mb-4 shadow-sm border-0">
                    <div class="card-body text-center bg-primary text-white rounded-3">
                        <h4 class="card-title mb-1 fw-bold">Patient Profile (All Tabs)</h4>
                        <p class="mb-0">
                            <?php echo htmlspecialchars($patientFullName, ENT_QUOTES, 'UTF-8'); ?>
                        </p>
                    </div>
                </div>

                <!-- NAV TABS for each section -->
                <ul class="nav nav-tabs custom-nav-tabs" id="patientTabs" role="tablist">
                    <li class="nav-item">
                        <button class="nav-link <?php if ($activeTab === 'overviewTab') echo 'active'; ?>"
                            id="overview-tab" data-bs-toggle="tab"
                            data-bs-target="#overviewTab" type="button"
                            role="tab" aria-controls="overviewTab"
                            aria-selected="<?php echo ($activeTab === 'overviewTab') ? 'true' : 'false'; ?>">
                            Overview
                        </button>
                    </li>
                    <li class="nav-item">
                        <button class="nav-link <?php if ($activeTab === 'vitalsTab') echo 'active'; ?>"
                            id="vitals-tab" data-bs-toggle="tab"
                            data-bs-target="#vitalsTab" type="button"
                            role="tab" aria-controls="vitalsTab"
                            aria-selected="<?php echo ($activeTab === 'vitalsTab') ? 'true' : 'false'; ?>">
                            Vitals
                        </button>
                    </li>
                    <li class="nav-item">
                        <button class="nav-link <?php if ($activeTab === 'debtsTab') echo 'active'; ?>"
                            id="debts-tab" data-bs-toggle="tab"
                            data-bs-target="#debtsTab" type="button"
                            role="tab" aria-controls="debtsTab"
                            aria-selected="<?php echo ($activeTab === 'debtsTab') ? 'true' : 'false'; ?>">
                            Debts
                        </button>
                    </li>
                    <li class="nav-item">
                        <button class="nav-link <?php if ($activeTab === 'followupsTab') echo 'active'; ?>"
                            id="followups-tab" data-bs-toggle="tab"
                            data-bs-target="#followupsTab" type="button"
                            role="tab" aria-controls="followupsTab"
                            aria-selected="<?php echo ($activeTab === 'followupsTab') ? 'true' : 'false'; ?>">
                            Follow-Ups
                        </button>
                    </li>
                    <li class="nav-item">
                        <button class="nav-link <?php if ($activeTab === 'appointmentsTab') echo 'active'; ?>"
                            id="appointments-tab" data-bs-toggle="tab"
                            data-bs-target="#appointmentsTab" type="button"
                            role="tab" aria-controls="appointmentsTab"
                            aria-selected="<?php echo ($activeTab === 'appointmentsTab') ? 'true' : 'false'; ?>">
                            Appointments
                        </button>
                    </li>
                    <li class="nav-item">
                        <button class="nav-link <?php if ($activeTab === 'diagnosesTab') echo 'active'; ?>"
                            id="diagnoses-tab" data-bs-toggle="tab"
                            data-bs-target="#diagnosesTab" type="button"
                            role="tab" aria-controls="diagnosesTab"
                            aria-selected="<?php echo ($activeTab === 'diagnosesTab') ? 'true' : 'false'; ?>">
                            Diagnoses
                        </button>
                    </li>
                    <li class="nav-item">
                        <button class="nav-link <?php if ($activeTab === 'reportsTab') echo 'active'; ?>"
                            id="reports-tab" data-bs-toggle="tab"
                            data-bs-target="#reportsTab" type="button"
                            role="tab" aria-controls="reportsTab"
                            aria-selected="<?php echo ($activeTab === 'reportsTab') ? 'true' : 'false'; ?>">
                            Reports
                        </button>
                    </li>
                </ul>

                <!-- TAB CONTENTS -->
                <div class="tab-content mt-3" id="patientTabsContent">
                    <!-- (1) Overview Tab -->
                    <div class="tab-pane fade <?php if ($activeTab === 'overviewTab') echo 'show active'; ?>"
                        id="overviewTab" role="tabpanel" aria-labelledby="overview-tab">
                        <?php include 'overview_section.php'; ?>
                    </div>

                    <!-- (2) Vitals Tab -->
                    <div class="tab-pane fade <?php if ($activeTab === 'vitalsTab') echo 'show active'; ?>"
                        id="vitalsTab" role="tabpanel" aria-labelledby="vitals-tab">
                        <?php include 'vitals_section.php'; ?>
                    </div>

                    <!-- (3) Debts Tab -->
                    <div class="tab-pane fade <?php if ($activeTab === 'debtsTab') echo 'show active'; ?>"
                        id="debtsTab" role="tabpanel" aria-labelledby="debts-tab">
                        <?php include 'debts_section.php'; ?>
                    </div>

                    <!-- (4) Follow-Ups Tab -->
                    <div class="tab-pane fade <?php if ($activeTab === 'followupsTab') echo 'show active'; ?>"
                        id="followupsTab" role="tabpanel" aria-labelledby="followups-tab">
                        <?php include 'followups_section.php'; ?>
                    </div>

                    <!-- (5) Appointments Tab -->
                    <div class="tab-pane fade <?php if ($activeTab === 'appointmentsTab') echo 'show active'; ?>"
                        id="appointmentsTab" role="tabpanel" aria-labelledby="appointments-tab">
                        <!-- Inline appointments UI -->
                        <div class="card p-3 shadow-sm border-0">
                            <div class="appointments-header mb-3">
                                <h5 class="mb-0">
                                    Appointments (Patient #<?php echo (int)$patient_id; ?>)
                                </h5>
                                <?php if ($userRole === 'staff' || $userRole === 'admin'): ?>
                                    <button class="btn btn-primary btn-action"
                                        data-bs-toggle="modal"
                                        data-bs-target="#addAppointmentModal">
                                        <i class="fas fa-plus"></i> Add Appointment
                                    </button>
                                <?php endif; ?>
                            </div>

                            <!-- Filter Form for Appointments -->
                            <form class="row g-3 mb-3" method="GET">
                                <input type="hidden" name="id" value="<?php echo (int)$patient_id; ?>">
                                <input type="hidden" name="appointments-tab" value="1">

                                <div class="col-md-3">
                                    <label class="form-label fw-bold">Start Date</label>
                                    <input type="date" class="form-control"
                                        name="appt_start"
                                        value="<?php echo htmlspecialchars($_GET['appt_start'] ?? '', ENT_QUOTES, 'UTF-8'); ?>">
                                </div>
                                <div class="col-md-3">
                                    <label class="form-label fw-bold">End Date</label>
                                    <input type="date" class="form-control"
                                        name="appt_end"
                                        value="<?php echo htmlspecialchars($_GET['appt_end'] ?? '', ENT_QUOTES, 'UTF-8'); ?>">
                                </div>
                                <div class="col-md-3">
                                    <label class="form-label fw-bold">Status</label>
                                    <select class="form-select" name="appt_status">
                                        <option value="">All</option>
                                        <option value="Scheduled"
                                            <?php if (($_GET['appt_status'] ?? '') === 'Scheduled') echo 'selected'; ?>>
                                            Scheduled
                                        </option>
                                        <option value="Completed"
                                            <?php if (($_GET['appt_status'] ?? '') === 'Completed') echo 'selected'; ?>>
                                            Completed
                                        </option>
                                        <option value="Cancelled"
                                            <?php if (($_GET['appt_status'] ?? '') === 'Cancelled') echo 'selected'; ?>>
                                            Cancelled
                                        </option>
                                    </select>
                                </div>
                                <div class="col-md-3 d-flex align-items-end">
                                    <button type="submit" class="btn btn-primary btn-action">
                                        <i class="fas fa-filter me-1"></i> Filter
                                    </button>
                                </div>
                            </form>

                            <?php if (!empty($appointments)): ?>
                                <div class="table-responsive">
                                    <table class="table table-bordered align-middle text-center">
                                        <thead class="table-light">
                                            <tr>
                                                <th>ID</th>
                                                <th>Date/Time</th>
                                                <th>Purpose</th>
                                                <th>Status</th>
                                                <th>Remarks</th>
                                                <th style="width:210px;">Actions</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <?php foreach ($appointments as $apt):
                                                $aptID = (int)$apt['AppointmentID'];
                                                // Prepare data to pass to the "Edit" modal
                                                $aptData = [
                                                    'AppointmentID'   => $aptID,
                                                    'AppointmentDate' => $apt['AppointmentDate'] ?? '',
                                                    'AppointmentTime' => substr($apt['AppointmentTime'] ?? '09:00:00', 0, 5),
                                                    'Purpose'         => $apt['Purpose'] ?? '',
                                                    'Status'          => $apt['Status'] ?? 'Scheduled',
                                                    'Remarks'         => $apt['Remarks'] ?? ''
                                                ];
                                                $hasDiagnosis = !empty($apt['has_diagnosis']);
                                            ?>
                                                <tr>
                                                    <td><?php echo $aptID; ?></td>
                                                    <td>
                                                        <?php echo htmlspecialchars($apt['AppointmentDate'] ?? '-', ENT_QUOTES, 'UTF-8'); ?>
                                                        <br>
                                                        <?php
                                                        echo (!empty($apt['AppointmentTime']))
                                                            ? substr($apt['AppointmentTime'], 0, 5)
                                                            : '--:--';
                                                        ?>
                                                    </td>
                                                    <td><?php echo htmlspecialchars($apt['Purpose'] ?? '-', ENT_QUOTES, 'UTF-8'); ?></td>
                                                    <td>
                                                        <?php if ($apt['Status'] === 'Completed'): ?>
                                                            <span class="badge bg-success">Completed</span>
                                                        <?php elseif ($apt['Status'] === 'Cancelled'): ?>
                                                            <span class="badge bg-danger">Cancelled</span>
                                                        <?php else: ?>
                                                            <span class="badge bg-warning text-dark">Scheduled</span>
                                                        <?php endif; ?>
                                                    </td>
                                                    <td style="white-space: pre-wrap;">
                                                        <?php echo nl2br(htmlspecialchars($apt['Remarks'] ?? '', ENT_QUOTES, 'UTF-8')); ?>
                                                    </td>
                                                    <td>
                                                        <div class="d-flex flex-wrap justify-content-center gap-1">
                                                            <!-- Edit only if staff or admin -->
                                                            <?php if ($userRole === 'staff' || $userRole === 'admin'): ?>
                                                                <button class="btn btn-warning btn-sm btn-action"
                                                                    data-bs-toggle="modal"
                                                                    data-bs-target="#editAppointmentModal"
                                                                    data-appointment='<?php echo json_encode($aptData); ?>'
                                                                    title="Edit Appointment">
                                                                    <i class="fas fa-edit"></i>
                                                                </button>
                                                            <?php endif; ?>

                                                            <!-- Add / View Diagnosis Button -->
                                                            <span id="diagBtn-<?php echo $aptID; ?>">
                                                                <?php if (!$hasDiagnosis): ?>
                                                                    <button class="btn btn-info btn-sm btn-action"
                                                                        onclick="addDiagnosis(<?php echo (int)$patient_id; ?>, <?php echo $aptID; ?>)"
                                                                        title="Add Diagnosis">
                                                                        <i class="fas fa-plus"></i>
                                                                    </button>
                                                                <?php else: ?>
                                                                    <a class="btn btn-info btn-sm btn-action"
                                                                        href="patientProfile.php?id=<?php echo (int)$patient_id; ?>&diagnoses-tab=1&appt_id=<?php echo $aptID; ?>"
                                                                        title="View Diagnosis">
                                                                        <i class="fas fa-stethoscope"></i>
                                                                    </a>
                                                                <?php endif; ?>
                                                            </span>

                                                            <!-- View Follow-Ups -->
                                                            <button class="btn btn-secondary btn-sm btn-action"
                                                                onclick="viewFollowUps(<?php echo $aptID; ?>)"
                                                                title="View Follow-Ups">
                                                                <i class="fas fa-eye"></i>
                                                            </button>

                                                            <!-- Delete only if admin -->
                                                            <?php if ($userRole === 'admin'): ?>
                                                                <form method="POST" class="d-inline"
                                                                    onsubmit="return confirm('Delete appointment #<?php echo $aptID; ?>?');">
                                                                    <input type="hidden" name="appt_action" value="deleteAppointment">
                                                                    <input type="hidden" name="appointment_id" value="<?php echo $aptID; ?>">
                                                                    <input type="hidden" name="patient_id" value="<?php echo (int)$patient_id; ?>">
                                                                    <button class="btn btn-danger btn-sm btn-action" title="Delete Appointment">
                                                                        <i class="fas fa-trash"></i>
                                                                    </button>
                                                                </form>
                                                            <?php endif; ?>
                                                        </div>
                                                    </td>
                                                </tr>
                                            <?php endforeach; ?>
                                        </tbody>
                                    </table>
                                </div>

                                <!-- Appointment Pagination -->
                                <?php if ($apTotalPages > 1): ?>
                                    <nav class="mt-3">
                                        <ul class="pagination justify-content-center">
                                            <?php if ($apPg > 1): ?>
                                                <li class="page-item">
                                                    <a class="page-link"
                                                        href="?id=<?php echo (int)$patient_id; ?>&appointments-tab=1&apg=<?php echo ($apPg - 1); ?>">
                                                        « Prev
                                                    </a>
                                                </li>
                                            <?php else: ?>
                                                <li class="page-item disabled"><span class="page-link">« Prev</span></li>
                                            <?php endif; ?>

                                            <?php for ($i = 1; $i <= $apTotalPages; $i++): ?>
                                                <li class="page-item <?php if ($i === $apPg) echo 'active'; ?>">
                                                    <a class="page-link"
                                                        href="?id=<?php echo (int)$patient_id; ?>&appointments-tab=1&apg=<?php echo $i; ?>">
                                                        <?php echo $i; ?>
                                                    </a>
                                                </li>
                                            <?php endfor; ?>

                                            <?php if ($apPg < $apTotalPages): ?>
                                                <li class="page-item">
                                                    <a class="page-link"
                                                        href="?id=<?php echo (int)$patient_id; ?>&appointments-tab=1&apg=<?php echo ($apPg + 1); ?>">
                                                        Next »
                                                    </a>
                                                </li>
                                            <?php else: ?>
                                                <li class="page-item disabled"><span class="page-link">Next »</span></li>
                                            <?php endif; ?>
                                        </ul>
                                    </nav>
                                <?php endif; ?>

                            <?php else: ?>
                                <p>No appointments found for this patient.</p>
                            <?php endif; ?>
                        </div>
                    </div>

                    <!-- (7) Reports Tab (SINGLE COPY) -->
                    <div class="tab-pane fade <?php if ($activeTab === 'reportsTab') echo 'show active'; ?>"
                        id="reportsTab" role="tabpanel" aria-labelledby="reports-tab">
                        <?php include 'reports_section.php'; ?>
                    </div>

                    <!-- (6) Diagnoses Tab -->
                    <div class="tab-pane fade <?php if ($activeTab === 'diagnosesTab') echo 'show active'; ?>"
                        id="diagnosesTab" role="tabpanel" aria-labelledby="diagnoses-tab">
                        <?php include 'diagnosis_section.php'; ?>
                    </div>

                </div><!-- end tab-content -->
            </div><!-- end container-fluid -->
        </div><!-- end page-content-wrapper -->
    </div><!-- end wrapper -->

    <!-- ===================== MODALS ===================== -->
    <!-- Add Appointment Modal -->
    <div class="modal fade" id="addAppointmentModal" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog">
            <form class="modal-content" method="POST">
                <input type="hidden" name="appt_action" value="addAppointment">
                <input type="hidden" name="patient_id" value="<?php echo (int)$patient_id; ?>">

                <div class="modal-header">
                    <h5 class="modal-title">Add Appointment</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <!-- Appointment Date/Time -->
                    <div class="mb-3">
                        <label class="form-label">Appointment Date</label>
                        <input type="date" class="form-control"
                            name="appointment_date"
                            value="<?php echo date('Y-m-d'); ?>" required>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Appointment Time</label>
                        <input type="time" class="form-control"
                            name="appointment_time"
                            value="09:00" required>
                    </div>

                    <!-- Purpose, Status, Remarks -->
                    <div class="mb-3">
                        <label class="form-label">Purpose</label>
                        <input type="text" class="form-control"
                            name="purpose" required>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Status</label>
                        <select class="form-select" name="status">
                            <option value="Scheduled">Scheduled</option>
                            <option value="Completed">Completed</option>
                            <option value="Cancelled">Cancelled</option>
                        </select>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Remarks</label>
                        <textarea class="form-control" name="remarks"></textarea>
                    </div>

                    <!-- Options: Auto Follow-Ups & Auto Diagnosis -->
                    <div class="form-check mb-3">
                        <input class="form-check-input" type="checkbox"
                            name="auto_schedule_followups"
                            id="auto_schedule_followups">
                        <label class="form-check-label" for="auto_schedule_followups">
                            Auto Schedule Follow-Ups (1wk, 3d, 1d prior)
                        </label>
                    </div>
                    <div class="form-check mb-3">
                        <input class="form-check-input" type="checkbox"
                            name="auto_create_diagnosis"
                            id="auto_create_diagnosis">
                        <label class="form-check-label" for="auto_create_diagnosis">
                            Also Create Diagnosis?
                        </label>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary btn-action"
                        data-bs-dismiss="modal">Close</button>
                    <button class="btn btn-primary btn-action">Add Appointment</button>
                </div>
            </form>
        </div>
    </div>

    <!-- Edit Appointment Modal -->
    <div class="modal fade" id="editAppointmentModal" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog">
            <form class="modal-content" method="POST">
                <input type="hidden" name="appt_action" value="editAppointment">
                <input type="hidden" name="appointment_id" id="appointment_id_edit">
                <input type="hidden" name="patient_id" value="<?php echo (int)$patient_id; ?>">

                <div class="modal-header">
                    <h5 class="modal-title">Edit Appointment</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <!-- Appointment Date/Time -->
                    <div class="mb-3">
                        <label class="form-label">Appointment Date</label>
                        <input type="date" class="form-control"
                            name="appointment_date"
                            id="appointment_date_edit" required>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Appointment Time</label>
                        <input type="time" class="form-control"
                            name="appointment_time"
                            id="appointment_time_edit" required>
                    </div>

                    <!-- Purpose, Status, Remarks -->
                    <div class="mb-3">
                        <label class="form-label">Purpose</label>
                        <input type="text" class="form-control"
                            name="purpose" id="purpose_edit" required>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Status</label>
                        <select class="form-select" name="status" id="status_edit" required>
                            <option value="Scheduled">Scheduled</option>
                            <option value="Completed">Completed</option>
                            <option value="Cancelled">Cancelled</option>
                        </select>
                        <small class="text-muted">Remarks are recommended if status is Cancelled/Completed.</small>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Remarks</label>
                        <textarea class="form-control"
                            name="remarks"
                            id="remarks_edit_appt"></textarea>
                    </div>

                    <!-- Auto Update Follow-Ups -->
                    <div class="form-check mb-3">
                        <input class="form-check-input" type="checkbox"
                            name="auto_update_followups"
                            id="auto_update_followups">
                        <label class="form-check-label" for="auto_update_followups">
                            Auto-Update Follow-Ups (Remove &amp; Recreate)
                        </label>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary btn-action"
                        data-bs-dismiss="modal">Close</button>
                    <button class="btn btn-warning btn-action">Update Appointment</button>
                </div>
            </form>
        </div>
    </div>

    <!-- View Follow-Ups Modal (shows a table of follow-ups for an appointment) -->
    <div class="modal fade" id="viewFollowUpsModal" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog modal-lg">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">Follow-Ups for This Appointment</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <div id="followUpsContainer">Loading...</div>
                </div>
                <div class="modal-footer">
                    <button class="btn btn-secondary btn-action" data-bs-dismiss="modal">Close</button>
                </div>
            </div>
        </div>
    </div>

    <!-- ===================== JAVASCRIPT (Bootstrap + custom) ===================== -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        /**
         * addDiagnosis(patientID, appointmentID):
         *  Quick-add a minimal Diagnosis for the given appointment/patient via AJAX.
         */
        function addDiagnosis(patientID, appointmentID) {
            const url = "<?php echo $baseURL; ?>actions/diagnosis/quick_add_diagnosis.php";
            const payload = {
                patient_id: patientID,
                appointment_id: appointmentID
            };
            fetch(url, {
                    method: "POST",
                    headers: {
                        "Content-Type": "application/json"
                    },
                    body: JSON.stringify(payload)
                })
                .then(response => response.json())
                .then(resp => {
                    if (!resp.success) {
                        alert("Error: " + resp.message);
                        return;
                    }
                    // If successful, replace the "Add Diagnosis" button with "View Diagnosis"
                    const diagContainer = document.getElementById("diagBtn-" + appointmentID);
                    if (diagContainer) {
                        diagContainer.innerHTML = `
                <a class="btn btn-info btn-sm btn-action"
                    href="patientProfile.php?id=<?php echo (int)$patient_id; ?>&diagnoses-tab=1&appt_id=${appointmentID}"
                    title="View Diagnosis">
                    <i class="fas fa-stethoscope"></i>
                </a>`;
                    }
                })
                .catch(err => {
                    console.error("addDiagnosis error:", err);
                    alert("Failed to add diagnosis. Check console.");
                });
        }

        /**
         * viewFollowUps(appointmentID):
         *  Fetches follow-ups for the given appointment via AJAX,
         *  then displays them in the #viewFollowUpsModal.
         */
        function viewFollowUps(appointmentID) {
            const url = "<?php echo $baseURL; ?>actions/followups/get_followups_by_appointment.php?appointment_id=" + appointmentID;
            const container = document.getElementById("followUpsContainer");
            container.innerHTML = "Loading...";

            fetch(url)
                .then(response => response.json())
                .then(data => {
                    if (!Array.isArray(data) || data.length < 1) {
                        container.innerHTML = "<p>No follow-ups found for this appointment.</p>";
                    } else {
                        let html = `<table class="table table-bordered align-middle">
                            <thead>
                                <tr>
                                    <th>ID</th>
                                    <th>Date/Time</th>
                                    <th>Category</th>
                                    <th>Type</th>
                                    <th>Status</th>
                                    <th>Remarks</th>
                                </tr>
                            </thead>
                            <tbody>`;
                        data.forEach(fu => {
                            let dtStr = fu.FollowUpDate ? new Date(fu.FollowUpDate).toLocaleString() : "-";
                            let cat = fu.category_name || "Manual";
                            html += `<tr>
                    <td>${fu.FollowUpID}</td>
                    <td>${dtStr}</td>
                    <td>${cat}</td>
                    <td>${fu.FollowUpType || ""}</td>
                    <td>${fu.FollowUpStatus || ""}</td>
                    <td style="white-space:pre-wrap;">${fu.Remarks || ""}</td>
                </tr>`;
                        });
                        html += "</tbody></table>";
                        container.innerHTML = html;
                    }
                    // Show the modal
                    let modal = new bootstrap.Modal(document.getElementById("viewFollowUpsModal"));
                    modal.show();
                })
                .catch(err => {
                    console.error("viewFollowUps error:", err);
                    container.innerHTML = "<p class='text-danger'>Error loading follow-ups. Check console.</p>";
                    let modal = new bootstrap.Modal(document.getElementById("viewFollowUpsModal"));
                    modal.show();
                });
        }

        /**
         * On DOMContentLoaded:
         *  - Initialize the "Edit Appointment" modal by populating fields from data-attributes.
         *  - Auto-dismiss flash messages after a delay.
         */
        document.addEventListener("DOMContentLoaded", function() {
            const editApptModalEl = document.getElementById("editAppointmentModal");
            if (editApptModalEl) {
                editApptModalEl.addEventListener("show.bs.modal", function(evt) {
                    const btn = evt.relatedTarget;
                    if (!btn) return;
                    // Parse the JSON object in data-appointment
                    const apptData = JSON.parse(btn.getAttribute("data-appointment") || "{}");
                    document.getElementById("appointment_id_edit").value = apptData.AppointmentID || "";
                    document.getElementById("appointment_date_edit").value = apptData.AppointmentDate || "";
                    document.getElementById("appointment_time_edit").value = apptData.AppointmentTime || "09:00";
                    document.getElementById("purpose_edit").value = apptData.Purpose || "";
                    document.getElementById("status_edit").value = apptData.Status || "Scheduled";
                    document.getElementById("remarks_edit_appt").value = apptData.Remarks || "";
                });
            }

            // Auto-dismiss alerts after 5s
            setTimeout(function() {
                let alerts = document.querySelectorAll('.alert');
                alerts.forEach(function(alert) {
                    alert.classList.remove('show');
                });
            }, 5000);
        });
    </script>

</body>

</html>