<?php
// pages/patient/reports_logic.php
/**
 * Handles add/edit/delete of reports. 
 * Key fix: ensure `patient_id` is included in forms so we can do `WHERE ReportID=? AND PatientID=?`.
 */

include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

header("Content-Type: application/json");

// Check session
if (!isset($_SESSION['user_id'])) {
    echo json_encode(['success' => false, 'message' => 'No valid session.']);
    exit;
}
$currentUserID = (int)$_SESSION['user_id'];
$userRole      = $_SESSION['role'] ?? 'staff';

// We expect a normal form submission => let's handle it. 
// But from your code snippet, you do `method="POST"` + `action="reports_logic.php"` => then redirect back
// Actually, we see you might do: <form method="POST" ...> WITHOUT ajax. We'll finalize that approach:

$reportAction = $_POST['report_action'] ?? '';
if (!$reportAction) {
    // no action => no output
    exit;
}

// Common function for safe redirect
function redirectToReports($pID)
{
    header("Location: ../../pages/patient/patientProfile.php?id=$pID&reports-tab=1");
    exit;
}

// (A) Add Report
if ($reportAction === 'addReport') {
    // staff cannot add?
    if ($userRole === 'staff') {
        $_SESSION['error'] = "Staff cannot add new reports.";
        redirectToReports($_POST['patient_id'] ?? 0);
    }
    $patientID = (int)($_POST['patient_id'] ?? 0);
    $appointmentID = !empty($_POST['appointment_id']) ? (int)$_POST['appointment_id'] : null;
    $diagnosisID = !empty($_POST['diagnosis_id']) ? (int)$_POST['diagnosis_id'] : null;
    $reportType = trim($_POST['report_type'] ?? 'Other');
    $reportDate = trim($_POST['report_date'] ?? date('Y-m-d'));
    $remarks = trim($_POST['remarks'] ?? '');

    // handle file upload
    $reportPath = null;
    if (!empty($_FILES['report_file']) && $_FILES['report_file']['error'] === UPLOAD_ERR_OK) {
        // fetch patient name for folder
        $pSt = $conn->prepare("SELECT first_name,last_name FROM patients WHERE id=? LIMIT 1");
        $pSt->bind_param('i', $patientID);
        $pSt->execute();
        $pRes = $pSt->get_result();
        if (!$pRes || $pRes->num_rows < 1) {
            $_SESSION['error'] = "Patient not found for file upload.";
            redirectToReports($patientID);
        }
        $pRow = $pRes->fetch_assoc();
        $pSt->close();
        $safeName = preg_replace('/[^A-Za-z0-9_\-]/', '_', $pRow['first_name'] . ' ' . $pRow['last_name']);
        $uplDir = ROOT_PATH . "uploads/reports/$safeName";
        if (!is_dir($uplDir)) mkdir($uplDir, 0777, true);
        $tmpName = $_FILES['report_file']['tmp_name'];
        $orig = $_FILES['report_file']['name'];
        $orig = preg_replace('/[^A-Za-z0-9_\-\.]/', '_', $orig);
        $dest = $uplDir . '/' . date('YmdHis') . '_' . $orig;
        if (!move_uploaded_file($tmpName, $dest)) {
            $_SESSION['error'] = "Could not upload file.";
            redirectToReports($patientID);
        }
        // store relative path => e.g. "reports/John_Doe/filename"
        $reportPath = "reports/$safeName/" . basename($dest);
    }

    // insert
    $sql = "
    INSERT INTO reports(
      PatientID, AppointmentID, DiagnosisID,
      ReportType, ReportDate, ReportPath,
      remarks, CreatedBy, UpdatedBy,
      CreatedAt, UpdatedAt
    ) VALUES (?,?,?,?,?,?,?,?,?,NOW(),NOW())
  ";
    $st = $conn->prepare($sql);
    if (!$st) {
        $_SESSION['error'] = "Prepare error: " . $conn->error;
        redirectToReports($patientID);
    }
    $st->bind_param(
        'iiissssii',
        $patientID,
        $appointmentID,
        $diagnosisID,
        $reportType,
        $reportDate,
        $reportPath,
        $remarks,
        $currentUserID,
        $currentUserID
    );
    $st->execute();
    $st->close();
    $_SESSION['success'] = "Report added successfully.";
    redirectToReports($patientID);
}

// (B) Edit Report
elseif ($reportAction === 'editReport') {
    if ($userRole === 'staff') {
        $_SESSION['error'] = "Staff cannot edit reports.";
        redirectToReports($_POST['patient_id'] ?? 0);
    }
    $reportID = (int)($_POST['report_id'] ?? 0);
    $patientID = (int)($_POST['patient_id'] ?? 0);
    $apptID = !empty($_POST['appointment_id']) ? (int)$_POST['appointment_id'] : null;
    $diagID = !empty($_POST['diagnosis_id']) ? (int)$_POST['diagnosis_id'] : null;
    $rType = trim($_POST['report_type'] ?? 'Other');
    $rDate = trim($_POST['report_date'] ?? date('Y-m-d'));
    $remarks = trim($_POST['remarks'] ?? '');

    // fetch old row
    $chk = $conn->prepare("SELECT ReportPath FROM reports WHERE ReportID=? AND PatientID=? LIMIT 1");
    $chk->bind_param('ii', $reportID, $patientID);
    $chk->execute();
    $res = $chk->get_result();
    if (!$res || $res->num_rows < 1) {
        $_SESSION['error'] = "Report not found or not linked to patient $patientID.";
        redirectToReports($patientID);
    }
    $old = $res->fetch_assoc();
    $chk->close();
    $oldPath = $old['ReportPath'] ?? null;
    $newPath = $oldPath;

    // handle new file
    if (!empty($_FILES['report_file']) && $_FILES['report_file']['error'] === UPLOAD_ERR_OK) {
        // remove old file
        if ($oldPath) {
            $oldAbs = ROOT_PATH . 'uploads/' . $oldPath;
            if (file_exists($oldAbs)) unlink($oldAbs);
        }
        // get patient name => folder
        $pSt = $conn->prepare("SELECT first_name,last_name FROM patients WHERE id=? LIMIT 1");
        $pSt->bind_param('i', $patientID);
        $pSt->execute();
        $pRs = $pSt->get_result();
        if (!$pRs || $pRs->num_rows < 1) {
            $_SESSION['error'] = "Patient not found for file upload in edit.";
            redirectToReports($patientID);
        }
        $pp = $pRs->fetch_assoc();
        $pSt->close();
        $safeName = preg_replace('/[^A-Za-z0-9_\-]/', '_', $pp['first_name'] . ' ' . $pp['last_name']);
        $uplDir = ROOT_PATH . "uploads/reports/$safeName";
        if (!is_dir($uplDir)) mkdir($uplDir, 0777, true);
        $tmp = $_FILES['report_file']['tmp_name'];
        $og = $_FILES['report_file']['name'];
        $og = preg_replace('/[^A-Za-z0-9_\-\.]/', '_', $og);
        $dest = $uplDir . '/' . date('YmdHis') . '_' . $og;
        if (!move_uploaded_file($tmp, $dest)) {
            $_SESSION['error'] = "Could not upload new file for report.";
            redirectToReports($patientID);
        }
        $newPath = "reports/$safeName/" . basename($dest);
    }

    // update
    $upd = $conn->prepare("
    UPDATE reports
    SET AppointmentID=?,
        DiagnosisID=?,
        ReportType=?,
        ReportDate=?,
        ReportPath=?,
        remarks=?,
        UpdatedBy=?,
        UpdatedAt=NOW()
    WHERE ReportID=? AND PatientID=?
  ");
    if (!$upd) {
        $_SESSION['error'] = "Prepare error: " . $conn->error;
        redirectToReports($patientID);
    }
    $upd->bind_param(
        'iissssiii',
        $apptID,
        $diagID,
        $rType,
        $rDate,
        $newPath,
        $remarks,
        $currentUserID,
        $reportID,
        $patientID
    );
    $upd->execute();
    $upd->close();
    $_SESSION['success'] = "Report #$reportID updated.";
    redirectToReports($patientID);
}

// (C) Delete Report
elseif ($reportAction === 'deleteReport') {
    if ($userRole === 'staff') {
        $_SESSION['error'] = "Staff cannot delete reports.";
        redirectToReports($_POST['patient_id'] ?? 0);
    }
    $rID = (int)($_POST['report_id'] ?? 0);
    $pID = (int)($_POST['patient_id'] ?? 0);
    if ($rID < 1 || $pID < 1) {
        $_SESSION['error'] = "Invalid report or patient ID for deletion.";
        redirectToReports($pID);
    }
    // fetch old path
    $chk = $conn->prepare("SELECT ReportPath FROM reports WHERE ReportID=? AND PatientID=? LIMIT 1");
    $chk->bind_param('ii', $rID, $pID);
    $chk->execute();
    $res = $chk->get_result();
    if ($res && $res->num_rows > 0) {
        $row = $res->fetch_assoc();
        $oldP = $row['ReportPath'] ?? null;
        $chk->close();
        // delete row
        $del = $conn->prepare("DELETE FROM reports WHERE ReportID=? AND PatientID=?");
        $del->bind_param('ii', $rID, $pID);
        $del->execute();
        $del->close();
        // delete file
        if ($oldP) {
            $abs = ROOT_PATH . 'uploads/' . $oldP;
            if (file_exists($abs)) unlink($abs);
        }
        $_SESSION['success'] = "Report #$rID deleted.";
    } else {
        $_SESSION['error'] = "Report not found or doesn't belong to patient.";
    }
    redirectToReports($pID);
}
