<?php

/**
 * vitals_logic.php
 *
 * Handles CREATE/UPDATE/DELETE for patient vitals records.
 * Relies on:
 *   - $conn (mysqli)      : The active DB connection
 *   - $currentUserID (int): The logged-in user's ID
 *   - $userRole (string)  : 'staff' or 'admin'
 *   - $vitalsAction (string) : action from POST (e.g. 'addVitals')
 *   - $_SESSION for storing error/success messages
 *
 * POST fields we expect:
 *   - vitals_action, patient_id,
 *   - pressure, diabetic, height, weight, temp, pulse_per_minute, ...
 */

if (!isset($vitalsAction) || empty($vitalsAction)) {
    return; // No vitals action to perform
}

// ============== (1) ADD VITALS ==============
if ($vitalsAction === 'addVitals') {
    // Both admin and staff can add vitals, if you allow that. 
    // If only admin can add, then:
    // if ($userRole === 'staff') { ... restrict ... }
    // For now, let's assume staff or admin can add.

    $pID      = (int)($_POST['patient_id'] ?? 0);
    $pressure = $_POST['pressure'] ?? null;
    $diabetic = $_POST['diabetic'] ?? null;
    $height   = $_POST['height']   ?? null;
    $weight   = $_POST['weight']   ?? null;
    $temp     = $_POST['temp']     ?? null;
    $pulse    = $_POST['pulse_per_minute'] ?? null;

    // Insert
    $sqlV = "
      INSERT INTO patient_vitals (
        patient_id,
        pressure,
        diabetic,
        height,
        weight,
        temp,
        pulse_per_minute,
        CreatedBy,
        UpdatedBy,
        CreatedAt,
        UpdatedAt,
        dateOfRecord
      ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, NOW(), NOW(), NOW())
    ";
    $stV = $conn->prepare($sqlV);
    if (!$stV) {
        die("Prepare failed (addVitals): " . $conn->error);
    }
    $stV->bind_param(
        'issssssii',
        $pID,
        $pressure,
        $diabetic,
        $height,
        $weight,
        $temp,
        $pulse,
        $currentUserID,
        $currentUserID
    );
    $stV->execute();
    $stV->close();

    $_SESSION['success'] = "Vitals added for patient #$pID.";
    header("Location: patientProfile.php?id=$pID&vitals-tab=1");
    exit;
}

// ============== (2) EDIT VITALS ==============
elseif ($vitalsAction === 'editVitals') {
    // If only admin can edit, add a check here. By default, let's allow staff or admin.
    $vtID     = (int)($_POST['vitals_id']    ?? 0);
    $pID      = (int)($_POST['patient_id']   ?? 0);
    $pressure = $_POST['pressure']          ?? null;
    $diabetic = $_POST['diabetic']          ?? null;
    $height   = $_POST['height']            ?? null;
    $weight   = $_POST['weight']            ?? null;
    $temp     = $_POST['temp']              ?? null;
    $pulse    = $_POST['pulse_per_minute']  ?? null;

    // update
    $upV = "
      UPDATE patient_vitals
      SET pressure=?,
          diabetic=?,
          height=?,
          weight=?,
          temp=?,
          pulse_per_minute=?,
          UpdatedBy=?,
          UpdatedAt=NOW()
      WHERE id=? AND patient_id=?
    ";
    $stUp = $conn->prepare($upV);
    if (!$stUp) {
        die("Prepare failed (editVitals): " . $conn->error);
    }
    $stUp->bind_param(
        'ssssssiii',
        $pressure,
        $diabetic,
        $height,
        $weight,
        $temp,
        $pulse,
        $currentUserID,
        $vtID,
        $pID
    );
    $stUp->execute();
    $stUp->close();

    $_SESSION['success'] = "Vitals #$vtID updated.";
    header("Location: patientProfile.php?id=$pID&vitals-tab=1");
    exit;
}

// ============== (3) DELETE VITALS ==============
elseif ($vitalsAction === 'deleteVitals') {
    // If staff cannot delete, then check here:
    // if ($userRole === 'staff') { ... block ... }

    $vtID = (int)($_POST['vitals_id']  ?? 0);
    $pID  = (int)($_POST['patient_id'] ?? 0);

    if ($vtID > 0) {
        $delV = "DELETE FROM patient_vitals WHERE id=? AND patient_id=?";
        $stDV = $conn->prepare($delV);
        if (!$stDV) {
            die("Prepare failed (deleteVitals): " . $conn->error);
        }
        $stDV->bind_param('ii', $vtID, $pID);
        $stDV->execute();
        $stDV->close();

        $_SESSION['success'] = "Vitals record #$vtID deleted.";
    }
    header("Location: patientProfile.php?id=$pID&vitals-tab=1");
    exit;
}
