<?php

/**
 * pages/user/profile.php
 *
 * Displays the logged–in user's profile with a blue gradient banner.
 * Shows the profile picture, full name (with ID and job title below it), and personal information
 * in a two‑column layout. For staff, additional details are shown.
 * Also includes a change password section.
 */

include '../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// Prevent caching
header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");
header("Pragma: no-cache");

// Redirect if not logged in
if (!isset($_SESSION['user_id'])) {
    header("Location: {$baseURL}pages/login.php");
    exit;
}

$currentUserID = (int) $_SESSION['user_id'];
$currentRole   = $_SESSION['role'] ?? 'staff';

// Fetch user and associated staff details (all users, both staff and admin have an entry in staff_details)
$sql = "
  SELECT u.*,
         sd.identification_number,
         sd.job_title,
         sd.staff_no,
         sd.bank_name,
         sd.bank_acc_number,
         sd.profile_picture
  FROM users u
  LEFT JOIN staff_details sd ON sd.user_id = u.id
  WHERE u.id = ?
  LIMIT 1
";
$stmt = $conn->prepare($sql);
$stmt->bind_param('i', $currentUserID);
$stmt->execute();
$res = $stmt->get_result();
if ($res->num_rows < 1) {
    die("User not found in the database.");
}
$user = $res->fetch_assoc();
$stmt->close();

// Determine profile picture from staff_details (both for staff and admin)
$profilePic = !empty($user['profile_picture'])
    ? $baseURL . "uploads/userProfile/" . $user['profile_picture']
    : "https://via.placeholder.com/150?text=Profile";

$errorMsg = '';
$successMsg = '';

// Handle password change
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['change_password_action'])) {
    $currentPassword = $_POST['current_password'] ?? '';
    $newPassword     = $_POST['new_password'] ?? '';
    $confirmPassword = $_POST['confirm_password'] ?? '';

    if (!password_verify($currentPassword, $user['password'])) {
        $errorMsg = "Current password is incorrect.";
    } elseif (empty($newPassword) || $newPassword !== $confirmPassword) {
        $errorMsg = "New passwords do not match or are empty.";
    } else {
        $hashed = password_hash($newPassword, PASSWORD_DEFAULT);
        $upd = $conn->prepare("UPDATE users SET password=? WHERE id=?");
        $upd->bind_param('si', $hashed, $currentUserID);
        $upd->execute();
        $upd->close();
        $successMsg = "Password changed successfully.";
        header("Location: profile.php");
        exit;
    }
}
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <title>My Profile</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">
    <link href="<?php echo $baseURL; ?>assets/css/styles.css" rel="stylesheet">
    <style>
        /* Profile Banner */
        .profile-banner {
            background: linear-gradient(135deg, #007bff, #66b2ff);
            border-radius: 10px;
            padding: 3rem 1rem 2rem;
            color: #fff;
            text-align: center;
            position: relative;
            margin-bottom: 2rem;
            box-shadow: 0 4px 10px rgba(0, 0, 0, 0.15);
        }

        .profile-banner .avatar {
            width: 150px;
            height: 150px;
            border-radius: 50%;
            overflow: hidden;
            position: absolute;
            left: 50%;
            transform: translateX(-50%);
            top: 0;
            /* Remove blue border; instead use a subtle drop shadow */
            box-shadow: 0 5px 15px rgba(0, 0, 0, 0.2);
            background: #fff;
        }

        .profile-banner .avatar img {
            width: 100%;
            height: 100%;
            object-fit: cover;
        }

        .profile-banner h2 {
            margin-top: 100px;
            font-weight: 600;
            text-shadow: 1px 1px 2px rgba(0, 0, 0, 0.3);
        }

        /* Display ID and Job Title below full name */
        .profile-banner .sub-info {
            font-size: 1rem;
            margin-top: 4px;
            color: #e0e0e0;
        }

        /* Personal Information Card */
        .profile-info-card {
            border: 1px solid #ddd;
            border-radius: 10px;
            background: #fff;
            padding: 1.5rem;
            margin-top: 2rem;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        }

        .profile-info-row {
            display: flex;
            justify-content: space-between;
            padding: 8px 0;
            border-bottom: 1px solid #eee;
        }

        .profile-info-row:last-child {
            border-bottom: none;
        }

        .profile-info-row .label {
            font-weight: 600;
            color: #555;
            min-width: 150px;
        }

        .profile-info-row .value {
            font-weight: 500;
            color: #222;
            text-align: right;
        }

        /* Change Password Card */
        .change-pass-card {
            background: #f9f9f9;
            border-radius: 10px;
            padding: 1.5rem;
            box-shadow: 0 3px 6px rgba(0, 0, 0, 0.1);
        }

        .change-pass-card .card-header {
            background-color: #007bff;
            color: #fff;
            border-top-left-radius: 10px;
            border-top-right-radius: 10px;
        }

        .change-pass-card .btn-update {
            background: #007bff;
            color: #fff;
            font-weight: 600;
            border-radius: 6px;
            padding: 10px;
            width: 100%;
            border: none;
            transition: background-color 0.2s ease-in-out;
        }

        .change-pass-card .btn-update:hover {
            background: #0056b3;
        }
    </style>
</head>

<body>
    <div id="wrapper">
        <?php include ROOT_PATH . 'includes/navbar.php'; ?>
        <div id="page-content-wrapper">
            <?php include ROOT_PATH . 'includes/sidebar.php'; ?>
            <div class="container mt-4">
                <!-- Flash Messages -->
                <?php if (!empty($errorMsg)): ?>
                    <div class="alert alert-danger alert-dismissible fade show">
                        <i class="fas fa-exclamation-triangle me-1"></i>
                        <?php echo htmlspecialchars($errorMsg); ?>
                        <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                    </div>
                <?php endif; ?>
                <?php if (!empty($successMsg)): ?>
                    <div class="alert alert-success alert-dismissible fade show">
                        <i class="fas fa-check-circle me-1"></i>
                        <?php echo htmlspecialchars($successMsg); ?>
                        <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                    </div>
                <?php endif; ?>

                <!-- Profile Banner -->
                <div class="profile-banner position-relative">
                    <div class="avatar">
                        <img src="<?php echo $profilePic; ?>" alt="Profile Picture">
                    </div>
                    <h2><?php echo htmlspecialchars(ucfirst(strtolower($user['first_name'])) . ' ' . ucfirst(strtolower($user['last_name']))); ?></h2>
                    <!-- Directly display ID and then Job Title below -->
                    <p class="sub-info"><?php echo htmlspecialchars($user['job_title'] ?? ''); ?></p>
                </div>

                <!-- Personal Information Card -->
                <div class="card profile-info-card shadow">
                    <div class="card-body">
                        <h5 class="card-title mb-4">Personal Information</h5>
                        <div class="profile-info-row">
                            <div class="label">Username</div>
                            <div class="value"><?php echo htmlspecialchars($user['username']); ?></div>
                        </div>
                        <div class="profile-info-row">
                            <div class="label">Full Name</div>
                            <div class="value"><?php echo htmlspecialchars(ucfirst(strtolower($user['first_name'])) . ' ' . ucfirst(strtolower($user['last_name']))); ?></div>
                        </div>
                        <div class="profile-info-row">
                            <div class="label">Role</div>
                            <div class="value"><?php echo htmlspecialchars($user['role']); ?></div>
                        </div>
                        <?php if ($user['role'] === 'staff'): ?>
                            <hr>
                            <h6 class="mb-3 text-secondary">Staff Information</h6>
                            <div class="profile-info-row">
                                <div class="label">Identification #</div>
                                <div class="value"><?php echo htmlspecialchars($user['identification_number'] ?? 'N/A'); ?></div>
                            </div>
                            <div class="profile-info-row">
                                <div class="label">Job Title</div>
                                <div class="value"><?php echo htmlspecialchars($user['job_title'] ?? 'N/A'); ?></div>
                            </div>
                            <div class="profile-info-row">
                                <div class="label">Staff No</div>
                                <div class="value"><?php echo htmlspecialchars($user['staff_no'] ?? 'N/A'); ?></div>
                            </div>
                            <div class="profile-info-row">
                                <div class="label">Bank Name</div>
                                <div class="value"><?php echo htmlspecialchars($user['bank_name'] ?? 'N/A'); ?></div>
                            </div>
                            <div class="profile-info-row">
                                <div class="label">Bank Acc #</div>
                                <div class="value"><?php echo htmlspecialchars($user['bank_acc_number'] ?? 'N/A'); ?></div>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>

                <!-- Change Password Card -->
                <div class="card change-pass-card shadow mt-4">
                    <div class="card-header">Change Password</div>
                    <div class="card-body">
                        <form method="POST">
                            <input type="hidden" name="change_password_action" value="1">
                            <div class="row g-3">
                                <div class="col-md-4">
                                    <label class="form-label fw-bold">Current Password</label>
                                    <input type="password" class="form-control" name="current_password" required>
                                </div>
                                <div class="col-md-4">
                                    <label class="form-label fw-bold">New Password</label>
                                    <input type="password" class="form-control" name="new_password" required>
                                </div>
                                <div class="col-md-4">
                                    <label class="form-label fw-bold">Confirm New Password</label>
                                    <input type="password" class="form-control" name="confirm_password" required>
                                </div>
                                <div class="col-md-12 mt-3">
                                    <button type="submit" class="btn btn-update">
                                        <i class="fas fa-key me-1"></i> Update Password
                                    </button>
                                </div>
                            </div><!-- row -->
                        </form>
                    </div>
                </div><!-- end change password card -->
            </div><!-- container -->
        </div><!-- page-content-wrapper -->
    </div><!-- wrapper -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        // Auto-hide alert messages after 5 seconds
        document.addEventListener("DOMContentLoaded", function() {
            setTimeout(() => {
                document.querySelectorAll('.alert').forEach(el => el.classList.remove('show'));
            }, 5000);
        });
    </script>
</body>

</html>