<?php

/**
 * globalReports.php
 *
 * Lists & manages Reports for ALL patients.
 * Incorporates logic from patientProfile => "Reports" tab,
 * with file uploads, old-file removal, staff restrictions, etc.
 */

include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");
header("Pragma: no-cache");

$currentUserID = $_SESSION['user_id'] ?? null;
$userRole      = $_SESSION['role']    ?? 'staff';
if (!$currentUserID) {
    die("No valid session. Please log in.");
}

if (!isset($_SESSION['error']))   $_SESSION['error'] = '';
if (!isset($_SESSION['success'])) $_SESSION['success'] = '';
$errorMsg   = $_SESSION['error'];
$successMsg = $_SESSION['success'];
$_SESSION['error'] = '';
$_SESSION['success'] = '';

// (A) POST => add/edit/delete
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $action = $_POST['action'] ?? '';

    // Add
    if ($action === 'addReport') {
        if ($userRole === 'staff') {
            $_SESSION['error'] = "Staff cannot add new reports.";
            header("Location: globalReports.php");
            exit;
        }
        $pID     = (int)$_POST['patient_id'];
        $apptID  = !empty($_POST['appointment_id']) ? (int)$_POST['appointment_id'] : null;
        $rType   = $_POST['report_type'] ?? 'Other';
        $rDate   = $_POST['report_date'] ?? date('Y-m-d');
        $remarks = $_POST['remarks']     ?? '';

        // fetch patient name => create subfolder
        $stmtP = $conn->prepare("SELECT first_name, last_name FROM patients WHERE id=? LIMIT 1");
        $stmtP->bind_param('i', $pID);
        $stmtP->execute();
        $rP = $stmtP->get_result();
        if ($rP->num_rows < 1) {
            $_SESSION['error'] = "Invalid patient for adding report.";
            header("Location: globalReports.php");
            exit;
        }
        $pRow = $rP->fetch_assoc();
        $stmtP->close();
        $safeName = preg_replace('/[^A-Za-z0-9_\-]/', '_', $pRow['first_name'] . ' ' . $pRow['last_name']);
        $uplDir   = ROOT_PATH . "uploads/reports/" . $safeName;
        if (!is_dir($uplDir)) {
            mkdir($uplDir, 0777, true);
        }

        $reportPath = null;
        if (!empty($_FILES['report_file']) && $_FILES['report_file']['error'] === UPLOAD_ERR_OK) {
            $tmp = $_FILES['report_file']['tmp_name'];
            $on  = $_FILES['report_file']['name'];
            $on  = preg_replace('/[^A-Za-z0-9_\-\.]/', '_', $on);
            $dest = $uplDir . '/' . date('YmdHis') . '_' . $on;
            if (!move_uploaded_file($tmp, $dest)) {
                $_SESSION['error'] = "Error moving uploaded file for new report.";
                header("Location: globalReports.php");
                exit;
            }
            $reportPath = "reports/$safeName/" . basename($dest);
        }

        // insert
        $inQ = "
      INSERT INTO reports (
        PatientID,
        AppointmentID,
        ReportType,
        ReportDate,
        ReportPath,
        remarks,
        CreatedBy,
        UpdatedBy,
        CreatedAt,
        UpdatedAt
      ) VALUES(?,?,?,?,?,?,?, ?, NOW(), NOW())
    ";
        $stIn = $conn->prepare($inQ);
        $stIn->bind_param('iissssii', $pID, $apptID, $rType, $rDate, $reportPath, $remarks, $currentUserID, $currentUserID);
        $stIn->execute();
        $stIn->close();

        $_SESSION['success'] = "Report added.";
        header("Location: globalReports.php");
        exit;
    }

    // Edit
    elseif ($action === 'editReport') {
        if ($userRole === 'staff') {
            $_SESSION['error'] = "Staff cannot edit reports.";
            header("Location: globalReports.php");
            exit;
        }
        $repID   = (int)$_POST['report_id'];
        $pID     = (int)$_POST['patient_id'];
        $apptID  = !empty($_POST['appointment_id']) ? (int)$_POST['appointment_id'] : null;
        $rType   = $_POST['report_type'] ?? 'Other';
        $rDate   = $_POST['report_date'] ?? date('Y-m-d');
        $remarks = $_POST['remarks']     ?? '';

        // fetch old
        $oQ = "SELECT ReportPath, PatientID FROM reports WHERE ReportID=? LIMIT 1";
        $stO = $conn->prepare($oQ);
        $stO->bind_param('i', $repID);
        $stO->execute();
        $rO = $stO->get_result();
        if ($rO->num_rows < 1) {
            $_SESSION['error'] = "Report #$repID not found.";
            header("Location: globalReports.php");
            exit;
        }
        $oldRow = $rO->fetch_assoc();
        $stO->close();

        $oldPath   = $oldRow['ReportPath'];
        $oldP      = (int)$oldRow['PatientID'];
        $newPath   = $oldPath;

        // If the patient changes, we might remove the old file or set newPath to null
        $removeOldFile = false;
        if ($oldP !== $pID && $oldPath) {
            // The file belongs to a different patient's folder => we remove it
            $absOld = ROOT_PATH . 'uploads/' . $oldPath;
            if (file_exists($absOld)) {
                $removeOldFile = true;
            }
            $newPath = null; // then we rely on new upload or no file
        }

        // fetch new patient's name => new folder
        $stmtP = $conn->prepare("SELECT first_name, last_name FROM patients WHERE id=? LIMIT 1");
        $stmtP->bind_param('i', $pID);
        $stmtP->execute();
        $rP = $stmtP->get_result();
        if ($rP->num_rows < 1) {
            $_SESSION['error'] = "Invalid new patient chosen for editing report #$repID.";
            header("Location: globalReports.php");
            exit;
        }
        $pRow = $rP->fetch_assoc();
        $stmtP->close();
        $safeName = preg_replace('/[^A-Za-z0-9_\-]/', '_', $pRow['first_name'] . ' ' . $pRow['last_name']);
        $uplDir = ROOT_PATH . "uploads/reports/" . $safeName;
        if (!is_dir($uplDir)) {
            mkdir($uplDir, 0777, true);
        }

        // if new file
        if (!empty($_FILES['report_file']) && $_FILES['report_file']['error'] === UPLOAD_ERR_OK) {
            // remove old if it exists
            if ($oldPath) {
                $abs = ROOT_PATH . 'uploads/' . $oldPath;
                if (file_exists($abs)) unlink($abs);
            }
            // upload new
            $tmp = $_FILES['report_file']['tmp_name'];
            $on = $_FILES['report_file']['name'];
            $on = preg_replace('/[^A-Za-z0-9_\-\.]/', '_', $on);
            $dest = $uplDir . '/' . date('YmdHis') . '_' . $on;
            if (!move_uploaded_file($tmp, $dest)) {
                $_SESSION['error'] = "Error uploading new file for report #$repID.";
                header("Location: globalReports.php");
                exit;
            }
            $newPath = "reports/$safeName/" . basename($dest);
        } else {
            // If patient changed but no new file => $newPath remains null or old
            if ($oldP !== $pID) {
                $newPath = null;
            }
        }

        // remove old if needed
        if ($removeOldFile && $oldPath) {
            $abs = ROOT_PATH . 'uploads/' . $oldPath;
            if (file_exists($abs)) unlink($abs);
        }

        // update
        $upQ = "
      UPDATE reports
      SET PatientID=?,
          AppointmentID=?,
          ReportType=?,
          ReportDate=?,
          ReportPath=?,
          remarks=?,
          UpdatedBy=?,
          UpdatedAt=NOW()
      WHERE ReportID=?
    ";
        $stU = $conn->prepare($upQ);
        $stU->bind_param('iissssii', $pID, $apptID, $rType, $rDate, $newPath, $remarks, $currentUserID, $repID);
        $stU->execute();
        $stU->close();

        $_SESSION['success'] = "Report #$repID updated.";
        header("Location: globalReports.php");
        exit;
    }

    // Delete
    elseif ($action === 'deleteReport') {
        if ($userRole === 'staff') {
            $_SESSION['error'] = "Staff cannot delete reports.";
            header("Location: globalReports.php");
            exit;
        }
        $repID = (int)($_POST['report_id'] ?? 0);
        if ($repID > 0) {
            $oQ = "SELECT ReportPath FROM reports WHERE ReportID=? LIMIT 1";
            $stO = $conn->prepare($oQ);
            $stO->bind_param('i', $repID);
            $stO->execute();
            $rO = $stO->get_result();
            $oldP = null;
            if ($rO->num_rows > 0) {
                $oldP = $rO->fetch_assoc()['ReportPath'];
            }
            $stO->close();
            // delete from DB
            $delQ = "DELETE FROM reports WHERE ReportID=?";
            $stD = $conn->prepare($delQ);
            $stD->bind_param('i', $repID);
            $stD->execute();
            $stD->close();
            // remove file
            if ($oldP) {
                $abs = ROOT_PATH . 'uploads/' . $oldP;
                if (file_exists($abs)) unlink($abs);
            }
            $_SESSION['success'] = "Report #$repID deleted.";
        }
        header("Location: globalReports.php");
        exit;
    }
}

// (B) GET => list + filter
$searchName = $_GET['search_name'] ?? '';
$startDate  = $_GET['start_date']  ?? '';
$endDate    = $_GET['end_date']    ?? '';

$whereClauses = [];
if (
    preg_match('/^\d{4}-\d{2}-\d{2}$/', $startDate) &&
    preg_match('/^\d{4}-\d{2}-\d{2}$/', $endDate)
) {
    $whereClauses[] = "r.ReportDate BETWEEN '$startDate' AND '$endDate'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $startDate)) {
    $whereClauses[] = "r.ReportDate>='$startDate'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $endDate)) {
    $whereClauses[] = "r.ReportDate<='$endDate'";
}
if (!empty($searchName)) {
    $esc = $conn->real_escape_string($searchName);
    $whereClauses[] = "(p.first_name LIKE '%$esc%' OR p.last_name LIKE '%$esc%')";
}
$fullWhere = '';
if (!empty($whereClauses)) {
    $fullWhere = 'WHERE ' . implode(' AND ', $whereClauses);
}

// pagination
$perPage = 10;
$page = isset($_GET['pg']) ? (int)$_GET['pg'] : 1;
if ($page < 1) $page = 1;
$offset = ($page - 1) * $perPage;

// count
$cQ = "
  SELECT COUNT(r.ReportID) AS total
  FROM reports r
  LEFT JOIN patients p ON r.PatientID=p.id
  $fullWhere
";
$rC = $conn->query($cQ);
$total = (int)($rC->fetch_assoc()['total'] ?? 0);
$totalPages = ceil($total / $perPage);

// fetch
$sql = "
  SELECT
    r.*,
    p.first_name AS p_first,
    p.last_name  AS p_last,
    u1.username  AS created_by_name,
    u2.username  AS updated_by_name
  FROM reports r
  LEFT JOIN patients p ON r.PatientID=p.id
  LEFT JOIN users u1   ON r.CreatedBy=u1.id
  LEFT JOIN users u2   ON r.UpdatedBy=u2.id
  $fullWhere
  ORDER BY r.ReportDate DESC, r.ReportID DESC
  LIMIT $perPage OFFSET $offset
";
$res = $conn->query($sql);
$reports = [];
if ($res && $res->num_rows > 0) {
    while ($row = $res->fetch_assoc()) {
        $reports[] = $row;
    }
}
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <title>Global Reports</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">
    <link href="<?php echo $baseURL; ?>assets/css/styles.css" rel="stylesheet">
</head>

<body>
    <div id="wrapper">
        <?php include ROOT_PATH . 'includes/navbar.php'; ?>
        <div id="page-content-wrapper">
            <?php include ROOT_PATH . 'includes/sidebar.php'; ?>

            <div class="container-fluid mt-4">
                <?php if ($errorMsg): ?>
                    <div class="alert alert-danger">
                        <i class="fas fa-exclamation-triangle"></i>
                        <?php echo htmlspecialchars($errorMsg); ?>
                    </div>
                <?php endif; ?>
                <?php if ($successMsg): ?>
                    <div class="alert alert-success">
                        <i class="fas fa-check-circle"></i>
                        <?php echo htmlspecialchars($successMsg); ?>
                    </div>
                <?php endif; ?>

                <div class="card mb-3">
                    <div class="card-body bg-primary text-white text-center rounded">
                        <h4 class="card-title mb-1">All Reports</h4>
                        <p class="mb-0">Manage &amp; View Reports Across All Patients</p>
                    </div>
                </div>

                <form class="row g-3 mb-3">
                    <div class="col-md-3">
                        <label class="form-label">Start Date</label>
                        <input type="date" class="form-control" name="start_date" value="<?php echo htmlspecialchars($startDate); ?>">
                    </div>
                    <div class="col-md-3">
                        <label class="form-label">End Date</label>
                        <input type="date" class="form-control" name="end_date" value="<?php echo htmlspecialchars($endDate); ?>">
                    </div>
                    <div class="col-md-3">
                        <label class="form-label">Patient Name</label>
                        <input type="text" class="form-control" name="search_name" value="<?php echo htmlspecialchars($searchName); ?>">
                    </div>
                    <div class="col-md-3 d-flex align-items-end">
                        <button class="btn btn-primary w-100"><i class="fas fa-filter"></i> Filter</button>
                    </div>
                </form>

                <?php if ($userRole === 'admin'): ?>
                    <div class="text-end mb-3">
                        <button class="btn btn-success" data-bs-toggle="modal" data-bs-target="#addReportModal">
                            <i class="fas fa-plus"></i> Add Report
                        </button>
                    </div>
                <?php endif; ?>

                <div class="table-responsive">
                    <table class="table table-bordered text-center align-middle">
                        <thead class="table-light">
                            <tr>
                                <th>ID</th>
                                <th>Patient</th>
                                <th>Report Type</th>
                                <th>Date</th>
                                <th>File</th>
                                <th>Remarks</th>
                                <th>Created/Updated By</th>
                                <th>Actions</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (!empty($reports)): ?>
                                <?php foreach ($reports as $rp):
                                    $rID = (int)$rp['ReportID'];
                                    $pName = trim($rp['p_first'] . ' ' . $rp['p_last']);
                                    $repData = [
                                        'ReportID' => $rID,
                                        'PatientID' => $rp['PatientID'],
                                        'AppointmentID' => $rp['AppointmentID'],
                                        'ReportType' => $rp['ReportType'],
                                        'ReportDate' => $rp['ReportDate'],
                                        'ReportPath' => $rp['ReportPath'],
                                        'remarks' => $rp['remarks']
                                    ];
                                ?>
                                    <tr>
                                        <td><?php echo $rID; ?></td>
                                        <td><?php echo htmlspecialchars($pName) . " (ID:{$rp['PatientID']})"; ?></td>
                                        <td><?php echo htmlspecialchars($rp['ReportType'] ?? 'Other'); ?></td>
                                        <td><?php echo htmlspecialchars($rp['ReportDate']); ?></td>
                                        <td>
                                            <?php if (!empty($rp['ReportPath'])): ?>
                                                <a href="<?php echo $baseURL . 'uploads/' . $rp['ReportPath']; ?>"
                                                    target="_blank"
                                                    class="btn btn-sm btn-info">
                                                    <i class="fas fa-file"></i> View
                                                </a>
                                            <?php else: ?>
                                                <span class="text-muted">No file</span>
                                            <?php endif; ?>
                                        </td>
                                        <td style="white-space:pre-wrap;"><?php echo nl2br(htmlspecialchars($rp['remarks'] ?? '')); ?></td>
                                        <td class="text-start" style="width:150px;">
                                            <small>Created: <?php echo htmlspecialchars($rp['created_by_name'] ?? ''); ?></small><br>
                                            <small>Updated: <?php echo htmlspecialchars($rp['updated_by_name'] ?? ''); ?></small>
                                        </td>
                                        <td>
                                            <?php if ($userRole === 'admin'): ?>
                                                <button class="btn btn-sm btn-warning"
                                                    data-bs-toggle="modal"
                                                    data-bs-target="#editReportModal"
                                                    data-report='<?php echo json_encode($repData); ?>'>
                                                    <i class="fas fa-edit"></i>
                                                </button>
                                                <form method="POST" class="d-inline-block" onsubmit="return confirm('Delete this report?');">
                                                    <input type="hidden" name="action" value="deleteReport">
                                                    <input type="hidden" name="report_id" value="<?php echo $rID; ?>">
                                                    <button class="btn btn-sm btn-danger"><i class="fas fa-trash"></i></button>
                                                </form>
                                            <?php else: ?>
                                                <em class="text-muted">Read-Only</em>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="8">No reports found.</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <?php if ($totalPages > 1): ?>
                    <nav class="mt-3">
                        <ul class="pagination justify-content-center">
                            <!-- prev -->
                            <?php if ($page > 1): ?>
                                <li class="page-item">
                                    <a class="page-link"
                                        href="?pg=<?php echo ($page - 1); ?>&start_date=<?php echo urlencode($startDate); ?>&end_date=<?php echo urlencode($endDate); ?>&search_name=<?php echo urlencode($searchName); ?>">
                                        &laquo; Prev
                                    </a>
                                </li>
                            <?php else: ?>
                                <li class="page-item disabled"><span class="page-link">&laquo; Prev</span></li>
                            <?php endif; ?>

                            <?php for ($i = 1; $i <= $totalPages; $i++): ?>
                                <li class="page-item <?php if ($i == $page) echo 'active'; ?>">
                                    <a class="page-link"
                                        href="?pg=<?php echo $i; ?>&start_date=<?php echo urlencode($startDate); ?>&end_date=<?php echo urlencode($endDate); ?>&search_name=<?php echo urlencode($searchName); ?>">
                                        <?php echo $i; ?>
                                    </a>
                                </li>
                            <?php endfor; ?>

                            <!-- next -->
                            <?php if ($page < $totalPages): ?>
                                <li class="page-item">
                                    <a class="page-link"
                                        href="?pg=<?php echo ($page + 1); ?>&start_date=<?php echo urlencode($startDate); ?>&end_date=<?php echo urlencode($endDate); ?>&search_name=<?php echo urlencode($searchName); ?>">
                                        Next &raquo;
                                    </a>
                                </li>
                            <?php else: ?>
                                <li class="page-item disabled"><span class="page-link">Next &raquo;</span></li>
                            <?php endif; ?>
                        </ul>
                    </nav>
                <?php endif; ?>

            </div>
        </div>
    </div>

    <!-- ADD Report Modal -->
    <div class="modal fade" id="addReportModal" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog">
            <form class="modal-content" method="POST" enctype="multipart/form-data">
                <input type="hidden" name="action" value="addReport">
                <div class="modal-header">
                    <h5 class="modal-title">Add Report</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <div class="mb-3">
                        <label class="form-label">Patient ID</label>
                        <input type="number" class="form-control" name="patient_id" required>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Appointment ID (optional)</label>
                        <input type="number" class="form-control" name="appointment_id">
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Report Type</label>
                        <select class="form-select" name="report_type">
                            <option value="Lab Test">Lab Test</option>
                            <option value="Imaging">Imaging</option>
                            <option value="Prescription">Prescription</option>
                            <option value="Other">Other</option>
                        </select>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Report Date</label>
                        <input type="date" class="form-control" name="report_date" value="<?php echo date('Y-m-d'); ?>">
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Upload File</label>
                        <input type="file" class="form-control" name="report_file" accept=".pdf,.jpg,.jpeg,.png,.doc,.docx,.xls,.xlsx">
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Remarks</label>
                        <textarea class="form-control" name="remarks"></textarea>
                    </div>
                </div>
                <div class="modal-footer">
                    <button class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    <button class="btn btn-primary">Add Report</button>
                </div>
            </form>
        </div>
    </div>

    <!-- EDIT Report Modal -->
    <div class="modal fade" id="editReportModal" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog">
            <form class="modal-content" method="POST" enctype="multipart/form-data">
                <input type="hidden" name="action" value="editReport">
                <input type="hidden" name="report_id" id="report_id_edit">
                <div class="modal-header">
                    <h5 class="modal-title">Edit Report</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <div class="mb-3">
                        <label class="form-label">Patient ID</label>
                        <input type="number" class="form-control" name="patient_id" id="patient_id_edit_report" required>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Appointment ID (optional)</label>
                        <input type="number" class="form-control" name="appointment_id" id="appointment_id_edit_report">
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Report Type</label>
                        <select class="form-select" name="report_type" id="report_type_edit">
                            <option value="Lab Test">Lab Test</option>
                            <option value="Imaging">Imaging</option>
                            <option value="Prescription">Prescription</option>
                            <option value="Other">Other</option>
                        </select>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Report Date</label>
                        <input type="date" class="form-control" name="report_date" id="report_date_edit">
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Upload New File (optional)</label>
                        <input type="file" class="form-control" name="report_file" id="report_file_edit" accept=".pdf,.jpg,.jpeg,.png,.doc,.docx,.xls,.xlsx">
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Remarks</label>
                        <textarea class="form-control" name="remarks" id="remarks_edit_report"></textarea>
                    </div>
                </div>
                <div class="modal-footer">
                    <button class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    <button class="btn btn-warning">Update Report</button>
                </div>
            </form>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        document.addEventListener("DOMContentLoaded", function() {
            const editReportEl = document.getElementById("editReportModal");
            if (editReportEl) {
                editReportEl.addEventListener("show.bs.modal", function(evt) {
                    const btn = evt.relatedTarget;
                    if (!btn) return;
                    const rd = JSON.parse(btn.getAttribute("data-report") || "{}");
                    document.getElementById("report_id_edit").value = rd.ReportID || "";
                    document.getElementById("patient_id_edit_report").value = rd.PatientID || "";
                    document.getElementById("appointment_id_edit_report").value = rd.AppointmentID || "";
                    document.getElementById("report_type_edit").value = rd.ReportType || "Other";
                    document.getElementById("report_date_edit").value = rd.ReportDate || "";
                    document.getElementById("remarks_edit_report").value = rd.remarks || "";
                });
            }
        });
    </script>
</body>

</html>