<?php

/**
 * pages/admin/userList.php
 *
 * Displays a list of users for Admin.
 * Every user (both staff and admin) is expected to have extra details stored
 * in the staff_details table (including identification number, job title,
 * staff no, bank name, bank account number, and profile picture).
 * The "View Details" (eye icon) button opens a modal that displays these details
 * in a professional two-column layout.
 */

include '../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// Prevent caching
header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");
header("Pragma: no-cache");

// Only admin can access this page
if ($_SESSION['role'] !== 'admin') {
    echo "<script>alert('Access denied. Admins only.'); window.location.href = '" . $baseURL . "pages/dashboard.php';</script>";
    exit;
}

// ------ 1. Handle Search/Filter Parameters ------
$search_username = isset($_GET['search_username']) ? trim($_GET['search_username']) : '';

// ------ 2. Pagination ------
$records_per_page = 10;
$current_pg = isset($_GET['pg']) ? (int)$_GET['pg'] : 1;
if ($current_pg < 1) {
    $current_pg = 1;
}
$offset = ($current_pg - 1) * $records_per_page;

// ------ 3. Count Total Users ------
if ($search_username !== '') {
    $count_sql = "SELECT COUNT(u.id) AS total
                  FROM users u
                  LEFT JOIN staff_details sd ON sd.user_id = u.id
                  WHERE u.username LIKE ?";
    $stmt = $conn->prepare($count_sql);
    $like_search = '%' . $search_username . '%';
    $stmt->bind_param('s', $like_search);
} else {
    $count_sql = "SELECT COUNT(u.id) AS total
                  FROM users u
                  LEFT JOIN staff_details sd ON sd.user_id = u.id";
    $stmt = $conn->prepare($count_sql);
}
$stmt->execute();
$count_result = $stmt->get_result();
$total_users = $count_result->fetch_assoc()['total'] ?? 0;
$total_pages = ceil($total_users / $records_per_page);
$stmt->close();

// ------ 4. Fetch Users with Pagination ------
if ($search_username !== '') {
    $sql = "SELECT u.*,
                   sd.identification_number,
                   sd.job_title,
                   sd.staff_no,
                   sd.bank_name,
                   sd.bank_acc_number,
                   sd.profile_picture
            FROM users u
            LEFT JOIN staff_details sd ON sd.user_id = u.id
            WHERE u.username LIKE ?
            ORDER BY u.id DESC
            LIMIT ? OFFSET ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param('sii', $like_search, $records_per_page, $offset);
} else {
    $sql = "SELECT u.*,
                   sd.identification_number,
                   sd.job_title,
                   sd.staff_no,
                   sd.bank_name,
                   sd.bank_acc_number,
                   sd.profile_picture
            FROM users u
            LEFT JOIN staff_details sd ON sd.user_id = u.id
            ORDER BY u.id DESC
            LIMIT ? OFFSET ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param('ii', $records_per_page, $offset);
}
$stmt->execute();
$result = $stmt->get_result();
$stmt->close();
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <title>User Management | Admin</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">
    <link href="<?php echo $baseURL; ?>assets/css/styles.css" rel="stylesheet">
    <style>
        /* Modal Content Styling */
        .modal-content {
            border-radius: 8px;
            border: none;
            box-shadow: 0 4px 15px rgba(0, 0, 0, 0.15);
            background-color: #f9f9f9;
        }

        /* Profile Image Container with Soft Blue Gradient */
        .profile-img-container {
            width: 120px;
            height: 120px;
            border-radius: 50%;
            background: linear-gradient(135deg, #e0f2ff, #b3daff);
            display: flex;
            align-items: center;
            justify-content: center;
            margin: 0 auto 10px;
            padding: 3px;
        }

        /* Profile Image Styling */
        .profile-img-container .profile-img {
            width: 110px;
            height: 110px;
            border-radius: 50%;
            object-fit: cover;
        }

        /* Header Info Styling */
        .modal-body h5 {
            margin-bottom: 4px;
            font-weight: 600;
            color: #333;
        }

        .modal-body p {
            margin-bottom: 8px;
            font-size: 14px;
            color: #555;
        }

        /* Two-column details layout */
        .staff-details-row {
            margin-bottom: 8px;
        }

        .staff-details-row .label {
            font-weight: 600;
            color: #444;
            min-width: 90px;
        }

        .staff-details-row .value {
            font-weight: 500;
            color: #222;
        }

        /* Close Button Styling */
        .modal-footer .btn-close-custom {
            background-color: #6c757d;
            color: #fff;
            border: none;
            border-radius: 6px;
            padding: 6px 12px;
            transition: background-color 0.2s ease-in-out;
        }

        .modal-footer .btn-close-custom:hover {
            background-color: #545b62;
        }
    </style>
</head>

<body>
    <div id="wrapper">
        <?php include ROOT_PATH . 'includes/navbar.php'; ?>
        <div id="page-content-wrapper">
            <?php include ROOT_PATH . 'includes/sidebar.php'; ?>
            <div class="container-fluid mt-4">
                <!-- Header Section -->
                <div class="card mb-4 shadow border-0">
                    <div class="card-body text-center bg-primary text-white rounded">
                        <h4 class="card-title mb-1">User Management</h4>
                        <p class="mb-0">Manage Users and Roles</p>
                    </div>
                </div>
                <!-- Search and Add User -->
                <div class="row g-3 mt-3">
                    <form method="GET" class="row g-3">
                        <input type="hidden" name="page" value="userList">
                        <div class="col-md-4">
                            <label for="search_username" class="form-label fw-bold">Search by Username</label>
                            <input type="text" class="form-control" name="search_username" id="search_username" placeholder="Enter username" value="<?php echo htmlspecialchars($search_username); ?>">
                        </div>
                        <div class="col-md-4 d-flex align-items-end">
                            <button type="submit" class="btn btn-primary w-100">
                                <i class="fas fa-search"></i> Search
                            </button>
                        </div>
                        <div class="col-md-4 d-flex align-items-end">
                            <button type="button" class="btn btn-success w-100" data-bs-toggle="modal" data-bs-target="#addUserModal">
                                <i class="fas fa-user-plus"></i> Add User
                            </button>
                        </div>
                    </form>
                </div>
                <!-- Users Table -->
                <div class="table-responsive mt-4">
                    <table class="table table-bordered text-center align-middle">
                        <thead class="table-light">
                            <tr>
                                <th>ID</th>
                                <th>Username</th>
                                <th>First Name</th>
                                <th>Last Name</th>
                                <th>Role</th>
                                <th style="width:200px;">Actions</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if ($result && $result->num_rows > 0): ?>
                                <?php while ($row = $result->fetch_assoc()):
                                    // Prepare extra staff details for the modal.
                                    // Every user (staff and admin) is assumed to have a staff_details record.
                                    $staffData = [
                                        'full_name' => ucfirst(strtolower($row['first_name'])) . ' ' . ucfirst(strtolower($row['last_name'])),
                                        'identification_number' => $row['identification_number'] ?? 'N/A',
                                        'job_title' => $row['job_title'] ?? 'N/A',
                                        'staff_no' => $row['staff_no'] ?? 'N/A',
                                        'bank_name' => $row['bank_name'] ?? 'N/A',
                                        'bank_acc_number' => $row['bank_acc_number'] ?? 'N/A',
                                        'profile_picture' => $row['profile_picture'] ?? ''
                                    ];
                                ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($row['id']); ?></td>
                                        <td><?php echo htmlspecialchars($row['username']); ?></td>
                                        <td><?php echo htmlspecialchars(ucfirst(strtolower($row['first_name']))); ?></td>
                                        <td><?php echo htmlspecialchars(ucfirst(strtolower($row['last_name']))); ?></td>
                                        <td><?php echo htmlspecialchars(ucfirst($row['role'])); ?></td>
                                        <td>
                                            <button class="btn btn-sm btn-info me-1 view-details-btn"
                                                data-user-id="<?php echo (int)$row['id']; ?>"
                                                data-staff='<?php echo json_encode($staffData, JSON_HEX_TAG | JSON_HEX_APOS | JSON_HEX_QUOT); ?>'
                                                title="View Details">
                                                <i class="fas fa-eye"></i>
                                            </button>
                                            <button class="btn btn-sm btn-primary edit-user-btn"
                                                data-user='<?php echo json_encode($row); ?>'
                                                title="Edit">
                                                <i class="fas fa-edit"></i> Edit
                                            </button>
                                        </td>
                                    </tr>
                                <?php endwhile; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="6">No users found.</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
                <!-- Pagination Controls -->
                <nav class="mt-4">
                    <ul class="pagination justify-content-center">
                        <?php if ($current_pg > 1): ?>
                            <li class="page-item">
                                <a class="page-link" href="?page=userList&pg=<?php echo $current_pg - 1; ?>&search_username=<?php echo urlencode($search_username); ?>">
                                    <i class="fas fa-chevron-left"></i>
                                </a>
                            </li>
                        <?php else: ?>
                            <li class="page-item disabled"><a class="page-link"><i class="fas fa-chevron-left"></i></a></li>
                        <?php endif; ?>
                        <?php for ($i = 1; $i <= $total_pages; $i++): ?>
                            <?php if ($i == $current_pg): ?>
                                <li class="page-item active"><a class="page-link"><?php echo $i; ?></a></li>
                            <?php else: ?>
                                <li class="page-item"><a class="page-link" href="?page=userList&pg=<?php echo $i; ?>&search_username=<?php echo urlencode($search_username); ?>"><?php echo $i; ?></a></li>
                            <?php endif; ?>
                        <?php endfor; ?>
                        <?php if ($current_pg < $total_pages): ?>
                            <li class="page-item">
                                <a class="page-link" href="?page=userList&pg=<?php echo $current_pg + 1; ?>&search_username=<?php echo urlencode($search_username); ?>">
                                    <i class="fas fa-chevron-right"></i>
                                </a>
                            </li>
                        <?php else: ?>
                            <li class="page-item disabled"><a class="page-link"><i class="fas fa-chevron-right"></i></a></li>
                        <?php endif; ?>
                    </ul>
                </nav>
            </div><!-- container-fluid -->
        </div><!-- page-content-wrapper -->
    </div><!-- wrapper -->

    <!-- ===================== MODALS ===================== -->

    <!-- (A) Add User Modal -->
    <div class="modal fade" id="addUserModal" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog modal-lg">
            <form id="addUserForm" class="modal-content" enctype="multipart/form-data" method="POST" action="<?php echo $baseURL; ?>actions/user_action.php?action=add">
                <div class="modal-header">
                    <h5 class="modal-title">Add New User</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <div id="addUserAlert"></div>
                    <div class="row g-3">
                        <div class="col-md-6">
                            <label for="add_first_name" class="form-label">First Name</label>
                            <input type="text" class="form-control" id="add_first_name" name="first_name" required>
                        </div>
                        <div class="col-md-6">
                            <label for="add_last_name" class="form-label">Last Name</label>
                            <input type="text" class="form-control" id="add_last_name" name="last_name" required>
                        </div>
                        <div class="col-md-6">
                            <label for="add_username" class="form-label">Username</label>
                            <input type="text" class="form-control" id="add_username" name="username" required>
                        </div>
                        <div class="col-md-6">
                            <label for="add_password" class="form-label">Password</label>
                            <input type="password" class="form-control" id="add_password" name="password" required>
                        </div>
                        <div class="col-md-6">
                            <label for="add_role" class="form-label">Role</label>
                            <select class="form-select" id="add_role" name="role" required>
                                <option value="">Select Role</option>
                                <option value="staff">Staff</option>
                                <option value="admin">Admin</option>
                            </select>
                        </div>
                    </div>
                    <hr>
                    <!-- Staff Details (always shown) -->
                    <div id="staffDetailsSection" class="pt-2">
                        <h6 class="mb-3">Staff Details</h6>
                        <div class="row g-3">
                            <div class="col-md-6">
                                <label for="add_identification" class="form-label">Identification Number</label>
                                <input type="text" class="form-control" id="add_identification" name="identification_number">
                            </div>
                            <div class="col-md-6">
                                <label for="add_job_title" class="form-label">Job Title</label>
                                <input type="text" class="form-control" id="add_job_title" name="job_title">
                            </div>
                            <div class="col-md-6">
                                <label for="add_staff_no" class="form-label">Staff No</label>
                                <input type="text" class="form-control" id="add_staff_no" name="staff_no">
                            </div>
                            <div class="col-md-6">
                                <label for="add_bank_name" class="form-label">Bank Name</label>
                                <input type="text" class="form-control" id="add_bank_name" name="bank_name">
                            </div>
                            <div class="col-md-6">
                                <label for="add_bank_acc" class="form-label">Bank Account Number</label>
                                <input type="text" class="form-control" id="add_bank_acc" name="bank_acc_number">
                            </div>
                            <div class="col-md-6">
                                <label for="add_profile_pic" class="form-label">Profile Picture</label>
                                <input type="file" class="form-control" id="add_profile_pic" name="profile_picture" accept="image/*">
                            </div>
                        </div>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                    <button type="submit" class="btn btn-success">Add User</button>
                </div>
            </form>
        </div>
    </div>

    <!-- (B) Edit User Modal -->
    <div class="modal fade" id="editUserModal" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog modal-lg">
            <form id="editUserForm" class="modal-content" enctype="multipart/form-data" method="POST" action="<?php echo $baseURL; ?>actions/user_action.php?action=edit">
                <div class="modal-header">
                    <h5 class="modal-title">Edit User</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <div id="editUserAlert"></div>
                    <input type="hidden" id="edit_user_id" name="id">
                    <div class="row g-3">
                        <div class="col-md-6">
                            <label for="edit_first_name" class="form-label">First Name</label>
                            <input type="text" class="form-control" id="edit_first_name" name="first_name" required>
                        </div>
                        <div class="col-md-6">
                            <label for="edit_last_name" class="form-label">Last Name</label>
                            <input type="text" class="form-control" id="edit_last_name" name="last_name" required>
                        </div>
                        <div class="col-md-6">
                            <label for="edit_username" class="form-label">Username</label>
                            <input type="text" class="form-control" id="edit_username" name="username" required>
                        </div>
                        <div class="col-md-6">
                            <label for="edit_password" class="form-label">Password</label>
                            <input type="password" class="form-control" id="edit_password" name="password" placeholder="Leave blank to keep current password">
                        </div>
                        <div class="col-md-6">
                            <label for="edit_role" class="form-label">Role</label>
                            <select class="form-select" id="edit_role" name="role" required>
                                <option value="">Select Role</option>
                                <option value="staff">Staff</option>
                                <option value="admin">Admin</option>
                            </select>
                        </div>
                    </div>
                    <hr>
                    <!-- Staff Details for editing (always shown) -->
                    <div id="editStaffDetailsSection">
                        <h6 class="mb-3">Staff Details</h6>
                        <div class="row g-3">
                            <div class="col-md-6">
                                <label for="edit_identification" class="form-label">Identification Number</label>
                                <input type="text" class="form-control" id="edit_identification" name="identification_number">
                            </div>
                            <div class="col-md-6">
                                <label for="edit_job_title" class="form-label">Job Title</label>
                                <input type="text" class="form-control" id="edit_job_title" name="job_title">
                            </div>
                            <div class="col-md-6">
                                <label for="edit_staff_no" class="form-label">Staff No</label>
                                <input type="text" class="form-control" id="edit_staff_no" name="staff_no">
                            </div>
                            <div class="col-md-6">
                                <label for="edit_bank_name" class="form-label">Bank Name</label>
                                <input type="text" class="form-control" id="edit_bank_name" name="bank_name">
                            </div>
                            <div class="col-md-6">
                                <label for="edit_bank_acc" class="form-label">Bank Account Number</label>
                                <input type="text" class="form-control" id="edit_bank_acc" name="bank_acc_number">
                            </div>
                            <div class="col-md-6">
                                <label for="edit_profile_pic" class="form-label">Profile Picture</label>
                                <input type="file" class="form-control" id="edit_profile_pic" name="profile_picture" accept="image/*">
                            </div>
                        </div>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                    <button type="submit" class="btn btn-primary">Update User</button>
                </div>
            </form>
        </div>
    </div>

    <!-- (C) View Staff Details Modal -->
    <div class="modal fade" id="staffDetailsModal" tabindex="-1" aria-labelledby="staffDetailsLabel" aria-hidden="true">
        <div class="modal-dialog modal-dialog-centered">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="staffDetailsLabel">Staff Details</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body text-center">
                    <!-- Profile Image Container -->
                    <div class="profile-img-container">
                        <img src="https://via.placeholder.com/110?text=No+Image" class="profile-img" alt="Profile Picture">
                    </div>
                    <!-- Full Name, ID and Job Title -->
                    <h5 id="staffFullName">Full Name</h5>
                    <p id="staffIDNumber">990804145981</p>
                    <p id="staffJobTitle">Software Developer</p>
                    <hr>
                    <!-- Two-column details layout for remaining fields -->
                    <div class="row staff-details-row">
                        <div class="col-6 text-end">
                            <span class="label">Staff No:</span>
                        </div>
                        <div class="col-6 text-start">
                            <span class="value" id="staffNo">AG002</span>
                        </div>
                    </div>
                    <div class="row staff-details-row">
                        <div class="col-6 text-end">
                            <span class="label">Bank Name:</span>
                        </div>
                        <div class="col-6 text-start">
                            <span class="value" id="staffBankName">Ambank</span>
                        </div>
                    </div>
                    <div class="row staff-details-row">
                        <div class="col-6 text-end">
                            <span class="label">Acc #:</span>
                        </div>
                        <div class="col-6 text-start">
                            <span class="value" id="staffBankAcc">1380000280</span>
                        </div>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-outline-secondary btn-close-custom" data-bs-dismiss="modal">Close</button>
                </div>
            </div>
        </div>
    </div>

    <!-- Bootstrap JS & jQuery -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script>
        const baseURL = "<?php echo $baseURL; ?>";

        // Populate the "View Details" modal with professional two-column layout.
        $(document).on('click', '.view-details-btn', function() {
            const staffData = $(this).data('staff'); // JSON object with extra staff details
            const pic = staffData.profile_picture ? baseURL + "uploads/userProfile/" + staffData.profile_picture : "https://via.placeholder.com/120?text=No+Image";
            $('#staffDetailsModal .profile-img').attr('src', pic);
            $('#staffFullName').text(staffData.full_name);
            $('#staffIDNumber').text(staffData.identification_number || 'N/A');
            $('#staffJobTitle').text(staffData.job_title || 'N/A');
            $('#staffNo').text(staffData.staff_no || 'N/A');
            $('#staffBankName').text(staffData.bank_name || 'N/A');
            $('#staffBankAcc').text(staffData.bank_acc_number || 'N/A');
            const modal = new bootstrap.Modal(document.getElementById("staffDetailsModal"));
            modal.show();
        });

        // Populate the Edit User modal when "Edit" button is clicked.
        $(document).on('click', '.edit-user-btn', function() {
            const userData = $(this).data('user');
            $('#edit_user_id').val(userData.id);
            $('#edit_first_name').val(userData.first_name);
            $('#edit_last_name').val(userData.last_name);
            $('#edit_username').val(userData.username);
            $('#edit_role').val(userData.role).trigger('change');
            // Pre-fill extra staff details (for both staff and admin)
            $('#edit_identification').val(userData.identification_number || '');
            $('#edit_job_title').val(userData.job_title || '');
            $('#edit_staff_no').val(userData.staff_no || '');
            $('#edit_bank_name').val(userData.bank_name || '');
            $('#edit_bank_acc').val(userData.bank_acc_number || '');
            const modal = new bootstrap.Modal(document.getElementById("editUserModal"));
            modal.show();
        });
    </script>
    <?php include ROOT_PATH . 'includes/footer.php'; ?>
</body>

</html>