<?php

/****************************************************************************
 *                       PATIENT PROFILE (ALL TABS)                         *
 *                         (BIG COMMENT SPACING)                            *
 ****************************************************************************/

date_default_timezone_set('Asia/Kuala_Lumpur');

// ---------------------------------------------------------------------------
// (1) REQUIRED FILES: Adjust these paths according to your folder structure.
// ---------------------------------------------------------------------------
include '../../common/url.php';     // Example: might define $baseURL or other constants
include ROOT_PATH . 'common/session.php'; // Manages $_SESSION checks
include ROOT_PATH . 'common/config.php';  // Your DB config or connection

/****************************************************************************
 * (A) USER + SESSION CHECK
 ****************************************************************************/
$currentUserID = $_SESSION['user_id'] ?? null;
$userRole      = $_SESSION['role']    ?? 'staff';
if (!$currentUserID) {
    die("No valid user session found. Please log in.");
}

// Prevent caching (optional security measure)
header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");
header("Pragma: no-cache");

/****************************************************************************
 * (B) FLASH MESSAGES + DETERMINE ACTIVE TAB
 ****************************************************************************/
if (!isset($_SESSION['error']))   $_SESSION['error']   = '';
if (!isset($_SESSION['success'])) $_SESSION['success'] = '';
$errorMsg   = $_SESSION['error'];
$successMsg = $_SESSION['success'];
$_SESSION['error']   = '';
$_SESSION['success'] = '';

// Identify which tab is active (default = 'overviewTab')
$activeTab = 'overviewTab';
if (isset($_GET['debts-tab'])) {
    $activeTab = 'debtsTab';
} elseif (isset($_GET['followups-tab'])) {
    $activeTab = 'followupsTab';
} elseif (isset($_GET['appointments-tab'])) {
    $activeTab = 'appointmentsTab';
} elseif (isset($_GET['diagnoses-tab'])) {
    $activeTab = 'diagnosesTab';
} elseif (isset($_GET['reports-tab'])) {
    $activeTab = 'reportsTab';
} elseif (isset($_GET['vitals-tab'])) {
    $activeTab = 'vitalsTab';
}

/****************************************************************************
 * (C) VALIDATE PATIENT ID
 ****************************************************************************/
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    echo "<div class='container mt-4'><h3>Invalid Patient ID.</h3></div>";
    exit;
}
$patient_id = (int)$_GET['id'];

/****************************************************************************
 * (D) HELPER FUNCTIONS (INSERT HISTORY)
 ****************************************************************************/
function insertAppointmentHistory(mysqli $conn, array $oldData, int $editedBy, string $actionType)
{
    $sql = "
      INSERT INTO appointments_history (
        AppointmentID,
        PatientID,
        FollowUpID,
        AppointmentDate,
        AppointmentTime,
        Purpose,
        Status,
        Remarks,
        EditedBy,
        EditedAt,
        ActionType
      ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, NOW(), ?)
    ";
    $stmt = $conn->prepare($sql);
    if (!$stmt) {
        error_log('insertAppointmentHistory error: ' . $conn->error);
        return;
    }
    $stmt->bind_param(
        'iiisssssis',
        $oldData['AppointmentID'],
        $oldData['PatientID'],
        $oldData['FollowUpID'],
        $oldData['AppointmentDate'],
        $oldData['AppointmentTime'],
        $oldData['Purpose'],
        $oldData['Status'],
        $oldData['Remarks'],
        $editedBy,
        $actionType
    );
    $stmt->execute();
    $stmt->close();
}

function insertFollowUpHistory(mysqli $conn, array $oldData, int $editedBy, string $actionType)
{
    $sql = "
      INSERT INTO follow_up_history (
        FollowUpID,
        PatientID,
        AppointmentID,
        FollowUpDate,
        StatusUpdate,
        FollowUpType,
        NextFollowUpDate,
        Remarks,
        EditedBy,
        EditedAt,
        ActionType,
        FollowUpStatus
      ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, NOW(), ?, ?)
    ";
    $stmt = $conn->prepare($sql);
    if (!$stmt) {
        error_log('insertFollowUpHistory error: ' . $conn->error);
        return;
    }
    $stmt->bind_param(
        'iiisssssiss',
        $oldData['FollowUpID'],
        $oldData['PatientID'],
        $oldData['AppointmentID'],
        $oldData['FollowUpDate'],
        $oldData['StatusUpdate'],
        $oldData['FollowUpType'],
        $oldData['NextFollowUpDate'],
        $oldData['Remarks'],
        $editedBy,
        $actionType,
        $oldData['FollowUpStatus']
    );
    $stmt->execute();
    $stmt->close();
}

/****************************************************************************
 * (E) POST-ACTIONS (CRUD for FollowUps, Appointments, Diagnoses, Reports,
 *     Vitals, etc.)
 ****************************************************************************/
// If there's a POST request, we will handle them in separate logic files.
if ($_SERVER['REQUEST_METHOD'] === 'POST') {

    // 1) FOLLOW-UPS LOGIC
    $followupAction = $_POST['followup_action'] ?? '';
    include 'followups_logic.php';  // (File to be provided in a separate response)

    // 2) APPOINTMENTS LOGIC
    $apptAction = $_POST['appt_action'] ?? '';
    include 'appointments_logic.php'; // (File to be provided in a separate response)

    // 3) DIAGNOSES LOGIC
    $diagAction = $_POST['diag_action'] ?? '';
    include 'diagnoses_logic.php';    // (File to be provided in a separate response)

    // 4) REPORTS LOGIC
    $reportAction = $_POST['report_action'] ?? '';
    include 'reports_logic.php';      // (File to be provided in a separate response)

    // 5) VITALS LOGIC
    $vitalsAction = $_POST['vitals_action'] ?? '';
    include 'vitals_logic.php';       // (File to be provided in a separate response)
}

/****************************************************************************
 * (F) FETCH DATA FOR OVERVIEW
 ****************************************************************************/
// 1) Fetch main patient record
$sqlP = 'SELECT * FROM patients WHERE id=? LIMIT 1';
$stP  = $conn->prepare($sqlP);
$stP->bind_param('i', $patient_id);
$stP->execute();
$resP = $stP->get_result();
if ($resP->num_rows < 1) {
    die('<div class="container mt-4"><h3>Patient not found in DB.</h3></div>');
}
$patient = $resP->fetch_assoc();
$stP->close();

// 2) Address
$sqlA = 'SELECT * FROM patient_address WHERE patient_id=? LIMIT 1';
$stA  = $conn->prepare($sqlA);
$stA->bind_param('i', $patient_id);
$stA->execute();
$addrRes = $stA->get_result();
$address = $addrRes->fetch_assoc();
$stA->close();

// 3) Medical History
$sqlMH = 'SELECT * FROM patient_medical_history WHERE patient_id=? LIMIT 1';
$stMH  = $conn->prepare($sqlMH);
$stMH->bind_param('i', $patient_id);
$stMH->execute();
$mRes = $stMH->get_result();
$medical_history = $mRes->fetch_assoc();
$stMH->close();

/****************************************************************************
 * (G) FETCH DEBTS, FOLLOW-UPS, APPOINTMENTS, DIAGNOSES, REPORTS, VITALS
 *     (All done in separate "fetch" includes).
 ****************************************************************************/
include 'debts_fetch.php';        // (File to be provided in a separate response)
include 'followups_fetch.php';    // (File to be provided in a separate response)
include 'appointments_fetch.php'; // (File to be provided in a separate response)
include 'diagnoses_fetch.php';    // (File to be provided in a separate response)
include 'reports_fetch.php';      // (File to be provided in a separate response)
include 'vitals_fetch.php';       // (File to be provided in a separate response)
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <title>Patient Profile (All Tabs)</title>

    <!-- Bootstrap + FontAwesome -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">

    <!-- Custom CSS -->
    <link href="<?php echo $baseURL; ?>assets/css/patientProfile.css" rel="stylesheet">
    <link href="<?php echo $baseURL; ?>assets/css/styles.css" rel="stylesheet">
</head>

<body>
    <div id="wrapper">
        <?php include ROOT_PATH . 'includes/navbar.php'; ?>
        <div id="page-content-wrapper">
            <?php include ROOT_PATH . 'includes/sidebar.php'; ?>

            <div class="container-fluid mt-4">
                <!-- Flash Messages -->
                <?php if (!empty($errorMsg)): ?>
                    <div class="alert alert-danger alert-dismissible fade show">
                        <i class="fas fa-exclamation-triangle me-1"></i>
                        <?php echo htmlspecialchars($errorMsg); ?>
                        <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                    </div>
                <?php endif; ?>
                <?php if (!empty($successMsg)): ?>
                    <div class="alert alert-success alert-dismissible fade show">
                        <i class="fas fa-check-circle me-1"></i>
                        <?php echo htmlspecialchars($successMsg); ?>
                        <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                    </div>
                <?php endif; ?>

                <!-- Page Title -->
                <div class="card mb-4 shadow-sm border-0">
                    <div class="card-body text-center bg-primary text-white rounded-3">
                        <h4 class="card-title mb-1 fw-bold">Patient Profile (All Tabs)</h4>
                        <p class="mb-0">Patient ID: <?php echo (int)$patient_id; ?></p>
                    </div>
                </div>

                <!-- Nav Tabs -->
                <ul class="nav nav-tabs custom-nav-tabs" id="patientTabs" role="tablist">
                    <li class="nav-item">
                        <button class="nav-link <?php if ($activeTab === 'overviewTab') echo 'active'; ?>"
                            id="overview-tab"
                            data-bs-toggle="tab"
                            data-bs-target="#overviewTab"
                            type="button"
                            role="tab"
                            aria-controls="overviewTab"
                            aria-selected="<?php echo ($activeTab === 'overviewTab') ? 'true' : 'false'; ?>">
                            Overview
                        </button>
                    </li>
                    <li class="nav-item">
                        <button class="nav-link <?php if ($activeTab === 'vitalsTab') echo 'active'; ?>"
                            id="vitals-tab"
                            data-bs-toggle="tab"
                            data-bs-target="#vitalsTab"
                            type="button"
                            role="tab"
                            aria-controls="vitalsTab"
                            aria-selected="<?php echo ($activeTab === 'vitalsTab') ? 'true' : 'false'; ?>">
                            Vitals
                        </button>
                    </li>
                    <li class="nav-item">
                        <button class="nav-link <?php if ($activeTab === 'debtsTab') echo 'active'; ?>"
                            id="debts-tab"
                            data-bs-toggle="tab"
                            data-bs-target="#debtsTab"
                            type="button"
                            role="tab"
                            aria-controls="debtsTab"
                            aria-selected="<?php echo ($activeTab === 'debtsTab') ? 'true' : 'false'; ?>">
                            Debts
                        </button>
                    </li>
                    <li class="nav-item">
                        <button class="nav-link <?php if ($activeTab === 'followupsTab') echo 'active'; ?>"
                            id="followups-tab"
                            data-bs-toggle="tab"
                            data-bs-target="#followupsTab"
                            type="button"
                            role="tab"
                            aria-controls="followupsTab"
                            aria-selected="<?php echo ($activeTab === 'followupsTab') ? 'true' : 'false'; ?>">
                            Follow-Ups
                        </button>
                    </li>
                    <li class="nav-item">
                        <button class="nav-link <?php if ($activeTab === 'appointmentsTab') echo 'active'; ?>"
                            id="appointments-tab"
                            data-bs-toggle="tab"
                            data-bs-target="#appointmentsTab"
                            type="button"
                            role="tab"
                            aria-controls="appointmentsTab"
                            aria-selected="<?php echo ($activeTab === 'appointmentsTab') ? 'true' : 'false'; ?>">
                            Appointments
                        </button>
                    </li>
                    <li class="nav-item">
                        <button class="nav-link <?php if ($activeTab === 'diagnosesTab') echo 'active'; ?>"
                            id="diagnoses-tab"
                            data-bs-toggle="tab"
                            data-bs-target="#diagnosesTab"
                            type="button"
                            role="tab"
                            aria-controls="diagnosesTab"
                            aria-selected="<?php echo ($activeTab === 'diagnosesTab') ? 'true' : 'false'; ?>">
                            Diagnoses
                        </button>
                    </li>
                    <li class="nav-item">
                        <button class="nav-link <?php if ($activeTab === 'reportsTab') echo 'active'; ?>"
                            id="reports-tab"
                            data-bs-toggle="tab"
                            data-bs-target="#reportsTab"
                            type="button"
                            role="tab"
                            aria-controls="reportsTab"
                            aria-selected="<?php echo ($activeTab === 'reportsTab') ? 'true' : 'false'; ?>">
                            Reports
                        </button>
                    </li>
                </ul>

                <!-- TAB CONTENTS -->
                <div class="tab-content mt-3" id="patientTabsContent">

                    <!-- (1) OVERVIEW TAB -->
                    <div class="tab-pane fade <?php if ($activeTab === 'overviewTab') echo 'show active'; ?>"
                        id="overviewTab"
                        role="tabpanel"
                        aria-labelledby="overview-tab">
                        <?php include 'overview_section.php'; ?>
                    </div>

                    <!-- (2) Vitals Tab -->
                    <div class="tab-pane fade <?php if ($activeTab === 'vitalsTab') echo 'show active'; ?>"
                        id="vitalsTab"
                        role="tabpanel"
                        aria-labelledby="vitals-tab">
                        <?php include 'vitals_section.php'; ?>
                    </div>

                    <!-- (3) Debts Tab -->
                    <div class="tab-pane fade <?php if ($activeTab === 'debtsTab') echo 'show active'; ?>"
                        id="debtsTab"
                        role="tabpanel"
                        aria-labelledby="debts-tab">
                        <?php include 'debts_section.php'; ?>
                    </div>

                    <!-- (4) Follow-Ups Tab -->
                    <div class="tab-pane fade <?php if ($activeTab === 'followupsTab') echo 'show active'; ?>"
                        id="followupsTab"
                        role="tabpanel"
                        aria-labelledby="followups-tab">
                        <?php include 'followups_section.php'; ?>
                    </div>

                    <!-- (5) Appointments Tab -->
                    <div class="tab-pane fade <?php if ($activeTab === 'appointmentsTab') echo 'show active'; ?>"
                        id="appointmentsTab"
                        role="tabpanel"
                        aria-labelledby="appointments-tab">
                        <?php include 'appointments_section.php'; ?>
                    </div>

                    <!-- (6) Diagnoses Tab -->
                    <div class="tab-pane fade <?php if ($activeTab === 'diagnosesTab') echo 'show active'; ?>"
                        id="diagnosesTab"
                        role="tabpanel"
                        aria-labelledby="diagnoses-tab">
                        <?php include 'diagnosis_section.php'; ?>
                    </div>

                    <!-- (7) Reports Tab -->
                    <div class="tab-pane fade <?php if ($activeTab === 'reportsTab') echo 'show active'; ?>"
                        id="reportsTab"
                        role="tabpanel"
                        aria-labelledby="reports-tab">
                        <?php include 'reports_section.php'; ?>
                    </div>
                </div> <!-- end tab-content -->
            </div> <!-- end container-fluid -->
        </div> <!-- end page-content-wrapper -->
    </div> <!-- end wrapper -->

    <!-- ===================== MODALS AND JS WILL BE APPENDED LATER ===================== -->

</body>

</html><?php
/**
 * appointments_section.php
 *
 * Renders the appointments table, filter form, and modals.
 * Assumes:
 *  - $appointments, $apPg, $apTotalPages are defined (from appointments_fetch.php)
 *  - $patient_id, $userRole, and $baseURL (for assets) are defined.
 */
?>
<div class="card p-3 shadow-sm border-0">
    <h5 class="mb-3">Appointments for Patient #<?php echo (int)$patient_id; ?></h5>
    
    <!-- Filter Form -->
    <form class="row g-3 mb-3" method="GET">
        <input type="hidden" name="id" value="<?php echo (int)$patient_id; ?>">
        <input type="hidden" name="appointments-tab" value="1">
        <div class="col-md-3">
            <label class="form-label">Start Date</label>
            <input type="date" name="appt_start" class="form-control" value="<?php echo htmlspecialchars($_GET['appt_start'] ?? ''); ?>">
        </div>
        <div class="col-md-3">
            <label class="form-label">End Date</label>
            <input type="date" name="appt_end" class="form-control" value="<?php echo htmlspecialchars($_GET['appt_end'] ?? ''); ?>">
        </div>
        <div class="col-md-3">
            <label class="form-label">Status</label>
            <select name="appt_status" class="form-select">
                <option value="">All</option>
                <option value="Scheduled" <?php if(($_GET['appt_status'] ?? '')==='Scheduled') echo 'selected'; ?>>Scheduled</option>
                <option value="Completed" <?php if(($_GET['appt_status'] ?? '')==='Completed') echo 'selected'; ?>>Completed</option>
                <option value="Cancelled" <?php if(($_GET['appt_status'] ?? '')==='Cancelled') echo 'selected'; ?>>Cancelled</option>
            </select>
        </div>
        <div class="col-md-3 d-flex align-items-end">
            <button type="submit" class="btn btn-primary"><i class="fas fa-filter me-1"></i>Filter</button>
        </div>
    </form>
    
    <!-- Add Appointment Button -->
    <?php if ($userRole === 'staff' || $userRole === 'admin'): ?>
        <button class="btn btn-primary mb-3" data-bs-toggle="modal" data-bs-target="#addAppointmentModal">
            <i class="fas fa-plus"></i> Add Appointment
        </button>
    <?php endif; ?>
    
    <!-- Appointments Table -->
    <?php if (!empty($appointments)): ?>
        <div class="table-responsive">
            <table class="table table-bordered align-middle text-center">
                <thead class="table-light">
                    <tr>
                        <th>ID</th>
                        <th>Date/Time</th>
                        <th>Purpose</th>
                        <th>Status</th>
                        <th>Remarks</th>
                        <th style="width:210px;">Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($appointments as $apt): 
                        $aptID    = (int)$apt['AppointmentID'];
                        $aptDate  = $apt['AppointmentDate'] ?? '';
                        $aptTime  = $apt['AppointmentTime'] ?? '';
                        $purpose  = $apt['Purpose'] ?? '';
                        $status   = $apt['Status'] ?? 'Scheduled';
                        $remarks  = $apt['Remarks'] ?? '';
                        $hasDx    = !empty($apt['has_diagnosis']);
                    ?>
                    <tr>
                        <td><?php echo $aptID; ?></td>
                        <td>
                            <?php echo htmlspecialchars($aptDate); ?><br>
                            <?php echo htmlspecialchars(substr($aptTime, 0, 5)); ?>
                        </td>
                        <td><?php echo htmlspecialchars($purpose); ?></td>
                        <td>
                            <?php if ($status === 'Completed'): ?>
                                <span class="badge bg-success">Completed</span>
                            <?php elseif ($status === 'Cancelled'): ?>
                                <span class="badge bg-danger">Cancelled</span>
                            <?php else: ?>
                                <span class="badge bg-warning text-dark">Scheduled</span>
                            <?php endif; ?>
                        </td>
                        <td style="white-space: pre-wrap;"><?php echo nl2br(htmlspecialchars($remarks)); ?></td>
                        <td>
                            <div class="d-flex flex-wrap justify-content-center gap-1">
                                <?php if ($userRole === 'staff' || $userRole === 'admin'): ?>
                                    <!-- Edit Appointment -->
                                    <button class="btn btn-warning btn-sm" data-bs-toggle="modal" data-bs-target="#editAppointmentModal"
                                        data-appointment='<?php echo json_encode([
                                            "AppointmentID"   => $aptID,
                                            "AppointmentDate" => $aptDate,
                                            "AppointmentTime" => substr($aptTime, 0, 5),
                                            "Purpose"         => $purpose,
                                            "Status"          => $status,
                                            "Remarks"         => $remarks
                                        ]); ?>'
                                        title="Edit Appointment">
                                        <i class="fas fa-edit"></i>
                                    </button>
                                <?php endif; ?>
                                
                                <!-- Diagnosis button: Add if none, or View if exists -->
                                <?php if (!$hasDx): ?>
                                    <button class="btn btn-info btn-sm" onclick="addDiagnosis(<?php echo $patient_id; ?>, <?php echo $aptID; ?>)" title="Add Diagnosis">
                                        <i class="fas fa-plus"></i>
                                    </button>
                                <?php else: ?>
                                    <a class="btn btn-info btn-sm" href="patientProfile.php?id=<?php echo (int)$patient_id; ?>&diagnoses-tab=1&appt_id=<?php echo $aptID; ?>" title="View Diagnosis">
                                        <i class="fas fa-stethoscope"></i>
                                    </a>
                                <?php endif; ?>
                                
                                <!-- View Follow-Ups -->
                                <button class="btn btn-secondary btn-sm" onclick="viewFollowUps(<?php echo $aptID; ?>)" title="View Follow-Ups">
                                    <i class="fas fa-eye"></i>
                                </button>
                                
                                <!-- Delete Appointment (admin only) -->
                                <?php if ($userRole === 'admin'): ?>
                                    <form method="POST" class="d-inline" onsubmit="return confirm('Delete appointment #<?php echo $aptID; ?>?');">
                                        <input type="hidden" name="appt_action" value="deleteAppointment">
                                        <input type="hidden" name="appointment_id" value="<?php echo $aptID; ?>">
                                        <input type="hidden" name="patient_id" value="<?php echo (int)$patient_id; ?>">
                                        <button class="btn btn-danger btn-sm" title="Delete Appointment">
                                            <i class="fas fa-trash"></i>
                                        </button>
                                    </form>
                                <?php endif; ?>
                            </div>
                        </td>
                    </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
        
        <!-- Pagination -->
        <?php if ($apTotalPages > 1): ?>
            <nav class="mt-3">
                <ul class="pagination justify-content-center">
                    <?php if ($apPg > 1): ?>
                        <li class="page-item"><a class="page-link" href="?id=<?php echo (int)$patient_id; ?>&appointments-tab=1&apg=<?php echo ($apPg - 1); ?>">« Prev</a></li>
                    <?php else: ?>
                        <li class="page-item disabled"><span class="page-link">« Prev</span></li>
                    <?php endif; ?>
                    
                    <?php for ($p = 1; $p <= $apTotalPages; $p++): ?>
                        <li class="page-item <?php if ($p === $apPg) echo 'active'; ?>">
                            <a class="page-link" href="?id=<?php echo (int)$patient_id; ?>&appointments-tab=1&apg=<?php echo $p; ?>"><?php echo $p; ?></a>
                        </li>
                    <?php endfor; ?>
                    
                    <?php if ($apPg < $apTotalPages): ?>
                        <li class="page-item"><a class="page-link" href="?id=<?php echo (int)$patient_id; ?>&appointments-tab=1&apg=<?php echo ($apPg + 1); ?>">Next »</a></li>
                    <?php else: ?>
                        <li class="page-item disabled"><span class="page-link">Next »</span></li>
                    <?php endif; ?>
                </ul>
            </nav>
        <?php endif; ?>
        
    <?php else: ?>
        <p>No appointments found for this patient.</p>
    <?php endif; ?>
</div>

<!-- Add Appointment Modal -->
<div class="modal fade" id="addAppointmentModal" tabindex="-1" aria-hidden="true">
    <div class="modal-dialog">
        <form class="modal-content" method="POST">
            <input type="hidden" name="appt_action" value="addAppointment">
            <input type="hidden" name="patient_id" value="<?php echo (int)$patient_id; ?>">
            <div class="modal-header">
                <h5 class="modal-title">Add Appointment</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <div class="mb-3">
                    <label class="form-label">Appointment Date</label>
                    <input type="date" class="form-control" name="appointment_date" value="<?php echo date('Y-m-d'); ?>" required>
                </div>
                <div class="mb-3">
                    <label class="form-label">Appointment Time</label>
                    <input type="time" class="form-control" name="appointment_time" value="09:00" required>
                </div>
                <div class="mb-3">
                    <label class="form-label">Purpose</label>
                    <input type="text" class="form-control" name="purpose" required>
                </div>
                <div class="mb-3">
                    <label class="form-label">Status</label>
                    <select class="form-select" name="status">
                        <option value="Scheduled">Scheduled</option>
                        <option value="Completed">Completed</option>
                        <option value="Cancelled">Cancelled</option>
                    </select>
                </div>
                <div class="mb-3">
                    <label class="form-label">Remarks</label>
                    <textarea class="form-control" name="remarks"></textarea>
                </div>
                <div class="form-check mb-3">
                    <input class="form-check-input" type="checkbox" name="auto_schedule_followups" id="auto_schedule_followups">
                    <label class="form-check-label" for="auto_schedule_followups">Auto Schedule Follow-Ups (1wk, 3d, 1d prior)</label>
                </div>
                <div class="form-check mb-3">
                    <input class="form-check-input" type="checkbox" name="auto_create_diagnosis" id="auto_create_diagnosis">
                    <label class="form-check-label" for="auto_create_diagnosis">Also Create Diagnosis?</label>
                </div>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                <button type="submit" class="btn btn-primary">Add Appointment</button>
            </div>
        </form>
    </div>
</div>

<!-- Edit Appointment Modal -->
<div class="modal fade" id="editAppointmentModal" tabindex="-1" aria-hidden="true">
    <div class="modal-dialog">
        <form class="modal-content" method="POST">
            <input type="hidden" name="appt_action" value="editAppointment">
            <input type="hidden" name="appointment_id" id="appointment_id_edit">
            <input type="hidden" name="patient_id" value="<?php echo (int)$patient_id; ?>">
            <div class="modal-header">
                <h5 class="modal-title">Edit Appointment</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <div class="mb-3">
                    <label class="form-label">Appointment Date</label>
                    <input type="date" class="form-control" name="appointment_date" id="appointment_date_edit" required>
                </div>
                <div class="mb-3">
                    <label class="form-label">Appointment Time</label>
                    <input type="time" class="form-control" name="appointment_time" id="appointment_time_edit" required>
                </div>
                <div class="mb-3">
                    <label class="form-label">Purpose</label>
                    <input type="text" class="form-control" name="purpose" id="purpose_edit" required>
                </div>
                <div class="mb-3">
                    <label class="form-label">Status</label>
                    <select class="form-select" name="status" id="status_edit" required>
                        <option value="Scheduled">Scheduled</option>
                        <option value="Completed">Completed</option>
                        <option value="Cancelled">Cancelled</option>
                    </select>
                </div>
                <div class="mb-3">
                    <label class="form-label">Remarks</label>
                    <textarea class="form-control" name="remarks" id="remarks_edit_appt"></textarea>
                </div>
                <div class="form-check mb-3">
                    <input type="checkbox" class="form-check-input" name="auto_update_followups" id="auto_update_followups">
                    <label class="form-check-label" for="auto_update_followups">Auto-Update Follow-Ups (Remove &amp; Recreate)</label>
                </div>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                <button type="submit" class="btn btn-warning">Update Appointment</button>
            </div>
        </form>
    </div>
</div>

<script>
// Populate Edit Appointment Modal with JSON data
document.addEventListener("DOMContentLoaded", function() {
    const editModal = document.getElementById("editAppointmentModal");
    editModal.addEventListener("show.bs.modal", function(event) {
        const button = event.relatedTarget;
        if (!button) return;
        const aptData = JSON.parse(button.getAttribute("data-appointment") || "{}");
        document.getElementById("appointment_id_edit").value = aptData.AppointmentID || "";
        document.getElementById("appointment_date_edit").value = aptData.AppointmentDate || "";
        document.getElementById("appointment_time_edit").value = aptData.AppointmentTime || "09:00";
        document.getElementById("purpose_edit").value = aptData.Purpose || "";
        document.getElementById("status_edit").value = aptData.Status || "Scheduled";
        document.getElementById("remarks_edit_appt").value = aptData.Remarks || "";
    });
});

// Dummy functions for additional actions (implement as needed)
function addDiagnosis(patientID, appointmentID) {
    // Use AJAX here if desired.
    alert("Add Diagnosis for patient " + patientID + ", appointment " + appointmentID);
}
function viewFollowUps(appointmentID) {
    // Use AJAX here if desired.
    alert("View follow-ups for appointment " + appointmentID);
}
</script>
